(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   1178675,      38057]*)
(*NotebookOutlinePosition[   1195347,      38618]*)
(*  CellTagsIndexPosition[   1191610,      38482]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Implementation der Algorithmen", "Section",
  PageWidth->PaperWidth,
  TextAlignment->Center,
  TextJustification->1,
  CellTags->"c:1"],

Cell["", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell["5.1. \[CapitalUDoubleDot]berblick", "Subsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:2"],

Cell["\<\
Alle Herleitungen, die  in  dieser  Arbeit  gemacht  wurden,  erfordern  mit  \
steigender  Ordnung in z und e einen exponentiell wachsenden Rechenaufwand. \
Der Einsatz von Computeralgebrasystemen ist gefragt.  \
Grunds\[ADoubleDot]tzlich eignet sich daf\[UDoubleDot]r jede symbolische \
Programmiersprache, die listenorientiert arbeitet. Die Idee der \
objektorientierten und symbolischen Programmiersprache ist keineswegs etwas \
Neues, so hat die Mutter aller Programmiersprachen LISP bereits alle F\
\[ADoubleDot]higkeiten, die hierf\[UDoubleDot]r ausreichen: Listen, \
Funktionen und Mustererkennung. Jede algebraische Umformung und mathematische \
Funktion kann dann im Prinzip als eine Transformation der Struktur einer \
Liste auf eine andere implementiert werden. Viele grundlegende Algorithmen, \
wie das Differenzieren und Integrieren eines Ausdrucks, stellt bereits das \
Package REDUCE bereit. Darauf aufbauend kann in direkter Weise ein \
Algorithmus implementiert werden, der Ausdr\[UDoubleDot]cke in Taylorreihen \
entwickelt. Ebenso sollte die Fertigkeit Gleichungssysteme zu \
l\[ODoubleDot]sen vorhanden sein, sie wird in den Herleitungen unz\
\[ADoubleDot]hlige Male dazu verwendet, unbestimmte Gr\[ODoubleDot]\[SZ]en, \
die aus den Ans\[ADoubleDot]tzen her r\[UDoubleDot]hren, zu bestimmen. Es \
werden nur grundlegende mathematische Funktionen angewandt, wobei oft die \
Beziehungen der trigonometrischen \[CapitalADoubleDot]quivalenzen verwendet \
werden. Um die auftretenden Differentialgleichungen zu l\[ODoubleDot]sen, \
wurden explizite Algorithmen entwickelt. Es ist daher nicht notwendig, \
vorgefertigte Integratoren hierf\[UDoubleDot]r zu verwenden. Alle \
Berechnungen mit Zahlen werden durch exakte Ganzzahlarithmetik durchgef\
\[UDoubleDot]hrt. Dies ist im Prinzip nicht notwendig, erm\[ODoubleDot]glicht \
aber eine bessere Kontrolle des numerischen Fehlers, der durch Division und \
Wurzelziehen von sehr kleinen und gro\[SZ]en Zahlen zu Stande kommt.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Der Markt an Software, die symbolische Programmierung implementiert, ist \
gro\[SZ]: So Derive (Texas Instruments), Waterloo Maple (Maple Soft) oder \
Reduce (Lisp). Die f\[UDoubleDot]r diese Arbeit verwendete Software ist ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " von Wolfram Research. Es handelt sich hierbei um ein sehr vielseitiges \
Softwareprodukt, das dennoch einheitlich in Form und Sprache bleibt und \
grundlegenden Prinzipien folgt. F\[UDoubleDot]r jedes mathematische, \
physikalische oder technische Problem findet sich, wenn nicht in den \
tausenden Standardfunktionen, so in einem der vielen Packages, ein oder \
mehrere L\[ODoubleDot]sungsvorschl\[ADoubleDot]ge. Ist kein entsprechender \
Algorithmus f\[UDoubleDot]r die L\[ODoubleDot]sung eines Problems vorhanden, \
so kann dieser in sehr direkter Art implementiert werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Das Problem, das bei einer solch gro\[SZ]en Allzwecksoftware unweigerlich \
auftritt, ist, dass man die \[CapitalUDoubleDot]bersicht \[UDoubleDot]ber die \
Ergebnisse leicht verlieren kann. Vor allem dann, wenn Algorithmen verwendet \
werden, die man nicht kennt und deren Ergebnisse nicht nachvollziehbar sind. \
So ist es heutzutage kein Problem mehr, auf einem GHz Prozessor mit \
entsprechender Software Integrale oder Differentialgleichungen von fast \
beliebiger Gestalt zu l\[ODoubleDot]sen. Ein anderes Problem schleicht sich \
ein: Was soll ich mit einem 10 Seiten - Ausdruck anfangen, der unleserlich, \
unstrukturiert und oft nicht reproduzierbar ist? Um dies zu verhindern ist es \
notwendig, die Ergebnisse auf ihre Nutzbarkeit f\[UDoubleDot]r weitere \
\[CapitalUDoubleDot]berlegungen immer wieder zu \[UDoubleDot]berpr\
\[UDoubleDot]fen. Die Bew\[ADoubleDot]ltigung eines Problems verlagert sich \
ein wenig mehr auf die Seite, Ergebnisse zu pr\[UDoubleDot]fen  anstatt sie \
zu erzeugen. Dies geschieht ebenfalls aufgrund der Menge an Information, die \
verarbeitet werden soll, oft automatisiert. Es muss daher nicht mehr die \
Aufgabe sein, alle Rechnungen per Hand durchzuf\[UDoubleDot]hren, vielmehr \
ihren Verlauf zu organisieren und zu automatisieren. So wurden die \
Herleitungen dieser Arbeit nach wie vor f\[UDoubleDot]r kleine Ordnungen mit \
der Hand durchgef\[UDoubleDot]hrt, um den dahinter stehenden Algorithmus zu \
begreifen. Im n\[ADoubleDot]chsten Schritt wurde dieser dann in eine \
geeignete Form gebracht, um ihn in die Programmiersprache zu  \
\[UDoubleDot]bersetzen. Hierbei wurde auf zwei Merkmale gro\[SZ]es Augenmerk \
gelegt: Geschwindigkeit aber auch Lesbarkeit. Das zweite auf Kosten des \
ersteren vollkommen aufzugeben, w\[ADoubleDot]re nicht sinnvoll gewesen. Es \
handelt sich daher nicht um die schnellsten Implementationen, jedoch sicher \
um lesbare und f\[UDoubleDot]r den Leser reproduzierbare.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.2. Beschreibung der Algorithmen - Lineare Analyse", "Subsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:3"],

Cell["\<\
Hier werden die Funktionen, die anhand der Algorithmen aus dem 2. Kapitel \
entstanden sind, definiert, kurz beschrieben und auf ihre Verwendbarkeit \
analysiert.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.1. PrimariesDistance",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:4"],

Cell[TextData[{
  "PrimariesDistance[n] entwickelt die L\[ODoubleDot]sung des Keplerproblems \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              FormBox[\(\(\ \)\(r\^\[DoublePrime]\)\(\ \)\),
                "TraditionalForm"], "=", 
              " ", \(\(1 - e\^2\)\/\(16  r\^3\)\)}],
            "TraditionalForm"], "-", \(1\/\(8  r\^2\)\)}], 
        TraditionalForm]]],
  " mit ",
  Cell[BoxData[
      \(TraditionalForm\`r(t)\  = \ \(1\/2\) \((1 - e\ \(cos(u(t))\))\)\)]],
  " gegeben in seiner transzendenten Form ",
  Cell[BoxData[
      \(TraditionalForm\`u(t)\  = \ t + e\ \(sin(u(t))\)\)]],
  " nach dem Parameter e bis zur n-ten Ordnung."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:5"],

Cell["\<\
Da es nicht m\[ODoubleDot]glich ist, die Keplergleichung u(t) in \
geschlossener Form anzugeben, muss diese approximiert werden. Die einfachste \
Art, diese numerisch zu l\[ODoubleDot]sen, ist durch einfache Iteration. Um \
einen analytischen Ausdruck zu bekommen, wird diese n-fach iteriert und dann \
nach dem Parameter e bis zur Ordnung n entwickelt. Dies geschieht durch \
einfache Taylorreihenentwicklung. Das Problem reduziert sich im Wesentlichen \
darauf, die i-ten Ableitungen der iterierten Form zu bilden, sowie die \
hierbei auftretenden trigonometrischen Ausdr\[UDoubleDot]cke wiederholt durch \
Reduktion bez\[UDoubleDot]glich ihrer Argumente zu vereinfachen.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:6"],

Cell[TextData[{
  "Voraussetzung :",
  StyleBox[" KeplerSolution",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(PrimariesDistance[
          n_Integer] := \(Module[{x}, $Derivation = \[IndentingNewLine]{x = 
                  Normal[KeplerSolution[n]], \[IndentingNewLine]x = 
                  Series[x, {e, 0, n}], \[IndentingNewLine]x = 
                  TrigReduce[x], \[IndentingNewLine]PrimariesDistance[
                    n] = \(1 + x\)\/2}]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:7"],

Cell["\<\
Der Algorithmus arbeitet gut und sehr schnell bei kleinen Ordnungen und \
liefert seine Ergebnisse in einer sehr kompakten Form.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.00300308 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .16487 -15.125 -5.8125 ]
[-0.0125 .16487 0 5.8125 ]
[-0.0125 .31502 -20.6875 -5.8125 ]
[-0.0125 .31502 0 5.8125 ]
[-0.0125 .46518 -20.6875 -5.8125 ]
[-0.0125 .46518 0 5.8125 ]
[-0.0125 .61533 -20.6875 -5.8125 ]
[-0.0125 .61533 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32.3125 -7.5625 ]
[-0.01875 .30902 -20.6875 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -49.2813 0 ]
[.5 .63053 49.2813 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .16487 m
.00625 .16487 L
s
gsave
-0.0125 .16487 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .31502 m
.00625 .31502 L
s
gsave
-0.0125 .31502 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .46518 m
.00625 .46518 L
s
gsave
-0.0125 .46518 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .61533 m
.00625 .61533 L
s
gsave
-0.0125 .61533 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04475 m
.00375 .04475 L
s
0 .07478 m
.00375 .07478 L
s
0 .10481 m
.00375 .10481 L
s
0 .13484 m
.00375 .13484 L
s
0 .1949 m
.00375 .1949 L
s
0 .22493 m
.00375 .22493 L
s
0 .25496 m
.00375 .25496 L
s
0 .28499 m
.00375 .28499 L
s
0 .34505 m
.00375 .34505 L
s
0 .37508 m
.00375 .37508 L
s
0 .40512 m
.00375 .40512 L
s
0 .43515 m
.00375 .43515 L
s
0 .49521 m
.00375 .49521 L
s
0 .52524 m
.00375 .52524 L
s
0 .55527 m
.00375 .55527 L
s
0 .5853 m
.00375 .5853 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95.0625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -110.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PrimariesDistance) show
157.563 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .02072 L
.06923 .02072 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .02072 L
.06923 .02072 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .02372 L
.14615 .02372 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .02372 L
.14615 .02372 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .02673 L
.22308 .02673 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .02673 L
.22308 .02673 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .02973 L
.3 .02973 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .02973 L
.3 .02973 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .03273 L
.37692 .03273 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .03273 L
.37692 .03273 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .03574 L
.45385 .03574 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .03574 L
.45385 .03574 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .03874 L
.53077 .03874 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .03874 L
.53077 .03874 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .04174 L
.60769 .04174 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .04174 L
.60769 .04174 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .04475 L
.68462 .04475 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .04475 L
.68462 .04475 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .04775 L
.76154 .04775 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .04775 L
.76154 .04775 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .05075 L
.83846 .05075 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .05075 L
.83846 .05075 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .05376 L
.91538 .05376 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .05376 L
.91538 .05376 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .05676 L
.99231 .05676 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .05676 L
.99231 .05676 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .02072 m
.00769 .02372 L
.06923 .02372 L
.06923 .02072 L
F
0 g
.00769 .02072 m
.00769 .02372 L
.06923 .02372 L
.06923 .02072 L
.00769 .02072 L
s
.8 1 0 r
.08462 .02372 m
.08462 .02973 L
.14615 .02973 L
.14615 .02372 L
F
0 g
.08462 .02372 m
.08462 .02973 L
.14615 .02973 L
.14615 .02372 L
.08462 .02372 L
s
.8 1 0 r
.16154 .02673 m
.16154 .03874 L
.22308 .03874 L
.22308 .02673 L
F
0 g
.16154 .02673 m
.16154 .03874 L
.22308 .03874 L
.22308 .02673 L
.16154 .02673 L
s
.8 1 0 r
.23846 .02973 m
.23846 .04775 L
.3 .04775 L
.3 .02973 L
F
0 g
.23846 .02973 m
.23846 .04775 L
.3 .04775 L
.3 .02973 L
.23846 .02973 L
s
.8 1 0 r
.31538 .03273 m
.31538 .05976 L
.37692 .05976 L
.37692 .03273 L
F
0 g
.31538 .03273 m
.31538 .05976 L
.37692 .05976 L
.37692 .03273 L
.31538 .03273 L
s
.8 1 0 r
.39231 .03574 m
.39231 .07177 L
.45385 .07177 L
.45385 .03574 L
F
0 g
.39231 .03574 m
.39231 .07177 L
.45385 .07177 L
.45385 .03574 L
.39231 .03574 L
s
.8 1 0 r
.46923 .03874 m
.46923 .08679 L
.53077 .08679 L
.53077 .03874 L
F
0 g
.46923 .03874 m
.46923 .08679 L
.53077 .08679 L
.53077 .03874 L
.46923 .03874 L
s
.8 1 0 r
.54615 .04174 m
.54615 .1018 L
.60769 .1018 L
.60769 .04174 L
F
0 g
.54615 .04174 m
.54615 .1018 L
.60769 .1018 L
.60769 .04174 L
.54615 .04174 L
s
.8 1 0 r
.62308 .04475 m
.62308 .11982 L
.68462 .11982 L
.68462 .04475 L
F
0 g
.62308 .04475 m
.62308 .11982 L
.68462 .11982 L
.68462 .04475 L
.62308 .04475 L
s
.8 1 0 r
.7 .04775 m
.7 .13784 L
.76154 .13784 L
.76154 .04775 L
F
0 g
.7 .04775 m
.7 .13784 L
.76154 .13784 L
.76154 .04775 L
.7 .04775 L
s
.8 1 0 r
.77692 .05075 m
.77692 .15886 L
.83846 .15886 L
.83846 .05075 L
F
0 g
.77692 .05075 m
.77692 .15886 L
.83846 .15886 L
.83846 .05075 L
.77692 .05075 L
s
.8 1 0 r
.85385 .05376 m
.85385 .17988 L
.91538 .17988 L
.91538 .05376 L
F
0 g
.85385 .05376 m
.85385 .17988 L
.91538 .17988 L
.91538 .05376 L
.85385 .05376 L
s
.8 1 0 r
.93077 .05676 m
.93077 .20391 L
.99231 .20391 L
.99231 .05676 L
F
0 g
.93077 .05676 m
.93077 .20391 L
.99231 .20391 L
.99231 .05676 L
.93077 .05676 L
s
0 1 .4 r
.00769 .02372 m
.00769 .02372 L
.06923 .02372 L
.06923 .02372 L
F
0 g
.00769 .02372 m
.00769 .02372 L
.06923 .02372 L
.06923 .02372 L
.00769 .02372 L
s
0 1 .4 r
.08462 .02973 m
.08462 .03574 L
.14615 .03574 L
.14615 .02973 L
F
0 g
.08462 .02973 m
.08462 .03574 L
.14615 .03574 L
.14615 .02973 L
.08462 .02973 L
s
0 1 .4 r
.16154 .03874 m
.16154 .04775 L
.22308 .04775 L
.22308 .03874 L
F
0 g
.16154 .03874 m
.16154 .04775 L
.22308 .04775 L
.22308 .03874 L
.16154 .03874 L
s
0 1 .4 r
.23846 .04775 m
.23846 .06276 L
.3 .06276 L
.3 .04775 L
F
0 g
.23846 .04775 m
.23846 .06276 L
.3 .06276 L
.3 .04775 L
.23846 .04775 L
s
0 1 .4 r
.31538 .05976 m
.31538 .08078 L
.37692 .08078 L
.37692 .05976 L
F
0 g
.31538 .05976 m
.31538 .08078 L
.37692 .08078 L
.37692 .05976 L
.31538 .05976 L
s
0 1 .4 r
.39231 .07177 m
.39231 .0988 L
.45385 .0988 L
.45385 .07177 L
F
0 g
.39231 .07177 m
.39231 .0988 L
.45385 .0988 L
.45385 .07177 L
.39231 .07177 L
s
0 1 .4 r
.46923 .08679 m
.46923 .11682 L
.53077 .11682 L
.53077 .08679 L
F
0 g
.46923 .08679 m
.46923 .11682 L
.53077 .11682 L
.53077 .08679 L
.46923 .08679 L
s
0 1 .4 r
.54615 .1018 m
.54615 .13784 L
.60769 .13784 L
.60769 .1018 L
F
0 g
.54615 .1018 m
.54615 .13784 L
.60769 .13784 L
.60769 .1018 L
.54615 .1018 L
s
0 1 .4 r
.62308 .11982 m
.62308 .15886 L
.68462 .15886 L
.68462 .11982 L
F
0 g
.62308 .11982 m
.62308 .15886 L
.68462 .15886 L
.68462 .11982 L
.62308 .11982 L
s
0 1 .4 r
.7 .13784 m
.7 .18289 L
.76154 .18289 L
.76154 .13784 L
F
0 g
.7 .13784 m
.7 .18289 L
.76154 .18289 L
.76154 .13784 L
.7 .13784 L
s
0 1 .4 r
.77692 .15886 m
.77692 .20691 L
.83846 .20691 L
.83846 .15886 L
F
0 g
.77692 .15886 m
.77692 .20691 L
.83846 .20691 L
.83846 .15886 L
.77692 .15886 L
s
0 1 .4 r
.85385 .17988 m
.85385 .23394 L
.91538 .23394 L
.91538 .17988 L
F
0 g
.85385 .17988 m
.85385 .23394 L
.91538 .23394 L
.91538 .17988 L
.85385 .17988 L
s
0 1 .4 r
.93077 .20391 m
.93077 .26097 L
.99231 .26097 L
.99231 .20391 L
F
0 g
.93077 .20391 m
.93077 .26097 L
.99231 .26097 L
.99231 .20391 L
.93077 .20391 L
s
0 .4 1 r
.00769 .02372 m
.00769 .02372 L
.06923 .02372 L
.06923 .02372 L
F
0 g
.00769 .02372 m
.00769 .02372 L
.06923 .02372 L
.06923 .02372 L
.00769 .02372 L
s
0 .4 1 r
.08462 .03574 m
.08462 .03874 L
.14615 .03874 L
.14615 .03574 L
F
0 g
.08462 .03574 m
.08462 .03874 L
.14615 .03874 L
.14615 .03574 L
.08462 .03574 L
s
0 .4 1 r
.16154 .04775 m
.16154 .05376 L
.22308 .05376 L
.22308 .04775 L
F
0 g
.16154 .04775 m
.16154 .05376 L
.22308 .05376 L
.22308 .04775 L
.16154 .04775 L
s
0 .4 1 r
.23846 .06276 m
.23846 .07177 L
.3 .07177 L
.3 .06276 L
F
0 g
.23846 .06276 m
.23846 .07177 L
.3 .07177 L
.3 .06276 L
.23846 .06276 L
s
0 .4 1 r
.31538 .08078 m
.31538 .0928 L
.37692 .0928 L
.37692 .08078 L
F
0 g
.31538 .08078 m
.31538 .0928 L
.37692 .0928 L
.37692 .08078 L
.31538 .08078 L
s
0 .4 1 r
.39231 .0988 m
.39231 .11382 L
.45385 .11382 L
.45385 .0988 L
F
0 g
.39231 .0988 m
.39231 .11382 L
.45385 .11382 L
.45385 .0988 L
.39231 .0988 L
s
0 .4 1 r
.46923 .11682 m
.46923 .13484 L
.53077 .13484 L
.53077 .11682 L
F
0 g
.46923 .11682 m
.46923 .13484 L
.53077 .13484 L
.53077 .11682 L
.46923 .11682 L
s
0 .4 1 r
.54615 .13784 m
.54615 .15886 L
.60769 .15886 L
.60769 .13784 L
F
0 g
.54615 .13784 m
.54615 .15886 L
.60769 .15886 L
.60769 .13784 L
.54615 .13784 L
s
0 .4 1 r
.62308 .15886 m
.62308 .18289 L
.68462 .18289 L
.68462 .15886 L
F
0 g
.62308 .15886 m
.62308 .18289 L
.68462 .18289 L
.68462 .15886 L
.62308 .15886 L
s
0 .4 1 r
.7 .18289 m
.7 .20992 L
.76154 .20992 L
.76154 .18289 L
F
0 g
.7 .18289 m
.7 .20992 L
.76154 .20992 L
.76154 .18289 L
.7 .18289 L
s
0 .4 1 r
.77692 .20691 m
.77692 .23694 L
.83846 .23694 L
.83846 .20691 L
F
0 g
.77692 .20691 m
.77692 .23694 L
.83846 .23694 L
.83846 .20691 L
.77692 .20691 L
s
0 .4 1 r
.85385 .23394 m
.85385 .26697 L
.91538 .26697 L
.91538 .23394 L
F
0 g
.85385 .23394 m
.85385 .26697 L
.91538 .26697 L
.91538 .23394 L
.85385 .23394 L
s
0 .4 1 r
.93077 .26097 m
.93077 .297 L
.99231 .297 L
.99231 .26097 L
F
0 g
.93077 .26097 m
.93077 .297 L
.99231 .297 L
.99231 .26097 L
.93077 .26097 L
s
.8 0 1 r
.00769 .02372 m
.00769 .02673 L
.06923 .02673 L
.06923 .02372 L
F
0 g
.00769 .02372 m
.00769 .02673 L
.06923 .02673 L
.06923 .02372 L
.00769 .02372 L
s
.8 0 1 r
.08462 .03874 m
.08462 .05376 L
.14615 .05376 L
.14615 .03874 L
F
0 g
.08462 .03874 m
.08462 .05376 L
.14615 .05376 L
.14615 .03874 L
.08462 .03874 L
s
.8 0 1 r
.16154 .05376 m
.16154 .07778 L
.22308 .07778 L
.22308 .05376 L
F
0 g
.16154 .05376 m
.16154 .07778 L
.22308 .07778 L
.22308 .05376 L
.16154 .05376 L
s
.8 0 1 r
.23846 .07177 m
.23846 .10781 L
.3 .10781 L
.3 .07177 L
F
0 g
.23846 .07177 m
.23846 .10781 L
.3 .10781 L
.3 .07177 L
.23846 .07177 L
s
.8 0 1 r
.31538 .0928 m
.31538 .14685 L
.37692 .14685 L
.37692 .0928 L
F
0 g
.31538 .0928 m
.31538 .14685 L
.37692 .14685 L
.37692 .0928 L
.31538 .0928 L
s
.8 0 1 r
.39231 .11382 m
.39231 .18889 L
.45385 .18889 L
.45385 .11382 L
F
0 g
.39231 .11382 m
.39231 .18889 L
.45385 .18889 L
.45385 .11382 L
.39231 .11382 L
s
.8 0 1 r
.46923 .13484 m
.46923 .23394 L
.53077 .23394 L
.53077 .13484 L
F
0 g
.46923 .13484 m
.46923 .23394 L
.53077 .23394 L
.53077 .13484 L
.46923 .13484 L
s
.8 0 1 r
.54615 .15886 m
.54615 .28499 L
.60769 .28499 L
.60769 .15886 L
F
0 g
.54615 .15886 m
.54615 .28499 L
.60769 .28499 L
.60769 .15886 L
.54615 .15886 L
s
.8 0 1 r
.62308 .18289 m
.62308 .33905 L
.68462 .33905 L
.68462 .18289 L
F
0 g
.62308 .18289 m
.62308 .33905 L
.68462 .33905 L
.68462 .18289 L
.62308 .18289 L
s
.8 0 1 r
.7 .20992 m
.7 .39911 L
.76154 .39911 L
.76154 .20992 L
F
0 g
.7 .20992 m
.7 .39911 L
.76154 .39911 L
.76154 .20992 L
.7 .20992 L
s
.8 0 1 r
.77692 .23694 m
.77692 .46217 L
.83846 .46217 L
.83846 .23694 L
F
0 g
.77692 .23694 m
.77692 .46217 L
.83846 .46217 L
.83846 .23694 L
.77692 .23694 L
s
.8 0 1 r
.85385 .26697 m
.85385 .53124 L
.91538 .53124 L
.91538 .26697 L
F
0 g
.85385 .26697 m
.85385 .53124 L
.91538 .53124 L
.91538 .26697 L
.85385 .26697 L
s
.8 0 1 r
.93077 .297 m
.93077 .60332 L
.99231 .60332 L
.99231 .297 L
F
0 g
.93077 .297 m
.93077 .60332 L
.99231 .60332 L
.99231 .297 L
.93077 .297 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
dWoo00<007ooOol01Woo00<007ooOol0Z7oo003AOol00`00Oomoo`08Ool00`00Oomoo`2WOol00<ao
o`80009oo`03001oogoo00Aoo`8000Aoo`03001oogoo0:Ioo`00bgoo00H007ooOol007oo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`2VOol00<]oo`06001oogoo001oo`001Goo0`0017oo00<007ooOol0
YWoo003;Ool01P00Oomoo`00Ool000Eoo`<000Aoo`03001oogoo0:Ioo`00bgoo00@007ooOol0009o
o`03001oogoo00Qoo`03001oogoo0:Moo`00c7oo0P0017oo00<007ooOol01Woo00<007ooOol0Z7oo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00Agoo1@004goo0`0057oo0P00
5goo0`0057oo00<007ooOol04goo0P005Woo00<007ooOol057oo00<007ooOol04goo0P004Woo1@00
0Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000ioo`D00003Ool0000002Aoo`00BGoo00<0
07ooOol04goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol04Woo00<007oo000057oo00<0
07oo00005Goo00<007ooOol04goo00<007oo00005Woo00<007ooOol04Goo00L007ooOomoo`00Ool0
000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<0
07ooOol08Goo0019Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol4000EOol00`00
Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00Ool0000EOol2000COol01`00Oomoogoo
001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo029oo`00BGoo00<007ooOol057oo00<007ooOol05Goo00<007ooOol0
4goo00<007oo000057oo0P005Goo0P005goo00<007ooOol04goo00<007ooOol04goo00<007oo0000
4goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0QOol004Uoo`03001oogoo01=oo`03001oo`00
01Aoo`03001oo`0001Ioo`8001Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`03001oo`0001=oo`07001oogooOol007oo000047oo00<007ooOol00Woo00<007oo
Ool03goo00L007ooOomoo`00Ool0000@Ool01`00Oomoogoo001oo`0002=oo`00B7oo0P005Woo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol04Woo0`005Goo0P0057oo0`005Goo00<007ooOol0
57oo0P004Woo0P0017oo00<007ooOol03Woo0P000goo0P0047oo0P0017oo00<007ooOol03Woo0P00
17oo00<007ooOol08Woo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00?Woo
o`00;`006Woo000nOol00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`08
Ool00`00Oomoo`0HOol003ioo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo00Qoo`03001oogoo01Qoo`00=Goo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
67oo000dOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0HOol003Aoo`03001oo`00
00Moool002l001Yoo`00=7oo00<007oo00001goo00@007ooOol0015l0003001oogoo009oo`03001l
07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001o
ogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol0
0Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O000
47`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O000
0`00Ool0000JOol003Aoo`03001oo`0000Moo`03001oogoo01<000Aooa<000Aoo`03001l07`000ml
0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<0
07ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<0
07`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0
000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Ool0000JOol003Eoo`03001oogoo00Ioo`03
001oogoo01<000Aoo`03001Wh6OP00mWh003001oogoo009ooa<000Aoo`03001l07`0011l0005001o
ogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol0
0Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O000
47`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O000
0`00Ool0000JOol003ioo`03001oogoo01Mooa<000Aoo`03001Wh6OP00mWh003001oogoo009ooa@0
00=oo`03001l07`0011l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oo`0001Yoo`00?Woo00<007ooOol05goo00<000?/0n`03`?/00<007ooOol00Woo00<0
06OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00@007ooOomooa@000=oo`03001l07`0011l
0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009o
o`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomo
ogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo00006Woo000nOol00`00Oomoo`0G
OolC0004Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP
00@007ooOomooa@000Aoo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00
Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo00006Woo000nOol00`00Oomo
o`0GOolC0004OolC0004Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019W
h003001oogoo009ooa<000Aoo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001o
ogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol0
0Woo00<007`0O0003g`000<007oo00006Woo000nOol00`00Oomoo`0GOol00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP
00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009ooa<000Aoo`03
001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo
00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo00006Woo000nOol2000HOol00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00@In001@00Oomo
ogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009ooa<000Aoo`03001l07`0011l0005001oogooOol0000BO000
1@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo00006Woo000nOol00`00
Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomoo`02OolC0004OolD0003Ool00`00In1Wh00@In001@00
Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo50000goo00<007`0O00047`000D007oo
Oomoo`00019l0003001oogoo009oo`03001l07`000ml0003001oo`0001Yoo`00?Woo00<007ooOol0
5goo4`0017oo4`0017oo00<000?/0n`040?/00D007ooOomoo`00019Wh005001oogooOol0000BIn00
0`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001000Oomoogoo50000goo500017oo00<0
07`0O0003g`000<007oo00006Woo000nOol00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03
001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003
001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo
Ool00Woo4`0000=oo`00Ool06Goo000nOol00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000n`3k00@0n`01000Oomoogoo50000goo00<006OPIn0046OP00<007ooOol00Woo00<006OP
In003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007oo
Ool00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03001o
ogoo009ooa@000=oo`030003k0?/0103k005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomo
o`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009o
o`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0;Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?
In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003
001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0;Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000BIn00
0`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomo
o`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0;Woo
00<006@OI1l03f@O00<007ooOol00Woo50000goo00<000?/0n`040?/00@007ooOomooa@000Aoo`03
001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003
001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo
Ool00Woo00<006OPIn003fOP00<007oo00006Woo000nOol2000_Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mW
h003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<0
07ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`0^OolC0004Ool00`00
I1mT7`0@I1l01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oogoo009oo`03001Wh6OP
00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo
009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo
00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01000Oomo
ogoo50000goo00<000?/0n`040?/00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<0
06OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D0
07ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0
000JOol003ioo`03001oogoo04Eoo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo
00004P?/00<007ooOol00Woo4`0017oo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00
Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo04Eoo`03001T7f@O011T
7`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<0
07ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<0
06OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1W
h00?In000`00Ool0000JOol003ioo`03001oogoo04Eoo`03001T7f@O011T7`04001oogooOolD0003
Ool00`000n`3k00@0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?
In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo
00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00
?Woo00<007ooOol0AGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0n`0
0`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomo
o`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0AGoo
00<006@OI1l046@O00D007ooOomoo`00019T7`04001oogooOolD0004Ool00`000n`3k00?0n`00`00
Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00
In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP
00mWh003001oo`0001Yoo`00?Woo00<007ooOol0AGoo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02OolC0004Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomo
o`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo0P00AWoo00<006@O
I1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?
0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02
Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03
001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0AGoo50000goo00<006@OI1l046@O00D0
07ooOomoo`000181W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3
k003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0
000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000n
Ool00`00Oomoo`1LOol00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<000?/
0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<006OPIn003fOP00<007oo
Ool00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo05aoo`03001T7f@O011T7`04001o
ogooOolD0004OolC0004Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomo
o`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009o
o`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0G7oo00<006@OI1l046@O00D007oo
Oomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003
001oogoo009ooa<000Aoo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`1LOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
00?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<006OPIn0046OP00D0
07ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0
000JOol003ioo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?
0n`00`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003
001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0G7oo00<006@OI1l0
46@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003
k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`03001Wh6OP011Wh005001o
ogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo0000
6Woo000nOol00`00Oomoo`1LOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/
00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00
Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`8005eoo`03001T7f@O011T7`05001o
ogooOol0000BI1l00`00Oomoo`02OolC0004Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3
k00?0n`00`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019W
h003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0G7oo00<006@O
I1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa<0
00Aoo`030003k0?/00l3k003001oogoo009ooa@000=oo`03001Wh6OP011Wh005001oogooOol0000B
In000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo05aoo`03001T
7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`0
1@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001o
o`0001Yoo`00?Woo00<007ooOol0G7oo50000goo00<006@OI1l046@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007oo
Ool00Woo00<000?/0n`040?/00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo07=oo`03001T7f@O011T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003
k0?/00l3k003001oogoo009oo`030003k0?/0103k005001oogooOol0000BIn001@00Oomoogoo0000
4VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`1cOol00`00
I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP
00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<0
07ooOol0Lgoo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D0
07ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0
000JOol002moo`03001oogoo009oo`03001oogoo00Moo`03001oogoo07=oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa<000Aooa<000Aoo`030003k0?/0103k004
001oogooOolD0003Ool00`00In1Wh00@In000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000J
Ool002ioo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo07=oo`03001T7f@O011T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo0000
4VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000`Ool01P00Oomoo`00Ool000Qo
o`<007=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001o
ogooOol0000B0n`01@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo0000
6Woo000^Ool20003Ool00`00Ool00008Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00019Wh003
001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00;Woo00<007ooOol00Woo00<007oo0000
27oo00<007ooOol0Lgoo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`0
40?/00D007ooOomoo`000183k005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In00
0`00Ool0000JOol002ioo`<000=oo`03001oogoo00Moo`03001oogoo07=oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo
00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`1cOol0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo0000
4P?/00@007ooOomooa@000Aoo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0Lgoo
00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo4`0017oo50000goo00<000?/0n`040?/00D007ooOomoo`000183k003001oogoo
009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0Lgoo00<006@OI1l046@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0
000B0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo07=ooa@0
00Aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/
00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`2;Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oogoo009o
o`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo0P00S7oo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O
00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00
Ool0000JOol003ioo`03001oogoo08]oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000n
Ool00`00Oomoo`2;Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007oo
Oomoo`000183k003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0
Rgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000B0n`0
0`00Oomoo`02OolC00000goo001oo`0IOol003ioo`03001oogoo08]oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa@000=o
oa@000=oo`030003k0?/0103k003001oogoo009oo`030003k0?/00l3k003001oo`0001Yoo`00?Woo
00<007ooOol0Rgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogoo
Ool0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol003ioo`03001oogoo08]o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<0
07ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00Oomoo`2;Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oogoo009oo`03
0003k0?/00l3k003001oo`0001Yoo`00?Woo00<007ooOol0Rgoo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`000181W`05001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`0
0`00Ool0000JOol003ioo`8008aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
0Il01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol0
0`00Oomoo`2;Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomo
o`000183k003001oogoo009oo`030003k0?/00l3k003001oo`0001Yoo`00?Woo00<007ooOol0Rgoo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0n`00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol003ioo`03001oogoo08]ooa<000Aoo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000B0Il01000Oomoogoo500017oo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00
Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0@I1l01000Oomoogoo50000goo00<0006O0Il0406O00<007ooOol00Woo00<000?/0n`03`?/
00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181
W`03001oogoo009oo`030003k0?/00l3k003001oo`0001Yoo`00?Woo00<007ooOol0XWoo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000J
Ool003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`000181W`03001oogoo009oo`030003k0?/00l3k003001oo`0001Yoo`00?Woo0P00
Xgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`0
0`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O
00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`000181W`03001oogoo009ooa<00003Ool007oo01Uoo`00?Woo00<0
07ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01000Oomoogoo
500017oo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo
00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`2R
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03
001oo`0001Yoo`00?Woo0P00Xgoo4`0017oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Ool0000JOol003ioo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O
00<007oo00006Woo000nOol00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1
W`03001oo`0001Yoo`006goo00<007ooOol00Woo00<007ooOol06goo00<007ooOol0^Goo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol001]oo`H001eoo`03001oogoo0;Uo
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo4`0000=oo`00Ool06Goo000LOol20002Ool00`00Oomoo`0KOol0
0`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`006goo
00<007ooOol00P007Woo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Ool0000JOol001]oo`H001eoo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@O
I1l03f@O00<007oo00006Woo000MOol01@00Ool007oo00001Woo1@000Woo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D0
07ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0
000JOol001aoo`D000Uoo`07001oogooOol007oo00000Woo00<007oo000027oo0`00^Goo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol001]oo`07001oo`00Ool007oo0000
27oo00L007ooOomoo`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`0077oo1@002Goo00L007ooOomoo`00Ool00002
Ool00`00Ool00008Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03
001oo`0001Yoo`006goo00D007oo001oo`0000Yoo`07001oogooOol007oo00000Woo00<007oo0000
27oo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol0
02Uoo`8000Aoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo0;Uoo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`2iOol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol0^Goo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo0;Uooa<000Aoo`03001T
7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007oo00006Woo000nOol00`00Oomoo`3@Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo0P00
dGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo01AoocL008Eoo`03001T7f@O011T7`05
001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
00006Woo000nOol00`00Oomoo`0BOoli0025Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007oo
Ool04Woo00<007ooOol0=Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05
001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001o
ogoo019oo`03001oogoo03Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00
Oomoo`0BOol00`00Oomoo`0@O00UOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo
00<007ooOol04Woo00<007ooOol047`09Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol0
03ioo`03001oogoo019oo`03001oogoo011l00]oo`8001Qoo`03001oogoo08=oo`03001T7f@O011T
7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@O00<Ool00`00Oomoo`0FOol00`00Oomo
o`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009o
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo0P004goo00<007ooOol047`01Woo0P0017oo00L0
07ooOol007oo001oo`05000=Ool00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol047`027oo00h007ooOol007oo001oo`00Ool007oo001oo`000Woo00<0
07ooOol02Woo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03
001oogoo011l00Moo`0?001oogooOol007oo001oo`00Ool007oo001oo`00009oo`03001oogoo00Yo
o`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@
O007Ool2000017oo000007oo100000Aoo`00Oomoo`<000eoo`03001oogoo08=oo`03001T7f@O011T
7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@O00EOol00`00Oomoo`0=Ool00`00Oomo
o`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009o
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol047`057oo0P00
3goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo
011l02Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@O00UOol00`00Oomoo`23OolD0003Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@
O00UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007oo00006Woo000nOol2000COol00`00Oomoo`0eOol00`00Oomoo`2JOol00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo
000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0B
Ool00`00Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@
In0FOol2000=Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0HOol0
0`00Oomoo`0:Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In07Ool2
0002Ool30002Ool30003Ool3000<Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@In06Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo
00Yoo`03001oogoo09Yoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011Wh0Ioo`03001oogoo
00=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`2JOol00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo
000nOol00`00Oomoo`0BOol00`00Oomoo`0@In05Ool40002Ool400000goo00000004Ool3000<Ool0
0`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007oo00006Woo000nOol2000COol00`00Oomoo`0@In06Ool00`00Oomoo`0LOol00`00Oomo
o`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0AOol00`00Oomoo`0AOol00`00Oomo
o`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0B
Ool00`00Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0e
Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@O
I1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2JOol0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo0000
6Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0n`UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000XOol50002
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0@0n`UOol00`00Oomo
o`2JOolD0003Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol0
02Yoo`07001oogooOol007oo00000Woo00<007oo000027oo0`004Woo00<007ooOol040?/37oo00<0
07ooOol05Woo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000ZOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Qoo`03001oogoo019oo`03001o
ogoo0103k0Ioo`@0009oo`04001oogooOol4000AOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`04001oogooOol20003Ool00`00Ool0
0008Ool00`00Oomoo`0BOol00`00Oomoo`0@0n`6Ool300000goo000000030002Ool01000Oomoo`00
47oo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo0000
6Woo000ZOol01@00Oomoogoo000017oo00<007oo000027oo00<007ooOol04Woo00<007ooOol040?/
27oo00D007ooOomoo`0000Aoo`04001oogoo000@Ool00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Uoo`8000=oo`<000=oo`03001oogoo00Mo
o`03001oogoo019oo`03001oogoo0103k0Moo`8000=oo`03001oogoo009oo`<0015oo`03001oogoo
0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol040?/4Goo00<007ooOol04Goo00<007ooOol0/Goo00<006@OI1l046@O
00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomo
o`0@0n`@Ool2000COol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo0103k2Eoo`03001oogoo0;5oo`03
001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol040?/9Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@O
I1l03f@O00<007oo00006Woo000nOol2000COol00`00Oomoo`0@0n`UOol00`00Oomoo`2aOol00`00
I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019o
o`03001oogoo03Eoo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT
7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0/Goo00<006@O
I1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol0
0`00Oomoo`0@0IlUOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo0101WbEoo`03001oogoo0;5oo`03
001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol0406O9Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@O
I1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0IlUOol00`00Oomoo`2a
Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001o
ogoo019oo`03001oogoo0101W`Ioo`@000Ioo`@0015oo`03001oogoo0;5oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
406O1Woo0`0027oo00@007ooOol0011oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009o
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo0P004goo00<007ooOol0406O27oo00<007ooOol0
1Woo00@007ooOol0011oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O
00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O1goo0P000Woo00<007oo
00000goo0`004Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O
00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0Il<Ool00`00Oomoo`02Ool00`00
Oomoo`0AOol00`00Oomoo`2aOolD0004Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001o
ogoo019oo`03001oogoo0101W`aoo`04001oogooOol2000COol00`00Oomoo`39Ool00`00I1mT7`0?
I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo0101WbEoo`03001oogoo0<Uoo`03
001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O9Goo00<007oo
Ool0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol0
0`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo
03Eoo`03001oogoo0<Uoo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol046@O9Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomo
o`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol003io
o`8001=oo`03001oogoo011T7bEoo`03001oogoo0<Uoo`03001T7f@O00mT7`03001oo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo
00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@I1l6Ool4000017oo001oo`000Woo10004Goo
00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomo
o`0@I1l6Ool30003Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0bGoo00<006@OI1l0
3f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@I1l8Ool00`00Oomoo`030003
Ool01000Oomoo`0047oo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00
Oomoo`0BOol00`00Oomoo`0@I1l7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`39Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011T7a5oo`03001o
ogoo015oo`03001oogoo0<Uoo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo
00<007ooOol046@O47oo0P004goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0
000JOol003ioo`8001=oo`03001oogoo011T7bEoo`03001oogoo0<Uoo`03001T7f@O00mT7`03001o
o`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<007ooOol0bGoo00<006@OI1l0
3f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`39Ool00`00
I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oocT00<]oo`03001T7f@O00mT7`03001o
o`0001Yoo`00?Woo00<007ooOol0ogoo5goo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00
Oomoo`3oOolGOolC00000goo001oo`0IOol003ioo`03001oogoo0?moob]oo`03001oogoo01Qoo`00
:Goo0`000goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0ogoo:goo00<007ooOol067oo
000YOol00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`3oOol[Ool00`00
Oomoo`0HOol002Yoo`07001oogooOol007oo00000Woo00<007oo000027ooo`00;`006Woo000ZOol0
1`00Oomoogoo001oo`00009oo`03001oo`000?mooe5oo`00:Goo00<007oo00000Woo00<007oo0000
0Woo00<007oo0000ogooDGoo000ZOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`3oOom@
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo002VOol30003Ool30002Ool3
00001goo001oo`00Ool007oo00@00004Ool000000002Ool30003Ool20002Ool20002Ool40002Ool3
0002Ool20004Ool20002Ool60002Ool00`00Ool000020003Ool2002<Ool00:Moo`03001oogoo00=o
o`03001oogoo009oo`09001oogoo001oo`00Ool007oo00<000=oo`03001oogoo009oo`05001oogoo
Ool00006Ool01000Oomoo`000Woo00@007ooOol000Eoo`04001oogoo0002Ool00`00Ool000020002
Ool01P00Oomoo`00Ool000Aoo`03001oogoo08aoo`00Ygoo0`000goo00<007ooOol00Woo00P007oo
Ool007oo001oo`000goo00D007ooOomoo`0000Aoo`04001oogooOol30003Ool01@00Oomoogoo0000
0Woo00@007ooOol000Aoo`05001oogooOol00006Ool01000Oomoo`000Woo00<007oo000017oo0`00
S7oo002WOol01@00Oomoo`00Ool0100000=oo`0000000Woo0P0000=oo`00Ool00Woo0P000Woo1000
00=oo`0000000goo0`000goo0P000Woo00D007ooOol007oo008000Aoo`800003Ool00000008000=o
o`800003Ool000000080009oo`<0009oo`<008aoo`00Ygoo00@007ooOol002Uoo`04001oogoo000;
Ool00`00Oomoo`2POol00:Ioo`@000Qoo`03001oogoo015oo`03001oogoo00Yoo`@000=oo`03001o
ogoo0:Uoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo0000\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {528.563, 288.563}} -> {-1.56523, \
0.911552, 0.00540782, 0.00540782}, {{104.5, 474.313}, {522.813, 294.25}} -> \
{-6.30713, 277.888, 0.0431596, 1.10552}, {{178.438, 233.938}, {390.063, \
316.063}} -> {-10.9028, 12.0673, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 40: ",
    FontWeight->"Bold"],
  "\[CapitalUDoubleDot]berblick \[UDoubleDot]ber die Anzahl der notwendigen \
Operationen, die PrimariesDistance in Abh\[ADoubleDot]ngigkeit der Ordnung \
erzeugt. "
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Anzahl der Terme, die w\[ADoubleDot]hrend den Ableitungen entstehen, w\
\[ADoubleDot]chst nicht linear mit der Ordnung. Geht man zu Ordnungen \
jenseits der 10., so muss sehr viel Zeit daf\[UDoubleDot]r aufgewendet \
werden, die einzelnen Terme zu vereinfachen, was sich direkt in der \
Berechnungszeit niederschl\[ADoubleDot]gt. Dies f\[UDoubleDot]hrt dazu, dass \
die verwendete Prozessorzeit exponentiell mit wachsender Ordnung ansteigt. \
Dem Algorithmus ist daher eine obere Schranke aufgrund dieser Tatsache \
gesetzt.  \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:8"],

Cell["Kap. 1.3. , 2.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.2. LinearCoefficient",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:9"],

Cell["\<\
LinearCoefficient[n] entwickelt den linearen Koeffizienten der polynomischen \
Bewegungsgleichung des Sitnikovproblems nach dem St\[ODoubleDot]rparameter e \
bis zur Ordnung n.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:10"],

Cell[TextData[{
  "Da nur kleine Abst\[ADoubleDot]nde des dritten K\[ODoubleDot]rpers von der \
Ebene der Prim\[ADoubleDot]rk\[ODoubleDot]rper betrachtet werden, wird seine \
Bewegungsgleichung nach der Amplitude z entwickelt. Der lineare Koeffizient \
ergibt sich durch Entwicklung von ",
  Cell[BoxData[
      \(TraditionalForm\`1/r \((t, e)\)\^3\)]],
  " nach der Exzentrizit\[ADoubleDot]t e, wobei r der Abstand der Prim\
\[ADoubleDot]rk\[ODoubleDot]rper vom Baryzentrum ist."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:11"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["PrimariesDistance",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(LinearCoefficient[
          n_Integer] := \(Module[{x}, $Derivation = \[IndentingNewLine]{x = 
                  1\/PrimariesDistance[n]\^3, \
\[IndentingNewLine]LinearCoefficient[n] = 
                  TrigReduce[
                    x]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:12"],

Cell["-", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:13"],

Cell["Kap. 2.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.3. AmplitudeFunctionSystem",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:14"],

Cell["\<\
AmplitudeFunctionSystem[n] erstellt das resultierende Gleichungssytem n-ter \
Ordnung f\[UDoubleDot]r den linearisierten Fall der Bewegungsgleichung des \
Sitnikovproblems. Das Resultat ist ein System aus (n+1) \
Differentialgleichungen 2. Ordnung und wird mittels der Funktion \
AmplitudeFunction gel\[ODoubleDot]st.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:15"],

Cell[TextData[{
  "Aus der Floquet - Theorie folgt, dass die Differentialgleichung f\
\[UDoubleDot]r die Amplitudenfunktion w: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(w\^\[DoublePrime] + \(g(t)\) w - 
          w\^\(-3\)\  = \ 0\)\)\)]],
  " lautet. Da in unserem Fall der linearisierten Bewegungsgleichung des \
Sitnikovproblems ",
  Cell[BoxData[
      \(TraditionalForm\`g\  = \ g(t, e)\)]],
  " ist, wird ein St\[ODoubleDot]ransatz der Amplitudenfunktion um den   \
Parameter e versucht: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox[
                RowBox[{
                  FormBox[\(w\  = \ w\_0\),
                    "TraditionalForm"], "+", \(\(w\_1\) e\)}],
                "TraditionalForm"], "+"}], "..."}], "+", " ", \(O(e\^n)\)}], 
        TraditionalForm]]],
  ". Setzt man diesen in die Differentialgleichung ein, so ergibt sich durch \
Vergleich der Koeffizienten in e ein Gleichungssytem, bestehend aus (n+1) \
Differentialgleichungen. Dieses kann dann rekursiv in den Funktionen gel\
\[ODoubleDot]st werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:16"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["LinearCoefficient",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(AmplitudeFunctionSystem[
          n_Integer] := \(Module[{x}, $Derivation = {x = 
                  SeriesData[e, 0, Table[\(Subscript[w, i]\)[t], {i, 0, n}], 
                    0, n + 1, 
                    1], \[IndentingNewLine]x = \[PartialD]\_{t, 2}x + 
                    LinearCoefficient[n]\ x - 1\/x\^3, \[IndentingNewLine]x = 
                  Simplify[x], \[IndentingNewLine]AmplitudeFunctionSystem[
                    n] = Replace[x\[LeftDoubleBracket]3\[RightDoubleBracket], 
                    lhs_ \[Rule] lhs \[Equal] 0, 
                    1]}\[IndentingNewLine]]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:17"],

Cell["\<\
Die Termanzahl sowie die Menge der auszuf\[UDoubleDot]hrenden Operationen \
wachsen mit zunehmender Ordnung exponentiell an. Da es sich um ein rekursiv \
zu l\[ODoubleDot]sendes System handelt, ist es erst dann m\[ODoubleDot]glich, \
Vereinfachungen vorzunehmen, wenn alle L\[ODoubleDot]sungen der darunter \
liegenden Ordnungen vorliegen. Dies stellt eine sch\[ODoubleDot]ne \
Herausforderung an den Integrator des Systems dar.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.000262184 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .14581 -20.6875 -5.8125 ]
[-0.0125 .14581 0 5.8125 ]
[-0.0125 .2769 -26.25 -5.8125 ]
[-0.0125 .2769 0 5.8125 ]
[-0.0125 .40799 -26.25 -5.8125 ]
[-0.0125 .40799 0 5.8125 ]
[-0.0125 .53908 -26.25 -5.8125 ]
[-0.0125 .53908 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.875 -7.5625 ]
[-0.01875 .30902 -26.25 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -66.1875 0 ]
[.5 .63053 66.1875 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .14581 m
.00625 .14581 L
s
gsave
-0.0125 .14581 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .2769 m
.00625 .2769 L
s
gsave
-0.0125 .2769 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
0 .40799 m
.00625 .40799 L
s
gsave
-0.0125 .40799 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
0 .53908 m
.00625 .53908 L
s
gsave
-0.0125 .53908 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04093 m
.00375 .04093 L
s
0 .06715 m
.00375 .06715 L
s
0 .09337 m
.00375 .09337 L
s
0 .11959 m
.00375 .11959 L
s
0 .17203 m
.00375 .17203 L
s
0 .19824 m
.00375 .19824 L
s
0 .22446 m
.00375 .22446 L
s
0 .25068 m
.00375 .25068 L
s
0 .30312 m
.00375 .30312 L
s
0 .32934 m
.00375 .32934 L
s
0 .35555 m
.00375 .35555 L
s
0 .38177 m
.00375 .38177 L
s
0 .43421 m
.00375 .43421 L
s
0 .46043 m
.00375 .46043 L
s
0 .48665 m
.00375 .48665 L
s
0 .51287 m
.00375 .51287 L
s
0 .5653 m
.00375 .5653 L
s
0 .59152 m
.00375 .59152 L
s
0 .61774 m
.00375 .61774 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -100.625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -127.188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AmplitudeFunctionSystem) show
191.375 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .01524 L
.06923 .01524 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .01524 L
.06923 .01524 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .0155 L
.14615 .0155 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .0155 L
.14615 .0155 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .01576 L
.22308 .01576 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .01576 L
.22308 .01576 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .01603 L
.3 .01603 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .01603 L
.3 .01603 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .01629 L
.37692 .01629 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .01629 L
.37692 .01629 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .01655 L
.45385 .01655 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .01655 L
.45385 .01655 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .01681 L
.53077 .01681 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .01681 L
.53077 .01681 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .01707 L
.60769 .01707 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .01707 L
.60769 .01707 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .01734 L
.68462 .01734 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .01734 L
.68462 .01734 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .0176 L
.76154 .0176 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .0176 L
.76154 .0176 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .01786 L
.83846 .01786 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .01786 L
.83846 .01786 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .01812 L
.91538 .01812 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .01812 L
.91538 .01812 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .01839 L
.99231 .01839 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .01839 L
.99231 .01839 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .01524 m
.00769 .0155 L
.06923 .0155 L
.06923 .01524 L
F
0 g
.00769 .01524 m
.00769 .0155 L
.06923 .0155 L
.06923 .01524 L
.00769 .01524 L
s
.8 1 0 r
.08462 .0155 m
.08462 .01629 L
.14615 .01629 L
.14615 .0155 L
F
0 g
.08462 .0155 m
.08462 .01629 L
.14615 .01629 L
.14615 .0155 L
.08462 .0155 L
s
.8 1 0 r
.16154 .01576 m
.16154 .0176 L
.22308 .0176 L
.22308 .01576 L
F
0 g
.16154 .01576 m
.16154 .0176 L
.22308 .0176 L
.22308 .01576 L
.16154 .01576 L
s
.8 1 0 r
.23846 .01603 m
.23846 .01943 L
.3 .01943 L
.3 .01603 L
F
0 g
.23846 .01603 m
.23846 .01943 L
.3 .01943 L
.3 .01603 L
.23846 .01603 L
s
.8 1 0 r
.31538 .01629 m
.31538 .02206 L
.37692 .02206 L
.37692 .01629 L
F
0 g
.31538 .01629 m
.31538 .02206 L
.37692 .02206 L
.37692 .01629 L
.31538 .01629 L
s
.8 1 0 r
.39231 .01655 m
.39231 .02546 L
.45385 .02546 L
.45385 .01655 L
F
0 g
.39231 .01655 m
.39231 .02546 L
.45385 .02546 L
.45385 .01655 L
.39231 .01655 L
s
.8 1 0 r
.46923 .01681 m
.46923 .02992 L
.53077 .02992 L
.53077 .01681 L
F
0 g
.46923 .01681 m
.46923 .02992 L
.53077 .02992 L
.53077 .01681 L
.46923 .01681 L
s
.8 1 0 r
.54615 .01707 m
.54615 .03543 L
.60769 .03543 L
.60769 .01707 L
F
0 g
.54615 .01707 m
.54615 .03543 L
.60769 .03543 L
.60769 .01707 L
.54615 .01707 L
s
.8 1 0 r
.62308 .01734 m
.62308 .04224 L
.68462 .04224 L
.68462 .01734 L
F
0 g
.62308 .01734 m
.62308 .04224 L
.68462 .04224 L
.68462 .01734 L
.62308 .01734 L
s
.8 1 0 r
.7 .0176 m
.7 .05037 L
.76154 .05037 L
.76154 .0176 L
F
0 g
.7 .0176 m
.7 .05037 L
.76154 .05037 L
.76154 .0176 L
.7 .0176 L
s
.8 1 0 r
.77692 .01786 m
.77692 .06007 L
.83846 .06007 L
.83846 .01786 L
F
0 g
.77692 .01786 m
.77692 .06007 L
.83846 .06007 L
.83846 .01786 L
.77692 .01786 L
s
.8 1 0 r
.85385 .01812 m
.85385 .07135 L
.91538 .07135 L
.91538 .01812 L
F
0 g
.85385 .01812 m
.85385 .07135 L
.91538 .07135 L
.91538 .01812 L
.85385 .01812 L
s
.8 1 0 r
.93077 .01839 m
.93077 .08446 L
.99231 .08446 L
.99231 .01839 L
F
0 g
.93077 .01839 m
.93077 .08446 L
.99231 .08446 L
.99231 .01839 L
.93077 .01839 L
s
0 1 .4 r
.00769 .0155 m
.00769 .01603 L
.06923 .01603 L
.06923 .0155 L
F
0 g
.00769 .0155 m
.00769 .01603 L
.06923 .01603 L
.06923 .0155 L
.00769 .0155 L
s
0 1 .4 r
.08462 .01629 m
.08462 .0176 L
.14615 .0176 L
.14615 .01629 L
F
0 g
.08462 .01629 m
.08462 .0176 L
.14615 .0176 L
.14615 .01629 L
.08462 .01629 L
s
0 1 .4 r
.16154 .0176 m
.16154 .01996 L
.22308 .01996 L
.22308 .0176 L
F
0 g
.16154 .0176 m
.16154 .01996 L
.22308 .01996 L
.22308 .0176 L
.16154 .0176 L
s
0 1 .4 r
.23846 .01943 m
.23846 .02415 L
.3 .02415 L
.3 .01943 L
F
0 g
.23846 .01943 m
.23846 .02415 L
.3 .02415 L
.3 .01943 L
.23846 .01943 L
s
0 1 .4 r
.31538 .02206 m
.31538 .02914 L
.37692 .02914 L
.37692 .02206 L
F
0 g
.31538 .02206 m
.31538 .02914 L
.37692 .02914 L
.37692 .02206 L
.31538 .02206 L
s
0 1 .4 r
.39231 .02546 m
.39231 .03674 L
.45385 .03674 L
.45385 .02546 L
F
0 g
.39231 .02546 m
.39231 .03674 L
.45385 .03674 L
.45385 .02546 L
.39231 .02546 L
s
0 1 .4 r
.46923 .02992 m
.46923 .04618 L
.53077 .04618 L
.53077 .02992 L
F
0 g
.46923 .02992 m
.46923 .04618 L
.53077 .04618 L
.53077 .02992 L
.46923 .02992 L
s
0 1 .4 r
.54615 .03543 m
.54615 .05902 L
.60769 .05902 L
.60769 .03543 L
F
0 g
.54615 .03543 m
.54615 .05902 L
.60769 .05902 L
.60769 .03543 L
.54615 .03543 L
s
0 1 .4 r
.62308 .04224 m
.62308 .07397 L
.68462 .07397 L
.68462 .04224 L
F
0 g
.62308 .04224 m
.62308 .07397 L
.68462 .07397 L
.68462 .04224 L
.62308 .04224 L
s
0 1 .4 r
.7 .05037 m
.7 .09521 L
.76154 .09521 L
.76154 .05037 L
F
0 g
.7 .05037 m
.7 .09521 L
.76154 .09521 L
.76154 .05037 L
.7 .05037 L
s
0 1 .4 r
.77692 .06007 m
.77692 .11854 L
.83846 .11854 L
.83846 .06007 L
F
0 g
.77692 .06007 m
.77692 .11854 L
.83846 .11854 L
.83846 .06007 L
.77692 .06007 L
s
0 1 .4 r
.85385 .07135 m
.85385 .15105 L
.91538 .15105 L
.91538 .07135 L
F
0 g
.85385 .07135 m
.85385 .15105 L
.91538 .15105 L
.91538 .07135 L
.85385 .07135 L
s
0 1 .4 r
.93077 .08446 m
.93077 .18592 L
.99231 .18592 L
.99231 .08446 L
F
0 g
.93077 .08446 m
.93077 .18592 L
.99231 .18592 L
.99231 .08446 L
.93077 .08446 L
s
0 .4 1 r
.00769 .01603 m
.00769 .01655 L
.06923 .01655 L
.06923 .01603 L
F
0 g
.00769 .01603 m
.00769 .01655 L
.06923 .01655 L
.06923 .01603 L
.00769 .01603 L
s
0 .4 1 r
.08462 .0176 m
.08462 .01891 L
.14615 .01891 L
.14615 .0176 L
F
0 g
.08462 .0176 m
.08462 .01891 L
.14615 .01891 L
.14615 .0176 L
.08462 .0176 L
s
0 .4 1 r
.16154 .01996 m
.16154 .02232 L
.22308 .02232 L
.22308 .01996 L
F
0 g
.16154 .01996 m
.16154 .02232 L
.22308 .02232 L
.22308 .01996 L
.16154 .01996 L
s
0 .4 1 r
.23846 .02415 m
.23846 .02861 L
.3 .02861 L
.3 .02415 L
F
0 g
.23846 .02415 m
.23846 .02861 L
.3 .02861 L
.3 .02415 L
.23846 .02415 L
s
0 .4 1 r
.31538 .02914 m
.31538 .03595 L
.37692 .03595 L
.37692 .02914 L
F
0 g
.31538 .02914 m
.31538 .03595 L
.37692 .03595 L
.37692 .02914 L
.31538 .02914 L
s
0 .4 1 r
.39231 .03674 m
.39231 .04723 L
.45385 .04723 L
.45385 .03674 L
F
0 g
.39231 .03674 m
.39231 .04723 L
.45385 .04723 L
.45385 .03674 L
.39231 .03674 L
s
0 .4 1 r
.46923 .04618 m
.46923 .06086 L
.53077 .06086 L
.53077 .04618 L
F
0 g
.46923 .04618 m
.46923 .06086 L
.53077 .06086 L
.53077 .04618 L
.46923 .04618 L
s
0 .4 1 r
.54615 .05902 m
.54615 .08026 L
.60769 .08026 L
.60769 .05902 L
F
0 g
.54615 .05902 m
.54615 .08026 L
.60769 .08026 L
.60769 .05902 L
.54615 .05902 L
s
0 .4 1 r
.62308 .07397 m
.62308 .10307 L
.68462 .10307 L
.68462 .07397 L
F
0 g
.62308 .07397 m
.62308 .10307 L
.68462 .10307 L
.68462 .07397 L
.62308 .07397 L
s
0 .4 1 r
.7 .09521 m
.7 .1348 L
.76154 .1348 L
.76154 .09521 L
F
0 g
.7 .09521 m
.7 .1348 L
.76154 .1348 L
.76154 .09521 L
.7 .09521 L
s
0 .4 1 r
.77692 .11854 m
.77692 .17098 L
.83846 .17098 L
.83846 .11854 L
F
0 g
.77692 .11854 m
.77692 .17098 L
.83846 .17098 L
.83846 .11854 L
.77692 .11854 L
s
0 .4 1 r
.85385 .15105 m
.85385 .22158 L
.91538 .22158 L
.91538 .15105 L
F
0 g
.85385 .15105 m
.85385 .22158 L
.91538 .22158 L
.91538 .15105 L
.85385 .15105 L
s
0 .4 1 r
.93077 .18592 m
.93077 .27821 L
.99231 .27821 L
.99231 .18592 L
F
0 g
.93077 .18592 m
.93077 .27821 L
.99231 .27821 L
.99231 .18592 L
.93077 .18592 L
s
.8 0 1 r
.00769 .01655 m
.00769 .01786 L
.06923 .01786 L
.06923 .01655 L
F
0 g
.00769 .01655 m
.00769 .01786 L
.06923 .01786 L
.06923 .01655 L
.00769 .01655 L
s
.8 0 1 r
.08462 .01891 m
.08462 .02232 L
.14615 .02232 L
.14615 .01891 L
F
0 g
.08462 .01891 m
.08462 .02232 L
.14615 .02232 L
.14615 .01891 L
.08462 .01891 L
s
.8 0 1 r
.16154 .02232 m
.16154 .02887 L
.22308 .02887 L
.22308 .02232 L
F
0 g
.16154 .02232 m
.16154 .02887 L
.22308 .02887 L
.22308 .02232 L
.16154 .02232 L
s
.8 0 1 r
.23846 .02861 m
.23846 .04146 L
.3 .04146 L
.3 .02861 L
F
0 g
.23846 .02861 m
.23846 .04146 L
.3 .04146 L
.3 .02861 L
.23846 .02861 L
s
.8 0 1 r
.31538 .03595 m
.31538 .05719 L
.37692 .05719 L
.37692 .03595 L
F
0 g
.31538 .03595 m
.31538 .05719 L
.37692 .05719 L
.37692 .03595 L
.31538 .03595 L
s
.8 0 1 r
.39231 .04723 m
.39231 .08079 L
.45385 .08079 L
.45385 .04723 L
F
0 g
.39231 .04723 m
.39231 .08079 L
.45385 .08079 L
.45385 .04723 L
.39231 .04723 L
s
.8 0 1 r
.46923 .06086 m
.46923 .11067 L
.53077 .11067 L
.53077 .06086 L
F
0 g
.46923 .06086 m
.46923 .11067 L
.53077 .11067 L
.53077 .06086 L
.46923 .06086 L
s
.8 0 1 r
.54615 .08026 m
.54615 .15289 L
.60769 .15289 L
.60769 .08026 L
F
0 g
.54615 .08026 m
.54615 .15289 L
.60769 .15289 L
.60769 .08026 L
.54615 .08026 L
s
.8 0 1 r
.62308 .10307 m
.62308 .2048 L
.68462 .2048 L
.68462 .10307 L
F
0 g
.62308 .10307 m
.62308 .2048 L
.68462 .2048 L
.68462 .10307 L
.62308 .10307 L
s
.8 0 1 r
.7 .1348 m
.7 .27506 L
.76154 .27506 L
.76154 .1348 L
F
0 g
.7 .1348 m
.7 .27506 L
.76154 .27506 L
.76154 .1348 L
.7 .1348 L
s
.8 0 1 r
.77692 .17098 m
.77692 .3587 L
.83846 .3587 L
.83846 .17098 L
F
0 g
.77692 .17098 m
.77692 .3587 L
.83846 .3587 L
.83846 .17098 L
.77692 .17098 L
s
.8 0 1 r
.85385 .22158 m
.85385 .47118 L
.91538 .47118 L
.91538 .22158 L
F
0 g
.85385 .22158 m
.85385 .47118 L
.91538 .47118 L
.91538 .22158 L
.85385 .22158 L
s
.8 0 1 r
.93077 .27821 m
.93077 .60332 L
.99231 .60332 L
.99231 .27821 L
F
0 g
.93077 .27821 m
.93077 .60332 L
.99231 .60332 L
.99231 .27821 L
.93077 .27821 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
eGoo00<007ooOol01Woo00<007ooOol0YGoo003DOol00`00Oomoo`08Ool00`00Oomoo`2TOol00<mo
o`80009oo`03001oogoo00Aoo`8000Aoo`03001oogoo0:=oo`00cWoo00H007ooOol007oo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`2SOol00<ioo`06001oogoo001oo`001Goo0`0017oo00<007ooOol0
Xgoo003>Ool01P00Oomoo`00Ool000Eoo`<000Aoo`03001oogoo0:=oo`00cWoo00@007ooOol0009o
o`03001oogoo00Qoo`03001oogoo0:Aoo`00cgoo0P0017oo00<007ooOol01Woo00<007ooOol0YGoo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00BWoo1@004goo0`0057oo0P00
5Woo0`005Goo00<007ooOol04goo0P005Woo00<007ooOol057oo00<007ooOol04goo0P004Woo1@00
0Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000ioo`D00003Ool00000025oo`00C7oo00<0
07ooOol04goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol04goo00<007oo000057oo00<0
07oo00005Goo00<007ooOol04goo00<007oo00005Woo00<007ooOol04Goo00L007ooOomoo`00Ool0
000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<0
07ooOol07Woo001<Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol4000FOol00`00
Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00Ool0000EOol2000COol01`00Oomoogoo
001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo01moo`00C7oo00<007ooOol057oo00<007ooOol05Goo00<007ooOol0
4Woo00<007oo00005Goo0P005Goo0P005goo00<007ooOol04goo00<007ooOol04goo00<007oo0000
4goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0NOol004aoo`03001oogoo01=oo`03001oo`00
01Aoo`03001oo`0001Eoo`8001Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`03001oo`0001=oo`07001oogooOol007oo000047oo00<007ooOol00Woo00<007oo
Ool03goo00L007ooOomoo`00Ool0000@Ool01`00Oomoogoo001oo`00021oo`00Bgoo0P005Woo00<0
07ooOol057oo00<007ooOol05Goo00<007ooOol04goo0`005Goo0P0057oo0`005Goo00<007ooOol0
57oo0P004Woo0P0017oo00<007ooOol03Woo0P000goo0P0047oo0P0017oo00<007ooOol03Woo0P00
17oo00<007ooOol07goo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00@Goo
o`00;`005goo0011Ool00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`08
Ool00`00Oomoo`0EOol0045oo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo00Qoo`03001oogoo01Eoo`00>7oo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
5Goo000gOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol003Moo`03001oo`00
00Moool002l001Moo`00=goo00<007oo00001goo00<007oo00004`0017oo4`0017oo4`0017oo4`00
17oo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02OolC0004OolD0003OolD
0003OolD00000goo001oo`0FOol003Moo`03001oo`0000Moo`03001oogoo01Mooa<000Aooa<000Ao
o`030003k0?/00l3k003001oogoo009ooa@000=oo`03001Wh6OP011Wh005001oogooOol0000BIn00
0`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomo
o`00019Wh003001oo`0001Moo`00>7oo00<007ooOol01Woo00<007ooOol0;Woo00<006@OI1l03f@O
00<007ooOol00Woo4`0017oo00<000?/0n`040?/00@007ooOomooa@000=oo`03001Wh6OP011Wh003
001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03
001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo
00004VOP00<007oo00005goo0011Ool00`00Oomoo`0^OolC0004OolC0004OolD0003Ool00`000n`3
k00@0n`01000Oomoogoo500017oo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019W
h005001oogooOol0000BIn000`00Ool0000GOol0045oo`03001oogoo04Eoo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo
Ool00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OP
In003fOP00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000B
In000`00Ool0000GOol0045oo`03001oogoo04Eoo`03001T7f@O00mT7`03001oogoo009ooa@000=o
oa@000=oo`030003k0?/0103k003001oogoo009ooa<000Aoo`03001Wh6OP00mWh003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomo
ogoo00004VOP00<007oo00005goo0011Ool00`00Oomoo`15Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oogoo009oo`03
0003k0?/00l3k003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003
001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo
00005goo0011Ool20016OolC0004Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomo
o`000183k003001oogoo009oo`030003k0?/00l3k003001oogoo009ooa<000Aoo`03001Wh6OP00mW
h003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<0
07oo00005goo0011Ool00`00Oomoo`1LOol00`00I1mT7`0@I1l01000Oomoogoo50000goo500017oo
00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00
Ool0000GOol0045oo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<0
07ooOol00Woo4`0017oo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn00
0`00Ool0000GOol0045oo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004P6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/
00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00
019Wh005001oogooOol0000BIn000`00Ool0000GOol0045oo`03001oogoo05aooa@000=oo`03001T
7f@O011T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool0
0`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00@In00
1@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<007ooOol0Lgoo
00<006@OI1l046@O00D007ooOomoo`000181W`03001oogoo009ooa<000Aoo`030003k0?/00l3k003
001oogoo009oo`030003k0?/00l3k003001oogoo009ooa@000=oo`03001Wh6OP011Wh005001oogoo
Ool0000BIn000`00Ool0000GOol0045oo`03001oogoo07=oo`03001T7f@O011T7`04001oogooOolD
0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3
k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP00D007ooOomoo`00019W
h003001oo`0001Moo`00@Goo0P00M7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/
00l3k003001oogoo009oo`030003k0?/0103k005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007oo00005goo0011Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<0
00?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D007ooOomoo`00019Wh005001oogooOol0
000BIn000`00Ool0000GOol0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01000Oomoogoo50000goo00<006OP
In0046OP00<007oo00005goo0011Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo4`0017oo00<000?/0n`03`?/00<0
07ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000BIn000`00Ool0
000GOol0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02
OolC0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00
0n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<0
07ooOol0Lgoo50000goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`0
40?/00D007ooOomoo`000183k005001oogooOol0000BIn000`00Ool0000GOol0045oo`03001oogoo
08Yoo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001oogoo
Ool0000B0n`01000Oomoogoo500000=oo`00Ool05Woo0011Ool00`00Oomoo`2:Ool00`00I1mT7`0@
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007oo
Oomoo`000183k003001oo`0001Moo`00@Goo0P00Rgoo00<006@OI1l046@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<0
07ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0
000GOol0045oo`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009ooa<000Aoo`030003k0?/0103k005001oogoo
Ool0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool00`00Oomoo`2:Ool00`00I1mT
7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D0
07ooOomoo`000183k003001oo`0001Moo`00@Goo00<007ooOol0RWoo00<006@OI1l046@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo4`0017oo00<0006O0Il03`6O00<007ooOol00Woo
00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0000GOol0045o
o`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103
k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool00`00Oomoo`2:
Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo
00004P?/00D007ooOomoo`000183k003001oo`0001Moo`00@Goo00<007ooOol0RWoo500017oo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0
000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B
0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool2002SOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02OolD0003Ool0
0`000n`3k00@0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool00`00Oomoo`2ROol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oo`00
01Moo`00@Goo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183
k005001oogooOol0000B0n`00`00Ool0000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O0101W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool0
0`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomo
o`000183k003001oo`0001Moo`00@Goo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo4`0017oo00<0006O0Il0406O00D007ooOomoo`000183k005
001oogooOol0000B0n`00`00Ool0000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001
W`6O0101W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo000]Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oo`0001Moo`00;7oo00<0
07oo00000Woo00<007oo00000Woo00<007oo000027oo0`00XWoo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0000GOol002ioo`06001oogoo
001oo`000Woo00<007oo000027oo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0000GOol002aoo`8000=oo`03001oo`00
009oo`03001oo`0000Qoo`03001oogoo0:9ooa<000Aoo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`04001oogooOolD0003Ool00`000n`3k00@
0n`00`00Ool0000GOol002aoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000Qoo`03001o
ogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001
W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007oo00005goo000/Ool30003
Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000183k003001oo`0001Moo`00@Goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0n`00`00Ool0000GOol0045oo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P?/00<007oo00005goo0011Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000183k003001oo`0001Moo`00@Goo0P00^Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo50000goo00<0006O0Il0406O00D007ooOomoo`000183k003
001oo`0001Moo`00@Goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0n`0
0`00Ool0000GOol0045oo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo00004P?/
00<007oo00005goo0011Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000183
k003001oo`0001Moo`00@Goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`04001oogooOolD0000
0goo001oo`0FOol0045oo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O
00<007oo00005goo0011Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oo`0001Moo`00@Goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B
0Il00`00Ool0000GOol0045oo`800;Yoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07oo00005goo0011Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oo`0001Moo`00@Goo00<007ooOol0^Goo4`0017oo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`03
001oogoo0=1oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
0Il01@00Oomoogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`3@Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
o`0001Moo`00@Goo00<007ooOol0d7oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`03001oogoo0=1o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`3@Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0@I1l01000Oomoogoo50000goo00<0006O0Il0406O00<007oo00005goo0011Ool2
003AOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`000181W`03001oo`0001Moo`00@Goo00<007ooOol0d7oo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Ool0000G
Ool0045oo`03001oogoo0=1oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`3@Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
0181W`03001oo`0001Moo`00@Goo00<007ooOol0d7oo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`03
001oogoo0=1oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
I1l01@00Oomoogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`3@Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001o
o`0001Moo`00@Goo00<007ooOol0d7oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`800=5oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4P6O00<007oo00005goo0011Ool00`00Oomoo`3@Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo00<0
07ooOol0d7oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`03001oogoo0=1oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo
00005goo0011Ool00`00Oomoo`3@Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo00<007ooOol0d7oo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000B0Il00`00Ool0000GOol002Eoo`D0009oo`03001oogoo009oo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo0=1oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo00005goo000WOol01`00Oomoogoo001oo`00
009oo`03001oo`00009oo`03001oo`0000Uoo`03001oogoo0=1ooa<000Aoo`03001T7f@O011T7`05
001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo00005goo000WOol01`00Oomoogoo001o
o`00009oo`03001oo`00009oo`03001oo`0000Uoo`<00>Moo`03001T7f@O011T7`05001oogooOol0
000BI1l01000Oomoogoo500000=oo`00Ool05Woo000WOol01`00Oomoogoo001oo`00009oo`03001o
o`00009oo`03001oo`0000Uoo`03001oogoo0>Moo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004V@O00<007oo00005goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00
009oo`03001oo`0000Uoo`03001oogoo0>Moo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004V@O00<007oo00005goo000VOol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`08Ool00`00Oomoo`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`03001oo`0001Moo`00@Goo00<007ooOol0igoo00<006@OI1l046@O00D007ooOomoo`00
019T7`05001oogooOol0000BI1l00`00Ool0000GOol001Qoo`03001oogoo009oo`03001oogoo025o
o`03001oogoo0>Moo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07oo00005goo000HOol6000SOol00`00Oomoo`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oo`0001Moo`006Goo0P000Woo00<007ooOol08Goo00<007ooOol0
igoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0
01Qoo`03001oogoo008002Aoo`800>Qoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007oo00005goo000HOol6000SOol00`00Oomoo`3WOol00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`006Woo00D007oo001oo`00029o
o`03001oogoo0>Moo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07oo00005goo000IOol5000SOol00`00Oomoo`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oo`0001Moo`0067oo00L007oo001oo`00Ool0000ROol00`00Oomo
o`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Mo
o`006Goo1@008goo00<007ooOol0igoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Ool0000GOol001Qoo`05001oo`00Ool0000TOol00`00Oomoo`3WOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo0P00j7oo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0045o
o`03001oogoo0>Moo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07oo00005goo0011Ool00`00Oomoo`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol0igoo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo0>Moo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomo
o`3WOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Mo
o`00@Goo00<007ooOol04Goo=`00Wgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moocT009moo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool2000@Ool00`00Oomoo`0e
Ool00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03
001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0WGoo50000goo00<0
06@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007oo
Ool047`09Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol047`09Goo00<007ooOol0]7oo00<006@OI1l046@O00D0
07ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`02goo0P00
67oo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo
00<007ooOol03goo00<007ooOol047`037oo00<007ooOol05Woo00<007ooOol0]7oo00<006@OI1l0
46@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`0
1Woo0P0017oo00L007ooOol007oo001oo`05000=Ool00`00Oomoo`2dOol00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O008Ool03P00
Oomoo`00Ool007oo001oo`00Ool007oo0002Ool00`00Oomoo`0:Ool00`00Oomoo`2dOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool2000@Ool00`00Oomoo`0@O007Ool0
3`00Oomoogoo001oo`00Ool007oo001oo`00Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`2dOol0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@O007Ool2000017oo000007oo100000Aoo`00Oomoo`<000eoo`03001oogoo0;Aoo`03001T
7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo
011l01Eoo`03001oogoo00eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l0
0`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011l01Aoo`8000moo`03001oogoo0;Ao
o`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03
001oogoo011l02Eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0
000GOol0045oo`03001oogoo00moo`03001oogoo011l02Eoo`03001oogoo0;Aoo`03001T7f@O011T
7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011l02Eo
o`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol002Eoo`D0
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo
03Eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol002Mo
o`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00002Goo0`003goo00<007ooOol0
=Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`009goo
00<007ooOol00goo00H007ooOol007oo0002Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomo
o`0@In0UOol00`00Oomoo`2dOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007oo00005goo
000WOol01000Oomoogoo0P000goo00<007oo00000Woo00<007oo00002Goo00<007ooOol03goo00<0
07ooOol046OP5Woo0P003Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03
001oo`0001Moo`009goo00D007ooOomoo`0000Aoo`03001oo`00009oo`03001oo`0000Uoo`03001o
ogoo00moo`03001oogoo011Wh1Qoo`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O011T7`05
001oogooOol0000BI1l00`00Ool0000GOol002Ioo`8000=oo`<000=oo`03001oogoo009oo`03001o
ogoo00Qoo`03001oogoo00moo`03001oogoo011Wh0Moo`80009oo`<0009oo`<000=oo`<000aoo`03
001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001o
ogoo00moo`03001oogoo011Wh0Ioo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo0000
0Woo00<007ooOol02Woo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001o
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP1Woo00<007ooOol00goo00<007ooOol0
0Woo00D007ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O011T7`05001o
ogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011Wh0Eoo`@0009o
o`@00003Ool0000000Aoo`<000aoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000B
I1l00`00Ool0000GOol0045oo`80011oo`03001oogoo011Wh0Ioo`03001oogoo01aoo`03001oogoo
0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00mo
o`03001oogoo011Wh15oo`03001oogoo015oo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogoo
Ool0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011Wh2Eoo`03001oogoo
0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00mo
o`03001oogoo011Wh2Eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00
Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011Wh2Eoo`03001oogoo0;Aoo`03001T7f@O
011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo03Eo
o`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03
001oogoo00moo`03001oogoo03Eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000B
I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0103k2Eoo`03001oogoo0;Aoo`03
001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`80011oo`03001oogoo0103
k2Eoo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045o
o`03001oogoo00moo`03001oogoo0103k0aoo`03001oogoo01Ioo`03001oogoo0;Aoo`03001T7f@O
011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0103
k0Ioo`@0009oo`04001oogooOol4000AOol00`00Oomoo`2dOol00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`6Ool300000goo0000
00030002Ool01000Oomoo`0047oo00<007ooOol0]7oo50000goo00<006@OI1l046@O00<007oo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`8Ool01@00Oomoogoo000017oo00@007ooOol0
011oo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<0
07ooOol040?/1goo0P000goo00<007ooOol00Woo0`004Goo00<007ooOol0bgoo00<006@OI1l046@O
00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`AOol00`00Oomoo`0AOol00`00
Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0103
k11oo`8001=oo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo0P0047oo00<0
07ooOol040?/9Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0@0n`UOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045o
o`03001oogoo00moo`03001oogoo0103k2Eoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`00
01Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0bgoo00<006@OI1l046@O00<0
07oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`3;Ool00`00I1mT7`0@
I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0101WbEoo`03001oogoo0<]oo`03
001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007oo
Ool0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0IlU
Ool00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`80011oo`03001oogoo0101
WbEoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<0
07ooOol0406O1Woo10001Woo10004Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0Il6Ool30008Ool01000Oomoo`0047oo00<007ooOol0
bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0Il8Ool0
0`00Oomoo`06Ool01000Oomoo`0047oo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0Il7Ool20002Ool00`00Ool00003Ool3000AOol00`00
Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0101
W`aoo`03001oogoo009oo`03001oogoo015oo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`00
01Moo`009Woo0`000goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
3goo00<007ooOol0406O37oo00@007ooOomoo`8001=oo`03001oogoo0<]oo`03001T7f@O011T7`03
001oo`0001Moo`009Woo00<007ooOol00Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
2Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo
00005goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`<000mo
o`03001oogoo0101WbEoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`009goo00L0
07ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomo
o`0eOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol002Ioo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo03Eoo`03
001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`009goo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol046@O9Goo00<007oo
Ool0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lU
Ool00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001o
ogoo011T7bEoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol0
3goo00<007ooOol046@O9Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool0
0`00Oomoo`0?Ool00`00Oomoo`0@I1l6Ool4000017oo001oo`000Woo10004Goo00<007ooOol0bgoo
00<006@OI1l046@O00<007oo00005goo0011Ool2000@Ool00`00Oomoo`0@I1l6Ool30003Ool00`00
Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1l8Ool00`00Oomoo`030003Ool01000Oomoo`0047oo00<0
07ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
I1l7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0
000GOol0045oo`03001oogoo00moo`03001oogoo011T7a5oo`03001oogoo015oo`03001oogoo0<]o
o`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046@O47oo0P00
4goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@I1lUOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo
00moo`03001oogoo011T7bEoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo
0P0047oo00<007ooOol046@O9Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000G
Ool0045oo`03001oogoo00moocT00<eoo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007oo
Ool0ogoo5Woo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`3oOolFOolD00000goo
001oo`0FOol0045oo`03001oogoo0?moob]oo`03001oogoo01Eoo`00@Goo00<007ooOol0ogoo:goo
00<007ooOol05Goo0011Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol0045oool002l001Moo`00
ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00XWoo0`00CWoo0P00
TGoo002SOol00`00Oomoo`1>Ool00`00Oomoo`2?Ool009Qoo`800009Ool00000001oo`00Ool007oo
00<0009oo`<0009oo`<000=oo`8000=oo`<0009oo`<0009oo`800004Ool000000004Ool50002Ool0
0`00Ool000020003Ool20002Ool30003Ool200000goo00000002Ool00`00Ool000020003Ool01000
Oomoogoo0P0017oo0P000goo0P0000Ioo`00Ool007oo001kOol009Qoo`04001oogooOol200001Woo
001oo`00Ool0009oo`04001oogoo0004Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo
00000Woo00<007oo000017oo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Ool00004Ool0
1000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00009oo`05001oo`00Ool00002Ool00`00
Ool00004Ool01000Oomoo`000Woo00<007oo00000goo00D007oo001oo`0007]oo`00VGoo0`0000Qo
o`00Ool007oo001oo`000Woo00@007ooOol000Aoo`05001oogooOol00004Ool01P00Oomoo`00Ool0
009oo`03001oo`000080009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo000017oo
00<007ooOol00goo00D007ooOomoo`00009oo`03001oo`00009oo`05001oogooOol00002Ool00`00
Ool00003Ool01@00Oomoogoo000017oo0`0000Ioo`00Ool007oo001kOol009Uoo`04001oo`00Ool2
00000goo001oo`040003Ool01000Oomoogoo0P000Woo100000Aoo`00001oo`80009oo`<00004Ool0
00000002Ool20002Ool200000goo000000040002Ool300000goo000000020002Ool20004Ool20000
0goo000000020003Ool00`00Oomoo`0200000goo00000002Ool200000goo000000020002Ool30000
1Goo000007oo0000O7oo002JOol00`00Oomoo`0<Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool00`00
Oomoo`04Ool01000Oomoo`0047oo00<007ooOol04Goo00<007oo000037oo00<007ooOol0QWoo002I
Ool2000=Ool20004Ool00`00Oomoo`0=Ool20005Ool5000FOol00`00Oomoo`0;Ool3002EOol00?mo
ohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-6.42717, 313.265, 0.0431596, 12.6627}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 41: ",
    FontWeight->"Bold"],
  "\[CapitalUDoubleDot]bersicht \[UDoubleDot]ber die Anzahl der Terme und \
Operationen, die von der Funktion AmplitudeFunctionSystem in \
Abh\[ADoubleDot]ngigkeit der Ordnung in e erzeugt werden."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Da eine durchgehende Struktur im Gleichungssystem zum Zeitpunkt der Arbeit \
nicht bekannt war, musste der Befehl ",
  StyleBox["Simplify",
    FontSlant->"Italic"],
  " verwendet werden, um das Aussehen der Gleichungen zu vereinfachen. Dieser \
ben\[ODoubleDot]tigt viel Zeit und Speicher, da er fast alle bekannten \
Umformungen des Systems ausprobieren muss, um auf eine einfache Form zu \
kommen."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:18"],

Cell["Kap. 2.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.4. AmplitudeFunction",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:19"],

Cell["\<\
AmplitudeFunction[n] berechnet die Amplitudenfunktion n-ter Ordnung in e \
durch iteratives L\[ODoubleDot]sen des Differentialgleichungsystems \
AmplitudeFunctionSystem[n].\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:20"],

Cell[TextData[{
  "Das aus dem St\[ODoubleDot]ransatz um den Parameter e resultierende System \
AmplitudeFunctionSystem[n] besteht aus (n+1) Differentialgleichungen der Form \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(\ \)\(w\_i\^\[DoublePrime]\)\(\ \)\),
            "TraditionalForm"], "+", 
          RowBox[{"8", 
            FormBox[\(\(\ \)\(w\_i\)\(\ \)\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`\(F\_i\)(w\_0,  ... , w\_j, t)\)]],
  " mit j < i. Die allgemeine L\[ODoubleDot]sung einer solchen \
Differentialgleichung ergibt sich zu:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        FormBox[
          RowBox[{
            FormBox[
              RowBox[{
                RowBox[{
                  FormBox[
                    RowBox[{
                      FormBox[\(\(w\_i\)(t)\),
                        "TraditionalForm"], "=", \(c\_1\)}],
                    "TraditionalForm"], \(cos(2 \@ 2)\)}], "+", \(c\_2\)}],
              "TraditionalForm"], \(sin(2 \(\@ 2\) t)\)}],
          "TraditionalForm"], "-", \(w\_\(i, part\)\)}], 
      TraditionalForm]], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die L\[ODoubleDot]sungen m\[UDoubleDot]ssen gem\[ADoubleDot]\[SZ] Floquet \
- Theorie die 2\[Pi] Periodizit\[ADoubleDot]t erf\[UDoubleDot]llen, die \
Konstanten ",
  Cell[BoxData[
      \(TraditionalForm\`c\_i\)]],
  " k\[ODoubleDot]nnen daher in diesem Fall o.B.d.A. null gesetzt werden. \
\[CapitalUDoubleDot]brig bleibt es, die partikul\[ADoubleDot]re \
L\[ODoubleDot]sung mit 2\[Pi] - Periodizit\[ADoubleDot]t zu finden.  Nun  ist \
 die einzige  periodische  L\[ODoubleDot]sung,  die die Gleichung nullter \
Ordnung (",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              FormBox[\(w\_0\),
                "TraditionalForm"], "+", \(8  w\_0\)}],
            "TraditionalForm"], "-", \(w\^\(-3\)\)}], TraditionalForm]]],
  " = 0) erf\[UDoubleDot]llt, die konstante Funktion. W\[ADoubleDot]hlt man \
die nicht komplexe, nicht negative L\[ODoubleDot]sung, so erh\[ADoubleDot]lt \
man f\[UDoubleDot]r ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\(w\_0\)\(\ \)\),
            "TraditionalForm"], "=", " ", \(1/2\^\(3/4\)\)}], 
        TraditionalForm]]],
  ". Setzt man diese in die Gleichung der n\[ADoubleDot]chsten Ordnung ein, \
so erh\[ADoubleDot]lt man wiederum eine Gleichung vom Typus, wie oben \
beschrieben. Gel\[ODoubleDot]st werden diese durch den Algorithmus, ",
  StyleBox["ParticularDSolve",
    FontSlant->"Italic"],
  ", wie unten beschrieben."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:21"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["AmplitudeFunctionSystem, ParticularDSolve",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(AmplitudeFunction[n_Integer]\), ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            
            RowBox[{\({x, Y, 
                Z = {\(Subscript[w, 0]\)[t] \[Rule] 1\/2\^\(3/4\)}}\), ",", 
              RowBox[{"$Derivation", "=", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  RowBox[{\(Y = AmplitudeFunctionSystem[n]\), ",", 
                    RowBox[{"Y", "=", 
                      RowBox[{"Y", "/.", "\[InvisibleSpace]", 
                        RowBox[{"Join", "[", 
                          RowBox[{"Z", ",", 
                            RowBox[{"{", 
                              RowBox[{
                                RowBox[{
                                  RowBox[{"Subscript", "[", \(w, 0\), 
                                    SuperscriptBox["]", "\[Prime]\[Prime]",
                                      MultilineFunction->None]}], "[", "t", 
                                  "]"}], "\[Rule]", "0"}], "}"}]}], "]"}]}]}],
                     ",", \(Do[{Y = Rest[Y], 
                        x = ParticularDSolve[
                            Y\[LeftDoubleBracket]1\[RightDoubleBracket], \
\(Subscript[w, i]\)[t], t], 
                        Z = Flatten[{Z, x}], \[IndentingNewLine]x = 
                          Flatten[Table[\[PartialD]\_{t, i}x, {i, 0, 2}]], 
                        Y = Y /. \[InvisibleSpace]x}, {i, 1, n}]\), 
                    ",", \(x = 
                      SeriesData[e, 0, 
                          Table[\(Subscript[w, i]\)[t], {i, 0, n}], 0, n + 1, 
                          1] /. \[InvisibleSpace]Z\), ",", 
                    "\[IndentingNewLine]", \(AmplitudeFunction[n] = x\)}], 
                  "}"}]}]}], "]"}], "\[LeftDoubleBracket]", \(-1\), 
          "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Abgesehen vom Kern des Algorithmus ",
  StyleBox["ParticularDSolve",
    FontSlant->"Italic"],
  ", der die auftretenden Differentialgleichungen l\[ODoubleDot]st, \
\[UDoubleDot]bernimmt die Funktion die Aufgaben, die gewonnenen \
L\[ODoubleDot]sungen und deren Ableitungen in das System einzusetzen, die \
Differentialgleichung bereitzustellen und aus den einzelnen \
L\[ODoubleDot]sungen die Gesamtl\[ODoubleDot]sung in Form einer Taylorreihe \
aufzustellen. "
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(ParticularDSolve[equ_, func_, 
          var_] := \(Module[{ansatz, x, xx, 
              k = 0}, $Derivation = \[IndentingNewLine]{x = 
                  InhomogenPart[equ, func], \[IndentingNewLine]x = 
                  TrigReduce[x], \[IndentingNewLine]x = 
                  Cases[x, 
                    Sin[_] | Cos[_], \[Infinity]], \[IndentingNewLine]xx = 
                  Prepend[Union[x], 1], \[IndentingNewLine]ansatz = \(x = 
                    Plus @@ \(\((#1\ A[\(k++\)] &)\) /@ xx\)\), 
                x = Table[\[PartialD]\_{var, i}\((func \[Rule] x)\), {i, 0, 
                      DifferentialOrder[equ]}], 
                x = Rewrite[
                    equ /. \[InvisibleSpace]x], \[IndentingNewLine]x = 
                  TrigReduce[
                    x\[LeftDoubleBracket]1\[RightDoubleBracket]], \
\[IndentingNewLine]x = Collect[x, Sin[_] | Cos[_]], 
                xx = Flatten[
                    Table[Cases[{x}, 
                          A_\ xx\[LeftDoubleBracket]
                              i\[RightDoubleBracket], \[Infinity]] \
/. \[InvisibleSpace]xx\[LeftDoubleBracket]i\[RightDoubleBracket] \[Rule] 
                          1, {i, 2, Length[xx]}]], 
                x = x /. \[InvisibleSpace]Table[
                      xx\[LeftDoubleBracket]i\[RightDoubleBracket] \[Rule] 
                        0, {i, 1, Length[xx]}], 
                x = Thread[Prepend[xx, x] \[Equal] 0], 
                x = Solve[x, 
                    Table[A[n], {n, 0, k - 1}]], \[IndentingNewLine]x = 
                  ansatz /. \[InvisibleSpace]Flatten[
                      x], \[IndentingNewLine]func \[Rule] 
                  x}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Funktion ",
  StyleBox["ParticularDSolve",
    FontSlant->"Italic"],
  " l\[ODoubleDot]st eine Differentialgleichung, indem sie einen \
trigonometrischen Ansatz der gleichen Form, wie die des inhomogenen Teils der \
Gleichung aufstellt. Hierzu werden alle trigonometrischen Funktionen der Form \
(cos(n t) und sin(n t)) aus dem inhomogenen Teil extrahiert und mit freien \
Koeffizienten versehen. Der Ansatz und seine Ableitungen werden in die \
Ausgangsgleichung eingesetzt und ein daraus resultierendes Gleichungssystem \
aufgestellt. Dieses wird gel\[ODoubleDot]st, das Ergebnis hat die Form des \
Ansatzes. Die 2\[Pi]-Periodizit\[ADoubleDot]t ist auf jeden Fall erf\
\[UDoubleDot]llt, da der Ausgangspunkt f\[UDoubleDot]r den Ansatz, der \
inhomogene Teil der Gleichung, ebenfalls 2\[Pi] periodisch war.   "
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(InhomogenPart[equ_, 
          y_[t_]] := \(Module[{x}, $Derivation = {x = DifferentialOrder[equ], 
                x = Table[\[PartialD]\_{t, i}\((y[t] \[Rule] 0)\), {i, 0, 
                      x}], x = equ /. \[InvisibleSpace]x, x = Rewrite[x], 
                x\[LeftDoubleBracket]1\[RightDoubleBracket]}]\)\
\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Der inhomogene Anteil der Gleichung wird durch ",
  StyleBox["InhomogenPart ",
    FontSlant->"Italic"],
  "bestimmt:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      InterpretationBox[GridBox[{
            {GridBox[{
                  {\(Rewrite[equ_Equal] := 
                      equ\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                          equ\[LeftDoubleBracket]2\[RightDoubleBracket] \
\[Equal] 0\)}
                  },
                GridBaseline->{Baseline, {1, 1}},
                ColumnWidths->0.999,
                ColumnAlignments->{Left}]}
            },
          GridBaseline->{Baseline, {1, 1}},
          ColumnAlignments->{Left}],
        Definition[ "Rewrite"],
        Editable->False],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(DifferentialOrder[exp_]\), ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            RowBox[{\({tmp = exp, i = 1}\), ",", 
              RowBox[{"$Derivation", "=", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"While", "[", 
                      RowBox[{
                        RowBox[{
                          RowBox[{"MemberQ", "[", 
                            RowBox[{"tmp", ",", 
                              RowBox[{
                                SuperscriptBox["_", 
                                  TagBox[\((i)\),
                                    Derivative],
                                  MultilineFunction->None], "[", "_", "]"}], 
                              ",", "\[Infinity]"}], "]"}], "||", 
                          RowBox[{"MemberQ", "[", 
                            RowBox[{"tmp", ",", 
                              RowBox[{
                                SuperscriptBox["_", 
                                  TagBox[\((_)\),
                                    Derivative],
                                  MultilineFunction->None], "[", "_", "]"}], 
                              ",", "\[Infinity]"}], "]"}]}], ",", 
                        RowBox[{"{", 
                          RowBox[{
                            RowBox[{"tmp", "=", 
                              RowBox[{"tmp", "/.", "\[InvisibleSpace]", 
                                RowBox[{
                                  RowBox[{
                                    SuperscriptBox["_", 
                                      TagBox[\((i)\),
                                        Derivative],
                                      MultilineFunction->None], "[", "_", 
                                    "]"}], "\[Rule]", "NULL"}]}]}], 
                            ",", \(i++\)}], "}"}]}], "]"}], ",", 
                    "\[IndentingNewLine]", \($Result = i - 1\)}], "}"}]}]}], 
            "]"}], "\[LeftDoubleBracket]", \(-1\), 
          "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["DifferentialOrder ",
    FontSlant->"Italic"],
  "bestimmt die h\[ODoubleDot]chste Ableitung der Gleichung. In unserem Fall \
ist diese zwei. Um die Funktionen jedoch auch f\[UDoubleDot]r \
sp\[ADoubleDot]tere Zwecke einsetzen zu k\[ODoubleDot]nnen, wurden diese, \
soweit es m\[ODoubleDot]glich war, f\[UDoubleDot]r einen allgemeineren Zweck \
geschrieben. Der Algorithmus ist somit auch bei Gleichungen mit \
h\[ODoubleDot]heren Ableitungen einsetzbar."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:22"],

Cell[TextData[{
  "Der Algorithmus arbeitet sehr schnell, wenn man bedenkt, dass die \
Gleichungen, die gel\[ODoubleDot]st werden sollen, aus einer Unzahl an Termen \
besteht. Zudem w\[ADoubleDot]chst die Anzahl der Operationen mit zunehmender \
Ordnung exponentiell an, was sich direkt auf die Komplexit\[ADoubleDot]t des \
inhomogenen Teiles der Gleichungen auswirkt. Zudem k\[ODoubleDot]nnen \
aufgrund des rekursiven Charakters des Systems erst w\[ADoubleDot]hrend der \
Laufzeit der Funktion eventuelle Vereinfachungen durchgef\[UDoubleDot]hrt \
werden. Diese beschr\[ADoubleDot]nken sich jedoch zum Gl\[UDoubleDot]ck auf \
das Vereinfachen von trigonometrischen Termen. Mit jeder Ordnung, daher jeder \
weiteren Gleichung im System, gegeben durch ",
  StyleBox["AmplitudeFunctionSystem,",
    FontSlant->"Italic"],
  "  kommen aufgrund der Produkte aus den vorherigen L\[ODoubleDot]sungen \
neue Terme mit weiteren trigonometrischen Argumenten hinzu."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Anzahl der Terme und Operationen nimmt nur schwach exponentiell mit \
wachsender Ordnung zu. Es ist daher ohne weiteres m\[ODoubleDot]glich, f\
\[UDoubleDot]r genauere Analysen gr\[ODoubleDot]\[SZ]ere Ordnungen zu \
verwenden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.0022726 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .12835 -15.125 -5.8125 ]
[-0.0125 .12835 0 5.8125 ]
[-0.0125 .24198 -20.6875 -5.8125 ]
[-0.0125 .24198 0 5.8125 ]
[-0.0125 .35561 -20.6875 -5.8125 ]
[-0.0125 .35561 0 5.8125 ]
[-0.0125 .46924 -20.6875 -5.8125 ]
[-0.0125 .46924 0 5.8125 ]
[-0.0125 .58287 -20.6875 -5.8125 ]
[-0.0125 .58287 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32.3125 -7.5625 ]
[-0.01875 .30902 -20.6875 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -49.375 0 ]
[.5 .63053 49.375 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12835 m
.00625 .12835 L
s
gsave
-0.0125 .12835 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .24198 m
.00625 .24198 L
s
gsave
-0.0125 .24198 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .35561 m
.00625 .35561 L
s
gsave
-0.0125 .35561 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
0 .46924 m
.00625 .46924 L
s
gsave
-0.0125 .46924 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .58287 m
.00625 .58287 L
s
gsave
-0.0125 .58287 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03744 m
.00375 .03744 L
s
0 .06017 m
.00375 .06017 L
s
0 .08289 m
.00375 .08289 L
s
0 .10562 m
.00375 .10562 L
s
0 .15107 m
.00375 .15107 L
s
0 .1738 m
.00375 .1738 L
s
0 .19652 m
.00375 .19652 L
s
0 .21925 m
.00375 .21925 L
s
0 .2647 m
.00375 .2647 L
s
0 .28743 m
.00375 .28743 L
s
0 .31015 m
.00375 .31015 L
s
0 .33288 m
.00375 .33288 L
s
0 .37833 m
.00375 .37833 L
s
0 .40106 m
.00375 .40106 L
s
0 .42378 m
.00375 .42378 L
s
0 .44651 m
.00375 .44651 L
s
0 .49196 m
.00375 .49196 L
s
0 .51469 m
.00375 .51469 L
s
0 .53741 m
.00375 .53741 L
s
0 .56014 m
.00375 .56014 L
s
0 .60559 m
.00375 .60559 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95.0625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -110.375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.188 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(AmplitudeFunction) show
157.750 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .01926 L
.06923 .01926 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .01926 L
.06923 .01926 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .02153 L
.14615 .02153 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .02153 L
.14615 .02153 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .02381 L
.22308 .02381 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .02381 L
.22308 .02381 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .02608 L
.3 .02608 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .02608 L
.3 .02608 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .02835 L
.37692 .02835 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .02835 L
.37692 .02835 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .03062 L
.45385 .03062 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .03062 L
.45385 .03062 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .0329 L
.53077 .0329 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .0329 L
.53077 .0329 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .03517 L
.60769 .03517 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .03517 L
.60769 .03517 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .03744 L
.68462 .03744 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .03744 L
.68462 .03744 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .03971 L
.76154 .03971 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .03971 L
.76154 .03971 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .04199 L
.83846 .04199 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .04199 L
.83846 .04199 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .04426 L
.91538 .04426 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .04426 L
.91538 .04426 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .04653 L
.99231 .04653 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .04653 L
.99231 .04653 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .01926 m
.00769 .02153 L
.06923 .02153 L
.06923 .01926 L
F
0 g
.00769 .01926 m
.00769 .02153 L
.06923 .02153 L
.06923 .01926 L
.00769 .01926 L
s
.8 1 0 r
.08462 .02153 m
.08462 .02608 L
.14615 .02608 L
.14615 .02153 L
F
0 g
.08462 .02153 m
.08462 .02608 L
.14615 .02608 L
.14615 .02153 L
.08462 .02153 L
s
.8 1 0 r
.16154 .02381 m
.16154 .0329 L
.22308 .0329 L
.22308 .02381 L
F
0 g
.16154 .02381 m
.16154 .0329 L
.22308 .0329 L
.22308 .02381 L
.16154 .02381 L
s
.8 1 0 r
.23846 .02608 m
.23846 .03971 L
.3 .03971 L
.3 .02608 L
F
0 g
.23846 .02608 m
.23846 .03971 L
.3 .03971 L
.3 .02608 L
.23846 .02608 L
s
.8 1 0 r
.31538 .02835 m
.31538 .0488 L
.37692 .0488 L
.37692 .02835 L
F
0 g
.31538 .02835 m
.31538 .0488 L
.37692 .0488 L
.37692 .02835 L
.31538 .02835 L
s
.8 1 0 r
.39231 .03062 m
.39231 .05789 L
.45385 .05789 L
.45385 .03062 L
F
0 g
.39231 .03062 m
.39231 .05789 L
.45385 .05789 L
.45385 .03062 L
.39231 .03062 L
s
.8 1 0 r
.46923 .0329 m
.46923 .06926 L
.53077 .06926 L
.53077 .0329 L
F
0 g
.46923 .0329 m
.46923 .06926 L
.53077 .06926 L
.53077 .0329 L
.46923 .0329 L
s
.8 1 0 r
.54615 .03517 m
.54615 .08062 L
.60769 .08062 L
.60769 .03517 L
F
0 g
.54615 .03517 m
.54615 .08062 L
.60769 .08062 L
.60769 .03517 L
.54615 .03517 L
s
.8 1 0 r
.62308 .03744 m
.62308 .09426 L
.68462 .09426 L
.68462 .03744 L
F
0 g
.62308 .03744 m
.62308 .09426 L
.68462 .09426 L
.68462 .03744 L
.62308 .03744 L
s
.8 1 0 r
.7 .03971 m
.7 .10789 L
.76154 .10789 L
.76154 .03971 L
F
0 g
.7 .03971 m
.7 .10789 L
.76154 .10789 L
.76154 .03971 L
.7 .03971 L
s
.8 1 0 r
.77692 .04199 m
.77692 .1238 L
.83846 .1238 L
.83846 .04199 L
F
0 g
.77692 .04199 m
.77692 .1238 L
.83846 .1238 L
.83846 .04199 L
.77692 .04199 L
s
.8 1 0 r
.85385 .04426 m
.85385 .13971 L
.91538 .13971 L
.91538 .04426 L
F
0 g
.85385 .04426 m
.85385 .13971 L
.91538 .13971 L
.91538 .04426 L
.85385 .04426 L
s
.8 1 0 r
.93077 .04653 m
.93077 .15789 L
.99231 .15789 L
.99231 .04653 L
F
0 g
.93077 .04653 m
.93077 .15789 L
.99231 .15789 L
.99231 .04653 L
.93077 .04653 L
s
0 1 .4 r
.00769 .02153 m
.00769 .02153 L
.06923 .02153 L
.06923 .02153 L
F
0 g
.00769 .02153 m
.00769 .02153 L
.06923 .02153 L
.06923 .02153 L
.00769 .02153 L
s
0 1 .4 r
.08462 .02608 m
.08462 .03062 L
.14615 .03062 L
.14615 .02608 L
F
0 g
.08462 .02608 m
.08462 .03062 L
.14615 .03062 L
.14615 .02608 L
.08462 .02608 L
s
0 1 .4 r
.16154 .0329 m
.16154 .03971 L
.22308 .03971 L
.22308 .0329 L
F
0 g
.16154 .0329 m
.16154 .03971 L
.22308 .03971 L
.22308 .0329 L
.16154 .0329 L
s
0 1 .4 r
.23846 .03971 m
.23846 .05108 L
.3 .05108 L
.3 .03971 L
F
0 g
.23846 .03971 m
.23846 .05108 L
.3 .05108 L
.3 .03971 L
.23846 .03971 L
s
0 1 .4 r
.31538 .0488 m
.31538 .06244 L
.37692 .06244 L
.37692 .0488 L
F
0 g
.31538 .0488 m
.31538 .06244 L
.37692 .06244 L
.37692 .0488 L
.31538 .0488 L
s
0 1 .4 r
.39231 .05789 m
.39231 .07608 L
.45385 .07608 L
.45385 .05789 L
F
0 g
.39231 .05789 m
.39231 .07608 L
.45385 .07608 L
.45385 .05789 L
.39231 .05789 L
s
0 1 .4 r
.46923 .06926 m
.46923 .08971 L
.53077 .08971 L
.53077 .06926 L
F
0 g
.46923 .06926 m
.46923 .08971 L
.53077 .08971 L
.53077 .06926 L
.46923 .06926 L
s
0 1 .4 r
.54615 .08062 m
.54615 .10562 L
.60769 .10562 L
.60769 .08062 L
F
0 g
.54615 .08062 m
.54615 .10562 L
.60769 .10562 L
.60769 .08062 L
.54615 .08062 L
s
0 1 .4 r
.62308 .09426 m
.62308 .12153 L
.68462 .12153 L
.68462 .09426 L
F
0 g
.62308 .09426 m
.62308 .12153 L
.68462 .12153 L
.68462 .09426 L
.62308 .09426 L
s
0 1 .4 r
.7 .10789 m
.7 .13971 L
.76154 .13971 L
.76154 .10789 L
F
0 g
.7 .10789 m
.7 .13971 L
.76154 .13971 L
.76154 .10789 L
.7 .10789 L
s
0 1 .4 r
.77692 .1238 m
.77692 .15789 L
.83846 .15789 L
.83846 .1238 L
F
0 g
.77692 .1238 m
.77692 .15789 L
.83846 .15789 L
.83846 .1238 L
.77692 .1238 L
s
0 1 .4 r
.85385 .13971 m
.85385 .17834 L
.91538 .17834 L
.91538 .13971 L
F
0 g
.85385 .13971 m
.85385 .17834 L
.91538 .17834 L
.91538 .13971 L
.85385 .13971 L
s
0 1 .4 r
.93077 .15789 m
.93077 .1988 L
.99231 .1988 L
.99231 .15789 L
F
0 g
.93077 .15789 m
.93077 .1988 L
.99231 .1988 L
.99231 .15789 L
.93077 .15789 L
s
0 .4 1 r
.00769 .02153 m
.00769 .02608 L
.06923 .02608 L
.06923 .02153 L
F
0 g
.00769 .02153 m
.00769 .02608 L
.06923 .02608 L
.06923 .02153 L
.00769 .02153 L
s
0 .4 1 r
.08462 .03062 m
.08462 .04199 L
.14615 .04199 L
.14615 .03062 L
F
0 g
.08462 .03062 m
.08462 .04199 L
.14615 .04199 L
.14615 .03062 L
.08462 .03062 L
s
0 .4 1 r
.16154 .03971 m
.16154 .05789 L
.22308 .05789 L
.22308 .03971 L
F
0 g
.16154 .03971 m
.16154 .05789 L
.22308 .05789 L
.22308 .03971 L
.16154 .03971 L
s
0 .4 1 r
.23846 .05108 m
.23846 .07835 L
.3 .07835 L
.3 .05108 L
F
0 g
.23846 .05108 m
.23846 .07835 L
.3 .07835 L
.3 .05108 L
.23846 .05108 L
s
0 .4 1 r
.31538 .06244 m
.31538 .0988 L
.37692 .0988 L
.37692 .06244 L
F
0 g
.31538 .06244 m
.31538 .0988 L
.37692 .0988 L
.37692 .06244 L
.31538 .06244 L
s
0 .4 1 r
.39231 .07608 m
.39231 .1238 L
.45385 .1238 L
.45385 .07608 L
F
0 g
.39231 .07608 m
.39231 .1238 L
.45385 .1238 L
.45385 .07608 L
.39231 .07608 L
s
0 .4 1 r
.46923 .08971 m
.46923 .1488 L
.53077 .1488 L
.53077 .08971 L
F
0 g
.46923 .08971 m
.46923 .1488 L
.53077 .1488 L
.53077 .08971 L
.46923 .08971 L
s
0 .4 1 r
.54615 .10562 m
.54615 .17834 L
.60769 .17834 L
.60769 .10562 L
F
0 g
.54615 .10562 m
.54615 .17834 L
.60769 .17834 L
.60769 .10562 L
.54615 .10562 L
s
0 .4 1 r
.62308 .12153 m
.62308 .20789 L
.68462 .20789 L
.68462 .12153 L
F
0 g
.62308 .12153 m
.62308 .20789 L
.68462 .20789 L
.68462 .12153 L
.62308 .12153 L
s
0 .4 1 r
.7 .13971 m
.7 .24198 L
.76154 .24198 L
.76154 .13971 L
F
0 g
.7 .13971 m
.7 .24198 L
.76154 .24198 L
.76154 .13971 L
.7 .13971 L
s
0 .4 1 r
.77692 .15789 m
.77692 .27606 L
.83846 .27606 L
.83846 .15789 L
F
0 g
.77692 .15789 m
.77692 .27606 L
.83846 .27606 L
.83846 .15789 L
.77692 .15789 L
s
0 .4 1 r
.85385 .17834 m
.85385 .3147 L
.91538 .3147 L
.91538 .17834 L
F
0 g
.85385 .17834 m
.85385 .3147 L
.91538 .3147 L
.91538 .17834 L
.85385 .17834 L
s
0 .4 1 r
.93077 .1988 m
.93077 .35333 L
.99231 .35333 L
.99231 .1988 L
F
0 g
.93077 .1988 m
.93077 .35333 L
.99231 .35333 L
.99231 .1988 L
.93077 .1988 L
s
.8 0 1 r
.00769 .02608 m
.00769 .02835 L
.06923 .02835 L
.06923 .02608 L
F
0 g
.00769 .02608 m
.00769 .02835 L
.06923 .02835 L
.06923 .02608 L
.00769 .02608 L
s
.8 0 1 r
.08462 .04199 m
.08462 .05562 L
.14615 .05562 L
.14615 .04199 L
F
0 g
.08462 .04199 m
.08462 .05562 L
.14615 .05562 L
.14615 .04199 L
.08462 .04199 L
s
.8 0 1 r
.16154 .05789 m
.16154 .08062 L
.22308 .08062 L
.22308 .05789 L
F
0 g
.16154 .05789 m
.16154 .08062 L
.22308 .08062 L
.22308 .05789 L
.16154 .05789 L
s
.8 0 1 r
.23846 .07835 m
.23846 .11471 L
.3 .11471 L
.3 .07835 L
F
0 g
.23846 .07835 m
.23846 .11471 L
.3 .11471 L
.3 .07835 L
.23846 .07835 L
s
.8 0 1 r
.31538 .0988 m
.31538 .1488 L
.37692 .1488 L
.37692 .0988 L
F
0 g
.31538 .0988 m
.31538 .1488 L
.37692 .1488 L
.37692 .0988 L
.31538 .0988 L
s
.8 0 1 r
.39231 .1238 m
.39231 .19198 L
.45385 .19198 L
.45385 .1238 L
F
0 g
.39231 .1238 m
.39231 .19198 L
.45385 .19198 L
.45385 .1238 L
.39231 .1238 L
s
.8 0 1 r
.46923 .1488 m
.46923 .23516 L
.53077 .23516 L
.53077 .1488 L
F
0 g
.46923 .1488 m
.46923 .23516 L
.53077 .23516 L
.53077 .1488 L
.46923 .1488 L
s
.8 0 1 r
.54615 .17834 m
.54615 .28743 L
.60769 .28743 L
.60769 .17834 L
F
0 g
.54615 .17834 m
.54615 .28743 L
.60769 .28743 L
.60769 .17834 L
.54615 .17834 L
s
.8 0 1 r
.62308 .20789 m
.62308 .3397 L
.68462 .3397 L
.68462 .20789 L
F
0 g
.62308 .20789 m
.62308 .3397 L
.68462 .3397 L
.68462 .20789 L
.62308 .20789 L
s
.8 0 1 r
.7 .24198 m
.7 .40106 L
.76154 .40106 L
.76154 .24198 L
F
0 g
.7 .24198 m
.7 .40106 L
.76154 .40106 L
.76154 .24198 L
.7 .24198 L
s
.8 0 1 r
.77692 .27606 m
.77692 .46242 L
.83846 .46242 L
.83846 .27606 L
F
0 g
.77692 .27606 m
.77692 .46242 L
.83846 .46242 L
.83846 .27606 L
.77692 .27606 L
s
.8 0 1 r
.85385 .3147 m
.85385 .53287 L
.91538 .53287 L
.91538 .3147 L
F
0 g
.85385 .3147 m
.85385 .53287 L
.91538 .53287 L
.91538 .3147 L
.85385 .3147 L
s
.8 0 1 r
.93077 .35333 m
.93077 .60332 L
.99231 .60332 L
.99231 .35333 L
F
0 g
.93077 .35333 m
.93077 .60332 L
.99231 .60332 L
.99231 .35333 L
.93077 .35333 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
dWoo00<007ooOol01Woo00<007ooOol0Z7oo003AOol00`00Oomoo`08Ool00`00Oomoo`2WOol00<ao
o`80009oo`03001oogoo00Aoo`8000Aoo`03001oogoo0:Ioo`00bgoo00H007ooOol007oo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`2VOol00<]oo`06001oogoo001oo`001Goo0`0017oo00<007ooOol0
YWoo003;Ool01P00Oomoo`00Ool000Eoo`<000Aoo`03001oogoo0:Ioo`00bgoo00@007ooOol0009o
o`03001oogoo00Qoo`03001oogoo0:Moo`00c7oo0P0017oo00<007ooOol01Woo00<007ooOol0Z7oo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00Agoo1@004goo0`0057oo0P00
5goo0`0057oo00<007ooOol04goo0P005Woo00<007ooOol057oo00<007ooOol04goo0P004Woo1@00
0Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000ioo`D00003Ool0000002Aoo`00BGoo00<0
07ooOol04goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol04Woo00<007oo000057oo00<0
07oo00005Goo00<007ooOol04goo00<007oo00005Woo00<007ooOol04Goo00L007ooOomoo`00Ool0
000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<0
07ooOol08Goo0019Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol4000EOol00`00
Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00Ool0000EOol2000COol01`00Oomoogoo
001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo029oo`00BGoo00<007ooOol057oo00<007ooOol05Goo00<007ooOol0
4goo00<007oo000057oo0P005Goo0P005goo00<007ooOol04goo00<007ooOol04goo00<007oo0000
4goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0QOol004Uoo`03001oogoo01=oo`03001oo`00
01Aoo`03001oo`0001Ioo`8001Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`03001oo`0001=oo`07001oogooOol007oo000047oo00<007ooOol00Woo00<007oo
Ool03goo00L007ooOomoo`00Ool0000@Ool01`00Oomoogoo001oo`0002=oo`00B7oo0P005Woo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol04Woo0`005Goo0P0057oo0`005Goo00<007ooOol0
57oo0P004Woo0P0017oo00<007ooOol03Woo0P000goo0P0047oo0P0017oo00<007ooOol03Woo0P00
17oo00<007ooOol08Woo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00?Woo
o`00;`006Woo000nOol00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`08
Ool00`00Oomoo`0HOol003ioo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo00Qoo`03001oogoo01Qoo`00=Goo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
67oo000dOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0HOol003Aoo`03001oo`00
00Moool002l001Yoo`00=7oo00<007oo00001goo00<007ooOol04`0017oo00<007`0O0003g`000<0
07ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l
0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l
000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomo
ogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003001oo`0001Yo
o`00=7oo00<007oo00001goo00<007ooOol04`0017oo4`0017oo4`0017oo00<007`0O00047`000D0
07ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomo
o`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l
000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml
0003001oo`0001Yoo`00=Goo00<007ooOol01Woo00<007ooOol04`0017oo4`0017oo00<006OPIn00
3fOP00<007ooOol00Woo50000goo00<007`0O00047`000D007ooOomoo`00019l0003001oogoo009o
o`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml
0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<0
07ooOol00Woo00<007`0O0003g`000<007oo00006Woo000nOol00`00Oomoo`0C0004OolC0004Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001000Oomoogoo50000goo500017oo00<0
07`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<0
07ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomo
o`02Ool00`00O01l000?O0000`00Ool0000JOol003ioo`03001oogoo01Moo`030001W`6O00l1W`03
001oogoo009ooa<000Aoo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007ooOol00Woo4`0017oo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02
Ool00`00O01l000?O0000`00Ool0000JOol003ioo`03001oogoo01Moo`030001W`6O00l1W`03001o
ogoo009oo`030003k0?/00l3k003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn00
1@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo4`0017oo00<0
07`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0
000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Ool0000JOol003ioo`8001Qoo`030001W`6O
00l1W`03001oogoo009ooa<000Aooa@000=oo`03001Wh6OP011Wh005001oogooOol0000BIn000`00
Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02OolC0004
OolD0003Ool00`00O01l000@O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`0
00<007oo00006Woo000nOol00`00Oomoo`0GOolC0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000n`3k00@0n`01@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001W
h6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001o
ogoo009oo`03001Wh6OP011Wh004001oogooOolD0003Ool00`00O01l000@O0000`00Oomoo`02Ool0
0`00O01l000?O0000`00Ool0000JOol003ioo`03001oogoo01Moo`03001T7f@O00mT7`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000BIn001@00
Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00
019Wh004001oogooOolD0004OolC00000goo001oo`0IOol003ioo`03001oogoo01Moo`03001T7f@O
00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k004001oogoo
OolD0003Ool00`00In1Wh00@In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00
In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00
Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`00
01Yoo`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo50000goo00<000?/0n`040?/00D007ooOomoo`00019Wh003001oogoo009oo`03001W
h6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001o
ogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol0
0Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`0GOolC0004Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomoo`00019Wh003
001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03
001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo
00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol2000_OolC0004Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P?/00@007ooOomooa@000Aoo`03001Wh6OP00mWh003001o
ogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001W
h6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn00
3fOP00<007oo00006Woo000nOol00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01000Oomoogoo50000goo00<000?/0n`040?/00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo
00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00
In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007ooOol00Woo00<0
06OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomo
o`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007oo
Ool00Woo4`0017oo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo
00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00
In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007ooOol00Woo00<0
00?/0n`03`?/00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomo
o`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01000Oomoogoo500017oo00<000?/
0n`03`?/00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007oo
Ool00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo02ioo`03001T7f@O00mT7`03001o
ogoo009ooa@000=oo`030001W`6O0101W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3
k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomo
o`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009o
o`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo0P00;goo4`0017oo00<006@OI1l046@O00D007oo
Oomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
OolC0004Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP
00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<0
07ooOol0AGoo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019W
h003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0AGoo00<006@O
I1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02OolC0004Ool00`00
0n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00
Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`00
01Yoo`00?Woo00<007ooOol0AGoo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomo
o`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D0
07ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007oo
Ool0AGoo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02OolC0004Ool00`00
In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP
00mWh003001oo`0001Yoo`00?Woo00<007ooOol0AGoo00<006@OI1l046@O00@007ooOomooa@000=o
o`030001W`6O0101W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3
k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0
000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000n
Ool00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`03
0003k0?/00l3k003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo
00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol20016Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009ooa<000Aoo`030003k0?/00l3k003001oogoo009oo`03001Wh6OP011Wh005001o
ogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo0000
6Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
0181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030003k0?/00l3k003001oogoo009ooa@000=oo`03001Wh6OP011Wh005001oogooOol0000B
In000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo04Eoo`03001T
7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol0
0Woo00<000?/0n`040?/00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Ool0000JOol003ioo`03001oogoo04Eooa@000=oo`03001T7f@O011T7`05
001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo
00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00
?Woo00<007ooOol0G7oo00<006@OI1l046@O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001o
ogoo009oo`030003k0?/0103k005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007ooOol0
0Woo00<006OPIn003fOP00<007oo00006Woo000_Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`1LOol00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo4`0017oo00<000?/0n`040?/00D007oo
Oomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000J
Ool002ioo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo05aoo`03001T7f@O011T7`04001o
ogooOolD0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00@0n`01000Oomoogoo50000goo00<006OPIn00
46OP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000`Ool01P00Oomoo`00Ool000Qo
o`<005aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00019Wh003001oogoo009oo`03001W
h6OP00mWh003001oo`0001Yoo`00;Woo0P000goo00<007oo000027oo00<007ooOol0G7oo00<006@O
I1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005
001oogooOol0000B0n`01@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo
00006Woo000^Ool00`00Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`1LOol00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`040?/00D007ooOomo
o`000183k005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol0
02ioo`<000=oo`03001oogoo00Moo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02OolD0003Ool00`000n`3k00@0n`01000Oomoogoo500017oo
00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`1LOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183
k005001oogooOol0000B0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000JOol003ioo`03
001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oogoo009oo`03
001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0G7oo50000goo00<006@OI1l046@O00<0
07ooOol00Woo4`0017oo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool0
0`00In1Wh00?In000`00Ool0000JOol003ioo`8007Aoo`03001T7f@O011T7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo
Ool00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`1cOol00`00I1mT7`0@I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P?/00D007ooOomo
o`000183k003001oogoo009oo`03001Wh6OP00mWh003001oo`0001Yoo`00?Woo00<007ooOol0Lgoo
00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00@007ooOomooa@0
00=oo`030003k0?/0103k003001oogoo009ooa<00003Ool007oo01Uoo`00?Woo00<007ooOol0Lgoo
00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`00
0181W`05001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol003io
o`03001oogoo07=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<0
07oo00006Woo000nOol00`00Oomoo`1cOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oogoo009oo`03
0003k0?/00l3k003001oo`0001Yoo`00?Woo00<007ooOol0Lgoo00<006@OI1l046@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0n`0
0`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol003ioo`8007Aoo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo
00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00Oomoo`1cOol0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02OolC0004Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00@007ooOomooa@000Ao
o`030003k0?/00l3k003001oo`0001Yoo`00?Woo00<007ooOol0Lgoo00<006@OI1l046@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B
0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol003ioo`03001oogoo07=oo`03001T
7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00
Oomoo`1cOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00
Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030003k0?/00l3k003001oo`00
01Yoo`00?Woo00<007ooOol0Lgoo500017oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol0
03ioo`8008aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo
00004P6O00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol00`00Oomoo`2;Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
ogoo009ooa<00003Ool007oo01Uoo`00?Woo00<007ooOol0Rgoo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Ool0000JOol003ioo`03001oogoo08]oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo
000nOol00`00Oomoo`2;Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02OolC0004Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0Rgoo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo08]oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07oo00006Woo000nOol2002<Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<0
07ooOol0Rgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo08]oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`2;Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0Rgoo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O
00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Ool0000JOol003ioo`03001oogoo08]ooa<000Aoo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000XOol50002Ool00`00Oomoo`02
Ool00`00Oomoo`07Ool00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool0
0`00Ool00008Ool3002ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02OolD0003Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007oo00006Woo000ZOol01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`03001oogoo
0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
011T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O
00<007oo00006Woo000ZOol01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`03001oogoo0:9o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T
7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07oo00006Woo000ZOol01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`03001oogoo0:9oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05
001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
00006Woo000YOol20004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2ROol00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yo
o`00?Woo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol2002S
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03
001oo`0001Yoo`00?Woo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo
000nOol00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0@I1l01000Oomoogoo50000goo00<0006O0Il0406O00<007ooOol00Woo00<0
006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0
XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O
00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol2002SOolC0004Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0^Goo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol001]oo`03001oogoo009oo`03001o
ogoo01]oo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo0000
6Woo000KOol6000MOol00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03
001oo`0001Yoo`0077oo0P000Woo00<007ooOol06goo00<007ooOol0^Goo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Ool0000JOol001]oo`03001oogoo008001ioo`03001oogoo0;Uo
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000KOol6000MOol00`00
Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`007Goo00D0
07oo001oo`0001aoo`800;Yoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo0000
6Woo000LOol5000MOol00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00@007ooOomooa@000Aoo`030001W`6O00l1W`03001oo`0001Yoo`00
6goo00L007oo001oo`00Ool0000LOol00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001
W`6O00l1W`03001oo`0001Yoo`0077oo1@007Goo00<007ooOol0^Goo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Ool0000JOol001]oo`05001oo`00Ool0000NOol00`00Oomoo`2iOol0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0^Goo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0;Uo
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol2002jOol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
019T7`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0^Goo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0;Uooa<0
00Aoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo
00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`3@Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yo
o`00?Woo00<007ooOol057oo=`00QGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol002Qoo`D0009oo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo019oocT008Eoo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000Z
Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`<0019oo`03001oogoo03Eoo`03001oogoo
08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo
4`0000=oo`00Ool06Goo000ZOol00`00Oomoo`03Ool01P00Oomoo`00Ool000Qoo`03001oogoo019o
o`03001oogoo03Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000ZOol01000Oomoogoo
0P000goo00<007oo000027oo00<007ooOol04Woo00<007ooOol047`09Goo00<007ooOol0Pgoo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Ool0000JOol002Yoo`05001oogooOol00004Ool00`00Ool00008Ool00`00Oomoo`0B
Ool00`00Oomoo`0@O00UOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Goo0P000goo
0`000goo00<007ooOol01goo00<007ooOol04Woo00<007ooOol047`02goo0P0067oo00<007ooOol0
Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011l00aoo`03001o
ogoo01Ioo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@O006Ool20004Ool01`00Oomoo`00Ool007oo00D000eoo`03001oogoo08=oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O
00<007oo00006Woo000nOol2000COol00`00Oomoo`0@O008Ool03P00Oomoo`00Ool007oo001oo`00
Ool007oo0002Ool00`00Oomoo`0:Ool00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo
00<007ooOol04Woo00<007ooOol047`01goo00l007ooOomoo`00Ool007oo001oo`00Ool007oo0000
0Woo00<007ooOol02Woo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo
019oo`03001oogoo011l00Moo`800004Ool00000Ool4000017oo001oogoo0`003Goo00<007ooOol0
Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011l01Eoo`03001o
ogoo00eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@O00DOol2000?Ool00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007oo
Ool04Woo00<007ooOol047`09Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03
001oogoo019oo`03001oogoo011l02Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool2000COol00`00Oomoo`0@O00UOol00`00Oomoo`23OolD0003Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0B
Ool00`00Oomoo`0eOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol0
0`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0UOol00`00Oomoo`2JOol0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo0000
6Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0FOol2000=Ool00`00Oomoo`2JOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0@In0HOol00`00Oomoo`0:Ool00`00Oomoo`2JOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0@In07Ool20002Ool30002Ool30003Ool3000<Ool00`00Oomo
o`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol2000COol00`00Oomoo`0@In06Ool01000Oomoo`000Woo00<007ooOol00Woo
00D007ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo09Yoo`03001T7f@O011T7`05001oogoo
Ool0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019o
o`03001oogoo011Wh0Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool00`00
Oomoo`0:Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo
00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In05Ool40002
Ool400000goo00000004Ool3000<Ool00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@In06Ool00`00Oomoo`0LOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@In0AOol00`00Oomoo`0AOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0UOol0
0`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007oo00006Woo000nOol2000COol00`00Oomoo`0@In0UOol00`00Oomoo`2JOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol0
0`00Oomoo`0eOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0n`UOol0
0`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0n`UOol00`00Oomoo`2JOol0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo0000
6Woo000YOol30003Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0@
0n`<Ool00`00Oomoo`0FOol00`00Oomoo`2JOolD0003Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol002Uoo`03001oogoo009oo`03001oo`00009oo`03001oo`00
00Qoo`03001oogoo019oo`03001oogoo0103k0Ioo`@0009oo`04001oogooOol4000AOol00`00Oomo
o`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`07
001oogooOol007oo00000Woo00<007oo000027oo0`004Woo00<007ooOol040?/1Woo0`0000=oo`00
00000`000Woo00@007ooOol0011oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03
001T7f@O00mT7`03001oo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool00`00Ool00008Ool0
0`00Oomoo`0BOol00`00Oomoo`0@0n`8Ool01@00Oomoogoo000017oo00@007ooOol0011oo`03001o
ogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Goo
00<007oo00000Woo00<007oo00000Woo00<007oo000027oo00<007ooOol04Woo00<007ooOol040?/
1goo0P000goo00<007ooOol00Woo0`004Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000ZOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0@0n`AOol00`00Oomoo`0AOol00`00Oomoo`2aOol0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo
019oo`03001oogoo0103k11oo`8001=oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009o
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol040?/9Goo00<0
07ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool2000COol00`00Oomoo`0@0n`UOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo0103k2Eoo`03001o
ogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo
00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo
00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomo
o`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03
001oogoo019oo`03001oogoo0101WbEoo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009o
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O9Goo00<0
07ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool00`00Oomoo`0BOol00`00Oomoo`0@0IlUOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`8001=oo`03001oogoo0101WbEoo`03001o
ogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo
00<007ooOol04Woo00<007ooOol0406O1Woo10001Woo10004Goo00<007ooOol0/Goo00<006@OI1l0
46@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00
Oomoo`0@0Il6Ool30008Ool01000Oomoo`0047oo00<007ooOol0/Goo00<006@OI1l046@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0Il8
Ool00`00Oomoo`06Ool01000Oomoo`0047oo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0Il7Ool2
0002Ool00`00Ool00003Ool3000AOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo0101W`aoo`03001o
ogoo009oo`03001oogoo015oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O37oo00@007ooOomo
o`8001=oo`03001oogoo0;5ooa@000Aoo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo0P004goo
00<007ooOol0406O9Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00
Oomoo`0BOol00`00Oomoo`0@0IlUOol00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol0
03ioo`03001oogoo019oo`03001oogoo03Eoo`03001oogoo0<Uoo`03001T7f@O00mT7`03001oo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0bGoo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`39Ool00`00I1mT
7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011T7bEoo`03001oogoo0<Uo
o`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<0
07ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol2000COol00`00Oomoo`0@I1lUOol0
0`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo
011T7`Ioo`@00004Ool007oo0002Ool4000AOol00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0
000JOol003ioo`03001oogoo019oo`03001oogoo011T7`Ioo`<000=oo`03001oogoo009oo`04001o
ogoo000@Ool00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019o
o`03001oogoo011T7`Qoo`03001oogoo00<000=oo`04001oogoo000@Ool00`00Oomoo`39Ool00`00
I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011T7`Moo`8000=oo`03
001oogoo009oo`<0015oo`03001oogoo0<Uoo`03001T7f@O00mT7`03001oo`0001Yoo`00:Goo0`00
0goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol046@O4Goo00<007oo
Ool04Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000YOol00`00Oomoo`02Ool0
0`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@I1l@Ool2000COol00`00
Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`03001oogoo00=oo`06001oogoo001o
o`0027oo0`004Woo00<007ooOol046@O9Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo0000
6Woo000ZOol01000Oomoogoo0P000goo00<007oo000027oo00<007ooOol04Woo00<007ooOol046@O
9Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000YOol00`00Ool00002Ool00`00
Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`39Ool0
0`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`04001oogooOol30003Ool00`00Oomoo`07Ool00`00
Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`39Ool00`00I1mT7`0?I1l00`00Ool0000JOol003io
o`03001oogoo019oocT00<]oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol0ogoo
5goo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`3oOolGOolC00000goo001oo`0I
Ool003ioo`800?moobaoo`03001oogoo01Qoo`00?Woo00<007ooOol0ogoo:goo00<007ooOol067oo
000nOol00`00Oomoo`3oOol[Ool00`00Oomoo`0HOol003ioool002l001Yoo`00ogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00/7oo0`00dgoo002aOol00`00Oomoo`3B
Ool00:Ioo`800009Ool00000001oo`00Ool007oo00<0009oo`<0009oo`<000=oo`8000=oo`<0009o
o`<0009oo`800004Ool000000004Ool50002Ool00`00Ool000020003Ool20002Ool30003Ool20000
0goo00000002Ool00`00Oomoo`29Ool00:Ioo`04001oogooOol200001Woo001oo`00Ool0009oo`04
001oogoo0004Ool01@00Oomoogoo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo0000
17oo00<007ooOol00Woo00H007ooOol007oo0002Ool00`00Ool00004Ool01000Oomoo`000Woo00D0
07ooOomoo`00009oo`03001oo`00009oo`03001oogoo08Uoo`00Ygoo0`0000Qoo`00Ool007oo001o
o`000Woo00@007ooOol000Aoo`05001oogooOol00004Ool01P00Oomoo`00Ool0009oo`03001oo`00
0080009oo`03001oogoo009oo`06001oogoo001oo`000Woo00<007oo000017oo00<007ooOol00goo
00D007ooOomoo`00009oo`03001oo`00009oo`03001oogoo08Uoo`00Ygoo00@007oo001oo`800003
Ool007oo00@000=oo`04001oogooOol20002Ool4000017oo000007oo0P000Woo0`0000Aoo`000000
009oo`80009oo`800003Ool0000000@0009oo`<00003Ool000000080009oo`8000Aoo`800003Ool0
0000008008aoo`00Z7oo00<007ooOol037oo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol0
17oo00@007ooOol0011oo`03001oogoo09]oo`00Ygoo0P003Goo0P0017oo00<007ooOol03Goo0P00
1Goo1@005Woo00<007ooOol0UGoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMo
o`00ogooQgoo003oOon7Ool00001\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-6.30713, 36.1406, 0.0431596, 1.46087}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 42: ",
    FontWeight->"Bold"],
  "Anzahl der von der Funktion AmplitudeFunction erzeugten Terme und \
Operationen, in Abh\[ADoubleDot]ngigkeit der Ordnung in e."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Komplexit\[ADoubleDot]t der Aufgabe schl\[ADoubleDot]gt sich direkt in \
der Berechnungszeit nieder. Ableitungen bis zur 17. Ordnung konnten trotzdem \
in annehmbarer Zeit durchgef\[UDoubleDot]hrt werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:23"],

Cell["Kap. 2.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.5. PhaseFunction",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:24"],

Cell["\<\
PhaseFunction[n] berechnet die Phasenfunktion des linearisierten \
Sitnikovproblems gem\[ADoubleDot]\[SZ] der  Floquet Theorie. Hierzu wird das \
Integral \[UDoubleDot]ber das Quadrat der Amplitudenfunktion gebildet.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:25"],

Cell["\<\
Aus dem Ansatz der Floquet - Theorie f\[UDoubleDot]r die L\[ODoubleDot]sung \
einer linearen gew\[ODoubleDot]hnlichen Differentialgleichung zweiter Ordnung \
mit periodischer Koeffizientenfunktion folgen zwei Bestimmungsgleichungen f\
\[UDoubleDot]r die zeitabh\[ADoubleDot]ngige Amplituden- und Phasenfunktion. \
Ist die Gleichung f\[UDoubleDot]r die Amplitudenfunktion w \
gel\[ODoubleDot]st, so ergibt sich die Phasenfunktion \[Psi] aus der \
Beziehung.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(TraditionalForm\`\[Psi](
        t) = \[Integral]\_0\%t\( 
              1\/\(w(s)\)\^2\) \[DifferentialD]s\)], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Funktion ",
  StyleBox["PhaseFunction ",
    FontSlant->"Italic"],
  " entwickelt den Integrand nach e und integriert ihn dann nach der Zeit. \
Das Ergebnis wird nach den trigonometrischen Ausdr\[UDoubleDot]cken \
sortiert."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:26"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["AmplitudeFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(PhaseFunction[
          n_Integer] := \(Module[{x}, \[IndentingNewLine]$Derivation = \
\[IndentingNewLine]{x = 
                  1\/AmplitudeFunction[n]\^2, \[IndentingNewLine]x = \
\[Integral]x \[DifferentialD]t, \[IndentingNewLine]x = 
                  TrigReduce[n], \[IndentingNewLine]PhaseFunction[n] = 
                  Collect[x, 
                    Sin[_] | 
                      Cos[_]]}]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:27"],

Cell["\<\
Die wesentlichen Aufgaben des Algorithmus wurden bereits in der \
mathematischen Beschreibung aufgezeigt. Die Anforderungen an die Funktion \
beschr\[ADoubleDot]nken sich auf die Entwicklung einer St\[ODoubleDot]rreihe, \
das Integrieren nach der Zeit von trigonometrischen Funktionen und das \
Sortieren eines Ausdrucks nach trigonometrischen Mustern. \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Term- und Operationsanzahl entspricht im Wesentlichen der von ",
  StyleBox["AmplitudeFunction",
    FontSlant->"Italic"],
  ". "
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:28"],

Cell["Kap. 2.4.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.6. LinearSolution",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:29"],

Cell["\<\
LinearSolution[n] gibt die L\[ODoubleDot]sung der linearisierten \
Bewegungsgleichung des Sitnikovproblems bis zur n-ten Ordnung \
bez\[UDoubleDot]glich des Parameters e aus. \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:30"],

Cell["\<\
Die L\[ODoubleDot]sung einer Differentialgleichung vom Hill\.b4schen Typus \
lautet gem\[ADoubleDot]\[SZ] Floquet - Theorie.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(TraditionalForm\`z(t) = 
      z\_0\/w\_0\ \(cos(\[Psi](t))\) + 
        w\_0\ v\_0\ \(sin(\[Psi](t))\)\)], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Hierbei sind ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`v\_0\)]],
  " die Anfangsamplitude bzw. Anfangsgeschwindigkeit und ",
  Cell[BoxData[
      \(TraditionalForm\`w\_0\)]],
  " die Amplitudenfunktion zum Zeitpunkt t = 0."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:31"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["AmplitudeFunction, PhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(LinearSolution[
          n_Integer] := \(Module[{w, \[Psi]}, $Derivation = \
\[IndentingNewLine]{w[t] = Normal[AmplitudeFunction[n]], 
                w[0] = Normal[
                      AmplitudeFunction[n]] /. \[InvisibleSpace]t \[Rule] 
                      0, \[Psi][t] = Normal[PhaseFunction[n]], 
                x = \(Cos[\[Psi][t]]\ Subscript[z, 0]\ w[t]\)\/w[0] + 
                    Sin[\[Psi][t]]\ w[0]\ w[t]\ Subscript[v, 0], 
                LinearSolution[n] = 
                  x}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:32"],

Cell[TextData[{
  "Die Funktion stellt nur die Ergebnisse der vorangegangenen Algorithmen \
zusammen. Die Anzahl der Terme und Operationen ergibt sich zu der doppelten \
Summe von jenen aus ",
  StyleBox["AmpltiudeFunction",
    FontSlant->"Italic"],
  " und ",
  StyleBox["PhaseFunction.",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.000528844 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .12048 -20.6875 -5.8125 ]
[-0.0125 .12048 0 5.8125 ]
[-0.0125 .22625 -20.6875 -5.8125 ]
[-0.0125 .22625 0 5.8125 ]
[-0.0125 .33202 -20.6875 -5.8125 ]
[-0.0125 .33202 0 5.8125 ]
[-0.0125 .43779 -20.6875 -5.8125 ]
[-0.0125 .43779 0 5.8125 ]
[-0.0125 .54356 -26.25 -5.8125 ]
[-0.0125 .54356 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.875 -7.5625 ]
[-0.01875 .30902 -26.25 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -40.9375 0 ]
[.5 .63053 40.9375 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12048 m
.00625 .12048 L
s
gsave
-0.0125 .12048 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
0 .22625 m
.00625 .22625 L
s
gsave
-0.0125 .22625 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(400) show
1.000 setlinewidth
grestore
0 .33202 m
.00625 .33202 L
s
gsave
-0.0125 .33202 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(600) show
1.000 setlinewidth
grestore
0 .43779 m
.00625 .43779 L
s
gsave
-0.0125 .43779 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(800) show
1.000 setlinewidth
grestore
0 .54356 m
.00625 .54356 L
s
gsave
-0.0125 .54356 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04116 m
.00375 .04116 L
s
0 .0676 m
.00375 .0676 L
s
0 .09404 m
.00375 .09404 L
s
0 .14693 m
.00375 .14693 L
s
0 .17337 m
.00375 .17337 L
s
0 .19981 m
.00375 .19981 L
s
0 .2527 m
.00375 .2527 L
s
0 .27914 m
.00375 .27914 L
s
0 .30558 m
.00375 .30558 L
s
0 .35846 m
.00375 .35846 L
s
0 .38491 m
.00375 .38491 L
s
0 .41135 m
.00375 .41135 L
s
0 .46423 m
.00375 .46423 L
s
0 .49068 m
.00375 .49068 L
s
0 .51712 m
.00375 .51712 L
s
0 .57 m
.00375 .57 L
s
0 .59644 m
.00375 .59644 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -100.625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -101.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(LinearSolution) show
140.875 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .01577 L
.06923 .01577 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .01577 L
.06923 .01577 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .01577 L
.14615 .01577 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .01577 L
.14615 .01577 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .01577 L
.22308 .01577 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .01577 L
.22308 .01577 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .01577 L
.3 .01577 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .01577 L
.3 .01577 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .01577 L
.37692 .01577 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .01577 L
.37692 .01577 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .01577 L
.45385 .01577 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .01577 L
.45385 .01577 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .01577 L
.53077 .01577 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .01577 L
.53077 .01577 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .01577 L
.60769 .01577 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .01577 L
.60769 .01577 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .01577 L
.68462 .01577 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .01577 L
.68462 .01577 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .01577 L
.76154 .01577 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .01577 L
.76154 .01577 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .01577 L
.83846 .01577 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .01577 L
.83846 .01577 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .01577 L
.91538 .01577 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .01577 L
.91538 .01577 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .01577 L
.99231 .01577 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .01577 L
.99231 .01577 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .01577 m
.00769 .01895 L
.06923 .01895 L
.06923 .01577 L
F
0 g
.00769 .01577 m
.00769 .01895 L
.06923 .01895 L
.06923 .01577 L
.00769 .01577 L
s
.8 1 0 r
.08462 .01577 m
.08462 .02106 L
.14615 .02106 L
.14615 .01577 L
F
0 g
.08462 .01577 m
.08462 .02106 L
.14615 .02106 L
.14615 .01577 L
.08462 .01577 L
s
.8 1 0 r
.16154 .01577 m
.16154 .02529 L
.22308 .02529 L
.22308 .01577 L
F
0 g
.16154 .01577 m
.16154 .02529 L
.22308 .02529 L
.22308 .01577 L
.16154 .01577 L
s
.8 1 0 r
.23846 .01577 m
.23846 .02952 L
.3 .02952 L
.3 .01577 L
F
0 g
.23846 .01577 m
.23846 .02952 L
.3 .02952 L
.3 .01577 L
.23846 .01577 L
s
.8 1 0 r
.31538 .01577 m
.31538 .03587 L
.37692 .03587 L
.37692 .01577 L
F
0 g
.31538 .01577 m
.31538 .03587 L
.37692 .03587 L
.37692 .01577 L
.31538 .01577 L
s
.8 1 0 r
.39231 .01577 m
.39231 .04222 L
.45385 .04222 L
.45385 .01577 L
F
0 g
.39231 .01577 m
.39231 .04222 L
.45385 .04222 L
.45385 .01577 L
.39231 .01577 L
s
.8 1 0 r
.46923 .01577 m
.46923 .05068 L
.53077 .05068 L
.53077 .01577 L
F
0 g
.46923 .01577 m
.46923 .05068 L
.53077 .05068 L
.53077 .01577 L
.46923 .01577 L
s
.8 1 0 r
.54615 .01577 m
.54615 .05914 L
.60769 .05914 L
.60769 .01577 L
F
0 g
.54615 .01577 m
.54615 .05914 L
.60769 .05914 L
.60769 .01577 L
.54615 .01577 L
s
.8 1 0 r
.62308 .01577 m
.62308 .06971 L
.68462 .06971 L
.68462 .01577 L
F
0 g
.62308 .01577 m
.62308 .06971 L
.68462 .06971 L
.68462 .01577 L
.62308 .01577 L
s
.8 1 0 r
.7 .01577 m
.7 .08029 L
.76154 .08029 L
.76154 .01577 L
F
0 g
.7 .01577 m
.7 .08029 L
.76154 .08029 L
.76154 .01577 L
.7 .01577 L
s
.8 1 0 r
.77692 .01577 m
.77692 .09298 L
.83846 .09298 L
.83846 .01577 L
F
0 g
.77692 .01577 m
.77692 .09298 L
.83846 .09298 L
.83846 .01577 L
.77692 .01577 L
s
.8 1 0 r
.85385 .01577 m
.85385 .10568 L
.91538 .10568 L
.91538 .01577 L
F
0 g
.85385 .01577 m
.85385 .10568 L
.91538 .10568 L
.91538 .01577 L
.85385 .01577 L
s
.8 1 0 r
.93077 .01577 m
.93077 .12048 L
.99231 .12048 L
.99231 .01577 L
F
0 g
.93077 .01577 m
.93077 .12048 L
.99231 .12048 L
.99231 .01577 L
.93077 .01577 L
s
0 1 .4 r
.00769 .01895 m
.00769 .02318 L
.06923 .02318 L
.06923 .01895 L
F
0 g
.00769 .01895 m
.00769 .02318 L
.06923 .02318 L
.06923 .01895 L
.00769 .01895 L
s
0 1 .4 r
.08462 .02106 m
.08462 .02952 L
.14615 .02952 L
.14615 .02106 L
F
0 g
.08462 .02106 m
.08462 .02952 L
.14615 .02952 L
.14615 .02106 L
.08462 .02106 L
s
0 1 .4 r
.16154 .02529 m
.16154 .03693 L
.22308 .03693 L
.22308 .02529 L
F
0 g
.16154 .02529 m
.16154 .03693 L
.22308 .03693 L
.22308 .02529 L
.16154 .02529 L
s
0 1 .4 r
.23846 .02952 m
.23846 .04539 L
.3 .04539 L
.3 .02952 L
F
0 g
.23846 .02952 m
.23846 .04539 L
.3 .04539 L
.3 .02952 L
.23846 .02952 L
s
0 1 .4 r
.31538 .03587 m
.31538 .05385 L
.37692 .05385 L
.37692 .03587 L
F
0 g
.31538 .03587 m
.31538 .05385 L
.37692 .05385 L
.37692 .03587 L
.31538 .03587 L
s
0 1 .4 r
.39231 .04222 m
.39231 .06443 L
.45385 .06443 L
.45385 .04222 L
F
0 g
.39231 .04222 m
.39231 .06443 L
.45385 .06443 L
.45385 .04222 L
.39231 .04222 L
s
0 1 .4 r
.46923 .05068 m
.46923 .07606 L
.53077 .07606 L
.53077 .05068 L
F
0 g
.46923 .05068 m
.46923 .07606 L
.53077 .07606 L
.53077 .05068 L
.46923 .05068 L
s
0 1 .4 r
.54615 .05914 m
.54615 .08875 L
.60769 .08875 L
.60769 .05914 L
F
0 g
.54615 .05914 m
.54615 .08875 L
.60769 .08875 L
.60769 .05914 L
.54615 .05914 L
s
0 1 .4 r
.62308 .06971 m
.62308 .1025 L
.68462 .1025 L
.68462 .06971 L
F
0 g
.62308 .06971 m
.62308 .1025 L
.68462 .1025 L
.68462 .06971 L
.62308 .06971 L
s
0 1 .4 r
.7 .08029 m
.7 .11731 L
.76154 .11731 L
.76154 .08029 L
F
0 g
.7 .08029 m
.7 .11731 L
.76154 .11731 L
.76154 .08029 L
.7 .08029 L
s
0 1 .4 r
.77692 .09298 m
.77692 .13423 L
.83846 .13423 L
.83846 .09298 L
F
0 g
.77692 .09298 m
.77692 .13423 L
.83846 .13423 L
.83846 .09298 L
.77692 .09298 L
s
0 1 .4 r
.85385 .10568 m
.85385 .15116 L
.91538 .15116 L
.91538 .10568 L
F
0 g
.85385 .10568 m
.85385 .15116 L
.91538 .15116 L
.91538 .10568 L
.85385 .10568 L
s
0 1 .4 r
.93077 .12048 m
.93077 .17125 L
.99231 .17125 L
.99231 .12048 L
F
0 g
.93077 .12048 m
.93077 .17125 L
.99231 .17125 L
.99231 .12048 L
.93077 .12048 L
s
0 .4 1 r
.00769 .02318 m
.00769 .03005 L
.06923 .03005 L
.06923 .02318 L
F
0 g
.00769 .02318 m
.00769 .03005 L
.06923 .03005 L
.06923 .02318 L
.00769 .02318 L
s
0 .4 1 r
.08462 .02952 m
.08462 .04486 L
.14615 .04486 L
.14615 .02952 L
F
0 g
.08462 .02952 m
.08462 .04486 L
.14615 .04486 L
.14615 .02952 L
.08462 .02952 L
s
0 .4 1 r
.16154 .03693 m
.16154 .06178 L
.22308 .06178 L
.22308 .03693 L
F
0 g
.16154 .03693 m
.16154 .06178 L
.22308 .06178 L
.22308 .03693 L
.16154 .03693 L
s
0 .4 1 r
.23846 .04539 m
.23846 .08082 L
.3 .08082 L
.3 .04539 L
F
0 g
.23846 .04539 m
.23846 .08082 L
.3 .08082 L
.3 .04539 L
.23846 .04539 L
s
0 .4 1 r
.31538 .05385 m
.31538 .09986 L
.37692 .09986 L
.37692 .05385 L
F
0 g
.31538 .05385 m
.31538 .09986 L
.37692 .09986 L
.37692 .05385 L
.31538 .05385 L
s
0 .4 1 r
.39231 .06443 m
.39231 .12313 L
.45385 .12313 L
.45385 .06443 L
F
0 g
.39231 .06443 m
.39231 .12313 L
.45385 .12313 L
.45385 .06443 L
.39231 .06443 L
s
0 .4 1 r
.46923 .07606 m
.46923 .14746 L
.53077 .14746 L
.53077 .07606 L
F
0 g
.46923 .07606 m
.46923 .14746 L
.53077 .14746 L
.53077 .07606 L
.46923 .07606 L
s
0 .4 1 r
.54615 .08875 m
.54615 .17495 L
.60769 .17495 L
.60769 .08875 L
F
0 g
.54615 .08875 m
.54615 .17495 L
.60769 .17495 L
.60769 .08875 L
.54615 .08875 L
s
0 .4 1 r
.62308 .1025 m
.62308 .20351 L
.68462 .20351 L
.68462 .1025 L
F
0 g
.62308 .1025 m
.62308 .20351 L
.68462 .20351 L
.68462 .1025 L
.62308 .1025 L
s
0 .4 1 r
.7 .11731 m
.7 .23524 L
.76154 .23524 L
.76154 .11731 L
F
0 g
.7 .11731 m
.7 .23524 L
.76154 .23524 L
.76154 .11731 L
.7 .11731 L
s
0 .4 1 r
.77692 .13423 m
.77692 .26909 L
.83846 .26909 L
.83846 .13423 L
F
0 g
.77692 .13423 m
.77692 .26909 L
.83846 .26909 L
.83846 .13423 L
.77692 .13423 L
s
0 .4 1 r
.85385 .15116 m
.85385 .30505 L
.91538 .30505 L
.91538 .15116 L
F
0 g
.85385 .15116 m
.85385 .30505 L
.91538 .30505 L
.91538 .15116 L
.85385 .15116 L
s
0 .4 1 r
.93077 .17125 m
.93077 .34419 L
.99231 .34419 L
.99231 .17125 L
F
0 g
.93077 .17125 m
.93077 .34419 L
.99231 .34419 L
.99231 .17125 L
.93077 .17125 L
s
.8 0 1 r
.00769 .03005 m
.00769 .03534 L
.06923 .03534 L
.06923 .03005 L
F
0 g
.00769 .03005 m
.00769 .03534 L
.06923 .03534 L
.06923 .03005 L
.00769 .03005 L
s
.8 0 1 r
.08462 .04486 m
.08462 .06284 L
.14615 .06284 L
.14615 .04486 L
F
0 g
.08462 .04486 m
.08462 .06284 L
.14615 .06284 L
.14615 .04486 L
.08462 .04486 L
s
.8 0 1 r
.16154 .06178 m
.16154 .0914 L
.22308 .0914 L
.22308 .06178 L
F
0 g
.16154 .06178 m
.16154 .0914 L
.22308 .0914 L
.22308 .06178 L
.16154 .06178 L
s
.8 0 1 r
.23846 .08082 m
.23846 .12419 L
.3 .12419 L
.3 .08082 L
F
0 g
.23846 .08082 m
.23846 .12419 L
.3 .12419 L
.3 .08082 L
.23846 .08082 L
s
.8 0 1 r
.31538 .09986 m
.31538 .15697 L
.37692 .15697 L
.37692 .09986 L
F
0 g
.31538 .09986 m
.31538 .15697 L
.37692 .15697 L
.37692 .09986 L
.31538 .09986 L
s
.8 0 1 r
.39231 .12313 m
.39231 .19822 L
.45385 .19822 L
.45385 .12313 L
F
0 g
.39231 .12313 m
.39231 .19822 L
.45385 .19822 L
.45385 .12313 L
.39231 .12313 L
s
.8 0 1 r
.46923 .14746 m
.46923 .24159 L
.53077 .24159 L
.53077 .14746 L
F
0 g
.46923 .14746 m
.46923 .24159 L
.53077 .24159 L
.53077 .14746 L
.46923 .14746 L
s
.8 0 1 r
.54615 .17495 m
.54615 .2913 L
.60769 .2913 L
.60769 .17495 L
F
0 g
.54615 .17495 m
.54615 .2913 L
.60769 .2913 L
.60769 .17495 L
.54615 .17495 L
s
.8 0 1 r
.62308 .20351 m
.62308 .34313 L
.68462 .34313 L
.68462 .20351 L
F
0 g
.62308 .20351 m
.62308 .34313 L
.68462 .34313 L
.68462 .20351 L
.62308 .20351 L
s
.8 0 1 r
.7 .23524 m
.7 .4013 L
.76154 .4013 L
.76154 .23524 L
F
0 g
.7 .23524 m
.7 .4013 L
.76154 .4013 L
.76154 .23524 L
.7 .23524 L
s
.8 0 1 r
.77692 .26909 m
.77692 .4637 L
.83846 .4637 L
.83846 .26909 L
F
0 g
.77692 .26909 m
.77692 .4637 L
.83846 .4637 L
.83846 .26909 L
.77692 .26909 L
s
.8 0 1 r
.85385 .30505 m
.85385 .53034 L
.91538 .53034 L
.91538 .30505 L
F
0 g
.85385 .30505 m
.85385 .53034 L
.91538 .53034 L
.91538 .30505 L
.85385 .30505 L
s
.8 0 1 r
.93077 .34419 m
.93077 .60332 L
.99231 .60332 L
.99231 .34419 L
F
0 g
.93077 .34419 m
.93077 .60332 L
.99231 .60332 L
.99231 .34419 L
.93077 .34419 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
eGoo00<007ooOol01Woo00<007ooOol0YGoo003DOol00`00Oomoo`08Ool00`00Oomoo`2TOol00<mo
o`80009oo`03001oogoo00Aoo`8000Aoo`03001oogoo0:=oo`00cWoo00H007ooOol007oo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`2SOol00<ioo`06001oogoo001oo`001Goo0`0017oo00<007ooOol0
Xgoo003>Ool01P00Oomoo`00Ool000Eoo`<000Aoo`03001oogoo0:=oo`00cWoo00@007ooOol0009o
o`03001oogoo00Qoo`03001oogoo0:Aoo`00cgoo0P0017oo00<007ooOol01Woo00<007ooOol0YGoo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00BWoo1@004goo0`0057oo0P00
5Woo0`005Goo00<007ooOol04goo0P005Woo00<007ooOol057oo00<007ooOol04goo0P004Woo1@00
0Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000ioo`D00003Ool00000025oo`00C7oo00<0
07ooOol04goo00<007ooOol05Woo00<007ooOol057oo00<007ooOol04goo00<007oo000057oo00<0
07oo00005Goo00<007ooOol04goo00<007oo00005Woo00<007ooOol04Goo00L007ooOomoo`00Ool0
000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<0
07ooOol07Woo001<Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0COol4000FOol00`00
Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00Ool0000EOol2000COol01`00Oomoogoo
001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo01moo`00C7oo00<007ooOol057oo00<007ooOol05Goo00<007ooOol0
4Woo00<007oo00005Goo0P005Goo0P005goo00<007ooOol04goo00<007ooOol04goo00<007oo0000
4goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0NOol004aoo`03001oogoo01=oo`03001oo`00
01Aoo`03001oo`0001Eoo`8001Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`03001oo`0001=oo`07001oogooOol007oo000047oo00<007ooOol00Woo00<007oo
Ool03goo00L007ooOomoo`00Ool0000@Ool01`00Oomoogoo001oo`00021oo`00Bgoo0P005Woo00<0
07ooOol057oo00<007ooOol05Goo00<007ooOol04goo0`005Goo0P0057oo0`005Goo00<007ooOol0
57oo0P004Woo0P0017oo00<007ooOol03Woo0P000goo0P0047oo0P0017oo00<007ooOol03Woo0P00
17oo00<007ooOol07goo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00@Goo
o`00;`005goo0011Ool00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`08
Ool00`00Oomoo`0EOol0045oo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo00Qoo`03001oogoo01Eoo`00>7oo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
5Goo000gOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol003Moo`03001oo`00
00Moool002l001Moo`00=goo00<007oo00001goo00<007oo00004`0017oo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<0
06OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomo
o`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oo`0001Mo
o`00=goo00<007oo00001goo00<007oo00004`0017oo4`0017oo00<006OPIn003fOP00<007ooOol0
0Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001o
ogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In00
0`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo0000
4VOP00D007ooOomoo`00019Wh003001oo`0001Moo`00>7oo00<007ooOol01Woo00<007oo00004P6O
00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo4`0017oo00<006OPIn003fOP00<007oo
Ool00Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?
In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003
001oo`0001Moo`00@Goo00<007oo00004`0017oo4`0017oo00<000?/0n`03`?/00<007ooOol00Woo
4`0017oo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02
Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?
In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003
001oo`0001Moo`00@Goo00<007oo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<006OPIn00
46OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In00
0`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool0
0`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oo`0001Moo`00@Goo
00<007oo00004`0017oo00<0006O0Il03`6O00<007ooOol00Woo4`0017oo00<000?/0n`03`?/00<0
07ooOol00Woo50000goo00<006OPIn0046OP00D007ooOomoo`00019Wh003001oogoo009oo`03001W
h6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001o
ogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo0000
5goo0011Ool00`00Oomoo`0GOol00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP
00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP
00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogoo
Ool0000BIn001@00Oomoogoo00004VOP00<007oo00005goo0011Ool2000HOol00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool0
0`000n`3k00@0n`01000Oomoogoo50000goo00<006OPIn0046OP00<007ooOol00Woo00<006OPIn00
3fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol0
0Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Ool0000GOol0
045oo`03001oogoo01Mooa<000Aoo`030001W`6O00l1W`03001oogoo009ooa<000Aoo`030003k0?/
0103k005001oogooOol0000B0n`01@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP
00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo
00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Ool0000GOol0045o
o`03001oogoo01Moo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomo
ogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D007ooOomoo`00019W
h005001oogooOol0000BIn000`00Ool0000GOol0045oo`03001oogoo01Moo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009ooa@0
00=oo`030003k0?/0103k004001oogooOolD0004Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00
In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00
Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<007ooOol05goo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomo
o`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019W
h003001oo`0001Moo`00@Goo00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007oo
Oomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02OolC0004Ool00`00In1Wh00?In000`00
Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP
00D007ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<007ooOol05goo4`0017oo4`0017oo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0
000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00In1Wh00?In000`00Oomo
o`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D0
07ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<007ooOol0;Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00@007ooOomooa@000=oo`03
0003k0?/0103k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`03001Wh6OP00mWh003
001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000B
In001@00Oomoogoo00004VOP00<007oo00005goo0011Ool2000_Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000183k003001oogoo009oo`030003k0?/00l3k003001oogoo009ooa<000Aoo`03001W
h6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo0000
4VOP00<007oo00005goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`00
0183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo
009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00
Oomoogoo00004VOP00<007oo00005goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00@0
07ooOomooa@000Aoo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomo
ogoo00004VOP00<007oo00005goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003
001oogoo009ooa<000Aoo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007oo00005goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02OolC0004Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030003
k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001o
ogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo0000
5goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo
009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/
00l3k003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007oo00005goo0011Ool00`00Oomoo`0^Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oogoo009ooa<000Aoo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001o
ogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<007oo0000
5goo0011Ool00`00Oomoo`0^OolC0004Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@
0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009ooa@0
00=oo`03001Wh6OP011Wh005001oogooOol0000BIn000`00Ool0000GOol0045oo`8004Ioo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol0
0Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D007ooOomoo`00019Wh005001o
ogooOol0000BIn000`00Ool0000GOol0045oo`03001oogoo04Eoo`03001T7f@O00mT7`03001oogoo
009ooa@000=oo`030001W`6O0101W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oo`0001Moo`00
@Goo00<007ooOol0AGoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02OolC
0004Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004VOP00D0
07ooOomoo`00019Wh003001oo`0001Moo`00@Goo00<007ooOol0AGoo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?
0n`00`00Oomoo`02Ool00`000n`3k00@0n`01000Oomoogoo50000goo00<006OPIn0046OP00<007oo
00005goo0011Ool00`00Oomoo`15Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003
k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004VOP00<007oo00005goo0011Ool00`00
Oomoo`15Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001oogoo
Ool0000B0n`01@00Oomoogoo00004VOP00<007oo00005goo000/Ool30003Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`15Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003
k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004VOP00<007oo00005goo000/Ool00`00
Oomoo`02Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`15Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009ooa<000Aoo`03
0003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004VOP00<007oo00005goo000]Ool0
1`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`<004Eoo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O011T7`04001oogooOolD0003Ool00`000Il1W`0@0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00@007ooOomooa@00003Ool007oo01Ioo`00
;Goo00L007ooOomoo`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`15OolC0004Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo000/
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`1LOol00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo000]Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1LOol00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003
k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo00005goo0011Ool00`00
Oomoo`1LOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009ooa@000=oo`030003k0?/0103k005001oogooOol0000B0n`00`00Ool0000G
Ool0045oo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001o
ogooOol0000B0n`00`00Ool0000GOol0045oo`03001oogoo05aoo`03001T7f@O011T7`05001oogoo
Ool0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O
00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0000GOol0045oo`03001oogoo05ao
o`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Ool0
000GOol0045oo`8005eoo`03001T7f@O011T7`05001oogooOol0000BI1l01000Oomoogoo500017oo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00
Ool0000GOol0045oo`03001oogoo05aoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00@007ooOomooa@000=o
o`030003k0?/0103k003001oo`0001Moo`00@Goo00<007ooOol0G7oo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@
0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oo`0001Moo`00@Goo00<007ooOol0
G7oo50000goo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00<007oo00005goo0011
Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
Ool00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0n`00`00Ool0000G
Ool0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001o
o`0001Moo`00@Goo00<007ooOol0Lgoo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/
00<007oo00005goo0011Ool2001dOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`04001oogooOolD00000goo
001oo`0FOol0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomo
o`02OolC0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo
00<007ooOol0Lgoo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo00005goo
0011Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0
000GOol0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oo`0001Moo`00@Goo00<007ooOol0Lgoo00<006@OI1l046@O00D007ooOomoo`00019T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo0000
4P6O00<007oo00005goo0011Ool00`00Oomoo`1cOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogoo
Ool0000B0Il00`00Ool0000GOol0045oo`03001oogoo07=oo`03001T7f@O011T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oo`0001Moo`00@Goo0P00M7oo50000goo00<006@OI1l046@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B
0Il00`00Ool0000GOol0045oo`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo0000
5goo0011Ool00`00Oomoo`2:Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02OolC0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo
00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo00<007ooOol0RWoo00<006@OI1l0
46@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Ool0000GOol0045oo`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O
00<007oo00005goo0011Ool00`00Oomoo`2:Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Mo
o`00@Goo00<007ooOol0RWoo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol002eoo`<0009o
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07oo00005goo000^Ool01P00Oomoo`00Ool0009oo`03001oo`0000Qoo`<008Yoo`03001T7f@O011T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007oo00005goo000/Ool4000017oo001oo`000Woo00<007oo000027oo00<007oo
Ool0RWoo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007oo
Oomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol002aoo`03001oo`00009oo`03001o
o`00009oo`03001oo`0000Qoo`03001oogoo08Yoo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo0000
5goo000]Ool20002Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`2:Ool00`00I1mT7`0@
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
OolC0004Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`00
01Moo`00;Woo00D007ooOomoo`0000Aoo`03001oogoo00Moo`03001oogoo08Yoo`03001T7f@O011T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`2:OolD0004Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo00<0
07ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Ool0000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05
001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo00005goo0011Ool2002SOol00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Mo
o`00@Goo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05
001oogooOol0000B0Il00`00Ool0000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001
W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo00005goo0011Ool00`00
Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`00
0181W`03001oo`0001Moo`00@Goo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol0045oo`03001oogoo0:9oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009ooa@000=oo`030001W`6O0101W`05001oogooOol0000B0Il00`00Ool0000GOol0045o
o`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`2ROol00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@
I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo0P00Xgoo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0
000GOol0045oo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
0Il01@00Oomoogoo00004P6O00<007oo00005goo0011Ool00`00Oomoo`2ROol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`00@Goo
00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogoo
Ool0000B0Il00`00Ool0000GOol0045oo`03001oogoo0:9ooa<000Aoo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007oo00005goo000HOol00`00Oomoo`02Ool00`00Oomoo`0QOol00`00
Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0@I1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oo`0001Moo`0067oo1P00
8goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l046@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Ool0000GOol0
01Uoo`80009oo`03001oogoo025oo`03001oogoo0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il01@00Oomoogoo
00004P6O00<007oo00005goo000HOol00`00Oomoo`02000TOol2002jOol00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01000Oomoogoo50000goo
00<0006O0Il0406O00<007oo00005goo000HOol6000SOol00`00Oomoo`2iOol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`000181W`03001oo`0001Moo`006Woo00D007oo001oo`00029oo`03001oogoo
0;Uoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo00005goo000IOol5000SOol0
0`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oo`0001Moo`0067oo
00L007oo001oo`00Ool0000ROol00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
0181W`03001oo`0001Moo`006Goo1@008goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000B0Il00`00Ool0000GOol001Qoo`05001oo`00Ool0000TOol00`00Oomoo`2iOol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`000181W`03001oo`0001Moo`00;7oo0P0017oo00<007ooOol0
0Woo00<007ooOol01goo00<007ooOol0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il0
0`00Ool0000GOol002aoo`03001oo`00009oo`03001oo`00009oo`03001oo`0000Qoo`<00;Uoo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05
001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo00005goo000/Ool00`00Ool00002Ool0
0`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`2iOol00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`000181W`03001oo`0001Moo`00;7oo0P000goo00<007oo00000Woo00<007oo000027oo00<007oo
Ool0^Goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Ool0000GOol002aoo`03001o
ogoo009oo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo0;Uoo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004P6O00<007oo00005goo000]Ool20003Ool00`00Oomoo`02Ool00`00Oomoo`07
Ool00`00Oomoo`2iOolC0004Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00@007ooOomooa@00003Ool007oo01Ioo`00@Goo00<007ooOol04Goo=`00R7oo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moocT008Qoo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`26Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`00
01Moo`00@Goo0P0047oo00<007ooOol0=Goo00<007ooOol0QWoo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0
045oo`03001oogoo00moo`03001oogoo011l02Eoo`03001oogoo08Ioo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`26Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001o
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`02goo0P0067oo00<007ooOol0QWoo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011l00aoo`03001oogoo01Io
o`03001oogoo08Ioo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
O006Ool20004Ool01`00Oomoo`00Ool007oo00D000eoo`03001oogoo08Ioo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo
00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O008Ool03P00Oomoo`00Ool007oo001oo`00
Ool007oo0002Ool00`00Oomoo`0:Ool00`00Oomoo`26Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo
00<007ooOol03goo00<007ooOol047`01goo00l007ooOomoo`00Ool007oo001oo`00Ool007oo0000
0Woo00<007ooOol02Woo00<007ooOol0QWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`80011oo`03
001oogoo011l00Moo`800004Ool00000Ool4000017oo001oogoo0`003Goo00<007ooOol0QWoo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011l01Eoo`03001oogoo00eo
o`03001oogoo08Ioo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
O00DOol2000?Ool00`00Oomoo`26Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol047`09Goo00<007ooOol0QWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo
00moo`03001oogoo011l02Eoo`03001oogoo08Ioo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00
Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`26OolC0004Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007oo
Ool0=Goo00<007ooOol0WGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo03Eoo`03001oogoo09eoo`03001T
7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool2000@
Ool00`00Oomoo`0@In0UOol00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP5Woo0P00
3Goo00<007ooOol0WGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l0
0`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011Wh1Qoo`03001oogoo00Yoo`03001o
ogoo09eoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In07Ool20002Ool30002Ool30003Ool3000<Ool0
0`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001o
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP1Woo00@007ooOol0009oo`03001oogoo
009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<0
07ooOol046OP1Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo
00Yoo`03001oogoo09eoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O
00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In05Ool40002Ool400000goo0000
0004Ool3000<Ool00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`03001oo`0001Moo`00;Goo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo
00<007ooOol03goo00<007ooOol046OP1Woo00<007ooOol077oo00<007ooOol0WGoo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol002aoo`03001oo`00
009oo`03001oo`00009oo`03001oo`0000Qoo`<000moo`03001oogoo011Wh15oo`03001oogoo015o
o`03001oogoo09eoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07oo00005goo000/Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`0?
Ool00`00Oomoo`0@In0UOol00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oo`0001Moo`00;Goo00L007ooOomoo`00Ool00002Ool00`00Ool00008
Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2MOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00;7oo00<007oo00000Woo00<007oo
00000Woo00<007oo000027oo00<007ooOol03goo00<007ooOol046OP9Goo00<007ooOol0WGoo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Ool0000GOol002eoo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00Moo`03001oogoo00moo`03001oogoo03Eoo`03
001oogoo09eoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo
00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2MOol00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol040?/9Goo00<007ooOol0WGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0103k2Eoo`03001o
ogoo09eoo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo0000
5goo0011Ool2000@Ool00`00Oomoo`0@0n`<Ool00`00Oomoo`0FOol00`00Oomoo`2MOolD0003Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@0n`6Ool40002Ool01000Oomoogoo10004Goo00<007ooOol0]7oo00<006@OI1l046@O00D0
07ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/1Woo0`00
00=oo`0000000`000Woo00@007ooOol0011oo`03001oogoo0;Aoo`03001T7f@O011T7`05001oogoo
Ool0000BI1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0103k0Qoo`05001oogoo
Ool00004Ool01000Oomoo`0047oo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T
7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/1goo0P000goo00<007ooOol0
0Woo0`004Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol040?/4Goo00<007ooOol04Goo00<007ooOol0]7oo00<0
06@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007oo
Ool040?/47oo0P004goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001o
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/9Goo00<007ooOol0]7oo00<006@OI1l0
46@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo0P0047oo00<007ooOol040?/9Goo00<0
07ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007oo
Ool03goo00<007ooOol040?/9Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T
7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0]7oo00<006@O
I1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0
=Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo
00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomo
o`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0
]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol0406O9Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001o
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0]7oo00<006@OI1l0
46@O00D007ooOomoo`00019T7`03001oo`0001Moo`00@Goo0P0047oo00<007ooOol0406O1Woo1000
1Woo10004Goo00<007ooOol0]7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol0406O1Woo0`0027oo00@007ooOol0011oo`03001oogoo
0;Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Ool0000GOol0045oo`03001oogoo00mo
o`03001oogoo0101W`Qoo`03001oogoo00Ioo`04001oogoo000@Ool00`00Oomoo`2dOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
0Il7Ool20002Ool00`00Ool00003Ool3000AOol00`00Oomoo`2dOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0Il<Ool00`00Oomo
o`02Ool00`00Oomoo`0AOol00`00Oomoo`2dOolD0003Ool00`00I1mT7`0@I1l00`00Ool0000GOol0
045oo`03001oogoo00moo`03001oogoo0101W`aoo`04001oogooOol2000COol00`00Oomoo`3;Ool0
0`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo0101WbEoo`03001o
ogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`009Goo1@000Woo00<007ooOol00Woo00<007oo
Ool00Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0bgoo00<0
06@OI1l046@O00<007oo00005goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03
001oo`0000Uoo`<000moo`03001oogoo03Eoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`00
01Moo`009goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00Oomo
o`0?Ool00`00Oomoo`0eOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol002Moo`07
001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00002Goo00<007ooOol03goo00<007oo
Ool046@O9Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo000WOol01`00Oomoogoo
001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011T7bEo
o`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`009Woo0P0017oo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol046@O9Goo00<007ooOol0
bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol0
0`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo
011T7`Ioo`@00004Ool007oo0002Ool4000AOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0
000GOol0045oo`03001oogoo00moo`03001oogoo011T7`Ioo`<000=oo`03001oogoo009oo`04001o
ogoo000@Ool00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`80011oo`03001o
ogoo011T7`Qoo`03001oogoo00<000=oo`04001oogoo000@Ool00`00Oomoo`3;Ool00`00I1mT7`0@
I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011T7`Moo`8000=oo`03001oogoo
009oo`<0015oo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol0
3goo00<007ooOol046@O4Goo00<007ooOol04Goo00<007ooOol0bgoo00<006@OI1l046@O00<007oo
00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1l@Ool2000COol00`00Oomoo`3;Ool00`00
I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011T7bEoo`03001oogoo
0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046@O9Goo
00<007ooOol0bgoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0@I1lUOol00`00Oomoo`3;Ool00`00I1mT7`0@I1l00`00Ool0000GOol0045oo`03001oogoo00mo
o`03001oogoo03Eoo`03001oogoo0<]oo`03001T7f@O011T7`03001oo`0001Moo`00@Goo0P0047oo
>@00cGoo00<006@OI1l046@O00<007oo00005goo0011Ool00`00Oomoo`3oOolFOol00`00I1mT7`0@
I1l00`00Ool0000GOol0045oo`03001oogoo0?mooaIooa@00003Ool007oo01Ioo`00@Goo00<007oo
Ool0ogoo:goo00<007ooOol05Goo0011Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol0045oo`03
001oogoo0?moob]oo`03001oogoo01Eoo`00@Gooo`00;`005goo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00/Goo1@0000Eoo`000000
07oo0080009oo`03001oogoo0080009oo`@00004Ool000000002Ool30003Ool20002Ool30003Ool3
0002Ool20002Ool30003Ool200000goo00000002Ool00`00Oomoo`2=Ool00;9oo`04001oogoo0002
Ool01@00Oomoogoo00000Woo00<007oo000017oo0`000goo00L007ooOomoo`00Ool00002Ool01000
Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00009oo`04001oogoo0003Ool01P00Oomoo`00
Ool0009oo`03001oogoo08eoo`00/Woo00<007ooOol00goo00D007ooOomoo`00009oo`03001oo`00
008000Aoo`05001oogooOol00005Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001o
o`001Goo00D007ooOomoo`00009oo`03001oo`00009oo`03001oogoo08eoo`00/Woo00<007ooOol0
0Woo0P000Woo10000Woo0`000goo0P000Woo10000Woo00<007ooOol00Woo0P000goo00<007ooOol0
0P0000=oo`00000010000Woo0P0017oo0P0000=oo`0000000P00T7oo002bOol00`00Oomoo`0KOol0
0`00Ool00008Ool00`00Oomoo`06Ool00`00Oomoo`2OOol00;5oo`<000Aoo`03001oogoo01Eoo`<0
00Moo`8000ioo`03001oogoo09Uoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo0000\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {601.438, 361.438}} -> {-1.56523, \
1.30565, 0.00540782, 0.00540782}, {{104.5, 474.313}, {595.688, 367.125}} -> \
{-6.42717, 2035.5, 0.0431596, 6.27778}, {{178.438, 233.938}, {462.938, \
388.938}} -> {-10.9028, 17.9762, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 43: ",
    FontWeight->"Bold"],
  "Anzahl der durchzuf\[UDoubleDot]hrenden Operationen, die von der N\
\[ADoubleDot]herungsl\[ODoubleDot]sung LinearSolution in \
Abh\[ADoubleDot]ngigkeit der Ordnung e erzeugt werden."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Anzahl der Terme der L\[ODoubleDot]sung der linearisierten \
Bewegungsgleichung des Sitnikov Problems w\[ADoubleDot]chst schwach \
exponentiell an und erfordert bei 13. Ordnung in e \[UDoubleDot]ber 1000 \
durchzuf\[UDoubleDot]hrende Operationen, um einen L\[ODoubleDot]sungswert zu \
berechnen.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:33"],

Cell["Kap. 2.4.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.7. PhaseShift",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:34"],

Cell["\<\
PhaseShift[n] gibt die Phasenverschiebung im linearisierten Sitnikovproblem \
bis zur n-ten Ordnung in e wieder. Sie entspricht dem linear mit der Zeit \
anwachsenden Koeffizienten von PhaseFunction.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:35"],

Cell[TextData[{
  "Die Phasenverschiebung der L\[ODoubleDot]sung des linearisierten \
Sitnikovproblems setzt sich aus s\[ADoubleDot]kularen und oszillierenden \
Teilen zusammen: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[
              RowBox[{
                FormBox[\(\[Phi]\_ges\),
                  "TraditionalForm"], " ", "=", " ", \(\[Phi]\_lin\)}],
              "TraditionalForm"], "*", "t"}], "+", \(\[Phi]\_osz\)}], 
        TraditionalForm]]],
  ". Die linear mit der Zeit anwachsende Gr\[ODoubleDot]\[SZ]e \
h\[ADoubleDot]ngt direkt mit der Stabilit\[ADoubleDot]t der \
L\[ODoubleDot]sung zusammen. "
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:36"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["PhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(PhaseShift[
          n_Integer] := \(Module[{x}, \[IndentingNewLine]$Derivation = \
\[IndentingNewLine]{x = PhaseFunction[n], 
                PhaseShift[n] = 
                  Coefficient[x, t, 1] + 
                    O[e]\^\(n + 1\)}]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:37"],

Cell["\<\
Die Anzahl der Terme und Operationen w\[ADoubleDot]chst mit steigender \
Ordnung linear an. Die Ordnungen (n,n+1) entsprechen sich. (n = 2,3,4,...) \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.0202967 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .1162 -9.5625 -5.8125 ]
[-0.0125 .1162 0 5.8125 ]
[-0.0125 .21768 -15.125 -5.8125 ]
[-0.0125 .21768 0 5.8125 ]
[-0.0125 .31917 -15.125 -5.8125 ]
[-0.0125 .31917 0 5.8125 ]
[-0.0125 .42065 -15.125 -5.8125 ]
[-0.0125 .42065 0 5.8125 ]
[-0.0125 .52213 -15.125 -5.8125 ]
[-0.0125 .52213 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26.75 -7.5625 ]
[-0.01875 .30902 -15.125 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -29.8125 0 ]
[.5 .63053 29.8125 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .1162 m
.00625 .1162 L
s
gsave
-0.0125 .1162 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .21768 m
.00625 .21768 L
s
gsave
-0.0125 .21768 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .31917 m
.00625 .31917 L
s
gsave
-0.0125 .31917 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .42065 m
.00625 .42065 L
s
gsave
-0.0125 .42065 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .52213 m
.00625 .52213 L
s
gsave
-0.0125 .52213 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03501 m
.00375 .03501 L
s
0 .05531 m
.00375 .05531 L
s
0 .07561 m
.00375 .07561 L
s
0 .0959 m
.00375 .0959 L
s
0 .1365 m
.00375 .1365 L
s
0 .15679 m
.00375 .15679 L
s
0 .17709 m
.00375 .17709 L
s
0 .19739 m
.00375 .19739 L
s
0 .23798 m
.00375 .23798 L
s
0 .25828 m
.00375 .25828 L
s
0 .27857 m
.00375 .27857 L
s
0 .29887 m
.00375 .29887 L
s
0 .33946 m
.00375 .33946 L
s
0 .35976 m
.00375 .35976 L
s
0 .38006 m
.00375 .38006 L
s
0 .40035 m
.00375 .40035 L
s
0 .44095 m
.00375 .44095 L
s
0 .46124 m
.00375 .46124 L
s
0 .48154 m
.00375 .48154 L
s
0 .50184 m
.00375 .50184 L
s
0 .54243 m
.00375 .54243 L
s
0 .56273 m
.00375 .56273 L
s
0 .58302 m
.00375 .58302 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -90.8125 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PhaseShift) show
118.625 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .05531 L
.06923 .05531 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .05531 L
.06923 .05531 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .05531 L
.14615 .05531 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .05531 L
.14615 .05531 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .05531 L
.22308 .05531 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .05531 L
.22308 .05531 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .07561 L
.3 .07561 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .07561 L
.3 .07561 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .07561 L
.37692 .07561 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .07561 L
.37692 .07561 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .0959 L
.45385 .0959 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .0959 L
.45385 .0959 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .0959 L
.53077 .0959 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .0959 L
.53077 .0959 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .1162 L
.60769 .1162 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .1162 L
.60769 .1162 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .1162 L
.68462 .1162 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .1162 L
.68462 .1162 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .1365 L
.76154 .1365 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .1365 L
.76154 .1365 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .1365 L
.83846 .1365 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .1365 L
.83846 .1365 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .15679 L
.91538 .15679 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .15679 L
.91538 .15679 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .15679 L
.99231 .15679 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .15679 L
.99231 .15679 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .05531 m
.00769 .05531 L
.06923 .05531 L
.06923 .05531 L
F
0 g
.00769 .05531 m
.00769 .05531 L
.06923 .05531 L
.06923 .05531 L
.00769 .05531 L
s
.8 1 0 r
.08462 .05531 m
.08462 .05531 L
.14615 .05531 L
.14615 .05531 L
F
0 g
.08462 .05531 m
.08462 .05531 L
.14615 .05531 L
.14615 .05531 L
.08462 .05531 L
s
.8 1 0 r
.16154 .05531 m
.16154 .05531 L
.22308 .05531 L
.22308 .05531 L
F
0 g
.16154 .05531 m
.16154 .05531 L
.22308 .05531 L
.22308 .05531 L
.16154 .05531 L
s
.8 1 0 r
.23846 .07561 m
.23846 .07561 L
.3 .07561 L
.3 .07561 L
F
0 g
.23846 .07561 m
.23846 .07561 L
.3 .07561 L
.3 .07561 L
.23846 .07561 L
s
.8 1 0 r
.31538 .07561 m
.31538 .07561 L
.37692 .07561 L
.37692 .07561 L
F
0 g
.31538 .07561 m
.31538 .07561 L
.37692 .07561 L
.37692 .07561 L
.31538 .07561 L
s
.8 1 0 r
.39231 .0959 m
.39231 .0959 L
.45385 .0959 L
.45385 .0959 L
F
0 g
.39231 .0959 m
.39231 .0959 L
.45385 .0959 L
.45385 .0959 L
.39231 .0959 L
s
.8 1 0 r
.46923 .0959 m
.46923 .0959 L
.53077 .0959 L
.53077 .0959 L
F
0 g
.46923 .0959 m
.46923 .0959 L
.53077 .0959 L
.53077 .0959 L
.46923 .0959 L
s
.8 1 0 r
.54615 .1162 m
.54615 .1162 L
.60769 .1162 L
.60769 .1162 L
F
0 g
.54615 .1162 m
.54615 .1162 L
.60769 .1162 L
.60769 .1162 L
.54615 .1162 L
s
.8 1 0 r
.62308 .1162 m
.62308 .1162 L
.68462 .1162 L
.68462 .1162 L
F
0 g
.62308 .1162 m
.62308 .1162 L
.68462 .1162 L
.68462 .1162 L
.62308 .1162 L
s
.8 1 0 r
.7 .1365 m
.7 .1365 L
.76154 .1365 L
.76154 .1365 L
F
0 g
.7 .1365 m
.7 .1365 L
.76154 .1365 L
.76154 .1365 L
.7 .1365 L
s
.8 1 0 r
.77692 .1365 m
.77692 .1365 L
.83846 .1365 L
.83846 .1365 L
F
0 g
.77692 .1365 m
.77692 .1365 L
.83846 .1365 L
.83846 .1365 L
.77692 .1365 L
s
.8 1 0 r
.85385 .15679 m
.85385 .15679 L
.91538 .15679 L
.91538 .15679 L
F
0 g
.85385 .15679 m
.85385 .15679 L
.91538 .15679 L
.91538 .15679 L
.85385 .15679 L
s
.8 1 0 r
.93077 .15679 m
.93077 .15679 L
.99231 .15679 L
.99231 .15679 L
F
0 g
.93077 .15679 m
.93077 .15679 L
.99231 .15679 L
.99231 .15679 L
.93077 .15679 L
s
0 1 .4 r
.00769 .05531 m
.00769 .05531 L
.06923 .05531 L
.06923 .05531 L
F
0 g
.00769 .05531 m
.00769 .05531 L
.06923 .05531 L
.06923 .05531 L
.00769 .05531 L
s
0 1 .4 r
.08462 .05531 m
.08462 .07561 L
.14615 .07561 L
.14615 .05531 L
F
0 g
.08462 .05531 m
.08462 .07561 L
.14615 .07561 L
.14615 .05531 L
.08462 .05531 L
s
0 1 .4 r
.16154 .05531 m
.16154 .07561 L
.22308 .07561 L
.22308 .05531 L
F
0 g
.16154 .05531 m
.16154 .07561 L
.22308 .07561 L
.22308 .05531 L
.16154 .05531 L
s
0 1 .4 r
.23846 .07561 m
.23846 .0959 L
.3 .0959 L
.3 .07561 L
F
0 g
.23846 .07561 m
.23846 .0959 L
.3 .0959 L
.3 .07561 L
.23846 .07561 L
s
0 1 .4 r
.31538 .07561 m
.31538 .0959 L
.37692 .0959 L
.37692 .07561 L
F
0 g
.31538 .07561 m
.31538 .0959 L
.37692 .0959 L
.37692 .07561 L
.31538 .07561 L
s
0 1 .4 r
.39231 .0959 m
.39231 .1162 L
.45385 .1162 L
.45385 .0959 L
F
0 g
.39231 .0959 m
.39231 .1162 L
.45385 .1162 L
.45385 .0959 L
.39231 .0959 L
s
0 1 .4 r
.46923 .0959 m
.46923 .1162 L
.53077 .1162 L
.53077 .0959 L
F
0 g
.46923 .0959 m
.46923 .1162 L
.53077 .1162 L
.53077 .0959 L
.46923 .0959 L
s
0 1 .4 r
.54615 .1162 m
.54615 .1365 L
.60769 .1365 L
.60769 .1162 L
F
0 g
.54615 .1162 m
.54615 .1365 L
.60769 .1365 L
.60769 .1162 L
.54615 .1162 L
s
0 1 .4 r
.62308 .1162 m
.62308 .1365 L
.68462 .1365 L
.68462 .1162 L
F
0 g
.62308 .1162 m
.62308 .1365 L
.68462 .1365 L
.68462 .1162 L
.62308 .1162 L
s
0 1 .4 r
.7 .1365 m
.7 .15679 L
.76154 .15679 L
.76154 .1365 L
F
0 g
.7 .1365 m
.7 .15679 L
.76154 .15679 L
.76154 .1365 L
.7 .1365 L
s
0 1 .4 r
.77692 .1365 m
.77692 .15679 L
.83846 .15679 L
.83846 .1365 L
F
0 g
.77692 .1365 m
.77692 .15679 L
.83846 .15679 L
.83846 .1365 L
.77692 .1365 L
s
0 1 .4 r
.85385 .15679 m
.85385 .17709 L
.91538 .17709 L
.91538 .15679 L
F
0 g
.85385 .15679 m
.85385 .17709 L
.91538 .17709 L
.91538 .15679 L
.85385 .15679 L
s
0 1 .4 r
.93077 .15679 m
.93077 .17709 L
.99231 .17709 L
.99231 .15679 L
F
0 g
.93077 .15679 m
.93077 .17709 L
.99231 .17709 L
.99231 .15679 L
.93077 .15679 L
s
0 .4 1 r
.00769 .05531 m
.00769 .07561 L
.06923 .07561 L
.06923 .05531 L
F
0 g
.00769 .05531 m
.00769 .07561 L
.06923 .07561 L
.06923 .05531 L
.00769 .05531 L
s
0 .4 1 r
.08462 .07561 m
.08462 .1365 L
.14615 .1365 L
.14615 .07561 L
F
0 g
.08462 .07561 m
.08462 .1365 L
.14615 .1365 L
.14615 .07561 L
.08462 .07561 L
s
0 .4 1 r
.16154 .07561 m
.16154 .1365 L
.22308 .1365 L
.22308 .07561 L
F
0 g
.16154 .07561 m
.16154 .1365 L
.22308 .1365 L
.22308 .07561 L
.16154 .07561 L
s
0 .4 1 r
.23846 .0959 m
.23846 .19739 L
.3 .19739 L
.3 .0959 L
F
0 g
.23846 .0959 m
.23846 .19739 L
.3 .19739 L
.3 .0959 L
.23846 .0959 L
s
0 .4 1 r
.31538 .0959 m
.31538 .19739 L
.37692 .19739 L
.37692 .0959 L
F
0 g
.31538 .0959 m
.31538 .19739 L
.37692 .19739 L
.37692 .0959 L
.31538 .0959 L
s
0 .4 1 r
.39231 .1162 m
.39231 .25828 L
.45385 .25828 L
.45385 .1162 L
F
0 g
.39231 .1162 m
.39231 .25828 L
.45385 .25828 L
.45385 .1162 L
.39231 .1162 L
s
0 .4 1 r
.46923 .1162 m
.46923 .25828 L
.53077 .25828 L
.53077 .1162 L
F
0 g
.46923 .1162 m
.46923 .25828 L
.53077 .25828 L
.53077 .1162 L
.46923 .1162 L
s
0 .4 1 r
.54615 .1365 m
.54615 .31917 L
.60769 .31917 L
.60769 .1365 L
F
0 g
.54615 .1365 m
.54615 .31917 L
.60769 .31917 L
.60769 .1365 L
.54615 .1365 L
s
0 .4 1 r
.62308 .1365 m
.62308 .31917 L
.68462 .31917 L
.68462 .1365 L
F
0 g
.62308 .1365 m
.62308 .31917 L
.68462 .31917 L
.68462 .1365 L
.62308 .1365 L
s
0 .4 1 r
.7 .15679 m
.7 .38006 L
.76154 .38006 L
.76154 .15679 L
F
0 g
.7 .15679 m
.7 .38006 L
.76154 .38006 L
.76154 .15679 L
.7 .15679 L
s
0 .4 1 r
.77692 .15679 m
.77692 .38006 L
.83846 .38006 L
.83846 .15679 L
F
0 g
.77692 .15679 m
.77692 .38006 L
.83846 .38006 L
.83846 .15679 L
.77692 .15679 L
s
0 .4 1 r
.85385 .17709 m
.85385 .44095 L
.91538 .44095 L
.91538 .17709 L
F
0 g
.85385 .17709 m
.85385 .44095 L
.91538 .44095 L
.91538 .17709 L
.85385 .17709 L
s
0 .4 1 r
.93077 .17709 m
.93077 .44095 L
.99231 .44095 L
.99231 .17709 L
F
0 g
.93077 .17709 m
.93077 .44095 L
.99231 .44095 L
.99231 .17709 L
.93077 .17709 L
s
.8 0 1 r
.00769 .07561 m
.00769 .07561 L
.06923 .07561 L
.06923 .07561 L
F
0 g
.00769 .07561 m
.00769 .07561 L
.06923 .07561 L
.06923 .07561 L
.00769 .07561 L
s
.8 0 1 r
.08462 .1365 m
.08462 .19739 L
.14615 .19739 L
.14615 .1365 L
F
0 g
.08462 .1365 m
.08462 .19739 L
.14615 .19739 L
.14615 .1365 L
.08462 .1365 L
s
.8 0 1 r
.16154 .1365 m
.16154 .19739 L
.22308 .19739 L
.22308 .1365 L
F
0 g
.16154 .1365 m
.16154 .19739 L
.22308 .19739 L
.22308 .1365 L
.16154 .1365 L
s
.8 0 1 r
.23846 .19739 m
.23846 .27857 L
.3 .27857 L
.3 .19739 L
F
0 g
.23846 .19739 m
.23846 .27857 L
.3 .27857 L
.3 .19739 L
.23846 .19739 L
s
.8 0 1 r
.31538 .19739 m
.31538 .27857 L
.37692 .27857 L
.37692 .19739 L
F
0 g
.31538 .19739 m
.31538 .27857 L
.37692 .27857 L
.37692 .19739 L
.31538 .19739 L
s
.8 0 1 r
.39231 .25828 m
.39231 .35976 L
.45385 .35976 L
.45385 .25828 L
F
0 g
.39231 .25828 m
.39231 .35976 L
.45385 .35976 L
.45385 .25828 L
.39231 .25828 L
s
.8 0 1 r
.46923 .25828 m
.46923 .35976 L
.53077 .35976 L
.53077 .25828 L
F
0 g
.46923 .25828 m
.46923 .35976 L
.53077 .35976 L
.53077 .25828 L
.46923 .25828 L
s
.8 0 1 r
.54615 .31917 m
.54615 .44095 L
.60769 .44095 L
.60769 .31917 L
F
0 g
.54615 .31917 m
.54615 .44095 L
.60769 .44095 L
.60769 .31917 L
.54615 .31917 L
s
.8 0 1 r
.62308 .31917 m
.62308 .44095 L
.68462 .44095 L
.68462 .31917 L
F
0 g
.62308 .31917 m
.62308 .44095 L
.68462 .44095 L
.68462 .31917 L
.62308 .31917 L
s
.8 0 1 r
.7 .38006 m
.7 .52213 L
.76154 .52213 L
.76154 .38006 L
F
0 g
.7 .38006 m
.7 .52213 L
.76154 .52213 L
.76154 .38006 L
.7 .38006 L
s
.8 0 1 r
.77692 .38006 m
.77692 .52213 L
.83846 .52213 L
.83846 .38006 L
F
0 g
.77692 .38006 m
.77692 .52213 L
.83846 .52213 L
.83846 .38006 L
.77692 .38006 L
s
.8 0 1 r
.85385 .44095 m
.85385 .60332 L
.91538 .60332 L
.91538 .44095 L
F
0 g
.85385 .44095 m
.85385 .60332 L
.91538 .60332 L
.91538 .44095 L
.85385 .44095 L
s
.8 0 1 r
.93077 .44095 m
.93077 .60332 L
.99231 .60332 L
.99231 .44095 L
F
0 g
.93077 .44095 m
.93077 .60332 L
.99231 .60332 L
.99231 .44095 L
.93077 .44095 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
d7oo00<007ooOol01Woo00<007ooOol0ZWoo003?Ool00`00Oomoo`08Ool00`00Oomoo`2YOol00<Uo
o`8000=oo`03001oogoo00=oo`8000Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001oogoo009o
o`<000Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001oogoo009oo`<000Eoo`03001o
ogoo0:Qoo`00b7oo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo0:Uoo`00bGoo0P001Goo
00<007ooOol01Woo00<007ooOol0ZWoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?mo
ohMoo`00A7oo1@004goo0`005Goo0P005Woo0`0057oo00<007ooOol04goo0P005Woo00<007ooOol0
57oo00<007ooOol057oo0P004Goo1@000Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000mo
o`D00003Ool0000002Ioo`00AWoo00<007ooOol04goo00<007ooOol05goo00<007ooOol057oo00<0
07ooOol04Woo00<007oo000057oo00<007oo00005Goo00<007ooOol04goo00<007oo00005goo00<0
07ooOol047oo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomo
ogoo00004goo00<007ooOol00goo00<007ooOol08goo0016Ool00`00Oomoo`0DOol00`00Oomoo`0E
Ool00`00Oomoo`0COol4000EOol00`00Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00
Ool0000FOol2000BOol01`00Oomoogoo001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo02Aoo`00AWoo00<007ooOol0
57oo00<007ooOol05Woo00<007ooOol04Woo00<007oo000057oo0P005Goo0P005goo00<007ooOol0
4goo00<007ooOol057oo00<007oo00004Woo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0SOol0
04Ioo`03001oogoo01=oo`03001oo`0001Eoo`03001oo`0001Eoo`8001Aoo`03001oogoo01Aoo`03
001oogoo01Aoo`03001oo`0001Aoo`03001oo`0001Eoo`03001oo`00019oo`07001oogooOol007oo
000047oo00<007ooOol00Woo00<007ooOol03goo00L007ooOomoo`00Ool0000AOol01`00Oomoogoo
001oo`0002Eoo`00AGoo0P005Woo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol04Woo0`00
5Goo0P0057oo0`005Goo00<007ooOol05Goo0P004Goo0P0017oo00<007ooOol03Woo0P000goo0P00
47oo0P0017oo00<007ooOol03goo0P0017oo00<007ooOol097oo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00?7ooo`00;`0077oo000lOol00`00Oomoo`08Ool00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0JOol003aoo`03001oogoo00Qoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo01Yoo`00<Woo00<007ooOol01goo
00<007ooOol0ogoo:goo00<007ooOol06Woo000aOol00`00Ool00008Ool00`00Oomoo`3oOol[Ool0
0`00Oomoo`0JOol0035oo`03001oo`0000Qoool002l001aoo`00<Goo00<007oo000027oo00<007oo
00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000?O0001000Oomoo`0077oo000aOol00`00Ool00008Ool00`00Ool0000AO0000`00
Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
00ml0004001oogoo000LOol0039oo`03001oogoo00Moo`03001oo`00015l0003001oogoo009oo`03
001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007oo
Ool001aoo`00?7oo00<007oo00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00
019l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00
019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000A
O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005
001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`000ml0004001oogoo000LOol003aoo`<0015l0003001oogoo009oo`03001l07`0011l0005
001oogooOol0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005
001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo
00<007oo00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000AO0000`00Oomoo`02
Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004
001oogoo000LOol003aoo`03001oo`00015l0003001oogoo009oo`03001l07`0011l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007oo
00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000AO0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo
000LOol003aooaH000=ooa@000=ooa@000=oo`03001l07`0011l0005001oogooOol0000BO0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo
000LOol003aoo`03001oo`000141W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B
0n`01@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007oo00004@6O
00<007ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000BO0001@00
Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000A0Il00`00Oomoo`02Ool00`000n`3k00@
0n`01@00Oomoogoo00004P?/00D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02
Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000@
O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo000LOol0
03aoo`03001oo`000141W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00
Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00
Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007oo00004@6O00<007oo
Ool00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000BO0001@00Oomoogoo
00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02
Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?
O0001000Oomoo`0077oo000lOolF0003OolD0003OolD0003OolD0003OolD0004Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo
00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo000LOol003aoo`03001oogoo
01Ioo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/00D007ooOomoo`00
0183k003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo
009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`0
00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O0Il0406O00D007ooOomoo`000181W`05
001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005
001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Oomoo`0FOol00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k005001oogooOol0000B0n`00`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo
000LOol003aoo`03001oogoo01Ioo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo
00004P?/00D007ooOomoo`000183k003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo
00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O0Il0406O
00D007ooOomoo`000181W`05001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`0
00D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000l
Ool2000GOol00`000Il1W`0@0Il01@00Oomoogoo00004P6O00@007ooOomooa@000=ooa@000Aooa<0
00Aooa@000=oo`03001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007oo
Ool00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O0Il0406O00D007ooOomoo`00
0181W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<000?/0n`03`?/
00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00
019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Oomoo`0F
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`05001oogooOol0000B
0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004
001oogoo000LOol003aoo`03001oogoo01Ioo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030003k0?/00l3k003001oogoo
009oo`030003k0?/00l3k003001oogoo009oo`03001l07`0011l0005001oogooOol0000BO0001@00
Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O
0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<007`0
O00047`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`00
77oo000bOol00`00Oomoo`07Ool00`00Oomoo`0FOol00`000Il1W`0@0Il01@00Oomoogoo00004P6O
00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`0
00D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0004001oogoo000LOol0035oo`03001oo`0000Qoo`80
01Moo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00D007ooOomoo`00
0181W`03001oogoo009ooa<000Aooa<000Aooa@000=ooa@000=oo`03001l07`0011l0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
00ml0004001oogoo000LOol003=oo`03001oogoo00Ioo`03001oogoo01Ioo`030001W`6O0101W`05
001oogooOol0000B0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005
001oogooOol0000B0n`01@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007oo
Ool00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00<Goo
0P002Goo00<007ooOol05Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B
0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000?O0001000Oomoo`0077oo000aOol00`00Oomoo`08Ool00`00Oomoo`0FOol00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo
000LOol0035oo`<000Qoo`03001oogoo01Ioo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00
Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O
0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/
0n`040?/00D007ooOomoo`000183k005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`00
77oo000lOol2000GOolD0003OolD0003Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo50000goo
50000goo500017oo4`0017oo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007oo
Ool001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogoo
Ool0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Oomoo`0FOol00`00I1mT7`0@
I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@
0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oogoo009oo`030003k0?/00l3k003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo000LOol0
03aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P?/
00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo
00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007oo
Oomoo`000181W`05001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00
Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001oogoo
Ool0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000183k003001oogoo
009oo`030003k0?/00l3k003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
00ml0004001oogoo000LOol003aoo`8001Moo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01000
Oomoogoo500017oo4`0017oo4`0017oo500000=oo`00Ool06goo000lOol00`00Oomoo`0FOol00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k004001oogoo
000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo
00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo
00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<000?/0n`03`?/00<007oo
Ool00Woo00<000?/0n`03`?/00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O
00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`01000Oomoo`0077oo000l
Ool00`00Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05
001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030003k0?/00l3k003001oogoo009oo`03
0003k0?/00l3k004001oogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogoo
Ool0000BI1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00@007ooOol001aoo`00?7oo00<007oo
Ool05Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il01@00Oomoogoo
00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
Ool00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?
0n`01000Oomoo`0077oo000lOol2000GOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009ooa<000Aooa<0009oo`03
001oogoo01Yoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0FOol00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000L
Ool003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D0
07ooOomoo`00019T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol0
0`00Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol003aoo`8001Mooa@000=ooa@000=ooa@000=ooa@000Aoo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<0
07ooOol0A7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0
A7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0A7oo00<0
06@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00:goo1@000Woo00<007ooOol01goo00<0
07ooOol0A7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00;Goo00L007ooOomo
o`00Ool00008Ool00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo
000]Ool01`00Oomoogoo001oo`0000Qoo`8004Eoo`03001T7f@O011T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001o
ogoo000LOol002eoo`07001oogooOol007oo000027oo00<007ooOol0A7oo00<006@OI1l046@O00D0
07ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00@007ooOol001aoo`00;Goo00L007ooOomoo`00Ool00008Ool00`00Oomoo`14Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000/Ool20004Ool00`00Oomoo`07Ool0
0`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomo
o`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`14Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol20015Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
1000Oomoo`0077oo000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomo
o`0077oo000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo
000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol2
0015Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo4`0017oo4`0017oo00<0
006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomo
o`0077oo000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo
000lOol00`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol0
0`00Oomoo`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomo
o`14Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`14Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol20015OolD0003OolD0004Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003ao
o`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@0
07ooOol001aoo`00?7oo00<007ooOol0Lgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo07=oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`007Goo00<0
07ooOol00Woo00<007ooOol05goo00<007ooOol0Lgoo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000MOol6000IOol2001dOol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol001ioo`80009oo`03001o
ogoo01Moo`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00@007ooOol001aoo`007Goo00<007ooOol00P006Woo00<007ooOol0Lgoo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`00
0181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000MOol6000IOol00`00
Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo
000LOol001moo`05001oo`00Ool0000HOol00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol001ioo`D000Qoo`D0009oo`03001oogoo
00Moo`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo
009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O
00@007ooOol001aoo`007Goo00L007oo001oo`00Ool00009Ool01`00Oomoogoo001oo`0000Qoo`80
07Aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa@000=ooa@0
00=oo`030001W`6O0101W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol001ioo`D000Yoo`03001oogoo
00=oo`03001oogoo00Ioo`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00@007ooOol001aoo`007Goo00D007oo001oo`0000]oo`04001oogooOol20009
Ool00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04
001oogoo000LOol002eoo`05001oogooOol0000:Ool00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol002aoo`8000=oo`<000Qoo`03
001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007oo
Ool001aoo`00?7oo00<007ooOol0Lgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`8007Aoo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
I1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0Lgoo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000l
Ool00`00Oomoo`0FOolg000VOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O
00l1W`04001oogoo000LOol003aoo`03001oogoo01AoocT002Ioo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007oo
Ool0=Goo00<007ooOol097oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`0TOol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`80
01Eoo`03001oogoo011l02Eoo`03001oogoo02Aooa<000Aooa<000Aoo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<0
07ooOol057oo00<007ooOol047`09Goo00<007ooOol0DWoo00<006@OI1l046@O00D007ooOomoo`00
019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0D
Ool00`00Oomoo`0@O00;Ool2000HOol00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo01Ao
o`03001oogoo011l00aoo`03001oogoo01Ioo`03001oogoo059oo`03001T7f@O011T7`05001oogoo
Ool0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007oo
Ool057oo00<007ooOol047`01Woo0P0017oo00L007ooOol007oo001oo`05000=Ool00`00Oomoo`1B
Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04
001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011l00Qoo`0>001oogoo001oo`00Ool0
07oo001oo`00Ool0009oo`03001oogoo00Yoo`03001oogoo059oo`03001T7f@O011T7`05001oogoo
Ool0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo0P005Goo
00<007ooOol047`01goo00l007ooOomoo`00Ool007oo001oo`00Ool007oo00000Woo00<007ooOol0
2Woo00<007ooOol0DWoo00<006@OI1l046@O00D007ooOomoo`00019T7`04001oogooOolD0004OolC
0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol0
0`00Oomoo`0DOol00`00Oomoo`0@O007Ool2000017oo000007oo100000Aoo`00Oomoo`<000eoo`03
001oogoo059oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol047`05Goo00<007ooOol0
3Goo00<007ooOol0DWoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@O00DOol2000?
Ool00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011l02Eoo`03001o
ogoo059oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol047`09Goo00<007ooOol0DWoo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000
Oomoo`0077oo000lOol2000EOol00`00Oomoo`0@O00UOol00`00Oomoo`1BOol00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003ao
o`03001oogoo01Aoo`03001oogoo03Eoo`03001oogoo059oo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0
57oo00<007ooOol0=Goo00<007ooOol0DWoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomo
o`0@In0UOol00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011Wh1Io
o`8000eoo`03001oogoo059oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00@007ooOol001aoo`00;7oo0`000goo00<007ooOol01goo00<007ooOol0
57oo00<007ooOol046OP67oo00<007ooOol02Woo00<007ooOol0DWoo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000/Ool00`00
Oomoo`02Ool00`00Ool00008Ool2000EOol00`00Oomoo`0@In07Ool20002Ool30002Ool30003Ool3
000<Ool00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`04001oogoo000LOol002eoo`07001oogooOol007oo000027oo00<007ooOol0
57oo00<007ooOol046OP1Woo00@007ooOol0009oo`03001oogoo009oo`05001oogooOol00002Ool0
0`00Oomoo`0:Ool00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`04001oogoo000LOol002eoo`07001oogooOol007oo000027oo00<0
07ooOol057oo00<007ooOol046OP1Woo00<007ooOol00goo00<007ooOol00Woo00D007ooOomoo`00
009oo`03001oogoo00Yoo`03001oogoo059oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00;7oo00<007oo00000Woo00<007oo
000027oo00<007ooOol057oo00<007ooOol046OP1Goo10000Woo100000=oo`00000017oo0`0037oo
00<007ooOol0DWoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il01000Oomoo`0077oo000]Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0D
Ool00`00Oomoo`0@In06Ool00`00Oomoo`0LOol00`00Oomoo`1BOol00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001o
ogoo01Aoo`03001oogoo011Wh15oo`03001oogoo015oo`03001oogoo059oo`03001T7f@O011T7`05
001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo
0P005Goo00<007ooOol046OP9Goo00<007ooOol0DWoo50000goo50000goo00<006@OI1l046@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo4`0017oo4`000Woo00<007ooOol06Woo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0@In0UOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0UOol00`00Oomoo`20
Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00
Oomoo`0eOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`UOol00`00Oomoo`20Ool0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2000EOol00`00Oomoo`0@0n`U
Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00
Oomoo`0DOol00`00Oomoo`0@0n`<Ool00`00Oomoo`0FOol00`00Oomoo`20Ool00`00I1mT7`0@I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`6Ool40002
Ool01000Oomoogoo10004Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007oo
Ool001aoo`00?7oo00<007ooOol057oo00<007ooOol040?/1Woo0`0000=oo`0000000`000Woo00@0
07ooOol0011oo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol0
03aoo`03001oogoo01Aoo`03001oogoo0103k0Qoo`05001oogooOol00004Ool01000Oomoo`0047oo
00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007oo
Ool057oo00<007ooOol040?/1goo0P000goo00<007ooOol00Woo0`004Goo00<007ooOol0P7oo00<0
06@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo0P005Goo00<007ooOol040?/4Goo
00<007ooOol04Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001ao
o`00?7oo00<007ooOol057oo00<007ooOol040?/47oo0P004goo00<007ooOol0P7oo00<006@OI1l0
46@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol040?/9Goo
00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007oo
Ool057oo00<007ooOol040?/9Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@0
07ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol040?/9Goo00<007ooOol0P7oo00<006@O
I1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol0=Goo
00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo0P005Goo
00<007ooOol0=Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001ao
o`00?7oo00<007ooOol057oo00<007ooOol0406O9Goo00<007ooOol0P7oo00<006@OI1l046@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol0406O9Goo00<007oo
Ool0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo
00<007ooOol0406O9Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol0
01aoo`00?7oo00<007ooOol057oo00<007ooOol0406O9Goo00<007ooOol0P7oo00<006@OI1l046@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00@007ooOol001aoo`00;7oo0`000goo00<007ooOol01goo00<007ooOol057oo
00<007ooOol0406O1Woo10001Woo10004Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00@007ooOol001aoo`00;7oo00<007ooOol00Woo00<007oo000027oo00<007ooOol057oo00<0
07ooOol0406O1Woo0`0027oo00@007ooOol0011oo`03001oogoo081oo`03001T7f@O011T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O00mT7`04001oogoo000LOol002eoo`03001oogoo00=oo`03001oogoo00Ioo`8001Eoo`03001o
ogoo0101W`Qoo`03001oogoo00Ioo`04001oogoo000@Ool00`00Oomoo`20OolD0004OolC0004Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000]Ool01000Oomo
ogoo0P002Goo00<007ooOol057oo00<007ooOol0406O1goo0P000Woo00<007oo00000goo0`004Goo
00<007ooOol0[goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001ao
o`00;7oo00<007oo00000Woo00<007ooOol027oo00<007ooOol057oo00<007ooOol0406O37oo00<0
07ooOol00Woo00<007ooOol04Goo00<007ooOol0[goo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00@007ooOol001aoo`00;Goo00@007ooOomoo`<000Qoo`03001oogoo01Aoo`03001o
ogoo0101W`aoo`04001oogooOol2000COol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0IlUOol0
0`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo
000lOol00`00Oomoo`0DOol00`00Oomoo`0@0IlUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2000EOol00`00Oomoo`0eOol00`00
Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol0
0`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo
000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@
I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomo
o`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2000EOol00`00Oomoo`0@
I1l6Ool4000017oo001oo`000Woo10004Goo00<007ooOol0[goo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol046@O1Woo
0`000goo00<007ooOol00Woo00@007ooOol0011oo`03001oogoo0:moo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011T
7`Qoo`03001oogoo00<000=oo`04001oogoo000@Ool00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@
I1l7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1lA
Ool00`00Oomoo`0AOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1l@Ool2000COol00`00Oomo
o`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2
000EOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomo
o`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol0
0`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00
Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000l
Ool00`00Oomoo`0DOoli002aOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000
Oomoo`0077oo000lOol00`00Oomoo`3nOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l01000Oomoo`0077oo000lOol2003oOolC0004OolC0002Ool00`00Oomoo`0JOol003aoo`03001o
ogoo0?moob]oo`03001oogoo01Yoo`00?7oo00<007ooOol0ogoo:goo00<007ooOol06Woo000lOol0
0`00Oomoo`3oOol[Ool00`00Oomoo`0JOol003aoool002l001aoo`00ogooQgoo003oOon7Ool00?mo
ohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00;Ioo`<0009oo`<00003
Ool007oo00@00003Ool0000000Aoo`80009oo`<00007Ool00000001oo`00Ool00`000Woo0`000goo
0P00Wgoo002gOol00`00Oomoo`02Ool01@00Oomoo`00Ool00`0017oo00@007ooOol000Aoo`03001o
o`00009oo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomoogoo00000Woo00<007ooOol0W7oo
002gOol30002Ool01000Oomoo`000goo00D007ooOomoo`0000=oo`<000Aoo`04001oogoo0002Ool0
1000Oomoo`0017oo00D007ooOomoo`000:5oo`00]goo00D007ooOol007oo00<000=oo`8000=oo`80
009oo`<000=oo`04001oogooOol30002Ool20003Ool300000goo00000002002OOol00;Moo`06001o
ogoo001oo`004goo00<007oo00000Woo00<007ooOol027oo00D007ooOomoo`000:5oo`00]Woo1000
00=oo`0000004goo0`0000=oo`0000001Goo00<007ooOol00goo00<007ooOol0XWoo003oOon7Ool0
0?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00001\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {718.125, 478.125}} -> {-1.56523, \
1.93667, 0.00540782, 0.00540782}, {{104.5, 474.313}, {712.375, 483.813}} -> \
{-6.18709, 72.1232, 0.0431596, 0.163572}, {{178.438, 233.938}, {579.625, \
505.625}} -> {-10.9028, 27.4374, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 49: ",
    FontWeight->"Bold"],
  "Anzahl der Terme in Abh\[ADoubleDot]ngigkeit der Ordnung, die von der \
Funktion PhaseShift bestimmt wird."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Auf die Bedeutung der Phasenverschiebung und ihr Zusammenhang mit der \
Stabilit\[ADoubleDot]t wird in Kapitel 2 eingegangen.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:38"],

Cell["Kap. 2.5.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.2.8. TransferMatrix",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:39"],

Cell[TextData[{
  "TransferMatrix[n] leitet die Abbildungsvorschrift R in ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              FormBox[\(\(\(x\&\[RightVector]\)\(\ \)\)\_\(n + 1\)\),
                "TraditionalForm"], " ", "=", " ", \(R\^n\)}],
            "TraditionalForm"], \(\(\(x\&\[RightVector]\)\(\ \)\)\_n\)}], 
        TraditionalForm]]],
  " \[UDoubleDot]ber eine Umlaufperiode der \
Prim\[ADoubleDot]rk\[ODoubleDot]rper bis zur n-ten Ordnung in e ab. R ist \
hierbei eine (2\[Times]2) Matrix, zeitunabh\[ADoubleDot]ngig mit det R  = 1. \
"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:40"],

Cell[TextData[{
  "Die L\[ODoubleDot]sung einer Gleichung vom Hill\.b4schen Typus ist z(t) = \
a\[CenterDot]w(t)+cos(\[Psi](t)+b) oder in anderer Schreibweise ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(z(t)\  = \ \(\(k\_1\)\(\[CenterDot]\)\)\),
              "TraditionalForm"], \(cos(\[Psi](t))\)}], 
          "+", \(\(k\_2\)\(\[CenterDot]\)\)}], TraditionalForm]]],
  "sin(\[Psi](t)). Die Transfermatrix ergibt sich gem\[ADoubleDot]\[SZ] \
Floquet - Theorie aus der kosinus- (c) und sinusartigen (s) \
L\[ODoubleDot]sung der Gleichung und ist durch sie und deren Ableitungen \
folgenderma\[SZ]en definiert:\t"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    RowBox[{"R", "=", 
      RowBox[{"(", GridBox[{
            {\(c \((T)\)\), \(s \((T)\)\)},
            {\(\(\ \)\(\(c\^\[Prime]\) \((T)\)\(\ \)\)\), \(\(\ \)\(\(s\^\
\[Prime]\) \((T)\)\(\ \)\)\)}
            }], ")"}]}]], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Hier ist T = 2\[Pi] die gleiche Periode wie in der Koeffizientenfunktion \
f(t+T) = f(t) in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(z\^\[DoublePrime]\  + \(f(t)\) z\  = \ 
        0. \)\)\)]],
  " Um von der allgemeinen L\[ODoubleDot]sung auf die sinus- und \
kosinusartige L\[ODoubleDot]sung zu kommen, werden die Anfangsbedingungen \
derart gew\[ADoubleDot]hlt, dass c(0) = 1, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(z\^\[Prime]\)(0)\  = \ 0\)\)\)]],
  " und s(0) = 0 sowie ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(s\^\[Prime]\)(0)\  = \ 1\)\)\)]],
  " sind. Bestimmt man mit Hilfe dieser Anfangsbedingungen die Konstanten ",
  Cell[BoxData[
      \(TraditionalForm\`k\_1\)]],
  " und ",
  Cell[BoxData[
      \(TraditionalForm\`k\_2\)]],
  ", so folgen c(t) und s(t) direkt aus diesen."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Bedeutung der Matrix R ist neben der Tatsache, dass sie eine \
Abbildungsvorschrift im Phasenraum definiert, in ihrer Spur zu suchen. Ist \
diese |Sp R| < 2, so bleibt die L\[ODoubleDot]sung an das System gebunden, \
ansonsten ungebunden. Diese Tatsache erm\[ODoubleDot]glicht die Durchf\
\[UDoubleDot]hrung einer einfachen  Stabilit\[ADoubleDot]tsanalyse.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:41"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["AmplitudeFunction, PhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TransferMatrix[
          n_Integer] := \(Module[{x, z, k, c, 
              s}, $Derivation = {z[t_] = 
                  k[1]\ Normal[AmplitudeFunction[n]]\ Cos[
                        Normal[PhaseFunction[n]]] + 
                    k[2]\ Normal[AmplitudeFunction[n]]\ Sin[
                        Normal[PhaseFunction[n]]], 
                x = {z[t] \[Equal] 1 /. \[InvisibleSpace]t \[Rule] 
                          0, \[PartialD]\_t z[t] \[Equal] 
                        0} /. \[InvisibleSpace]t \[Rule] 0, 
                x = Solve[x, {k[1], k[2]}], 
                c[t_] = 
                  z[t] /. \[InvisibleSpace]x\[LeftDoubleBracket]1\
\[RightDoubleBracket], 
                x = {z[t] \[Equal] 0 /. \[InvisibleSpace]t \[Rule] 
                          0, \[PartialD]\_t z[t] \[Equal] 
                        1} /. \[InvisibleSpace]t \[Rule] 0, 
                x = Solve[x, {k[1], k[2]}], 
                s[t_] = 
                  z[t] /. \[InvisibleSpace]x\[LeftDoubleBracket]1\
\[RightDoubleBracket], 
                x = {{c[t], 
                        s[t]}, {\[PartialD]\_t c[t], \[PartialD]\_t s[
                            t]}} /. \[InvisibleSpace]t \[Rule] 2\ \[Pi], 
                x = Collect[x, {Sin[_], Cos[_], e}], 
                TransferMatrix[n] = 
                  Simplify[
                    x]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:42"],

Cell["\<\
Die Funktion implementiert das Verfahren, die Koeffizienten der kosinus- \
sowie sinusartigen L\[ODoubleDot]sung aufzufinden und daraus die \
Transfermatrix R aufzustellen. Folgende Darstellung veranschaulicht die \
Anzahl der auftretenden Operationen in Abh\[ADoubleDot]ngigkeit mit \
wachsender Ordnung:\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[BoxData[""], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.00374907 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .10844 -15.125 -5.8125 ]
[-0.0125 .10844 0 5.8125 ]
[-0.0125 .20217 -15.125 -5.8125 ]
[-0.0125 .20217 0 5.8125 ]
[-0.0125 .2959 -15.125 -5.8125 ]
[-0.0125 .2959 0 5.8125 ]
[-0.0125 .38962 -20.6875 -5.8125 ]
[-0.0125 .38962 0 5.8125 ]
[-0.0125 .48335 -20.6875 -5.8125 ]
[-0.0125 .48335 0 5.8125 ]
[-0.0125 .57708 -20.6875 -5.8125 ]
[-0.0125 .57708 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32.3125 -7.5625 ]
[-0.01875 .30902 -20.6875 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -40.9375 0 ]
[.5 .63053 40.9375 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10844 m
.00625 .10844 L
s
gsave
-0.0125 .10844 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
0 .20217 m
.00625 .20217 L
s
gsave
-0.0125 .20217 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .2959 m
.00625 .2959 L
s
gsave
-0.0125 .2959 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(75) show
1.000 setlinewidth
grestore
0 .38962 m
.00625 .38962 L
s
gsave
-0.0125 .38962 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
0 .48335 m
.00625 .48335 L
s
gsave
-0.0125 .48335 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(125) show
1.000 setlinewidth
grestore
0 .57708 m
.00625 .57708 L
s
gsave
-0.0125 .57708 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03346 m
.00375 .03346 L
s
0 .05221 m
.00375 .05221 L
s
0 .07095 m
.00375 .07095 L
s
0 .0897 m
.00375 .0897 L
s
0 .12719 m
.00375 .12719 L
s
0 .14593 m
.00375 .14593 L
s
0 .16468 m
.00375 .16468 L
s
0 .18342 m
.00375 .18342 L
s
0 .22091 m
.00375 .22091 L
s
0 .23966 m
.00375 .23966 L
s
0 .2584 m
.00375 .2584 L
s
0 .27715 m
.00375 .27715 L
s
0 .31464 m
.00375 .31464 L
s
0 .33339 m
.00375 .33339 L
s
0 .35213 m
.00375 .35213 L
s
0 .37088 m
.00375 .37088 L
s
0 .40837 m
.00375 .40837 L
s
0 .42711 m
.00375 .42711 L
s
0 .44586 m
.00375 .44586 L
s
0 .4646 m
.00375 .4646 L
s
0 .50209 m
.00375 .50209 L
s
0 .52084 m
.00375 .52084 L
s
0 .53958 m
.00375 .53958 L
s
0 .55833 m
.00375 .55833 L
s
0 .59582 m
.00375 .59582 L
s
0 .61457 m
.00375 .61457 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95.0625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -101.938 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(TransferMatrix) show
140.875 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .02221 L
.06923 .02221 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .02221 L
.06923 .02221 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .02221 L
.14615 .02221 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .02221 L
.14615 .02221 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .02221 L
.22308 .02221 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .02221 L
.22308 .02221 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .02221 L
.3 .02221 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .02221 L
.3 .02221 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .02221 L
.37692 .02221 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .02221 L
.37692 .02221 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .02221 L
.45385 .02221 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .02221 L
.45385 .02221 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .02221 L
.53077 .02221 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .02221 L
.53077 .02221 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .02221 L
.60769 .02221 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .02221 L
.60769 .02221 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .02221 L
.68462 .02221 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .02221 L
.68462 .02221 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .02221 L
.76154 .02221 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .02221 L
.76154 .02221 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .02221 L
.83846 .02221 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .02221 L
.83846 .02221 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .02221 L
.91538 .02221 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .02221 L
.91538 .02221 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .02221 L
.99231 .02221 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .02221 L
.99231 .02221 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .02221 m
.00769 .03721 L
.06923 .03721 L
.06923 .02221 L
F
0 g
.00769 .02221 m
.00769 .03721 L
.06923 .03721 L
.06923 .02221 L
.00769 .02221 L
s
.8 1 0 r
.08462 .02221 m
.08462 .03721 L
.14615 .03721 L
.14615 .02221 L
F
0 g
.08462 .02221 m
.08462 .03721 L
.14615 .03721 L
.14615 .02221 L
.08462 .02221 L
s
.8 1 0 r
.16154 .02221 m
.16154 .03721 L
.22308 .03721 L
.22308 .02221 L
F
0 g
.16154 .02221 m
.16154 .03721 L
.22308 .03721 L
.22308 .02221 L
.16154 .02221 L
s
.8 1 0 r
.23846 .02221 m
.23846 .03721 L
.3 .03721 L
.3 .02221 L
F
0 g
.23846 .02221 m
.23846 .03721 L
.3 .03721 L
.3 .02221 L
.23846 .02221 L
s
.8 1 0 r
.31538 .02221 m
.31538 .03721 L
.37692 .03721 L
.37692 .02221 L
F
0 g
.31538 .02221 m
.31538 .03721 L
.37692 .03721 L
.37692 .02221 L
.31538 .02221 L
s
.8 1 0 r
.39231 .02221 m
.39231 .03721 L
.45385 .03721 L
.45385 .02221 L
F
0 g
.39231 .02221 m
.39231 .03721 L
.45385 .03721 L
.45385 .02221 L
.39231 .02221 L
s
.8 1 0 r
.46923 .02221 m
.46923 .03721 L
.53077 .03721 L
.53077 .02221 L
F
0 g
.46923 .02221 m
.46923 .03721 L
.53077 .03721 L
.53077 .02221 L
.46923 .02221 L
s
.8 1 0 r
.54615 .02221 m
.54615 .03721 L
.60769 .03721 L
.60769 .02221 L
F
0 g
.54615 .02221 m
.54615 .03721 L
.60769 .03721 L
.60769 .02221 L
.54615 .02221 L
s
.8 1 0 r
.62308 .02221 m
.62308 .03721 L
.68462 .03721 L
.68462 .02221 L
F
0 g
.62308 .02221 m
.62308 .03721 L
.68462 .03721 L
.68462 .02221 L
.62308 .02221 L
s
.8 1 0 r
.7 .02221 m
.7 .03721 L
.76154 .03721 L
.76154 .02221 L
F
0 g
.7 .02221 m
.7 .03721 L
.76154 .03721 L
.76154 .02221 L
.7 .02221 L
s
.8 1 0 r
.77692 .02221 m
.77692 .03721 L
.83846 .03721 L
.83846 .02221 L
F
0 g
.77692 .02221 m
.77692 .03721 L
.83846 .03721 L
.83846 .02221 L
.77692 .02221 L
s
.8 1 0 r
.85385 .02221 m
.85385 .03721 L
.91538 .03721 L
.91538 .02221 L
F
0 g
.85385 .02221 m
.85385 .03721 L
.91538 .03721 L
.91538 .02221 L
.85385 .02221 L
s
.8 1 0 r
.93077 .02221 m
.93077 .03721 L
.99231 .03721 L
.99231 .02221 L
F
0 g
.93077 .02221 m
.93077 .03721 L
.99231 .03721 L
.99231 .02221 L
.93077 .02221 L
s
0 1 .4 r
.00769 .03721 m
.00769 .04471 L
.06923 .04471 L
.06923 .03721 L
F
0 g
.00769 .03721 m
.00769 .04471 L
.06923 .04471 L
.06923 .03721 L
.00769 .03721 L
s
0 1 .4 r
.08462 .03721 m
.08462 .0597 L
.14615 .0597 L
.14615 .03721 L
F
0 g
.08462 .03721 m
.08462 .0597 L
.14615 .0597 L
.14615 .03721 L
.08462 .03721 L
s
0 1 .4 r
.16154 .03721 m
.16154 .0597 L
.22308 .0597 L
.22308 .03721 L
F
0 g
.16154 .03721 m
.16154 .0597 L
.22308 .0597 L
.22308 .03721 L
.16154 .03721 L
s
0 1 .4 r
.23846 .03721 m
.23846 .0597 L
.3 .0597 L
.3 .03721 L
F
0 g
.23846 .03721 m
.23846 .0597 L
.3 .0597 L
.3 .03721 L
.23846 .03721 L
s
0 1 .4 r
.31538 .03721 m
.31538 .0597 L
.37692 .0597 L
.37692 .03721 L
F
0 g
.31538 .03721 m
.31538 .0597 L
.37692 .0597 L
.37692 .03721 L
.31538 .03721 L
s
0 1 .4 r
.39231 .03721 m
.39231 .0597 L
.45385 .0597 L
.45385 .03721 L
F
0 g
.39231 .03721 m
.39231 .0597 L
.45385 .0597 L
.45385 .03721 L
.39231 .03721 L
s
0 1 .4 r
.46923 .03721 m
.46923 .0597 L
.53077 .0597 L
.53077 .03721 L
F
0 g
.46923 .03721 m
.46923 .0597 L
.53077 .0597 L
.53077 .03721 L
.46923 .03721 L
s
0 1 .4 r
.54615 .03721 m
.54615 .0597 L
.60769 .0597 L
.60769 .03721 L
F
0 g
.54615 .03721 m
.54615 .0597 L
.60769 .0597 L
.60769 .03721 L
.54615 .03721 L
s
0 1 .4 r
.62308 .03721 m
.62308 .0597 L
.68462 .0597 L
.68462 .03721 L
F
0 g
.62308 .03721 m
.62308 .0597 L
.68462 .0597 L
.68462 .03721 L
.62308 .03721 L
s
0 1 .4 r
.7 .03721 m
.7 .0597 L
.76154 .0597 L
.76154 .03721 L
F
0 g
.7 .03721 m
.7 .0597 L
.76154 .0597 L
.76154 .03721 L
.7 .03721 L
s
0 1 .4 r
.77692 .03721 m
.77692 .0597 L
.83846 .0597 L
.83846 .03721 L
F
0 g
.77692 .03721 m
.77692 .0597 L
.83846 .0597 L
.83846 .03721 L
.77692 .03721 L
s
0 1 .4 r
.85385 .03721 m
.85385 .0597 L
.91538 .0597 L
.91538 .03721 L
F
0 g
.85385 .03721 m
.85385 .0597 L
.91538 .0597 L
.91538 .03721 L
.85385 .03721 L
s
0 1 .4 r
.93077 .03721 m
.93077 .0597 L
.99231 .0597 L
.99231 .03721 L
F
0 g
.93077 .03721 m
.93077 .0597 L
.99231 .0597 L
.99231 .03721 L
.93077 .03721 L
s
0 .4 1 r
.00769 .04471 m
.00769 .07095 L
.06923 .07095 L
.06923 .04471 L
F
0 g
.00769 .04471 m
.00769 .07095 L
.06923 .07095 L
.06923 .04471 L
.00769 .04471 L
s
0 .4 1 r
.08462 .0597 m
.08462 .10844 L
.14615 .10844 L
.14615 .0597 L
F
0 g
.08462 .0597 m
.08462 .10844 L
.14615 .10844 L
.14615 .0597 L
.08462 .0597 L
s
0 .4 1 r
.16154 .0597 m
.16154 .11594 L
.22308 .11594 L
.22308 .0597 L
F
0 g
.16154 .0597 m
.16154 .11594 L
.22308 .11594 L
.22308 .0597 L
.16154 .0597 L
s
0 .4 1 r
.23846 .0597 m
.23846 .13843 L
.3 .13843 L
.3 .0597 L
F
0 g
.23846 .0597 m
.23846 .13843 L
.3 .13843 L
.3 .0597 L
.23846 .0597 L
s
0 .4 1 r
.31538 .0597 m
.31538 .14593 L
.37692 .14593 L
.37692 .0597 L
F
0 g
.31538 .0597 m
.31538 .14593 L
.37692 .14593 L
.37692 .0597 L
.31538 .0597 L
s
0 .4 1 r
.39231 .0597 m
.39231 .16843 L
.45385 .16843 L
.45385 .0597 L
F
0 g
.39231 .0597 m
.39231 .16843 L
.45385 .16843 L
.45385 .0597 L
.39231 .0597 L
s
0 .4 1 r
.46923 .0597 m
.46923 .17593 L
.53077 .17593 L
.53077 .0597 L
F
0 g
.46923 .0597 m
.46923 .17593 L
.53077 .17593 L
.53077 .0597 L
.46923 .0597 L
s
0 .4 1 r
.54615 .0597 m
.54615 .22841 L
.60769 .22841 L
.60769 .0597 L
F
0 g
.54615 .0597 m
.54615 .22841 L
.60769 .22841 L
.60769 .0597 L
.54615 .0597 L
s
0 .4 1 r
.62308 .0597 m
.62308 .23591 L
.68462 .23591 L
.68462 .0597 L
F
0 g
.62308 .0597 m
.62308 .23591 L
.68462 .23591 L
.68462 .0597 L
.62308 .0597 L
s
0 .4 1 r
.7 .0597 m
.7 .30339 L
.76154 .30339 L
.76154 .0597 L
F
0 g
.7 .0597 m
.7 .30339 L
.76154 .30339 L
.76154 .0597 L
.7 .0597 L
s
0 .4 1 r
.77692 .0597 m
.77692 .31089 L
.83846 .31089 L
.83846 .0597 L
F
0 g
.77692 .0597 m
.77692 .31089 L
.83846 .31089 L
.83846 .0597 L
.77692 .0597 L
s
0 .4 1 r
.85385 .0597 m
.85385 .34838 L
.91538 .34838 L
.91538 .0597 L
F
0 g
.85385 .0597 m
.85385 .34838 L
.91538 .34838 L
.91538 .0597 L
.85385 .0597 L
s
0 .4 1 r
.93077 .0597 m
.93077 .35588 L
.99231 .35588 L
.99231 .0597 L
F
0 g
.93077 .0597 m
.93077 .35588 L
.99231 .35588 L
.99231 .0597 L
.93077 .0597 L
s
.8 0 1 r
.00769 .07095 m
.00769 .10094 L
.06923 .10094 L
.06923 .07095 L
F
0 g
.00769 .07095 m
.00769 .10094 L
.06923 .10094 L
.06923 .07095 L
.00769 .07095 L
s
.8 0 1 r
.08462 .10844 m
.08462 .18342 L
.14615 .18342 L
.14615 .10844 L
F
0 g
.08462 .10844 m
.08462 .18342 L
.14615 .18342 L
.14615 .10844 L
.08462 .10844 L
s
.8 0 1 r
.16154 .11594 m
.16154 .19842 L
.22308 .19842 L
.22308 .11594 L
F
0 g
.16154 .11594 m
.16154 .19842 L
.22308 .19842 L
.22308 .11594 L
.16154 .11594 L
s
.8 0 1 r
.23846 .13843 m
.23846 .24341 L
.3 .24341 L
.3 .13843 L
F
0 g
.23846 .13843 m
.23846 .24341 L
.3 .24341 L
.3 .13843 L
.23846 .13843 L
s
.8 0 1 r
.31538 .14593 m
.31538 .2584 L
.37692 .2584 L
.37692 .14593 L
F
0 g
.31538 .14593 m
.31538 .2584 L
.37692 .2584 L
.37692 .14593 L
.31538 .14593 L
s
.8 0 1 r
.39231 .16843 m
.39231 .30339 L
.45385 .30339 L
.45385 .16843 L
F
0 g
.39231 .16843 m
.39231 .30339 L
.45385 .30339 L
.45385 .16843 L
.39231 .16843 L
s
.8 0 1 r
.46923 .17593 m
.46923 .31839 L
.53077 .31839 L
.53077 .17593 L
F
0 g
.46923 .17593 m
.46923 .31839 L
.53077 .31839 L
.53077 .17593 L
.46923 .17593 L
s
.8 0 1 r
.54615 .22841 m
.54615 .39337 L
.60769 .39337 L
.60769 .22841 L
F
0 g
.54615 .22841 m
.54615 .39337 L
.60769 .39337 L
.60769 .22841 L
.54615 .22841 L
s
.8 0 1 r
.62308 .23591 m
.62308 .40837 L
.68462 .40837 L
.68462 .23591 L
F
0 g
.62308 .23591 m
.62308 .40837 L
.68462 .40837 L
.68462 .23591 L
.62308 .23591 L
s
.8 0 1 r
.7 .30339 m
.7 .51334 L
.76154 .51334 L
.76154 .30339 L
F
0 g
.7 .30339 m
.7 .51334 L
.76154 .51334 L
.76154 .30339 L
.7 .30339 L
s
.8 0 1 r
.77692 .31089 m
.77692 .52834 L
.83846 .52834 L
.83846 .31089 L
F
0 g
.77692 .31089 m
.77692 .52834 L
.83846 .52834 L
.83846 .31089 L
.77692 .31089 L
s
.8 0 1 r
.85385 .34838 m
.85385 .58832 L
.91538 .58832 L
.91538 .34838 L
F
0 g
.85385 .34838 m
.85385 .58832 L
.91538 .58832 L
.91538 .34838 L
.85385 .34838 L
s
.8 0 1 r
.93077 .35588 m
.93077 .60332 L
.99231 .60332 L
.99231 .35588 L
F
0 g
.93077 .35588 m
.93077 .60332 L
.99231 .60332 L
.99231 .35588 L
.93077 .35588 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
dWoo00<007ooOol01Woo00<007ooOol0Z7oo003AOol00`00Oomoo`08Ool00`00Oomoo`2WOol00<ao
o`80009oo`03001oogoo00Aoo`8000Aoo`03001oogoo0:Ioo`00bgoo00H007ooOol007oo0005Ool0
0`00Oomoo`04Ool00`00Oomoo`2VOol00<]oo`06001oogoo001oo`001Goo0`0017oo00<007ooOol0
YWoo003;Ool01P00Oomoo`00Ool000Eoo`<000Aoo`03001oogoo0:Ioo`00bgoo00@007ooOol0009o
o`03001oogoo00Qoo`03001oogoo0:Moo`00c7oo0P0017oo00<007ooOol01Woo00<007ooOol0Z7oo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00Agoo1@004goo0`0057oo0P00
5goo0`0057oo00<007ooOol04goo0P005Woo00<007ooOol057oo00<007ooOol04goo0P004Woo1@00
0Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000ioo`D00003Ool0000002Aoo`00BGoo00<0
07ooOol04goo00<007ooOol05Woo00<007ooOol05Goo00<007ooOol04Woo00<007oo000057oo00<0
07oo00005Goo00<007ooOol04goo00<007oo00005Woo00<007ooOol04Goo00L007ooOomoo`00Ool0
000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomoogoo00004Woo00<007ooOol00goo00<0
07ooOol08Goo0019Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol4000EOol00`00
Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00Ool0000EOol2000COol01`00Oomoogoo
001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo029oo`00BGoo00<007ooOol057oo00<007ooOol05Goo00<007ooOol0
4goo00<007oo000057oo0P005Goo0P005goo00<007ooOol04goo00<007ooOol04goo00<007oo0000
4goo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`03Ool00`00Oomoo`0QOol004Uoo`03001oogoo01=oo`03001oo`00
01Aoo`03001oo`0001Ioo`8001Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oo`0001Aoo`03
001oo`0001Aoo`03001oo`0001=oo`07001oogooOol007oo000047oo00<007ooOol00Woo00<007oo
Ool03goo00L007ooOomoo`00Ool0000@Ool01`00Oomoogoo001oo`0002=oo`00B7oo0P005Woo00<0
07ooOol057oo00<007ooOol05Woo00<007ooOol04Woo0`005Goo0P0057oo0`005Goo00<007ooOol0
57oo0P004Woo0P0017oo00<007ooOol03Woo0P000goo0P0047oo0P0017oo00<007ooOol03Woo0P00
17oo00<007ooOol08Woo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00?Woo
o`00;`006Woo000nOol00`00Oomoo`09Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`08
Ool00`00Oomoo`0HOol003ioo`03001oogoo00Uoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo00Qoo`03001oogoo01Qoo`00=Goo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
67oo000dOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0HOol003Aoo`03001oo`00
00Moool002l001Yoo`00=7oo00<007oo00001goo00@007ooOol0015l0003001oogoo009oo`03001l
07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001o
ogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol0
0Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O000
47`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O000
0`00Ool0000JOol003Aoo`03001oo`0000Moo`03001oogoo01<000Aooa<000Aooa<000Aooa@000=o
oa@000=ooa@000Aooa<000Aooa<000Aooa<000Aooa@000=ooa@000=ooa@000Aooa<00003Ool007oo
01Uoo`00=Goo00<007ooOol01Woo00@007ooOol0015Wh003001oogoo009oo`03001Wh6OP00mWh003
001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000B
In001@00Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OP
In003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn0046OP00D007oo
Oomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Ool0000J
Ool003ioo`04001oogoo000AIn000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00
In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00
019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo
009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00
Oomoogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol200000goo
001Wh00@In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00
Oomoo`02Ool00`00In1Wh00@In001@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo
009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP
00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP
00<007ooOol00Woo00<006OPIn003fOP00<007oo00006Woo000nOol00`00Oomoo`0C0004OolC0004
OolC0004OolD0003OolD0003OolD0004OolC0004OolC0004OolC0004OolD0003OolD0003OolD0004
OolC00000goo001oo`0IOol003ioo`04001oogoo000A0n`00`00Oomoo`02Ool00`000n`3k00?0n`0
0`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo0000
4P?/00D007ooOomoo`000183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003
k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001o
ogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007oo0000
6Woo000nOol01000Oomoo`004@?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<0
00?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D007ooOomoo`000183k005001oogooOol0
000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomo
o`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D0
07ooOomoo`000183k003001oogoo009oo`030003k0?/00l3k003001oo`0001Yoo`00?Woo00<007oo
Ool04`0017oo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<0
00?/0n`040?/00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3
k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomo
o`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`000183k003001oogoo009o
o`030003k0?/00l3k003001oo`0001Yoo`00?Woo00@007ooOol00141W`03001oogoo009oo`030003
k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001o
ogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol0
0Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`0
40?/00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`0
0`00Ool0000JOol003ioo`800003Ool0006O0101W`03001oogoo009oo`030003k0?/00l3k003001o
ogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`0
1@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`0
3`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D007ooOomo
o`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Ool0000JOol0
03ioo`04001oogoo000A0Il00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3
k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`000183
k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo009o
o`030003k0?/00l3k003001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomo
ogoo00004P?/00<007ooOol00Woo00<000?/0n`03`?/00<007oo00006Woo000nOol01000Oomoo`00
4@6O00<007ooOol00Woo4`0017oo4`0017oo50000goo50000goo500017oo4`0017oo4`0017oo4`00
17oo50000goo50000goo500017oo4`0000=oo`00Ool06Goo000nOol01000Oomoo`004@6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oo`0001Yoo`00?Woo00@007ooOol00141W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O
00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Ool0000JOol003ioo`04001oogoo000A0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B
0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol2
00000goo0000000A0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol01000Oomoo`004F@O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oo`0001Yoo`00?Woo00@007ooOol0015T7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0
000JOol003ioo`04001oogoo000AI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol01000
Oomoo`004F@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo0P0000=oo`00I1l046@O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00@007ooOol0015T7`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Ool0000JOol003ioo`04001oogoo000AI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000n
Ool01000Oomoo`004F@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00;Woo0`000goo00<007oo
Ool01goo00<007ooOol04`0017oo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00;Woo00<007ooOol00Woo00<007oo
000027oo00<007ooOol05goo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
Ool00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00;goo00<007ooOol00goo00<007ooOol0
1Woo0`005goo4`0017oo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
o`0001Yoo`00;goo00@007ooOomoo`8000Uoo`03001oogoo01Moo`03001T7f@O00mT7`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`00
0181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol002io
o`03001oo`00009oo`03001oogoo00Qoo`03001oogoo01Moo`03001T7f@O00mT7`03001oogoo009o
oa<000Aoo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol002moo`04001oogooOol30008Ool00`00
Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo
00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000n
Ool00`00Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol2000HOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000n
Ool00`00Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03
001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`0GOol00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo0000
6Woo000nOol00`00Oomoo`0GOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02OolD0003Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
Ool00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo01Moo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol0
03ioo`8001Qoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O011T7`04001oogooOolD0003Ool00`000Il1W`0@0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`03
0001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo
00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo
009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomo
ogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yo
o`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
o`0001Yoo`00?Woo0P0067oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03
001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`04001oogooOolD0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo
00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00
Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo
009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l00`00Oomoo`02OolC0004Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oo`0001Yoo`00?Woo00<007ooOol05goo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo0P0067oo
4`0017oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05
001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo
00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00
?Woo00<007ooOol0;Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
o`0001Yoo`00?Woo00<007ooOol0;Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0;Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oo`0001Yoo`00;goo00<007ooOol00Woo00<007ooOol01goo00<007oo
Ool0;Woo4`0017oo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`00
0181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00;Woo00<007oo00000Woo00<0
07oo000027oo0`00AGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00<7oo00H007ooOol007oo
0008Ool00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000^Ool20003Ool00`00
Ool00008Ool00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000^Ool00`00Oomo
o`02Ool00`00Ool00008Ool00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000^
Ool30003Ool00`00Oomoo`07Ool00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogoo
Ool0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo
000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol20016Ool00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo
00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa<000Aoo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O
00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009ooa<000Aoo`030001W`6O0101W`05001oogooOol0000B0Il01@00
Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol20016Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`15Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O
0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O
00<007oo00006Woo000nOol00`00Oomoo`15OolD0003Ool00`00I1mT7`0@I1l01@00Oomoogoo0000
4V@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo
05aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
0Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0G7oo00<006@OI1l046@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`1L
Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O
0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Ool0000JOol003ioo`8005eooa@000=oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`1cOol00`00I1mT7`0@I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`00
0181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0Lgoo00<0
06@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03
001oogoo07=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05
001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
00006Woo000nOol00`00Oomoo`1cOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oo`0001Yoo`00?Woo00<007ooOol0Lgoo00<006@OI1l046@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`8007Aoo`03001T7f@O011T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`1cOol00`00
I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O
00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00?Woo00<0
07ooOol0Lgoo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D0
07ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0
000JOol003ioo`03001oogoo07=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
0001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O
0Il03`6O00<007oo00006Woo000_Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`1cOol0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`006goo
00<007ooOol00Woo00<007ooOol037oo00L007ooOomoo`00Ool00008Ool3001cOol00`00I1mT7`0@
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`006goo1P003Woo00<0
07ooOol00goo00<007ooOol01Woo00<007ooOol0Lgoo00<006@OI1l046@O00<007ooOol00Woo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Ool0000JOol001aoo`80009oo`03001oogoo00eoo`03001oogoo
008000Uoo`03001oogoo07=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001
W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007oo00006Woo000KOol00`00Oomoo`02000>Ool00`00Ool00002Ool00`00Oomoo`08Ool0
0`00Oomoo`1cOolD0004Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02OolD0003Ool00`000Il1W`0@0Il01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000KOol6000=Ool30002Ool30008
Ool00`00Oomoo`2;Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004P6O00D007oo
Oomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`007Goo00D007oo001o
o`0001aoo`03001oogoo08]oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`04001oogooOolD0003Ool0
0`000Il1W`0@0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol001aoo`D001eoo`80
08aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O
00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000KOol01`00Ool007oo001oo`0001ao
o`03001oogoo08]ooa<000Aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007oo00006Woo000LOol5000MOol00`00Oomoo`2ROol00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`0001Yoo`00
6goo00D007oo001oo`0001ioo`03001oogoo0:9oo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo0000
4P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomoo`2ROol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oo`00
01Yoo`00?Woo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`800:=oo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo00006Woo000nOol00`00Oomo
o`2ROol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1
W`03001oo`0001Yoo`00?Woo00<007ooOol0XWoo00<006@OI1l03f@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo0:9oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo0000
6Woo000nOol00`00Oomoo`0DOolg001GOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00@007ooOomooa@000Aoo`03
0001W`6O00l1W`03001oo`0001Yoo`00?Woo0P004goo>@00Egoo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001o
ogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Ool0000JOol003ioo`03001oogoo
019oo`03001oogoo03Eoo`03001oogoo05Eoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O
00<007ooOol00Woo4`0000=oo`00Ool06Goo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00
Oomoo`1EOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O
00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol047`09Goo00<007ooOol0EGoo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O
00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011l02Eoo`03001oogoo05Eoo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogoo
Ool0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo
000nOol00`00Oomoo`0BOol00`00Oomoo`0@O00;Ool2000HOol00`00Oomoo`1EOol00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00
?Woo0P004goo00<007ooOol047`037oo00<007ooOol05Woo00<007ooOol0EGoo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00
019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003io
o`03001oogoo019oo`03001oogoo011l00Ioo`8000Aoo`07001oogoo001oo`00Ool01@003Goo00<0
07ooOol0EGoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011l00Qoo`0>001oogoo001o
o`00Ool007oo001oo`00Ool0009oo`03001oogoo00Yoo`03001oogoo05Eoo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000B
I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol0
0`00Oomoo`0BOol00`00Oomoo`0@O007Ool03`00Oomoogoo001oo`00Ool007oo001oo`00Ool00002
Ool00`00Oomoo`0:Ool00`00Oomoo`1EOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03
001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:7oo1@000Woo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol04Woo00<007ooOol047`01goo0P0000Aoo`00001oo`@00004Ool007oo
Ool3000=Ool00`00Oomoo`1EOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo
009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool00`00Ool0
0008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00EOol00`00Oomoo`0=Ool00`00Oomoo`1EOol00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`00
01Yoo`00:Woo00L007ooOomoo`00Ool00002Ool00`00Ool00008Ool3000BOol00`00Oomoo`0@O00D
Ool2000?Ool00`00Oomoo`1EOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo
009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool00`00Ool0
0008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00UOol00`00Oomoo`1EOolC0004Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03
001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool0
0`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00UOol00`00Oomoo`1/Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03
001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:Goo0P0017oo00<007ooOol00Woo00<0
07ooOol01goo00<007ooOol04Woo00<007ooOol047`09Goo00<007ooOol0K7oo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo03Eo
o`03001oogoo06aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0
000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000n
Ool2000COol00`00Oomoo`0eOol00`00Oomoo`1/OolC0004Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol046OP9Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000J
Ool003ioo`03001oogoo019oo`03001oogoo011Wh1Ioo`8000eoo`03001oogoo08=oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O
00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0HOol00`00Oomoo`0:Ool00`00
Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo
009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046OP1goo
0P000Woo0`000Woo0`000goo0`0037oo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00
019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003io
o`03001oogoo019oo`03001oogoo011Wh0Ioo`04001oogoo0002Ool00`00Oomoo`02Ool01@00Oomo
ogoo00000Woo00<007ooOol02Woo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`80
01=oo`03001oogoo011Wh0Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool0
0`00Oomoo`0:Ool00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo
00<007ooOol046OP1Goo10000Woo100000=oo`00000017oo0`0037oo00<007ooOol0Pgoo00<006@O
I1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011Wh0Ioo`03001oogoo01aoo`03
001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007oo
Ool00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In0A
Ool00`00Oomoo`0AOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol046OP9Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05
001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001o
ogoo019oo`03001oogoo011Wh2Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000B
I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol2
000COol00`00Oomoo`0@In0UOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O
00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol0=Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03
001oogoo019oo`03001oogoo03Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000B
I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol0
0`00Oomoo`0BOol00`00Oomoo`0@0n`UOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol040?/9Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007oo
Oomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000J
Ool003ioo`8001=oo`03001oogoo0103k0aoo`03001oogoo01Ioo`03001oogoo08=oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O
00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@0n`6Ool40002Ool01000Oomoogoo
10004Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001o
ogoo0103k0Ioo`<00003Ool0000000<0009oo`04001oogoo000@Ool00`00Oomoo`23Ool00`00I1mT
7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT
7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol040?/27oo00D007ooOomoo`0000Ao
o`04001oogoo000@Ool00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007oo
Oomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:7oo1@0000Aoo`00
000000=oo`03001oogoo00Moo`03001oogoo019oo`03001oogoo0103k0Moo`8000=oo`03001oogoo
009oo`<0015oo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo
00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000ZOol01@00Oomoogoo0000
17oo00<007oo000027oo00<007ooOol04Woo00<007ooOol040?/4Goo00<007ooOol04Goo00<007oo
Ool0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00Ioo`<0019oo`03001oogoo0103k11oo`8001=oo`03001oogoo08=oo`03001T7f@O011T7`05
001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo
00006Woo000ZOol00`00Oomoo`02Ool01000Oomoogoo0P002Goo00<007ooOol04Woo00<007ooOol0
40?/9Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol002Yoo`07001oogooOol007oo0000
0Woo00<007ooOol027oo00<007ooOol04Woo00<007ooOol040?/9Goo00<007ooOol0Pgoo00<006@O
I1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Ool0000JOol002Uoo`8000Aoo`04001oogooOol30008Ool00`00Oomoo`0BOol00`00Oomo
o`0@0n`UOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol0=Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`8001=oo`03001oogoo
03Eoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O
00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomo
o`0@0IlUOol00`00Oomoo`23Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol0406O9Goo00<007ooOol0Pgoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogoo
Ool0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019o
o`03001oogoo0101WbEoo`03001oogoo08=oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00
Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomo
o`0BOol00`00Oomoo`0@0IlUOol00`00Oomoo`23OolD0003Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol0
0`00Oomoo`0@0Il6Ool40006Ool4000AOol00`00Oomoo`2JOol00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol2000COol00`00Oomo
o`0@0Il6Ool30008Ool01000Oomoo`0047oo00<007ooOol0VWoo00<006@OI1l046@O00D007ooOomo
o`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo
00<007ooOol0406O27oo00<007ooOol01Woo00@007ooOol0011oo`03001oogoo09Yoo`03001T7f@O
011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003io
o`03001oogoo019oo`03001oogoo0101W`Moo`80009oo`03001oo`0000=oo`<0015oo`03001oogoo
09Yooa@000=oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol0406O37oo00<007ooOol00Woo00<007ooOol04Goo00<007oo
Ool0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol0
0`00Oomoo`0BOol00`00Oomoo`0@0Il<Ool01000Oomoogoo0P004goo00<007ooOol0/Goo00<006@O
I1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol00`00Oomoo`0BOol0
0`00Oomoo`0@0IlUOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Ool0000JOol003ioo`8001=oo`03001oogoo0101WbEoo`03001oogoo0;5oo`03001T7f@O
011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol0=Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07oo00006Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2aOol00`00I1mT7`0@
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo019oo`03001o
ogoo011T7bEoo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<007ooOol0/Goo00<006@O
I1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo00006Woo000nOol2000COol00`00Oomo
o`0@I1lUOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Ool0000JOol003ioo`03001oogoo019oo`03001oogoo011T7bEoo`03001oogoo0;5oo`03001T7f@O
011T7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol046@O1Woo100000Aoo`00Ool0009oo`@0015oo`03001oogoo0;5oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
46@O1Woo0`000goo00<007ooOol00Woo00@007ooOol0011oo`03001oogoo0;5oo`03001T7f@O011T
7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007oo
Ool046@O27oo00<007ooOol00`000goo00@007ooOol0011oo`03001oogoo0;5oo`03001T7f@O011T
7`03001oogoo009oo`03001T7f@O00mT7`03001oo`0001Yoo`00:7oo1@000Woo00<007ooOol00Woo
00<007ooOol01goo00<007ooOol04Woo00<007ooOol046@O1goo0P000goo00<007ooOol00Woo0`00
4Goo00<007ooOol0/Goo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007oo0000
6Woo000ZOol01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`<0019oo`03001oogoo011T7a5o
o`03001oogoo015oo`03001oogoo0;5oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT
7`03001oo`0001Yoo`00:Woo00<007ooOol00goo00H007ooOol007oo0008Ool00`00Oomoo`0BOol0
0`00Oomoo`0@I1l@Ool2000COol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Ool0000JOol002Yoo`04001oogooOol20003Ool00`00Ool00008Ool00`00Oomo
o`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`2aOol00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Ool0000JOol002Yoo`05001oogooOol00004Ool00`00Ool00008Ool00`00Oomo
o`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`2aOolD0004Ool00`00I1mT7`0?I1l00`00Ool0000J
Ool002Uoo`8000=oo`<000=oo`03001oogoo00Moo`03001oogoo019oo`03001oogoo011T7bEoo`03
001oogoo0<Uoo`03001T7f@O00mT7`03001oo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
=Goo00<007ooOol0bGoo00<006@OI1l03f@O00<007oo00006Woo000nOol2000COoli003;Ool00`00
I1mT7`0?I1l00`00Ool0000JOol003ioo`03001oogoo0?mooaMoo`03001T7f@O00mT7`03001oo`00
01Yoo`00?Woo00<007ooOol0ogoo5goo4`0000=oo`00Ool06Goo000nOol00`00Oomoo`3oOol[Ool0
0`00Oomoo`0HOol003ioo`03001oogoo0?moob]oo`03001oogoo01Qoo`00?Woo0P00ogoo;7oo00<0
07ooOol067oo000nOooo000_000JOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00ogooQgoo002_Ool30002Ool30002Ool60002Ool01000Ool00000
0goo0`000goo0P000Woo0`0000Aoo`00001oo`800003Ool000000080009oo`80009oo`<0009oo`<0
009oo`04001oogoo002BOol00;1oo`03001oogoo009oo`04001oogooOol30002Ool01000Oomoo`00
0goo00D007ooOomoo`0000=oo`03001oogoo00=oo`04001oogoo0003Ool00`00Ool000020002Ool0
1000Oomoo`000Woo00<007ooOol00Woo00<007ooOol00Woo0P00Tgoo002`Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool01000Oomoo`000Woo00@007ooOol000Aoo`04001oogooOol30003Ool02000Oomo
o`00Ool007oo0003Ool01000Oomoo`001Goo00<007ooOol00Woo00<007ooOol00Woo0P00Tgoo002`
Ool01000Oomoogoo10000Woo0P0000=oo`0000000P000goo0P000Woo0`000Woo0`000Woo1P0000=o
o`0000000Woo0P0000=oo`0000000P000Woo100000=oo`0000000goo00@007ooOol0099oo`00[Woo
00D007oo001oo`0001Ioo`03001oogoo00Yoo`800003Ool0000000Ioo`03001oogoo0:9oo`00[Woo
1@005goo00<007ooOol02Goo0P0000=oo`0000004Goo00<007ooOol0Ugoo003oOon7Ool00?moohMo
o`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00001\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {683.625, 443.625}} -> {-1.56523, \
1.7501, 0.00540782, 0.00540782}, {{104.5, 474.313}, {677.875, 449.313}} -> \
{-6.30713, 359.909, 0.0431596, 0.885545}, {{178.438, 233.938}, {545.125, \
471.125}} -> {-10.9028, 24.6401, 0.0605412, 0.081082}}]
}, Open  ]],

Cell[TextData[{
  StyleBox["Grafik 50: ",
    FontWeight->"Bold"],
  "Ergebnis der Funktion TransferMatrix in Abh\[ADoubleDot]ngigkeit der \
Ordnung des St\[ODoubleDot]rparameters e."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Spur der Matrix ergibt sich \[UDoubleDot]ber die Funktion Tr[R] und wurde \
in Kapitel 2, Abschnitt 2.5. bis zur 17. Ordnung entwickelt. Die Anzahl der \
wachsenden Terme bleibt hier angenehmerweise klein in \
Abh\[ADoubleDot]ngigkeit mit steigender Ordnung .\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0384615 0.0769231 0.0147151 0.0226386 [
[.03846 -0.0125 -4.78125 -11.625 ]
[.03846 -0.0125 4.78125 0 ]
[.11538 -0.0125 -4.78125 -11.625 ]
[.11538 -0.0125 4.78125 0 ]
[.19231 -0.0125 -4.78125 -11.625 ]
[.19231 -0.0125 4.78125 0 ]
[.26923 -0.0125 -4.78125 -11.625 ]
[.26923 -0.0125 4.78125 0 ]
[.34615 -0.0125 -4.78125 -11.625 ]
[.34615 -0.0125 4.78125 0 ]
[.42308 -0.0125 -4.78125 -11.625 ]
[.42308 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.57692 -0.0125 -4.78125 -11.625 ]
[.57692 -0.0125 4.78125 0 ]
[.65385 -0.0125 -4.78125 -11.625 ]
[.65385 -0.0125 4.78125 0 ]
[.73077 -0.0125 -7.5625 -11.625 ]
[.73077 -0.0125 7.5625 0 ]
[.80769 -0.0125 -7.5625 -11.625 ]
[.80769 -0.0125 7.5625 0 ]
[.88462 -0.0125 -7.5625 -11.625 ]
[.88462 -0.0125 7.5625 0 ]
[.96154 -0.0125 -7.5625 -11.625 ]
[.96154 -0.0125 7.5625 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .12791 -9.5625 -5.8125 ]
[-0.0125 .12791 0 5.8125 ]
[-0.0125 .2411 -15.125 -5.8125 ]
[-0.0125 .2411 0 5.8125 ]
[-0.0125 .35429 -15.125 -5.8125 ]
[-0.0125 .35429 0 5.8125 ]
[-0.0125 .46749 -15.125 -5.8125 ]
[-0.0125 .46749 0 5.8125 ]
[-0.0125 .58068 -15.125 -5.8125 ]
[-0.0125 .58068 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26.75 -7.5625 ]
[-0.01875 .30902 -15.125 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -71.5313 0 ]
[.5 .63053 71.5313 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03846 0 m
.03846 .00625 L
s
gsave
.03846 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.11538 0 m
.11538 .00625 L
s
gsave
.11538 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.19231 0 m
.19231 .00625 L
s
gsave
.19231 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.26923 0 m
.26923 .00625 L
s
gsave
.26923 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.34615 0 m
.34615 .00625 L
s
gsave
.34615 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.42308 0 m
.42308 .00625 L
s
gsave
.42308 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
.57692 0 m
.57692 .00625 L
s
gsave
.57692 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
1.000 setlinewidth
grestore
.65385 0 m
.65385 .00625 L
s
gsave
.65385 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
1.000 setlinewidth
grestore
.73077 0 m
.73077 .00625 L
s
gsave
.73077 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
.80769 0 m
.80769 .00625 L
s
gsave
.80769 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
1.000 setlinewidth
grestore
.88462 0 m
.88462 .00625 L
s
gsave
.88462 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
1.000 setlinewidth
grestore
.96154 0 m
.96154 .00625 L
s
gsave
.96154 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(e) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12791 m
.00625 .12791 L
s
gsave
-0.0125 .12791 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
0 .2411 m
.00625 .2411 L
s
gsave
-0.0125 .2411 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .35429 m
.00625 .35429 L
s
gsave
-0.0125 .35429 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
1.000 setlinewidth
grestore
0 .46749 m
.00625 .46749 L
s
gsave
-0.0125 .46749 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .58068 m
.00625 .58068 L
s
gsave
-0.0125 .58068 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03735 m
.00375 .03735 L
s
0 .05999 m
.00375 .05999 L
s
0 .08263 m
.00375 .08263 L
s
0 .10527 m
.00375 .10527 L
s
0 .15055 m
.00375 .15055 L
s
0 .17319 m
.00375 .17319 L
s
0 .19582 m
.00375 .19582 L
s
0 .21846 m
.00375 .21846 L
s
0 .26374 m
.00375 .26374 L
s
0 .28638 m
.00375 .28638 L
s
0 .30902 m
.00375 .30902 L
s
0 .33166 m
.00375 .33166 L
s
0 .37693 m
.00375 .37693 L
s
0 .39957 m
.00375 .39957 L
s
0 .42221 m
.00375 .42221 L
s
0 .44485 m
.00375 .44485 L
s
0 .49013 m
.00375 .49013 L
s
0 .51276 m
.00375 .51276 L
s
0 .5354 m
.00375 .5354 L
s
0 .55804 m
.00375 .55804 L
s
0 .60332 m
.00375 .60332 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -132.531 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Tr) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.125 12.250 moveto
(@) show
79.688 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(TransferMatrix) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
157.563 12.250 moveto
(@) show
163.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
174.250 12.250 moveto
(D) show
179.813 12.250 moveto
(D) show
190.938 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
202.063 12.250 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.00769 .01472 m
.00769 .05999 L
.06923 .05999 L
.06923 .01472 L
F
0 g
.5 Mabswid
.00769 .01472 m
.00769 .05999 L
.06923 .05999 L
.06923 .01472 L
.00769 .01472 L
s
1 0 0 r
.08462 .01472 m
.08462 .05999 L
.14615 .05999 L
.14615 .01472 L
F
0 g
.08462 .01472 m
.08462 .05999 L
.14615 .05999 L
.14615 .01472 L
.08462 .01472 L
s
1 0 0 r
.16154 .01472 m
.16154 .05999 L
.22308 .05999 L
.22308 .01472 L
F
0 g
.16154 .01472 m
.16154 .05999 L
.22308 .05999 L
.22308 .01472 L
.16154 .01472 L
s
1 0 0 r
.23846 .01472 m
.23846 .05999 L
.3 .05999 L
.3 .01472 L
F
0 g
.23846 .01472 m
.23846 .05999 L
.3 .05999 L
.3 .01472 L
.23846 .01472 L
s
1 0 0 r
.31538 .01472 m
.31538 .05999 L
.37692 .05999 L
.37692 .01472 L
F
0 g
.31538 .01472 m
.31538 .05999 L
.37692 .05999 L
.37692 .01472 L
.31538 .01472 L
s
1 0 0 r
.39231 .01472 m
.39231 .05999 L
.45385 .05999 L
.45385 .01472 L
F
0 g
.39231 .01472 m
.39231 .05999 L
.45385 .05999 L
.45385 .01472 L
.39231 .01472 L
s
1 0 0 r
.46923 .01472 m
.46923 .05999 L
.53077 .05999 L
.53077 .01472 L
F
0 g
.46923 .01472 m
.46923 .05999 L
.53077 .05999 L
.53077 .01472 L
.46923 .01472 L
s
1 0 0 r
.54615 .01472 m
.54615 .05999 L
.60769 .05999 L
.60769 .01472 L
F
0 g
.54615 .01472 m
.54615 .05999 L
.60769 .05999 L
.60769 .01472 L
.54615 .01472 L
s
1 0 0 r
.62308 .01472 m
.62308 .05999 L
.68462 .05999 L
.68462 .01472 L
F
0 g
.62308 .01472 m
.62308 .05999 L
.68462 .05999 L
.68462 .01472 L
.62308 .01472 L
s
1 0 0 r
.7 .01472 m
.7 .05999 L
.76154 .05999 L
.76154 .01472 L
F
0 g
.7 .01472 m
.7 .05999 L
.76154 .05999 L
.76154 .01472 L
.7 .01472 L
s
1 0 0 r
.77692 .01472 m
.77692 .05999 L
.83846 .05999 L
.83846 .01472 L
F
0 g
.77692 .01472 m
.77692 .05999 L
.83846 .05999 L
.83846 .01472 L
.77692 .01472 L
s
1 0 0 r
.85385 .01472 m
.85385 .05999 L
.91538 .05999 L
.91538 .01472 L
F
0 g
.85385 .01472 m
.85385 .05999 L
.91538 .05999 L
.91538 .01472 L
.85385 .01472 L
s
1 0 0 r
.93077 .01472 m
.93077 .05999 L
.99231 .05999 L
.99231 .01472 L
F
0 g
.93077 .01472 m
.93077 .05999 L
.99231 .05999 L
.99231 .01472 L
.93077 .01472 L
s
.8 1 0 r
.00769 .05999 m
.00769 .08263 L
.06923 .08263 L
.06923 .05999 L
F
0 g
.00769 .05999 m
.00769 .08263 L
.06923 .08263 L
.06923 .05999 L
.00769 .05999 L
s
.8 1 0 r
.08462 .05999 m
.08462 .08263 L
.14615 .08263 L
.14615 .05999 L
F
0 g
.08462 .05999 m
.08462 .08263 L
.14615 .08263 L
.14615 .05999 L
.08462 .05999 L
s
.8 1 0 r
.16154 .05999 m
.16154 .08263 L
.22308 .08263 L
.22308 .05999 L
F
0 g
.16154 .05999 m
.16154 .08263 L
.22308 .08263 L
.22308 .05999 L
.16154 .05999 L
s
.8 1 0 r
.23846 .05999 m
.23846 .08263 L
.3 .08263 L
.3 .05999 L
F
0 g
.23846 .05999 m
.23846 .08263 L
.3 .08263 L
.3 .05999 L
.23846 .05999 L
s
.8 1 0 r
.31538 .05999 m
.31538 .08263 L
.37692 .08263 L
.37692 .05999 L
F
0 g
.31538 .05999 m
.31538 .08263 L
.37692 .08263 L
.37692 .05999 L
.31538 .05999 L
s
.8 1 0 r
.39231 .05999 m
.39231 .08263 L
.45385 .08263 L
.45385 .05999 L
F
0 g
.39231 .05999 m
.39231 .08263 L
.45385 .08263 L
.45385 .05999 L
.39231 .05999 L
s
.8 1 0 r
.46923 .05999 m
.46923 .08263 L
.53077 .08263 L
.53077 .05999 L
F
0 g
.46923 .05999 m
.46923 .08263 L
.53077 .08263 L
.53077 .05999 L
.46923 .05999 L
s
.8 1 0 r
.54615 .05999 m
.54615 .08263 L
.60769 .08263 L
.60769 .05999 L
F
0 g
.54615 .05999 m
.54615 .08263 L
.60769 .08263 L
.60769 .05999 L
.54615 .05999 L
s
.8 1 0 r
.62308 .05999 m
.62308 .08263 L
.68462 .08263 L
.68462 .05999 L
F
0 g
.62308 .05999 m
.62308 .08263 L
.68462 .08263 L
.68462 .05999 L
.62308 .05999 L
s
.8 1 0 r
.7 .05999 m
.7 .08263 L
.76154 .08263 L
.76154 .05999 L
F
0 g
.7 .05999 m
.7 .08263 L
.76154 .08263 L
.76154 .05999 L
.7 .05999 L
s
.8 1 0 r
.77692 .05999 m
.77692 .08263 L
.83846 .08263 L
.83846 .05999 L
F
0 g
.77692 .05999 m
.77692 .08263 L
.83846 .08263 L
.83846 .05999 L
.77692 .05999 L
s
.8 1 0 r
.85385 .05999 m
.85385 .08263 L
.91538 .08263 L
.91538 .05999 L
F
0 g
.85385 .05999 m
.85385 .08263 L
.91538 .08263 L
.91538 .05999 L
.85385 .05999 L
s
.8 1 0 r
.93077 .05999 m
.93077 .08263 L
.99231 .08263 L
.99231 .05999 L
F
0 g
.93077 .05999 m
.93077 .08263 L
.99231 .08263 L
.99231 .05999 L
.93077 .05999 L
s
0 1 .4 r
.00769 .08263 m
.00769 .08263 L
.06923 .08263 L
.06923 .08263 L
F
0 g
.00769 .08263 m
.00769 .08263 L
.06923 .08263 L
.06923 .08263 L
.00769 .08263 L
s
0 1 .4 r
.08462 .08263 m
.08462 .10527 L
.14615 .10527 L
.14615 .08263 L
F
0 g
.08462 .08263 m
.08462 .10527 L
.14615 .10527 L
.14615 .08263 L
.08462 .08263 L
s
0 1 .4 r
.16154 .08263 m
.16154 .10527 L
.22308 .10527 L
.22308 .08263 L
F
0 g
.16154 .08263 m
.16154 .10527 L
.22308 .10527 L
.22308 .08263 L
.16154 .08263 L
s
0 1 .4 r
.23846 .08263 m
.23846 .10527 L
.3 .10527 L
.3 .08263 L
F
0 g
.23846 .08263 m
.23846 .10527 L
.3 .10527 L
.3 .08263 L
.23846 .08263 L
s
0 1 .4 r
.31538 .08263 m
.31538 .10527 L
.37692 .10527 L
.37692 .08263 L
F
0 g
.31538 .08263 m
.31538 .10527 L
.37692 .10527 L
.37692 .08263 L
.31538 .08263 L
s
0 1 .4 r
.39231 .08263 m
.39231 .10527 L
.45385 .10527 L
.45385 .08263 L
F
0 g
.39231 .08263 m
.39231 .10527 L
.45385 .10527 L
.45385 .08263 L
.39231 .08263 L
s
0 1 .4 r
.46923 .08263 m
.46923 .10527 L
.53077 .10527 L
.53077 .08263 L
F
0 g
.46923 .08263 m
.46923 .10527 L
.53077 .10527 L
.53077 .08263 L
.46923 .08263 L
s
0 1 .4 r
.54615 .08263 m
.54615 .10527 L
.60769 .10527 L
.60769 .08263 L
F
0 g
.54615 .08263 m
.54615 .10527 L
.60769 .10527 L
.60769 .08263 L
.54615 .08263 L
s
0 1 .4 r
.62308 .08263 m
.62308 .10527 L
.68462 .10527 L
.68462 .08263 L
F
0 g
.62308 .08263 m
.62308 .10527 L
.68462 .10527 L
.68462 .08263 L
.62308 .08263 L
s
0 1 .4 r
.7 .08263 m
.7 .10527 L
.76154 .10527 L
.76154 .08263 L
F
0 g
.7 .08263 m
.7 .10527 L
.76154 .10527 L
.76154 .08263 L
.7 .08263 L
s
0 1 .4 r
.77692 .08263 m
.77692 .10527 L
.83846 .10527 L
.83846 .08263 L
F
0 g
.77692 .08263 m
.77692 .10527 L
.83846 .10527 L
.83846 .08263 L
.77692 .08263 L
s
0 1 .4 r
.85385 .08263 m
.85385 .10527 L
.91538 .10527 L
.91538 .08263 L
F
0 g
.85385 .08263 m
.85385 .10527 L
.91538 .10527 L
.91538 .08263 L
.85385 .08263 L
s
0 1 .4 r
.93077 .08263 m
.93077 .10527 L
.99231 .10527 L
.99231 .08263 L
F
0 g
.93077 .08263 m
.93077 .10527 L
.99231 .10527 L
.99231 .08263 L
.93077 .08263 L
s
0 .4 1 r
.00769 .08263 m
.00769 .10527 L
.06923 .10527 L
.06923 .08263 L
F
0 g
.00769 .08263 m
.00769 .10527 L
.06923 .10527 L
.06923 .08263 L
.00769 .08263 L
s
0 .4 1 r
.08462 .10527 m
.08462 .15055 L
.14615 .15055 L
.14615 .10527 L
F
0 g
.08462 .10527 m
.08462 .15055 L
.14615 .15055 L
.14615 .10527 L
.08462 .10527 L
s
0 .4 1 r
.16154 .10527 m
.16154 .15055 L
.22308 .15055 L
.22308 .10527 L
F
0 g
.16154 .10527 m
.16154 .15055 L
.22308 .15055 L
.22308 .10527 L
.16154 .10527 L
s
0 .4 1 r
.23846 .10527 m
.23846 .17319 L
.3 .17319 L
.3 .10527 L
F
0 g
.23846 .10527 m
.23846 .17319 L
.3 .17319 L
.3 .10527 L
.23846 .10527 L
s
0 .4 1 r
.31538 .10527 m
.31538 .17319 L
.37692 .17319 L
.37692 .10527 L
F
0 g
.31538 .10527 m
.31538 .17319 L
.37692 .17319 L
.37692 .10527 L
.31538 .10527 L
s
0 .4 1 r
.39231 .10527 m
.39231 .19582 L
.45385 .19582 L
.45385 .10527 L
F
0 g
.39231 .10527 m
.39231 .19582 L
.45385 .19582 L
.45385 .10527 L
.39231 .10527 L
s
0 .4 1 r
.46923 .10527 m
.46923 .19582 L
.53077 .19582 L
.53077 .10527 L
F
0 g
.46923 .10527 m
.46923 .19582 L
.53077 .19582 L
.53077 .10527 L
.46923 .10527 L
s
0 .4 1 r
.54615 .10527 m
.54615 .21846 L
.60769 .21846 L
.60769 .10527 L
F
0 g
.54615 .10527 m
.54615 .21846 L
.60769 .21846 L
.60769 .10527 L
.54615 .10527 L
s
0 .4 1 r
.62308 .10527 m
.62308 .21846 L
.68462 .21846 L
.68462 .10527 L
F
0 g
.62308 .10527 m
.62308 .21846 L
.68462 .21846 L
.68462 .10527 L
.62308 .10527 L
s
0 .4 1 r
.7 .10527 m
.7 .35429 L
.76154 .35429 L
.76154 .10527 L
F
0 g
.7 .10527 m
.7 .35429 L
.76154 .35429 L
.76154 .10527 L
.7 .10527 L
s
0 .4 1 r
.77692 .10527 m
.77692 .35429 L
.83846 .35429 L
.83846 .10527 L
F
0 g
.77692 .10527 m
.77692 .35429 L
.83846 .35429 L
.83846 .10527 L
.77692 .10527 L
s
0 .4 1 r
.85385 .10527 m
.85385 .39957 L
.91538 .39957 L
.91538 .10527 L
F
0 g
.85385 .10527 m
.85385 .39957 L
.91538 .39957 L
.91538 .10527 L
.85385 .10527 L
s
0 .4 1 r
.93077 .10527 m
.93077 .39957 L
.99231 .39957 L
.99231 .10527 L
F
0 g
.93077 .10527 m
.93077 .39957 L
.99231 .39957 L
.99231 .10527 L
.93077 .10527 L
s
.8 0 1 r
.00769 .10527 m
.00769 .12791 L
.06923 .12791 L
.06923 .10527 L
F
0 g
.00769 .10527 m
.00769 .12791 L
.06923 .12791 L
.06923 .10527 L
.00769 .10527 L
s
.8 0 1 r
.08462 .15055 m
.08462 .21846 L
.14615 .21846 L
.14615 .15055 L
F
0 g
.08462 .15055 m
.08462 .21846 L
.14615 .21846 L
.14615 .15055 L
.08462 .15055 L
s
.8 0 1 r
.16154 .15055 m
.16154 .21846 L
.22308 .21846 L
.22308 .15055 L
F
0 g
.16154 .15055 m
.16154 .21846 L
.22308 .21846 L
.22308 .15055 L
.16154 .15055 L
s
.8 0 1 r
.23846 .17319 m
.23846 .26374 L
.3 .26374 L
.3 .17319 L
F
0 g
.23846 .17319 m
.23846 .26374 L
.3 .26374 L
.3 .17319 L
.23846 .17319 L
s
.8 0 1 r
.31538 .17319 m
.31538 .26374 L
.37692 .26374 L
.37692 .17319 L
F
0 g
.31538 .17319 m
.31538 .26374 L
.37692 .26374 L
.37692 .17319 L
.31538 .17319 L
s
.8 0 1 r
.39231 .19582 m
.39231 .30902 L
.45385 .30902 L
.45385 .19582 L
F
0 g
.39231 .19582 m
.39231 .30902 L
.45385 .30902 L
.45385 .19582 L
.39231 .19582 L
s
.8 0 1 r
.46923 .19582 m
.46923 .30902 L
.53077 .30902 L
.53077 .19582 L
F
0 g
.46923 .19582 m
.46923 .30902 L
.53077 .30902 L
.53077 .19582 L
.46923 .19582 L
s
.8 0 1 r
.54615 .21846 m
.54615 .35429 L
.60769 .35429 L
.60769 .21846 L
F
0 g
.54615 .21846 m
.54615 .35429 L
.60769 .35429 L
.60769 .21846 L
.54615 .21846 L
s
.8 0 1 r
.62308 .21846 m
.62308 .35429 L
.68462 .35429 L
.68462 .21846 L
F
0 g
.62308 .21846 m
.62308 .35429 L
.68462 .35429 L
.68462 .21846 L
.62308 .21846 L
s
.8 0 1 r
.7 .35429 m
.7 .5354 L
.76154 .5354 L
.76154 .35429 L
F
0 g
.7 .35429 m
.7 .5354 L
.76154 .5354 L
.76154 .35429 L
.7 .35429 L
s
.8 0 1 r
.77692 .35429 m
.77692 .5354 L
.83846 .5354 L
.83846 .35429 L
F
0 g
.77692 .35429 m
.77692 .5354 L
.83846 .5354 L
.83846 .35429 L
.77692 .35429 L
s
.8 0 1 r
.85385 .39957 m
.85385 .60332 L
.91538 .60332 L
.91538 .39957 L
F
0 g
.85385 .39957 m
.85385 .60332 L
.91538 .60332 L
.91538 .39957 L
.85385 .39957 L
s
.8 0 1 r
.93077 .39957 m
.93077 .60332 L
.99231 .60332 L
.99231 .39957 L
F
0 g
.93077 .39957 m
.93077 .60332 L
.99231 .60332 L
.99231 .39957 L
.93077 .39957 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
d7oo00<007ooOol01Woo00<007ooOol0ZWoo003?Ool00`00Oomoo`08Ool00`00Oomoo`2YOol00<Uo
o`8000=oo`03001oogoo00=oo`8000Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo00Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001oogoo009o
o`<000Eoo`03001oogoo0:Qoo`00b7oo00@007ooOol0009oo`03001oogoo009oo`<000Eoo`03001o
ogoo0:Qoo`00b7oo00@007ooOol000=oo`03001oogoo00Qoo`03001oogoo0:Uoo`00bGoo0P001Goo
00<007ooOol01Woo00<007ooOol0ZWoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?mo
ohMoo`00A7oo1@004goo0`005Goo0P005Woo0`0057oo00<007ooOol04goo0P005Woo00<007ooOol0
57oo00<007ooOol057oo0P004Goo1@000Woo00<007ooOol03Goo2P003Goo1@0000Aoo`00000000mo
o`D00003Ool0000002Ioo`00AWoo00<007ooOol04goo00<007ooOol05goo00<007ooOol057oo00<0
07ooOol04Woo00<007oo000057oo00<007oo00005Goo00<007ooOol04goo00<007oo00005goo00<0
07ooOol047oo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool00`00Oomoo`0?Ool01@00Oomo
ogoo00004goo00<007ooOol00goo00<007ooOol08goo0016Ool00`00Oomoo`0DOol00`00Oomoo`0E
Ool00`00Oomoo`0COol4000EOol00`00Oomoo`0BOol00`00Ool0000EOol00`00Oomoo`0COol00`00
Ool0000FOol2000BOol01`00Oomoogoo001oo`00011oo`03001oogoo009oo`03001oogoo00moo`03
001oogoo009oo`03001oogoo011oo`03001oogoo009oo`03001oogoo02Aoo`00AWoo00<007ooOol0
57oo00<007ooOol05Woo00<007ooOol04Woo00<007oo000057oo0P005Goo0P005goo00<007ooOol0
4goo00<007ooOol057oo00<007oo00004Woo00L007ooOomoo`00Ool0000@Ool00`00Oomoo`02Ool0
0`00Oomoo`0?Ool00`00Oomoo`02Ool00`00Oomoo`0@Ool00`00Oomoo`03Ool00`00Oomoo`0SOol0
04Ioo`03001oogoo01=oo`03001oo`0001Eoo`03001oo`0001Eoo`8001Aoo`03001oogoo01Aoo`03
001oogoo01Aoo`03001oo`0001Aoo`03001oo`0001Eoo`03001oo`00019oo`07001oogooOol007oo
000047oo00<007ooOol00Woo00<007ooOol03goo00L007ooOomoo`00Ool0000AOol01`00Oomoogoo
001oo`0002Eoo`00AGoo0P005Woo00<007ooOol05Goo00<007ooOol05Goo00<007ooOol04Woo0`00
5Goo0P0057oo0`005Goo00<007ooOol05Goo0P004Goo0P0017oo00<007ooOol03Woo0P000goo0P00
47oo0P0017oo00<007ooOol03goo0P0017oo00<007ooOol097oo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00?7ooo`00;`0077oo000lOol00`00Oomoo`08Ool00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`0DOol00`00Oomoo`0EOol00`00Oomoo`0DOol00`00Oomoo`0D
Ool00`00Oomoo`0DOol00`00Oomoo`09Ool00`00Oomoo`0JOol003aoo`03001oogoo00Qoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo01Aoo`03001oogoo01Eoo`03001oogoo01Aoo`03001o
ogoo01Aoo`03001oogoo01Aoo`03001oogoo00Uoo`03001oogoo01Yoo`00<Woo00<007ooOol01goo
00<007ooOol0ogoo:goo00<007ooOol06Woo000aOol00`00Ool00008Ool00`00Oomoo`3oOol[Ool0
0`00Oomoo`0JOol0035oo`03001oo`0000Qoool002l001aoo`00<Goo00<007oo000027oo00<007oo
00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000?O0001000Oomoo`0077oo000aOol00`00Ool00008Ool00`00Ool0000AO0000`00
Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
00ml0004001oogoo000LOol0039oo`03001oogoo00Moo`03001oo`00015l0003001oogoo009oo`03
001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`0011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007oo
Ool001aoo`00?7oo00<007oo00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00
019l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00
019l0005001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000A
O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005
001oogooOol0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?
O0000`00Oomoo`02Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03
001l07`000ml0004001oogoo000LOol003aoo`03001oo`00015l0003001oogoo009oo`03001l07`0
011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo
009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0
011l0005001oogooOol0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`0
00<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001ao
o`00?7oo0`004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogoo
Ool0000BO0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00
Oomoo`02Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000AO0000`00Oomoo`02
Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03
001l07`000ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004
001oogoo000LOol003aoo`03001oo`00015l0003001oogoo009oo`03001l07`0011l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogoo
Ool0000BO0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo
00<007`0O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo00<007oo
00004G`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O00047`000D007ooOomoo`00019l0005001oogooOol0000B
O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02
Ool00`00O01l000?O0001000Oomoo`0077oo000lOol00`00Ool0000AO0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0005001oogooOol0000BO0000`00
Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00O01l000?O0000`00Oomoo`02Ool00`00
O01l000@O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`0
00ml0003001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`000ml0004001oogoo
000LOol003aoo`03001oo`00015l0003001oogoo009oo`03001l07`0011l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000D007ooOomoo`00019l0003001oogoo009oo`03001l07`000ml0003
001oogoo009oo`03001l07`000ml0003001oogoo009oo`03001l07`0011l0005001oogooOol0000B
O0001@00Oomoogoo00004W`000<007ooOol00Woo00<007`0O0003g`000<007ooOol00Woo00<007`0
O0003g`000<007ooOol00Woo00<007`0O0003g`000@007ooOol001aoo`00?7oo5@0017oo50000goo
50000goo50000goo500017oo4`0017oo4`0017oo50000goo50000goo500017oo4`0017oo4`0017oo
4`000Woo00<007ooOol06Woo000lOol00`00Ool0000AIn000`00Oomoo`02Ool00`00In1Wh00@In00
1@00Oomoogoo00004VOP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In00
1@00Oomoogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001o
ogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh004001oogoo000LOol003ao
o`03001oo`00015Wh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomo
ogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomo
ogoo00004VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<0
07ooOol00Woo00<006OPIn003fOP00@007ooOol001aoo`00?7oo00<007oo00004FOP00<007ooOol0
0Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn001@00Oomoogoo0000
4VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol0
0Woo00<006OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool0
0`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In00
1000Oomoo`0077oo000lOol00`00Ool0000AIn000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomo
ogoo00004VOP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00@In001@00Oomo
ogoo00004VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009o
o`03001Wh6OP00mWh003001oogoo009oo`03001Wh6OP00mWh004001oogoo000LOol003aoo`03001o
o`00015Wh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo0000
4VOP00D007ooOomoo`00019Wh003001oogoo009oo`03001Wh6OP00mWh003001oogoo009oo`03001W
h6OP00mWh003001oogoo009oo`03001Wh6OP011Wh005001oogooOol0000BIn001@00Oomoogoo0000
4VOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol0
0Woo00<006OPIn003fOP00@007ooOol001aoo`00?7oo00<007oo00004FOP00<007ooOol00Woo00<0
06OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn001@00Oomoogoo00004VOP00<0
07ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<006OPIn003fOP00<007ooOol00Woo00<0
06OPIn0046OP00D007ooOomoo`00019Wh005001oogooOol0000BIn000`00Oomoo`02Ool00`00In1W
h00?In000`00Oomoo`02Ool00`00In1Wh00?In000`00Oomoo`02Ool00`00In1Wh00?In001000Oomo
o`0077oo000lOolF0003OolD0003OolD0003OolD0003OolD0004OolC0004OolC0004OolD0003OolD
0003OolD0004OolC0004OolC0004OolC0002Ool00`00Oomoo`0JOol003aoo`03001oo`000141W`03
001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00D007oo
Oomoo`000183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003
001oogoo009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007oo
Ool00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/
0n`03`?/00@007ooOol001aoo`00?7oo00<007oo00004@6O00<007ooOol00Woo00<000?/0n`040?/
00D007ooOomoo`000183k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo
00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/
00D007ooOomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00
Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`01000Oomoo`0077oo000l
Ool00`00Ool0000A0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007oo
Oomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007oo
Oomoo`000183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003
001oogoo009oo`030003k0?/00l3k004001oogoo000LOol003aoo`03001oo`000141W`03001oogoo
009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00D007ooOomoo`00
0183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo
009oo`030003k0?/0103k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo
00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/
00@007ooOol001aoo`00?7oo00<007oo00004@6O00<007ooOol00Woo00<000?/0n`040?/00D007oo
Oomoo`000183k005001oogooOol0000B0n`01@00Oomoogoo00004P?/00<007ooOol00Woo00<000?/
0n`03`?/00<007ooOol00Woo00<000?/0n`03`?/00<007ooOol00Woo00<000?/0n`040?/00D007oo
Oomoo`000183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02
Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00?0n`01000Oomoo`0077oo000lOol00`00
Ool0000A0Il00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00
0183k005001oogooOol0000B0n`00`00Oomoo`02Ool00`000n`3k00?0n`00`00Oomoo`02Ool00`00
0n`3k00?0n`00`00Oomoo`02Ool00`000n`3k00@0n`01@00Oomoogoo00004P?/00D007ooOomoo`00
0183k003001oogoo009oo`030003k0?/00l3k003001oogoo009oo`030003k0?/00l3k003001oogoo
009oo`030003k0?/00l3k004001oogoo000LOol003aooaD000Aooa@000=ooa@000=ooa@000=ooa@0
00Aooa<000Aooa<000Aooa@000=ooa@000=ooa@000Aooa<000Aooa<000Aooa<0009oo`03001oogoo
01Yoo`00?7oo00<007oo00004F@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Ool0000AI1l0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol003aoo`03001oo`00015T7`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00
?7oo00<007oo00004F@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000bOol00`00Oomoo`07Ool00`00Ool0
000AI1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`04001oogoo000LOol0035oo`03001oo`0000Qoo`03001oo`00015T7`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00@007ooOol001aoo`00<goo00<007ooOol01Woo5@0017oo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000aOol20009Ool0
0`00Oomoo`0FOol00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`05001o
ogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol0035oo`03001oogoo00Qoo`03001oogoo01Ioo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00
<Goo0`0027oo00<007ooOol05Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0
000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0FOol00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003ao
o`03001oogoo01Ioo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol2000GOolD
0003OolD0003Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomo
o`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`05001oogooOol0
000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`04001oogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomo
o`0077oo000lOol00`00Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T
7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101
W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00
?7oo0P005goo00<006@OI1l046@O00D007ooOomoo`00019T7`04001oogooOolD0003OolD0004Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il0
1@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003ao
o`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00D0
07ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomo
o`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomo
o`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomo
o`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`04001oogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il0406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomo
o`0077oo000lOol00`00Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomo
o`00019T7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomo
o`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`8001Moo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009ooa<000Ao
oa<000Aoo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0406O00D007ooOomoo`000181
W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0FOol0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001o
ogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001oogooOol0000B0Il01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo00<006@OI1l0
46@O00D007ooOomoo`00019T7`05001oogooOol0000BI1l01@00Oomoogoo00004V@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il0
406O00D007ooOomoo`000181W`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo
000lOol00`00Oomoo`0FOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T
7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`000Il1W`0@0Il01@00Oomoogoo00004P6O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo01Ioo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004V@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O0101W`05001o
ogooOol0000B0Il01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo0P00
5goo50000goo50000goo00<006@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009ooa@000=ooa@000=oo`030001
W`6O0101W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo04Aoo`03001T7f@O011T
7`05001oogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181
W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009o
o`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo04Aoo`03001T7f@O011T7`05001o
ogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo04Aoo`03001T7f@O011T7`05001oogooOol0
000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009o
o`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`04001oogoo000LOol003aoo`03001oogoo04Aoo`03001T7f@O011T7`05001oogooOol0000BI1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001o
ogoo000LOol002]oo`D0009oo`03001oogoo00Moo`03001oogoo04Aoo`03001T7f@O011T7`05001o
ogooOol0000BI1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol002eoo`07001oogooOol007oo000027oo00<007ooOol0A7oo00<0
06@OI1l046@O00D007ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00;Goo00L007ooOomoo`00Ool00008Ool2
0015Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T
7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000]Ool01`00Oomoogoo001o
o`0000Qoo`03001oogoo04Aoo`03001T7f@O011T7`05001oogooOol0000BI1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol002eo
o`07001oogooOol007oo000027oo00<007ooOol0A7oo00<006@OI1l046@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@0
07ooOol001aoo`00;7oo0P0017oo00<007ooOol01goo00<007ooOol0A7oo00<006@OI1l046@O00D0
07ooOomoo`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<0
07ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0A7oo00<006@OI1l046@O00D007ooOomo
o`00019T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00@007ooOol001aoo`00?7oo00<007ooOol0A7oo00<006@OI1l046@O00D007ooOomoo`00019T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@0
07ooOol001aoo`00?7oo00<007ooOol0A7oo00<006@OI1l046@O00D007ooOomoo`00019T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T
7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol0
01aoo`00?7oo0P00AGoo50000goo500017oo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D0
07ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1
W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo07=oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001o
ogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol0
0Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<0
07ooOol0Lgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1
W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomo
o`0077oo000lOol00`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomo
ogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol0Lgoo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol2001dOol0
0`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0@I1l0
1@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001o
ogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003ao
o`03001oogoo07=oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0
006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@0
07ooOol001aoo`007Goo00<007ooOol00Woo00<007ooOol05goo00<007ooOol0Lgoo00<006@OI1l0
3f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l046@O00D007ooOomo
o`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool0
0`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000MOol6000IOol0
0`00Oomoo`1cOol00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001
W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001o
ogoo000LOol001ioo`80009oo`03001oogoo01Moo`03001oogoo07=oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O011T7`05001oogooOol0000BI1l0
1@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il0
3`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`007Goo00<007ooOol00P006Woo
00<007ooOol0Lgoo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`00
0Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000
Oomoo`0077oo000MOol6000IOol2001dOolC0004OolC0004Ool00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol001moo`05001oo`00
Ool0000HOol00`00Oomoo`2QOol00`00I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`00
0181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`04001oogoo000LOol001ioo`D001Uoo`03001oogoo0:5oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001ao
o`007Goo00L007oo001oo`00Ool0000HOol00`00Oomoo`2QOol00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol001ioo`D001Uoo`03
001oogoo0:5oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007oo
Ool00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O
0Il03`6O00@007ooOol001aoo`007Goo00D007oo001oo`0001Yoo`03001oogoo0:5oo`03001T7f@O
011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo00<0006O0Il03`6O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001ao
o`00?7oo00<007ooOol0XGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02
Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol2002ROol00`00I1mT7`0@I1l01@00Oomoogoo
00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`03
0001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol003aoo`03001oogoo
0:5oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo00004P6O00<007ooOol00Woo
00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O
00@007ooOol001aoo`00?7oo00<007ooOol0XGoo00<006@OI1l046@O00D007ooOomoo`00019T7`05
001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`2QOol00`00
I1mT7`0@I1l01@00Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O
00l1W`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo
000LOol003aoo`03001oogoo0:5oo`03001T7f@O011T7`05001oogooOol0000BI1l01@00Oomoogoo
00004P6O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00<007oo
Ool00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol05Woo=`00E7oo00<006@O
I1l046@O00D007ooOomoo`00019T7`05001oogooOol0000B0Il00`00Oomoo`02Ool00`000Il1W`0?
0Il00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`00
77oo000[Ool50002Ool00`00Oomoo`07Ool00`00Oomoo`0DOoli001DOol00`00I1mT7`0@I1l01@00
Oomoogoo00004V@O00D007ooOomoo`000181W`03001oogoo009oo`030001W`6O00l1W`03001oogoo
009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol002eoo`07
001oogooOol007oo000027oo0P005Goo00<007ooOol0=Goo00<007ooOol0DWoo50000goo50000goo
500017oo4`0017oo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001ao
o`00;Goo00<007ooOol00goo00<007ooOol01Woo00<007ooOol057oo00<007ooOol0=Goo00<007oo
Ool0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00;Goo00@007ooOomoo`80
00Uoo`03001oogoo01Aoo`03001oogoo011l02Eoo`03001oogoo081oo`03001T7f@O011T7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001
W`6O00l1W`04001oogoo000LOol002eoo`05001oogooOol0000:Ool00`00Oomoo`0DOol00`00Oomo
o`0@O00UOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000/
Ool20003Ool30008Ool00`00Oomoo`0DOol00`00Oomoo`0@O00;Ool2000HOol00`00Oomoo`20Ool0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il0
0`00Oomoo`02Ool00`000Il1W`0?0Il01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomo
o`0@O00<Ool00`00Oomoo`0FOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`000Il1W`0?0Il00`00Oomoo`02Ool00`000Il1W`0?0Il01000
Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@O006Ool20004Ool01`00Oomoo`00Ool0
07oo00D000eoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol0
03aoo`8001Eoo`03001oogoo011l00Qoo`0>001oogoo001oo`00Ool007oo001oo`00Ool0009oo`03
001oogoo00Yoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001oogoo000LOol0
03aoo`03001oogoo01Aoo`03001oogoo011l00Moo`0?001oogooOol007oo001oo`00Ool007oo001o
o`00009oo`03001oogoo00Yoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`030001W`6O00l1W`03001oogoo009oo`030001W`6O00l1W`04001o
ogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011l00Moo`800004Ool00000Ool4000017oo
001oogoo0`003Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001ao
o`00?7oo00<007ooOol057oo00<007ooOol047`05Goo00<007ooOol03Goo00<007ooOol0P7oo00<0
06@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<0
07ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol0
47`057oo0P003goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001ao
o`00?7oo00<007ooOol057oo00<007ooOol047`09Goo00<007ooOol0P7oo00<006@OI1l046@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O0Il03`6O00<007ooOol00Woo00<0
006O0Il03`6O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol047`09Goo00<007oo
Ool0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0006O
0Il03`6O00<007ooOol00Woo00<0006O0Il03`6O00@007ooOol001aoo`00?7oo0P005Goo00<007oo
Ool047`09Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<0
07ooOol00Woo4`0017oo4`000Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0e
Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00
Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000
Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0UOol00`00Oomoo`20Ool00`00I1mT
7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0F
Ool2000=Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0@In0HOol00`00Oomoo`0:Ool00`00Oomoo`20Ool00`00I1mT
7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2000EOol00`00Oomoo`0@In07Ool20002
Ool30002Ool30003Ool3000<Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000
Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In06Ool01000Oomoo`000Woo00<007oo
Ool00Woo00D007ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo081oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011Wh0Ioo`03001o
ogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`20Ool0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomo
o`0@In05Ool40002Ool400000goo00000004Ool3000<Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In06Ool00`00
Oomoo`0LOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00
Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0@In0AOol00`00Oomoo`0AOol00`00Oomoo`20Ool00`00I1mT
7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0U
Ool00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol2000E
Ool00`00Oomoo`0@In0UOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomo
o`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0UOol00`00Oomoo`20Ool00`00I1mT7`0@
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00
Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0D
Ool00`00Oomoo`0eOol00`00Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?
I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`00
77oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`UOol00`00Oomoo`20Ool00`00I1mT7`0@I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool0
0`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`UOol00`00
Oomoo`20Ool00`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00
I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000/Ool30003Ool00`00
Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0@0n`<Ool00`00Oomoo`0FOol00`00Oomoo`20Ool0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000/Ool00`00Oomoo`02Ool00`00Ool0
0008Ool2000EOol00`00Oomoo`0@0n`6Ool40002Ool01000Oomoogoo10004Goo00<007ooOol0P7oo
00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00;Goo00L007ooOomoo`00Ool00008
Ool00`00Oomoo`0DOol00`00Oomoo`0@0n`6Ool300000goo000000030002Ool01000Oomoo`0047oo
00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00;Goo00L007oo
Oomoo`00Ool00008Ool00`00Oomoo`0DOol00`00Oomoo`0@0n`8Ool01@00Oomoogoo000017oo00@0
07ooOol0011oo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol0
02aoo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo01Aoo`03001oogoo0103k0Moo`8000=o
o`03001oogoo009oo`<0015oo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001o
ogoo000LOol002eoo`03001oogoo009oo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo0103
k15oo`03001oogoo015oo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo
000LOol003aoo`03001oogoo01Aoo`03001oogoo0103k11oo`8001=oo`03001oogoo081oo`03001T
7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo0103
k2Eoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`80
01Eoo`03001oogoo0103k2Eoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001o
ogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo0103k2Eoo`03001oogoo081oo`03001T7f@O
011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo03Eoo`03
001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo
01Aoo`03001oogoo03Eoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo
000LOol003aoo`03001oogoo01Aoo`03001oogoo0101WbEoo`03001oogoo081oo`03001T7f@O011T
7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009o
o`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo0101WbEoo`03
001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo
01Aoo`03001oogoo0101WbEoo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001o
ogoo000LOol003aoo`8001Eoo`03001oogoo0101WbEoo`03001oogoo081oo`03001T7f@O011T7`03
001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03
001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo0101W`Ioo`@000Io
o`@0015oo`03001oogoo081oo`03001T7f@O011T7`03001oogoo009oo`03001T7f@O00mT7`03001o
ogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003ao
o`03001oogoo01Aoo`03001oogoo0101W`Ioo`<000Qoo`04001oogoo000@Ool00`00Oomoo`20Ool0
0`00I1mT7`0@I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l0
0`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol00`00Oomo
o`0@0Il8Ool00`00Oomoo`06Ool01000Oomoo`0047oo00<007ooOol0P7oo00<006@OI1l046@O00<0
07ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<0
06@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol057oo00<007ooOol0406O1goo0P000Woo
00<007oo00000goo0`004Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@O
I1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007oo
Ool001aoo`00?7oo00<007ooOol057oo00<007ooOol0406O37oo00<007ooOol00Woo00<007ooOol0
4Goo00<007ooOol0P7oo00<006@OI1l046@O00<007ooOol00Woo00<006@OI1l03f@O00<007ooOol0
0Woo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<0
07ooOol057oo00<007ooOol0406O37oo00@007ooOomoo`8001=oo`03001oogoo081oo`03001T7f@O
011T7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`03001oogoo
009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`8001Eoo`03001oogoo0101WbEoo`03001o
ogoo081ooa@000Aooa<000Aoo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001o
ogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo0101WbEoo`03001oogoo0:moo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03
001oogoo03Eoo`03001oogoo0:moo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04
001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo03Eoo`03001oogoo0:moo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03
001oogoo011T7bEoo`03001oogoo0:moo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011T7bEoo`03001oogoo0:moo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`8001Eoo`03
001oogoo011T7bEoo`03001oogoo0:moo`03001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT
7`04001oogoo000LOol003aoo`03001oogoo01Aoo`03001oogoo011T7bEoo`03001oogoo0:moo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo
01Aoo`03001oogoo011T7`Ioo`@00004Ool007oo0002Ool4000AOol00`00Oomoo`2_Ool00`00I1mT
7`0?I1l00`00Oomoo`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000lOol00`00Oomoo`0DOol0
0`00Oomoo`0@I1l6Ool30003Ool00`00Oomoo`02Ool01000Oomoo`0047oo00<007ooOol0[goo00<0
06@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol0
57oo00<007ooOol046@O27oo00<007ooOol00`000goo00@007ooOol0011oo`03001oogoo0:moo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol003aoo`03001oogoo
01Aoo`03001oogoo011T7`Moo`8000=oo`03001oogoo009oo`<0015oo`03001oogoo0:moo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol002aoo`<000=oo`03001o
ogoo00Moo`03001oogoo01Aoo`03001oogoo011T7a5oo`03001oogoo015oo`03001oogoo0:moo`03
001T7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol002aoo`03001oogoo
009oo`03001oo`0000Qoo`8001Eoo`03001oogoo011T7a1oo`8001=oo`03001oogoo0:moo`03001T
7f@O00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol002eoo`03001oogoo00=o
o`03001oogoo00Ioo`03001oogoo01Aoo`03001oogoo011T7bEoo`03001oogoo0:moo`03001T7f@O
00mT7`03001oogoo009oo`03001T7f@O00mT7`04001oogoo000LOol002eoo`04001oogooOol20009
Ool00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomo
o`02Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000/Ool00`00Ool00002Ool00`00Oomoo`08Ool0
0`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2_Ool00`00I1mT7`0?I1l00`00Oomoo`02
Ool00`00I1mT7`0?I1l01000Oomoo`0077oo000]Ool01000Oomoogoo0`0027oo00<007ooOol057oo
00<007ooOol0=Goo00<007ooOol0[goo00<006@OI1l03f@O00<007ooOol00Woo00<006@OI1l03f@O
00@007ooOol001aoo`00?7oo00<007ooOol057oo>@00/Goo00<006@OI1l03f@O00<007ooOol00Woo
00<006@OI1l03f@O00@007ooOol001aoo`00?7oo00<007ooOol0oWoo00<006@OI1l03f@O00<007oo
Ool00Woo00<006@OI1l03f@O00@007ooOol001aoo`00?7oo0P00ogoo4`0017oo4`000Woo00<007oo
Ool06Woo000lOol00`00Oomoo`3oOol[Ool00`00Oomoo`0JOol003aoo`03001oogoo0?moob]oo`03
001oogoo01Yoo`00?7oo00<007ooOol0ogoo:goo00<007ooOol06Woo000lOooo000_000LOol00?mo
ohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool009Yoo`80055oo`8000io
o`8000=oo`80089oo`00VWoo00<007ooOol0D7oo00L007ooOomoo`00Ool0000:Ool00`00Oomoo`02
Ool00`00Oomoo`20Ool008ioo`<0009oo`<000Aoo`04001oogooOol30002Ool30002Ool60002Ool0
1000Ool000000goo0`000goo0P000Woo0`0000Aoo`00001oo`800003Ool000000080009oo`80009o
o`<0009oo`<0009oo`04001oogoo000:Ool00`00Oomoo`02Ool01000Ool007oo1@000goo00<007oo
Ool00Woo00<007ooOol027oo1000M7oo002?Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool01000Oomoogoo0`000Woo00@007ooOol000=oo`05001oogooOol00003
Ool00`00Oomoo`03Ool01000Oomoo`000goo00<007oo00000P000Woo00@007ooOol0009oo`03001o
ogoo009oo`03001oogoo009oo`8000]oo`04001oogooOol50002Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`08Ool00`00Ool0001eOol008moo`03001oogoo009oo`03001oogoo00=oo`03
001oogoo009oo`03001oogoo009oo`03001oogoo00=oo`04001oogoo0002Ool01000Oomoo`0017oo
00@007ooOomoo`<000=oo`08001oogoo001oo`00Ool000=oo`04001oogoo0005Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00
Oomoo`02Ool00`00Oomoo`08Ool2001fOol008moo`04001oogooOol40003Ool00`00Oomoo`02Ool0
1000Oomoogoo10000Woo0P0000=oo`0000000P000goo0P000Woo0`000Woo0`000Woo1P0000=oo`00
00000Woo0P0000=oo`0000000P000Woo100000=oo`0000000goo00@007ooOol000Yoo`04001oogoo
Ool50002Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00`00Oomoo`1dOol008eo
o`05001oo`00Ool00008Ool02000Oomoo`00Ool007oo000FOol00`00Oomoo`0:Ool200000goo0000
0006Ool00`00Oomoo`0JOol00`00Oomoo`02Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomo
o`02Ool00`00Oomoo`09Ool3001dOol008eoo`D000Qoo`800003Ool0000000<001Moo`03001oogoo
00Uoo`800003Ool00000015oo`03001oogoo00moo`8000Aoo`04001oo`00Ool20004Ool20003Ool2
0022Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMo
o`00\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {381.25, 141.25}} -> {-1.56523, \
0.114912, 0.00540782, 0.00540782}, {{104.5, 474.313}, {375.5, 146.938}} -> \
{-6.18709, 15.2593, 0.0431596, 0.146651}, {{178.438, 233.938}, {242.75, \
168.75}} -> {-10.9028, 0.122938, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 51: ",
    FontWeight->"Bold"],
  "\[CapitalUDoubleDot]bersicht \[UDoubleDot]ber die Termanzahl, die vom \
Algorithmus in Abh\[ADoubleDot]ngigkeit der Ordnung in e erzeugt werden."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:43"],

Cell["Kap. 2.5.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.3. Beschreibung der Algorithmen - Nichtlineare Analyse", "Subsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:44"],

Cell["\<\
Hier werden die Funktionen, die anhand der Algorithmen aus dem 3. Kapitel \
entstanden sind, definiert, kurz beschrieben und auf ihre Verwendbarkeit \
analysiert.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.1. ApproximateEquation",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:45"],

Cell["\<\
ApproximateEquation[n] gibt die Bewegungsgleichung des Sitnikovproblems mit \
r(t) - entwickelt um die Exzentrizit\[ADoubleDot]t e bis zur n-ten Ordnung - \
wieder.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:46"],

Cell["Die Bewegungsgleichung des Sitnikovproblems lautet: ", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(z\^\[DoublePrime]\  + 
        z\/\((\(r(t)\)\^2 + z\^2)\)\^\(3/2\) = 0\)\)\)], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Der Abstand der Prim\[ADoubleDot]rk\[ODoubleDot]rper r(t) ist \
\[UDoubleDot]ber die transzendente Keplergleichung u(t) = t+e*sin(u(t)) durch \
",
  Cell[BoxData[
      \(TraditionalForm\`r(t)\  = \ 1\/2\)]],
  "(1-e*cos(u(t))) gegeben. Entwickelt man u(t) nach dem \
St\[ODoubleDot]rparameter e, so erh\[ADoubleDot]lt man einen Ausdruck f\
\[UDoubleDot]r r(t) in Form einer Taylorreihe."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:47"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["PrimariesDistance",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(ApproximateEquation[n_Integer]\), ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            RowBox[{\({x}\), ",", 
              RowBox[{"$Derivation", "=", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  
                  RowBox[{\(x = PrimariesDistance[n]\), ",", 
                    "\[IndentingNewLine]", \(x = x\^2\), ",", 
                    "\[IndentingNewLine]", \(x = TrigReduce[x]\), ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{\(ApproximateEquation[n]\), "=", 
                      RowBox[{
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["z", "\[Prime]\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "+", \(z[t]\/\((Normal[x] + z[t]\^2)\)\^\(3/2\)\)}],
                         "\[Equal]", "0"}]}]}], "}"}]}]}], "]"}], 
          "\[LeftDoubleBracket]", \(-1\), "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:48"],

Cell["\<\
Die Gleichung ApproximateEquation[13] wurde f\[UDoubleDot]r die Bestimmung \
der numerischen L\[ODoubleDot]sungen in dieser Arbeit verwendet.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:49"],

Cell["Kap. 2.4., 3.4.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.2. PolynomialEquation",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:50"],

Cell[TextData[{
  "PolynomialEquation[n] entwickelt die Bewegungsgleichung des \
Sitnikovproblems nach e und z derart, dass in den Produkten ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(e\^l\),
            "TraditionalForm"], \(z\^m\)}], TraditionalForm]]],
  "    l+m \[LessEqual] n bleibt."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:51"],

Cell[TextData[{
  "Da nur L\[ODoubleDot]sungen mit kleinen Exzentrizit\[ADoubleDot]ten und \
Amplituden in dieser Arbeit untersucht wurden, wird die Differentialgleichung \
nach e und z derart entwickelt, dass in den auftretenden Termen ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(e\^l\),
            "TraditionalForm"], \(z\^m\)}], TraditionalForm]]],
  "  l+m \[LessEqual] n bleibt. Die L\[ODoubleDot]sungen sind somit auch nur \
in jenen Parametergrenzen konvergent, wo sowohl der Absolutbetrag der \
Exzentrizit\[ADoubleDot]t |e| als auch das Verh\[ADoubleDot]ltnis |z(t)/r(t)| \
kleiner 1 bleiben. Die Entwicklung nach dem Parameter e resultiert aus der \
Approximation von r(t), die Differentialgleichung kann daher durch die Form:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[\(z\^\[DoublePrime]\),
            "TraditionalForm"], "+", 
          " ", \(\[Sum]\+\(k\  = \ 0\)\%n\(\( g\_i\)(t)\) z\^\(2  k + 1\)\)}],
         " ", "=", "0"}], TraditionalForm]], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["beschrieben werden.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:52"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["PrimariesDistance",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(PolynomialEquation[n_Integer]\), ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            RowBox[{\({x}\), ",", 
              RowBox[{"$Derivation", "=", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  RowBox[{
                    RowBox[{"x", "=", 
                      RowBox[{
                        RowBox[{
                          SuperscriptBox["z", "\[Prime]\[Prime]",
                            MultilineFunction->None], "[", "t", "]"}], 
                        "+", \(\[Sum]\+\(k = 0\)\%\(\(n - 1\)\/2\)\(Binomial[\
\(-\(3\/2\)\), k]\ z[t]\^\(2\ k + 1\)\)\/r[t]\^\(2\ k + 3\)\)}]}], 
                    ",", \(x = 
                      x /. \[InvisibleSpace]r[t] \[Rule] 
                          PrimariesDistance[n]\), ",", 
                    "\[IndentingNewLine]", \(x = Normal[x]\), ",", 
                    "\[IndentingNewLine]", \(x = Expand[x]\), ",", 
                    "\[IndentingNewLine]", \(x = 
                      x /. \[InvisibleSpace]_\ z[t]\^j_\ e\^k_ \[RuleDelayed] 
                          0 /; j + k > n\), 
                    ",", \(x = 
                      x /. \[InvisibleSpace]_\ z[t]\^j_\ e | _\ z[
                                t]\ e\^j_ \[RuleDelayed] 
                          0 /; j \[GreaterEqual] n\), ",", 
                    "\[IndentingNewLine]", \(x = 
                      x /. \[InvisibleSpace]_\ z[t]\ e \[RuleDelayed] 
                          0 /; n \[Equal] 1\), ",", 
                    "\[IndentingNewLine]", \(x = TrigReduce[x]\), ",", 
                    "\[IndentingNewLine]", \(x = Collect[x, {z[t], e}]\), ",",
                     "\[IndentingNewLine]", \(PolynomialEquation[n] = 
                      x \[Equal] 0\)}], "}"}]}]}], "]"}], 
          "\[LeftDoubleBracket]", \(-1\), "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:53"],

Cell[TextData[{
  "Die Funktion approximiert die Bewegungsgleichung, indem sie den Abstand \
der Prim\[ADoubleDot]rk\[ODoubleDot]rper in die polynome Darstellung einsetzt \
und nach den kleinen Parametern entwickelt. Mit Hilfe von Ersetzungsregeln \
wird die Bedingung ",
  Cell[BoxData[
      \(TraditionalForm\`\(e\^l\) z\^m\)]],
  ", l+m \[LessEqual] n erf\[UDoubleDot]llt. Die Anzahl der durchzuf\
\[UDoubleDot]hrenden Operationen w\[ADoubleDot]chst exponentiell mit \
steigender Ordnung an, wie aus Grafik 52 ersichtlich ist:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0714286 0.142857 0.0147151 0.0057146 [
[.07143 -0.0125 -4.78125 -11.625 ]
[.07143 -0.0125 4.78125 0 ]
[.21429 -0.0125 -4.78125 -11.625 ]
[.21429 -0.0125 4.78125 0 ]
[.35714 -0.0125 -4.78125 -11.625 ]
[.35714 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.64286 -0.0125 -4.78125 -11.625 ]
[.64286 -0.0125 4.78125 0 ]
[.78571 -0.0125 -4.78125 -11.625 ]
[.78571 -0.0125 4.78125 0 ]
[.92857 -0.0125 -4.78125 -11.625 ]
[.92857 -0.0125 4.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .12901 -15.125 -5.8125 ]
[-0.0125 .12901 0 5.8125 ]
[-0.0125 .2433 -15.125 -5.8125 ]
[-0.0125 .2433 0 5.8125 ]
[-0.0125 .35759 -15.125 -5.8125 ]
[-0.0125 .35759 0 5.8125 ]
[-0.0125 .47188 -15.125 -5.8125 ]
[-0.0125 .47188 0 5.8125 ]
[-0.0125 .58618 -20.6875 -5.8125 ]
[-0.0125 .58618 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -32.3125 -7.5625 ]
[-0.01875 .30902 -20.6875 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -52.0625 0 ]
[.5 .63053 52.0625 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 0 m
.07143 .00625 L
s
gsave
.07143 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35714 0 m
.35714 .00625 L
s
gsave
.35714 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.64286 0 m
.64286 .00625 L
s
gsave
.64286 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92857 0 m
.92857 .00625 L
s
gsave
.92857 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .12901 m
.00625 .12901 L
s
gsave
-0.0125 .12901 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .2433 m
.00625 .2433 L
s
gsave
-0.0125 .2433 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .35759 m
.00625 .35759 L
s
gsave
-0.0125 .35759 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
0 .47188 m
.00625 .47188 L
s
gsave
-0.0125 .47188 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(80) show
1.000 setlinewidth
grestore
0 .58618 m
.00625 .58618 L
s
gsave
-0.0125 .58618 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .04329 m
.00375 .04329 L
s
0 .07186 m
.00375 .07186 L
s
0 .10043 m
.00375 .10043 L
s
0 .15758 m
.00375 .15758 L
s
0 .18615 m
.00375 .18615 L
s
0 .21473 m
.00375 .21473 L
s
0 .27187 m
.00375 .27187 L
s
0 .30045 m
.00375 .30045 L
s
0 .32902 m
.00375 .32902 L
s
0 .38616 m
.00375 .38616 L
s
0 .41474 m
.00375 .41474 L
s
0 .44331 m
.00375 .44331 L
s
0 .50046 m
.00375 .50046 L
s
0 .52903 m
.00375 .52903 L
s
0 .5576 m
.00375 .5576 L
s
0 .61475 m
.00375 .61475 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -95.0625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -113.063 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(PolynomialEquation) show
163.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01429 .01472 m
.01429 .02614 L
.12857 .02614 L
.12857 .01472 L
F
0 g
.5 Mabswid
.01429 .01472 m
.01429 .02614 L
.12857 .02614 L
.12857 .01472 L
.01429 .01472 L
s
1 0 0 r
.15714 .01472 m
.15714 .02614 L
.27143 .02614 L
.27143 .01472 L
F
0 g
.15714 .01472 m
.15714 .02614 L
.27143 .02614 L
.27143 .01472 L
.15714 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .02614 L
.41429 .02614 L
.41429 .01472 L
F
0 g
.3 .01472 m
.3 .02614 L
.41429 .02614 L
.41429 .01472 L
.3 .01472 L
s
1 0 0 r
.44286 .01472 m
.44286 .02614 L
.55714 .02614 L
.55714 .01472 L
F
0 g
.44286 .01472 m
.44286 .02614 L
.55714 .02614 L
.55714 .01472 L
.44286 .01472 L
s
1 0 0 r
.58571 .01472 m
.58571 .02614 L
.7 .02614 L
.7 .01472 L
F
0 g
.58571 .01472 m
.58571 .02614 L
.7 .02614 L
.7 .01472 L
.58571 .01472 L
s
1 0 0 r
.72857 .01472 m
.72857 .02614 L
.84286 .02614 L
.84286 .01472 L
F
0 g
.72857 .01472 m
.72857 .02614 L
.84286 .02614 L
.84286 .01472 L
.72857 .01472 L
s
1 0 0 r
.87143 .01472 m
.87143 .02614 L
.98571 .02614 L
.98571 .01472 L
F
0 g
.87143 .01472 m
.87143 .02614 L
.98571 .02614 L
.98571 .01472 L
.87143 .01472 L
s
.8 1 0 r
.01429 .02614 m
.01429 .02614 L
.12857 .02614 L
.12857 .02614 L
F
0 g
.01429 .02614 m
.01429 .02614 L
.12857 .02614 L
.12857 .02614 L
.01429 .02614 L
s
.8 1 0 r
.15714 .02614 m
.15714 .03186 L
.27143 .03186 L
.27143 .02614 L
F
0 g
.15714 .02614 m
.15714 .03186 L
.27143 .03186 L
.27143 .02614 L
.15714 .02614 L
s
.8 1 0 r
.3 .02614 m
.3 .03757 L
.41429 .03757 L
.41429 .02614 L
F
0 g
.3 .02614 m
.3 .03757 L
.41429 .03757 L
.41429 .02614 L
.3 .02614 L
s
.8 1 0 r
.44286 .02614 m
.44286 .05472 L
.55714 .05472 L
.55714 .02614 L
F
0 g
.44286 .02614 m
.44286 .05472 L
.55714 .05472 L
.55714 .02614 L
.44286 .02614 L
s
.8 1 0 r
.58571 .02614 m
.58571 .07186 L
.7 .07186 L
.7 .02614 L
F
0 g
.58571 .02614 m
.58571 .07186 L
.7 .07186 L
.7 .02614 L
.58571 .02614 L
s
.8 1 0 r
.72857 .02614 m
.72857 .10615 L
.84286 .10615 L
.84286 .02614 L
F
0 g
.72857 .02614 m
.72857 .10615 L
.84286 .10615 L
.84286 .02614 L
.72857 .02614 L
s
.8 1 0 r
.87143 .02614 m
.87143 .14044 L
.98571 .14044 L
.98571 .02614 L
F
0 g
.87143 .02614 m
.87143 .14044 L
.98571 .14044 L
.98571 .02614 L
.87143 .02614 L
s
0 1 .4 r
.01429 .02614 m
.01429 .03186 L
.12857 .03186 L
.12857 .02614 L
F
0 g
.01429 .02614 m
.01429 .03186 L
.12857 .03186 L
.12857 .02614 L
.01429 .02614 L
s
0 1 .4 r
.15714 .03186 m
.15714 .04329 L
.27143 .04329 L
.27143 .03186 L
F
0 g
.15714 .03186 m
.15714 .04329 L
.27143 .04329 L
.27143 .03186 L
.15714 .03186 L
s
0 1 .4 r
.3 .03757 m
.3 .06043 L
.41429 .06043 L
.41429 .03757 L
F
0 g
.3 .03757 m
.3 .06043 L
.41429 .06043 L
.41429 .03757 L
.3 .03757 L
s
0 1 .4 r
.44286 .05472 m
.44286 .089 L
.55714 .089 L
.55714 .05472 L
F
0 g
.44286 .05472 m
.44286 .089 L
.55714 .089 L
.55714 .05472 L
.44286 .05472 L
s
0 1 .4 r
.58571 .07186 m
.58571 .12901 L
.7 .12901 L
.7 .07186 L
F
0 g
.58571 .07186 m
.58571 .12901 L
.7 .12901 L
.7 .07186 L
.58571 .07186 L
s
0 1 .4 r
.72857 .10615 m
.72857 .18044 L
.84286 .18044 L
.84286 .10615 L
F
0 g
.72857 .10615 m
.72857 .18044 L
.84286 .18044 L
.84286 .10615 L
.72857 .10615 L
s
0 1 .4 r
.87143 .14044 m
.87143 .24901 L
.98571 .24901 L
.98571 .14044 L
F
0 g
.87143 .14044 m
.87143 .24901 L
.98571 .24901 L
.98571 .14044 L
.87143 .14044 L
s
0 .4 1 r
.01429 .03186 m
.01429 .03186 L
.12857 .03186 L
.12857 .03186 L
F
0 g
.01429 .03186 m
.01429 .03186 L
.12857 .03186 L
.12857 .03186 L
.01429 .03186 L
s
0 .4 1 r
.15714 .04329 m
.15714 .04329 L
.27143 .04329 L
.27143 .04329 L
F
0 g
.15714 .04329 m
.15714 .04329 L
.27143 .04329 L
.27143 .04329 L
.15714 .04329 L
s
0 .4 1 r
.3 .06043 m
.3 .07186 L
.41429 .07186 L
.41429 .06043 L
F
0 g
.3 .06043 m
.3 .07186 L
.41429 .07186 L
.41429 .06043 L
.3 .06043 L
s
0 .4 1 r
.44286 .089 m
.44286 .10615 L
.55714 .10615 L
.55714 .089 L
F
0 g
.44286 .089 m
.44286 .10615 L
.55714 .10615 L
.55714 .089 L
.44286 .089 L
s
0 .4 1 r
.58571 .12901 m
.58571 .16329 L
.7 .16329 L
.7 .12901 L
F
0 g
.58571 .12901 m
.58571 .16329 L
.7 .16329 L
.7 .12901 L
.58571 .12901 L
s
0 .4 1 r
.72857 .18044 m
.72857 .22616 L
.84286 .22616 L
.84286 .18044 L
F
0 g
.72857 .18044 m
.72857 .22616 L
.84286 .22616 L
.84286 .18044 L
.72857 .18044 L
s
0 .4 1 r
.87143 .24901 m
.87143 .31759 L
.98571 .31759 L
.98571 .24901 L
F
0 g
.87143 .24901 m
.87143 .31759 L
.98571 .31759 L
.98571 .24901 L
.87143 .24901 L
s
.8 0 1 r
.01429 .03186 m
.01429 .03757 L
.12857 .03757 L
.12857 .03186 L
F
0 g
.01429 .03186 m
.01429 .03757 L
.12857 .03757 L
.12857 .03186 L
.01429 .03186 L
s
.8 0 1 r
.15714 .04329 m
.15714 .05472 L
.27143 .05472 L
.27143 .04329 L
F
0 g
.15714 .04329 m
.15714 .05472 L
.27143 .05472 L
.27143 .04329 L
.15714 .04329 L
s
.8 0 1 r
.3 .07186 m
.3 .11186 L
.41429 .11186 L
.41429 .07186 L
F
0 g
.3 .07186 m
.3 .11186 L
.41429 .11186 L
.41429 .07186 L
.3 .07186 L
s
.8 0 1 r
.44286 .10615 m
.44286 .17472 L
.55714 .17472 L
.55714 .10615 L
F
0 g
.44286 .10615 m
.44286 .17472 L
.55714 .17472 L
.55714 .10615 L
.44286 .10615 L
s
.8 0 1 r
.58571 .16329 m
.58571 .28902 L
.7 .28902 L
.7 .16329 L
F
0 g
.58571 .16329 m
.58571 .28902 L
.7 .28902 L
.7 .16329 L
.58571 .16329 L
s
.8 0 1 r
.72857 .22616 m
.72857 .41474 L
.84286 .41474 L
.84286 .22616 L
F
0 g
.72857 .22616 m
.72857 .41474 L
.84286 .41474 L
.84286 .22616 L
.72857 .22616 L
s
.8 0 1 r
.87143 .31759 m
.87143 .60332 L
.98571 .60332 L
.98571 .31759 L
F
0 g
.87143 .31759 m
.87143 .60332 L
.98571 .60332 L
.98571 .31759 L
.87143 .31759 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
dWoo00<007ooOol01Woo00<007ooOol0Z7oo003AOol00`00Oomoo`08Ool00`00Oomoo`2WOol00<ao
o`80009oo`03001oogoo009oo`03001oogoo008000=oo`03001oogoo0:Ioo`00bgoo00H007ooOol0
07oo0005Ool00`00Ool00004Ool00`00Oomoo`2VOol00<]oo`06001oogoo001oo`001Woo0P0017oo
00<007ooOol0YWoo003;Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`03001oogoo0:Ioo`00
bgoo00@007ooOol0009oo`03001oogoo00Aoo`05001oogooOol0002YOol00<aoo`8000Aoo`04001o
ogooOol20003Ool00`00Oomoo`2XOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo001AOol5000WOol3000XOol2000ZOol3000XOol00`00Oomoo`0WOol2000ZOol00`00Oomoo`0^
Ool005=oo`03001oogoo02Moo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Ioo`03001o
o`0002Qoo`03001oo`0002Uoo`03001oogoo02ioo`00Dgoo00<007ooOol0:7oo00<007ooOol0:7oo
00<007ooOol09goo1000:Goo00<007ooOol09Woo00<007oo0000:Goo00<007ooOol0;Woo001COol0
0`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Ool0000XOol2000YOol2000[Ool0
0`00Oomoo`0]Ool005=oo`03001oogoo02Moo`03001oo`0002Qoo`03001oo`0002Uoo`8002Qoo`03
001oogoo02Qoo`03001oogoo02Qoo`03001oo`0002moo`00DWoo0P00:Woo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol09Woo0`00:Goo0P00:7oo0`00;goo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00?Wooo`00;`006Woo000nOol00`00Oomoo`0COol00`00Oomoo`0X
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0X
Ool00`00Oomoo`0BOol00`00Oomoo`0HOol003ioo`03001oogoo01=oo`03001oogoo02Qoo`03001o
ogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001o
ogoo019oo`03001oogoo01Qoo`00=Goo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
67oo000dOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0HOol003Aoo`03001oo`00
00Moool002l001Yoo`00=7oo00<007oo00001goo00<007ooOol00Woo00<007`0O0007g`000<007oo
Ool01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0
O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007oo
Ool01Woo00<007`0O0007g`000D007ooOomoo`0001Yoo`00=7oo00<007oo00001goo00<007ooOol0
0Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O000
7g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol0
1Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000D007ooOomoo`0001Yoo`00=Goo
00<007ooOol01Woo00<007ooOol00Woo8`0027oo8`0027oo8`0027oo8`0027oo8`0027oo8`0027oo
8`000goo00<007ooOol067oo000nOol00`00Oomoo`02Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn00
0`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool0
0`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`02OolS0008OolS0008Ool00`00
In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00
Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo
000nOol00`00Oomoo`02Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1W
h00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomo
ogoo00006Woo000nOol00`00Oomoo`02OolS0008Ool00`000n`3k00O0n`00`00Oomoo`06OolS0008
Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00O
In000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol2000^OolS0008Ool0
0`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn00
0`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo0000
6Woo000nOol00`00Oomoo`0]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00
Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00
In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomo
o`0]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1W
h00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomo
o`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`0]Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06
Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00O
In001@00Oomoogoo00006Woo000nOol00`00Oomoo`0]OolS0008Ool00`000n`3k00O0n`00`00Oomo
o`06OolS0008Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool0
0`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOolS0008Ool00`000n`3k00O
0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06
Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`000Il1W`0O0Il0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool0
0`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00
Oomoo`1HOol00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00
In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00
Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3
k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomo
o`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol2001IOolS0008Ool00`000n`3k00O
0n`00`00Oomoo`06OolS0008Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00
Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3
k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomo
o`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06
Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol0
0`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn00
1@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
0n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00
Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00I1mT
7`0OI1l00`00Oomoo`06OolS0008Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn00
0`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00
Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo
000nOol00`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1W
h00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00O
In000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol2001IOol00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`00In1Wh00OIn000`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000n
Ool00`00Oomoo`1HOol00`00I1mT7`0OI1l00`00Oomoo`06OolS0008Ool00`000n`3k00O0n`00`00
Oomoo`06OolS0008Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000nOol00`00Oomoo`1HOol0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo0000
6Woo000nOol00`00Oomoo`1HOolS0008Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O
0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo
00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo0000
6Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00
Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo
000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomoogoo00006Woo000^
Ool30003Ool00`00Oomoo`07Ool00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
0n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00
Oomoogoo00006Woo000^Ool00`00Oomoo`02Ool00`00Ool00008Ool30023Ool00`00I1mT7`0OI1l0
0`00Oomoo`06OolS0008Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00In1Wh00OIn001@00Oomo
ogoo00006Woo000_Ool01`00Oomoogoo001oo`0000Qoo`03001oogoo08=oo`03001T7f@O01mT7`03
001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k003001oogoo00Ioo`03
001Wh6OP01mWh005001oogooOol0000JOol002moo`07001oogooOol007oo000027oo00<007ooOol0
Pgoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`0
7`?/00<007ooOol01Woo00<006OPIn007fOP00D007ooOomoo`0001Yoo`00;Woo00<007oo00000Woo
00<007oo000027oo00<007ooOol0Pgoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O
00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<006OPIn007fOP00D007ooOomoo`00
01Yoo`00;goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0Pgoo00<006@OI1l07f@O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo8`00
0goo00<007ooOol067oo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
0Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00
Oomoogoo00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomo
ogoo00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo
00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
6Woo000nOol20024Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol0
0`00Oomoo`23Ool00`00I1mT7`0OI1l00`00Oomoo`06OolS0008Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06
Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`23Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`00
0n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`23OolS0008Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00
Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT
7`0OI1l00`00Oomoo`06OolS0008Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol2002_
Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O
0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool0
0`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00
Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`00
0n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomo
o`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000n
Ool00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06
Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomo
ogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol2002_Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomo
ogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
1@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06OolS0008
Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomo
ogoo00006Woo000_Ool30002Ool00`00Oomoo`07Ool00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo
000`Ool01P00Oomoo`00Ool000Qoo`03001oogoo0:ioo`03001T7f@O01mT7`03001oogoo00Ioo`03
001T7f@O01mT7`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000JOol002ioo`@00004
Ool007oo0008Ool3002^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomo
o`06Ool00`000n`3k00O0n`01@00Oomoogoo00006Woo000^Ool00`00Ool00002Ool00`00Ool00008
Ool00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06
OolS0003Ool00`00Oomoo`0HOol002moo`80009oo`03001oo`0000Qoo`03001oogoo0:ioo`03001T
7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`05001o
ogooOol0000JOol0031oo`05001oogooOol00009Ool00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo
000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomo
o`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00
Oomoogoo00006Woo000nOol2002_Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00
Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^
Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il01@00Oomoogoo00006Woo000nOol00`00Oomoo`2^Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000nOol00`00
Oomoo`2^OolS0008Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00006Woo000nOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
1@00Oomoogoo00006Woo000KOol00`00Oomoo`02Ool00`00Oomoo`0KOol00`00Oomoo`3IOol00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000KOol6000MOol0
0`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo0000
6Woo000LOol20002Ool00`00Oomoo`0KOol2003JOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
0Il1W`0O0Il01@00Oomoogoo00006Woo000KOol00`00Oomoo`02000NOol00`00Oomoo`3IOol00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00006Woo000KOol6000MOol0
0`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo0000
6Woo000MOol01@00Ool007oo000077oo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo
00<0006O0Il07`6O00D007ooOomoo`0001Yoo`0077oo1@007Goo00<007ooOol0fGoo00<006@OI1l0
7f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Yoo`006goo00L007oo001oo`00
Ool0000LOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06OolS0003Ool00`00Oomoo`0H
Ool001aoo`D001eoo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT
7`05001oogooOol0000JOol001]oo`05001oo`00Ool0000NOol00`00Oomoo`3IOol00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol2003JOol00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`3I
Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol0
0`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00
Oomoogoo00006Woo000nOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT
7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06
Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`0DOolg002>Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`0B
Ooli002>Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo
000^Ool20004Ool00`00Oomoo`07Ool00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2<Ool0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000^Ool00`00
Ool00002Ool00`00Ool00008Ool3000BOol00`00Oomoo`0eOol00`00Oomoo`2<Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000^Ool00`00Ool00002Ool0
0`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00UOol00`00Oomoo`2<Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000^Ool20003Ool00`00Ool0
0008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00UOol00`00Oomoo`2<Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000^Ool00`00Oomoo`02Ool00`00Ool0
0008Ool00`00Oomoo`0BOol00`00Oomoo`0@O00;Ool2000HOol00`00Oomoo`2<Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000_Ool20003Ool00`00Oomo
o`07Ool00`00Oomoo`0BOol00`00Oomoo`0@O00<Ool00`00Oomoo`0FOol00`00Oomoo`2<Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomo
o`0BOol00`00Oomoo`0@O006Ool20004Ool01`00Oomoo`00Ool007oo00D000eoo`03001oogoo08ao
o`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`05001oogooOol0000JOol003ioo`03
001oogoo019oo`03001oogoo011l00Qoo`0>001oogoo001oo`00Ool007oo001oo`00Ool0009oo`03
001oogoo00Yoo`03001oogoo08aoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`05
001oogooOol0000JOol003ioo`03001oogoo019oo`03001oogoo011l00Moo`0?001oogooOol007oo
001oo`00Ool007oo001oo`00009oo`03001oogoo00Yoo`03001oogoo08aoo`03001T7f@O01mT7`03
001oogoo00Ioo`03001T7f@O01mT7`05001oogooOol0000JOol003ioo`03001oogoo019oo`03001o
ogoo011l00Moo`800004Ool00000Ool4000017oo001oogoo0`003Goo00<007ooOol0S7oo00<006@O
I1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo0P004goo00<0
07ooOol047`05Goo00<007ooOol03Goo00<007ooOol0S7oo00<006@OI1l07f@O00<007ooOol01Woo
00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol047`057oo
0P003goo00<007ooOol0S7oo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol047`09Goo00<007ooOol0S7oo00<006@O
I1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol047`09Goo00<007ooOol0S7oo00<006@OI1l07f@O00<007ooOol01Woo00<006@O
I1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol047`09Goo00<007oo
Ool0S7oo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0S7oo00<006@OI1l07f@O00<007ooOol0
1Woo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo
00<007ooOol0S7oo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol046OP9Goo00<007ooOol0S7oo00<006@OI1l07f@O
00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo0P004goo00<007ooOol0
46OP5Woo0P003Goo00<007ooOol0S7oo8`0027oo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol046OP67oo00<007ooOol02Woo00<007ooOol0]goo00<006@O
I1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046OP1goo0P000Woo
0`000Woo0`000goo0`0037oo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00
?Woo00<007ooOol04Woo00<007ooOol046OP1Woo00@007ooOol0009oo`03001oogoo009oo`05001o
ogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`2gOol00`00I1mT7`0OI1l01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@In06Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
1@00Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomo
o`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046OP1Goo10000Woo100000=oo`00000017oo
0`0037oo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol046OP1Woo00<007ooOol077oo00<007ooOol0]goo00<006@OI1l07f@O00D007oo
Oomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046OP4Goo00<007ooOol04Goo00<007oo
Ool0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
46OP9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo0P004goo00<0
07ooOol046OP9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol046OP9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0]goo00<006@OI1l07f@O00D0
07ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0]goo00<006@O
I1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol040?/9Goo00<007oo
Ool0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
40?/9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol040?/37oo00<007ooOol05Woo00<007ooOol0]goo00<006@OI1l07f@O00D007oo
Oomoo`0001Yoo`00;goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol0
40?/1Woo10000Woo00@007ooOomoo`@0015oo`03001oogoo0;Moo`03001T7f@O01mT7`05001oogoo
Ool0000JOol002ioo`03001oo`00009oo`03001oo`0000Qoo`<0019oo`03001oogoo0103k0Ioo`<0
0003Ool0000000<0009oo`04001oogoo000@Ool00`00Oomoo`2gOol00`00I1mT7`0OI1l01@00Oomo
ogoo00006Woo000^Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@
0n`8Ool01@00Oomoogoo000017oo00@007ooOol0011oo`03001oogoo0;Moo`03001T7f@O01mT7`05
001oogooOol0000JOol002moo`07001oogooOol007oo000027oo00<007ooOol04Woo00<007ooOol0
40?/1goo0P000goo00<007ooOol00Woo0`004Goo00<007ooOol0]goo00<006@OI1l07f@O00D007oo
Oomoo`0001Yoo`00;Woo00<007oo00000Woo00<007oo000027oo00<007ooOol04Woo00<007ooOol0
40?/4Goo00<007ooOol04Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00
;goo00<007ooOol00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol040?/47oo0P004goo
00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol040?/9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol040?/9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol040?/9Goo00<007ooOol0]goo00<006@OI1l07f@O
00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0]goo00<0
06@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo0P004goo00<007ooOol0=Goo00<007ooOol0]goo
00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O9Goo
00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol0406O9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<0
07ooOol04Woo00<007ooOol0406O9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O9Goo00<007ooOol0]goo00<006@OI1l07f@O
00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O1Woo10001Woo10004Goo
00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<0
07ooOol0406O1Woo0`0027oo00@007ooOol0011oo`03001oogoo0;Moo`03001T7f@O01mT7`05001o
ogooOol0000JOol003ioo`03001oogoo019oo`03001oogoo0101W`Qoo`03001oogoo00Ioo`04001o
ogoo000@Ool00`00Oomoo`2gOol00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomo
o`0BOol00`00Oomoo`0@0Il7Ool20002Ool00`00Ool00003Ool3000AOol00`00Oomoo`2gOol00`00
I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol2000COol00`00Oomoo`0@0Il<Ool00`00Oomoo`02
Ool00`00Oomoo`0AOol00`00Oomoo`2gOol00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol0
0`00Oomoo`0BOol00`00Oomoo`0@0Il<Ool01000Oomoogoo0P004goo00<007ooOol0]goo00<006@O
I1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0406O9Goo00<007oo
Ool0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
406O9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol0=Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo
00<007ooOol04Woo00<007ooOol0=Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`00
01Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<007ooOol0]goo00<006@OI1l07f@O
00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O9Goo00<007ooOol0]goo
00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo0P004goo00<007ooOol046@O9Goo00<007oo
Ool0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol0
46@O9Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol0
4Woo00<007ooOol046@O1Woo100000Aoo`00Ool0009oo`@0015oo`03001oogoo0;Moo`03001T7f@O
01mT7`05001oogooOol0000JOol003ioo`03001oogoo019oo`03001oogoo011T7`Ioo`<000=oo`03
001oogoo009oo`04001oogoo000@Ool00`00Oomoo`2gOol00`00I1mT7`0OI1l01@00Oomoogoo0000
6Woo000nOol00`00Oomoo`0BOol00`00Oomoo`0@I1l8Ool00`00Oomoo`030003Ool01000Oomoo`00
47oo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo
00<007ooOol046@O1goo0P000goo00<007ooOol00Woo0`004Goo00<007ooOol0]goo00<006@OI1l0
7f@O00D007ooOomoo`0001Yoo`00?Woo00<007ooOol04Woo00<007ooOol046@O4Goo00<007ooOol0
4Goo00<007ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00:7oo1@000Woo00<007oo
Ool00Woo00<007ooOol01goo00<007ooOol04Woo00<007ooOol046@O47oo0P004goo00<007ooOol0
]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002Ool00`00
Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0@I1lUOol00`00Oomoo`2gOol00`00I1mT7`0OI1l0
1@00Oomoogoo00006Woo000ZOol01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`<0019oo`03
001oogoo011T7bEoo`03001oogoo0;Moo`03001T7f@O01mT7`05001oogooOol0000JOol002Yoo`07
001oogooOol007oo00000Woo00<007oo000027oo00<007ooOol04Woo00<007ooOol046@O9Goo00<0
07ooOol0]goo00<006@OI1l07f@O00D007ooOomoo`0001Yoo`00:Woo00L007ooOomoo`00Ool00002
Ool00`00Ool00008Ool00`00Oomoo`0BOol00`00Oomoo`0eOol00`00Oomoo`2gOol00`00I1mT7`0O
I1l01@00Oomoogoo00006Woo000YOol20004Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomo
o`0BOoli002iOol00`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`3oOol5Ool0
0`00I1mT7`0OI1l01@00Oomoogoo00006Woo000nOol00`00Oomoo`3oOol5OolS0003Ool00`00Oomo
o`0HOol003ioo`03001oogoo0?moob]oo`03001oogoo01Qoo`00?Woo00<007ooOol0ogoo:goo00<0
07ooOol067oo000nOol2003oOol/Ool00`00Oomoo`0HOol003ioool002l001Yoo`00ogooQgoo003o
Oon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00/goo0P00:7oo0P00Ygoo002dOol0
0`00Oomoo`0WOol00`00Oomoo`2UOol00:=oo`<000Aoo`80009oo`<000=oo`03001oogoo0080009o
o`03001oogoo00800007Ool007oo001oo`00Ool00`000Woo100000Eoo`00000007oo00D0009oo`<0
009oo`<00003Ool000000080009oo`80009oo`<000=oo`800003Ool00000009oo`03001oogoo08Mo
o`00Y7oo00<007ooOol00Woo00@007ooOol0009oo`07001oogooOol007oo00000Woo00H007ooOol0
07oo0002Ool2000017oo001oo`000Woo00@007ooOomoo`<000=oo`05001oogooOol00002Ool00`00
Ool00002Ool00`00Ool00002Ool00`00Ool000020002Ool01000Oomoo`000Woo00D007ooOomoo`00
009oo`03001oo`00009oo`03001oogoo08Moo`00Y7oo0`000Woo00@007ooOol0009oo`07001oogoo
Ool007oo00000Woo00H007ooOol007oo0002Ool2000017oo001oo`000Woo00<007ooOol00goo00D0
07ooOomoo`0000=oo`03001oogoo009oo`06001oogoo001oo`000Woo00D007ooOomoo`00009oo`03
001oogoo00=oo`05001oogooOol00002Ool00`00Ool00002Ool00`00Oomoo`27Ool00:Aoo`04001o
ogoo0002Ool20003Ool00`00Oomoo`0200000goo000000040003Ool200001Goo000007oo00000Woo
0P0017oo0P000goo00@007ooOomoo`8000Aoo`D00003Ool00000009oo`800003Ool000000080009o
o`8000Aoo`800003Ool00000008008Yoo`00Y7oo00@007ooOol000Moo`03001oogoo021oo`05001o
ogooOol00002Ool00`00Oomoo`0>Ool00`00Oomoo`2IOol00:=oo`@000Moo`8001Qoo`03001oogoo
00Ioo`80009oo`D001Ioo`03001oogoo09=oo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo
003oOon7Ool00?moohMoo`00ogooQgoo0000\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-3.16538, 14.3725, 0.0232398, 0.580963}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 52: ",
    FontWeight->"Bold"],
  "\[CapitalUDoubleDot]bersicht \[UDoubleDot]ber die Termanzahl, die vom \
Algorithmus in Abh\[ADoubleDot]ngigkeit der Ordnung in \[Lambda] erzeugt \
wird."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Genauigkeit der Approximation wird in Kapitel 3 diskutiert.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:54"],

Cell["Kap. 1.3., 3.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.3. CourantSnyderTransformedA",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:55"],

Cell["\<\
CourantSnyderTransformedA[n] f\[UDoubleDot]hrt die Courant & Snyder - \
Transformation an der polynomischen Bewegungsgleichung des Sitnikovproblems \
n-ter Ordnung mit unbekannter Amplitudenfunktion w durch. Die darin \
vorkommende Variable t h\[ADoubleDot]ngt nun von \[Psi], der linearisierten \
Phasenfunktion der L\[ODoubleDot]sung ab.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:56"],

Cell["\<\
Die Courant & Snyder - Transformation baut auf den Ergebnissen der Floquet - \
Theorie auf. Nimmt man eine polynomische Differentialgleichung:\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(z\^\[DoublePrime]\  + \(g(t)\) z + F(z, t) = 
      0\)\)\)], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  " und f\[UDoubleDot]hrt an ihr die Transformationen y = z/w und \[Psi] = ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \ \)\(\[Integral]\_0\%t\ 
        1/w\^2 \(\(\[DifferentialD]s\)\(\ \)\)\)\)\)]],
  " durch, wobei w die Amplitudenfunktion und \[Psi] die Phasenfunktion des \
linearisierten Falls kennzeichnen, so erh\[ADoubleDot]lt man eine \
Differentialgleichung der Form:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(TraditionalForm\`\(\(\ \)\(y\^\[DoublePrime]\  + y + F(y, t(\[Psi])) = 
      0\)\)\)], "DisplayFormula",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Der lineare Teil der Gleichung kann somit durch die Courant & Snyder - \
Transformation auf die Form des gest\[ODoubleDot]rten harmonischen \
Oszillators gebracht werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:57"],

Cell[TextData[{
  "Voraussetzung :",
  StyleBox[" PolynomialEquation, CourantSnyderTransform",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(CourantSnyderTransformedA[n_Integer]\), ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            RowBox[{\({x}\), ",", 
              RowBox[{"$Derivation", "=", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  
                  RowBox[{\(x = PolynomialEquation[n]\), 
                    ",", \(x = 
                      CourantSnyderTransform[x, w, {z, t}, {y, \[Psi]}]\), 
                    ",", \(x = 
                      Expand[x\[LeftDoubleBracket]1\[RightDoubleBracket]]\), 
                    ",", "\[IndentingNewLine]", 
                    RowBox[{"x", "=", 
                      RowBox[{"Expand", "[", 
                        FractionBox["x", 
                          RowBox[{"Coefficient", "[", 
                            RowBox[{"x", ",", 
                              RowBox[{
                                SuperscriptBox["y", "\[Prime]\[Prime]",
                                  MultilineFunction->None], "[", "\[Psi]", 
                                "]"}], ",", "1"}], "]"}]], "]"}]}], 
                    ",", \(x = Collect[x, {y[\[Psi]], w, e}]\), 
                    ",", \(CourantSnyderTransformedA[n] = x \[Equal] 0\)}], 
                  "}"}]}]}], "]"}], "\[LeftDoubleBracket]", \(-1\), 
          "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Funktion f\[UDoubleDot]hrt die Courant & Snyder - Transformation \
automatisiert an der polynomischen Bewegungsgleichung durch. Herzst\
\[UDoubleDot]ck des Algorithmus ist der Befehl ",
  StyleBox["CourantSnyderTransform",
    FontSlant->"Italic"],
  ":"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[
      RowBox[{\(CourantSnyderTransform[exp_, af_, {x_, t_}, {y_, \[Psi]_}]\), 
        ":=", 
        RowBox[{
          RowBox[{"Module", "[", 
            RowBox[{\({w, x}\), ",", 
              RowBox[{"$Derivation", "=", "\[IndentingNewLine]", 
                RowBox[{"{", 
                  
                  RowBox[{\(x = 
                      TransformDependentVar[exp, x[t], 
                        y[t] \[Equal] x[t]\/w[t]]\), 
                    ",", \(x = 
                      TransformIndependentVar[x, 
                        y[t], \[Psi][
                            t] \[Equal] \[Integral]\(1\/w[t]\^2\) \
\[DifferentialD]t]\), ",", 
                    RowBox[{"x", "=", 
                      RowBox[{"x", "/.", "\[InvisibleSpace]", 
                        RowBox[{
                          RowBox[{
                            SuperscriptBox["w", "\[Prime]\[Prime]",
                              MultilineFunction->None], "[", "t", "]"}], 
                          "\[Rule]", \(1\/w[t]\^3 - 
                            Coefficient[
                                exp\[LeftDoubleBracket]1\[RightDoubleBracket],\
 x[t], 1]\ w[t]\)}]}]}], 
                    ",", \(x = 
                      FullSimplify[x, w[t] > 0, Trig \[Rule] False]\), 
                    ",", \($Result = 
                      x\[LeftDoubleBracket]1\[RightDoubleBracket] - 
                            x\[LeftDoubleBracket]2\[RightDoubleBracket] \
\[Equal] 0 /. \[InvisibleSpace]w[t] \[Rule] af\)}], "}"}]}]}], "]"}], 
          "\[LeftDoubleBracket]", \(-1\), "\[RightDoubleBracket]"}]}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["CourantSnyderTransform[exp, af, {x,t}, {y,\[Psi]}]",
    FontSlant->"Italic"],
  " f\[UDoubleDot]hrt die Courant & Snyder Transformation am Ausdruck ",
  StyleBox["exp",
    FontSlant->"Italic"],
  " mit der Amplitudenfunktion ",
  StyleBox["af",
    FontSlant->"Italic"],
  " von den Variablen ",
  StyleBox["x",
    FontSlant->"Italic"],
  " von ",
  StyleBox["t",
    FontSlant->"Italic"],
  " auf die Variablen ",
  StyleBox["y",
    FontSlant->"Italic"],
  " von ",
  StyleBox["\[Psi]",
    FontSlant->"Italic"],
  " durch."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Transformation der abh\[ADoubleDot]ngigen Variable wird hierbei durch \
die Funktion ",
  StyleBox["TransformDependentVar",
    FontSlant->"Italic"],
  " durchgef\[UDoubleDot]hrt:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TransformDependentVar[exp_, fun_, 
          rel_Equal] := \(Module[{x, 
              o}, $Derivation = \[IndentingNewLine]{o = 
                  DifferentialOrder[exp], \[IndentingNewLine]x = 
                  Table[\[PartialD]\_{fun\[LeftDoubleBracket]1\
\[RightDoubleBracket], i}rel, {i, 0, o}], \[IndentingNewLine]x = 
                  Solve[x, 
                    Table[\[PartialD]\_{fun\[LeftDoubleBracket]1\
\[RightDoubleBracket], i}fun, {i, 0, o}]], \[IndentingNewLine]x = 
                  Flatten[x], \[IndentingNewLine]$Result = 
                  exp /. \[InvisibleSpace]x}]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Es wird im Ausdruck ",
  StyleBox["exp",
    FontSlant->"Italic"],
  " die abh\[ADoubleDot]ngige Variable definiert durch die Funktion ",
  StyleBox["fun",
    FontSlant->"Italic"],
  " \[UDoubleDot]ber die Beziehung ",
  StyleBox["rel",
    FontSlant->"Italic"],
  "  transformiert."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Transformation der unabh\[ADoubleDot]ngigen Variablen wird \
\[UDoubleDot]ber die Funktion ",
  StyleBox["TransformIndependentVar",
    FontSlant->"Italic"],
  " vollzogen: "
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TransformIndependentVar[exp_, fun_, 
          rel_] := \(Module[{x, y, 
              o}, $Derivation = \[IndentingNewLine]{o = 
                  DifferentialOrder[exp], \[IndentingNewLine]y = Head[fun], 
                x = Table[\[PartialD]\_{rel\[LeftDoubleBracket]1, 1\
\[RightDoubleBracket], i}\((y[
                            rel\[LeftDoubleBracket]1\[RightDoubleBracket]] \
\[Equal] y[rel\[LeftDoubleBracket]1, 1\[RightDoubleBracket]])\), {i, 0, o}], 
                x = x /. \[InvisibleSpace]rel\[LeftDoubleBracket]1\
\[RightDoubleBracket] \[Rule] 
                      Head[rel\[LeftDoubleBracket]1\[RightDoubleBracket]], 
                x = Solve[x, 
                    Table[\[PartialD]\_{fun\[LeftDoubleBracket]1\
\[RightDoubleBracket], i}fun, {i, 0, o}]], \[IndentingNewLine]x = Flatten[x], 
                y = rel /. \[InvisibleSpace]Equal \[Rule] Rule, 
                y = Table[\[PartialD]\_{y\[LeftDoubleBracket]1, 1\
\[RightDoubleBracket], i}y, {i, 0, 
                      o}], \[IndentingNewLine]$Result = \(exp \
/. \[InvisibleSpace]x\) /. \[InvisibleSpace]y}]\)\[LeftDoubleBracket]\(-1\)\
\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die \[CapitalUDoubleDot]bergabe an die Funktion entspricht der von ",
  StyleBox["TransformDependentVar",
    FontSlant->"Italic"],
  ". F\[UDoubleDot]r die Festlegung der maximal auftretenden Ableitung wird \
die Funktion ",
  StyleBox["DifferentialOrder",
    FontSlant->"Italic"],
  " (s.o.) ben\[ODoubleDot]tigt. Die Objekte ",
  StyleBox["TransformDependentVar ",
    FontSlant->"Italic"],
  "und ",
  StyleBox["TransformIndependentVar",
    FontSlant->"Italic"],
  " sind ebenfalls f\[UDoubleDot]r beliebige Differentialgleichungen \
einsetzbar."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:58"],

Cell["Kap. 3.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.4. CourantSnyderTransformedB",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:59"],

Cell[TextData[{
  "CourantSnyderTransformedB[n] f\[UDoubleDot]hrt die Courant & Snyder - \
Transformation an der polynomischen Bewegungsgleichung des Sitnikovproblems \
n-ter Ordnung durch. Die darin vorkommende Variable t h\[ADoubleDot]ngt nun \
im Unterschied zu ",
  StyleBox["CourantSnyderTransformedA",
    FontSlant->"Italic"],
  "  von \[Psi] ab."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:60"],

Cell[TextData[{
  "Siehe ",
  StyleBox["CourantSnyderTransformedA",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:61"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["CourantSnyderTransformedA, AmplitudeFunction ",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(CourantSnyderTransformedB[
          n_Integer] := \(Module[{x, 
              xx}, $Derivation = {x = \(CourantSnyderTransformedA[
                      n]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
                xx = AmplitudeFunction[n], 
                x = x /. \[InvisibleSpace]w \[Rule] xx, 
                x = Expand[Normal[x]], 
                x = x /. \[InvisibleSpace]_\ e\^i_\ y[\[Psi]]\^j_ \
\[RuleDelayed] 0 /; i + j > n, 
                x = x /. \[InvisibleSpace]_\ e\ y[\[Psi]]\^j_ | _\ e\^j_\ y[\
\[Psi]] \[RuleDelayed] 0 /; j \[Equal] n, x = TrigReduce[x], 
                CourantSnyderTransformedB[n] = 
                  Collect[x, {y[\[Psi]], e}] \[Equal] 
                    0}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Funktion setzt die Amplitudenfunktion in die von ",
  StyleBox["CourantSnyderTransformedA",
    FontSlant->"Italic"],
  " aufgestellte Differentialgleichung ein und reorganisiert die Gleichung."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:62"],

Cell["Kap. 3.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.5. InversePhaseFunction",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:63"],

Cell["\<\
InversePhaseFunction[n] berechnet zu der Phasenfunktion der Floquet - Theorie \
die Umkehrtransformation bis zur n-ten Ordnung.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:64"],

Cell[TextData[{
  "Die Phasenfunktion stellt eine Beziehung ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\  = \ \[Psi]\)]],
  "(t,e) dar. Gesucht sei deren Umkehrung, daher t = t(\[Psi],e). Die \
Phasenfunktion ist in Form einer St\[ODoubleDot]rreihe bekannt. Im ersten \
Schritt setzt man f\[UDoubleDot]r deren Umkehrung eine St\[ODoubleDot]rreihe \
mit unbekannten Koeffizientenfunktionen an und in die \
urspr\[UDoubleDot]ngliche Beziehung ein. Entwickelt und ordnet man dieses \
nach dem Parameter e, so erh\[ADoubleDot]lt man ein Gleichungssystem, welches \
die Bedingungen f\[UDoubleDot]r die Koeffizientenfunktionen bestimmt. Dieses \
kann induktiv gel\[ODoubleDot]st werden, die St\[ODoubleDot]rreihe der \
Umkehrfunktion ist nun bekannt."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:65"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["PerturbativeSeries, PhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(InversePhaseFunction[
          n_Integer] := \(Module[{x, xx, 
              X}, $Derivation = \[IndentingNewLine]{x = 
                  Normal[PhaseFunction[n]], 
                xx = Normal[PerturbativeSeries[t[\[Psi]], e, n]], 
                x = x /. \[InvisibleSpace]t \[Rule] 
                      xx, \[IndentingNewLine]x = 
                  Series[x, {e, 0, 
                        n}] \[Equal] \[Psi], \[IndentingNewLine]X = 
                  x\[LeftDoubleBracket]1, 
                    3\[RightDoubleBracket], \[IndentingNewLine]X = {X\
\[LeftDoubleBracket]1\[RightDoubleBracket] \[Equal] \[Psi], 
                    Thread[Rest[X] \[Equal] 0]}, 
                x = Solve[
                    X\[LeftDoubleBracket]1\[RightDoubleBracket], \(Subscript[
                        t, 0]\)[\[Psi]]], \[IndentingNewLine]X = 
                  Flatten[X /. \[InvisibleSpace]x], 
                X = Solve[X, Table[\(Subscript[t, i]\)[\[Psi]], {i, 1, n}]], 
                X = Flatten[Append[X, x]], \[IndentingNewLine]x = 
                  TrigReduce[
                    xx /. \[InvisibleSpace]X], \[IndentingNewLine]x = 
                  Series[x, {e, 0, n}], 
                InversePhaseFunction[n] = 
                  SeriesData[e, 0, 
                    Collect[
                      x\[LeftDoubleBracket]3\[RightDoubleBracket], {Sin[_] | 
                          Cos[_], \[Psi]}], 0, n + 1, 
                    1]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:66"],

Cell["\<\
Die Hauptaufgaben des Algorithmus bestehen darin, einen Ausdruck nach einem \
kleinen Parameter zu entwickeln, das Gleichungssystem, das die unbestimmten \
Koeffizientenfunktionen bestimmt, aufzustellen, und dieses zu \
l\[ODoubleDot]sen. Die Anzahl der Terme, die bei der Prozedur entstehen, \
entspricht jener der Amplitudenfunktion.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Das Problem eine Umkehrfunktion zu einer gegebenen St\[ODoubleDot]rreihe \
zu bilden, tritt in dieser Arbeit zweimal auf. Einmal muss sie, wie hier zur \
Phasenfunktion, ein weiteres Mal zu der von der Poincar\[EAcute] - Lindstedt \
- Methode resultierenden ",
  StyleBox["SigmaFunction ",
    FontSlant->"Italic"],
  "(Abbildung von \[Sigma] \[Rule] \[Tau]) berechnet werden. Es ist ein \
leichtes einen Algorithmus zu finden, der diese Aufgabe f\[UDoubleDot]r jede \
beliebige St\[ODoubleDot]rreihe l\[ODoubleDot]st. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " l\[ADoubleDot]sst sich dies auf die folgende Art und Weise realisieren:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(InversePerturbativeSeries[ser_SeriesData, \[Psi]_[t_], 
          n_] := \(Module[{e = ser\[LeftDoubleBracket]1\[RightDoubleBracket], 
              x, xx, X}, $Derivation = \[IndentingNewLine]{x = Normal[ser], 
                xx = Normal[PerturbativeSeries[t[\[Psi]], e, n]], 
                x = x /. \[InvisibleSpace]t \[Rule] 
                      xx, \[IndentingNewLine]x = 
                  Series[x, {e, 0, 
                        n}] \[Equal] \[Psi], \[IndentingNewLine]X = 
                  x\[LeftDoubleBracket]1, 
                    3\[RightDoubleBracket], \[IndentingNewLine]X = {X\
\[LeftDoubleBracket]1\[RightDoubleBracket] \[Equal] \[Psi], 
                    Thread[Rest[X] \[Equal] 0]}, 
                x = Solve[
                    X\[LeftDoubleBracket]1\[RightDoubleBracket], \(Subscript[
                        t, 0]\)[\[Psi]]], 
                X = Flatten[X /. \[InvisibleSpace]x], 
                X = Solve[X, Table[\(Subscript[t, i]\)[\[Psi]], {i, 1, n}]], 
                X = Flatten[Append[X, x]], \[IndentingNewLine]x = 
                  xx /. \[InvisibleSpace]X, \[IndentingNewLine]$Result = 
                  Series[x, {e, 0, 
                      n}]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\)\
,
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Zu einer Relation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\[Psi](t) = \[Psi]\_0\),
              "TraditionalForm"], \((t)\)}], "+", \(\(\(\[Psi]\_1\)(t)\) e\), 
          "+", 
          FormBox[
            RowBox[{
              RowBox[{
                RowBox[{
                  FormBox[\(\(\(\[Psi]\_2\)(t)\) e\^2\),
                    "TraditionalForm"], "+"}], "..."}], \(O(e\^n)\)}],
            "TraditionalForm"]}], TraditionalForm]]],
  " wird eine weitere ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(t(\[Psi]) = \(t\_0\)(\[Psi]) + \(\(t\_1\)(\[Psi])\) 
                  e + \(\(t\_2\)(\[Psi])\) e\^2\),
            "TraditionalForm"], "+", \(O(e\^n)\)}], TraditionalForm]]],
  " erzeugt, welche die Bedingung \[Psi](t(\[Psi]) und t(\[Psi](t)) gleich id \
+ ",
  Cell[BoxData[
      \(TraditionalForm\`O(e\^n)\)]],
  " erf\[UDoubleDot]llt. Es zeigt sich, dass die Inverse ein anderes \
Konvergenzverhalten aufweisen kann."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0031746 0.0147151 3225.6 [
[.02381 -0.0125 -4.78125 -11.625 ]
[.02381 -0.0125 4.78125 0 ]
[.18254 -0.0125 -7.5625 -11.625 ]
[.18254 -0.0125 7.5625 0 ]
[.34127 -0.0125 -10.3438 -11.625 ]
[.34127 -0.0125 10.3438 0 ]
[.5 -0.0125 -10.3438 -11.625 ]
[.5 -0.0125 10.3438 0 ]
[.65873 -0.0125 -10.3438 -11.625 ]
[.65873 -0.0125 10.3438 0 ]
[.81746 -0.0125 -10.3438 -11.625 ]
[.81746 -0.0125 10.3438 0 ]
[.97619 -0.0125 -10.3438 -11.625 ]
[.97619 -0.0125 10.3438 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -4.78125 -23.25 ]
[.5 -0.0125 4.78125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .09536 -48.5 -5.8125 ]
[-0.0125 .09536 0 5.8125 ]
[-0.0125 .176 -42.9375 -5.8125 ]
[-0.0125 .176 0 5.8125 ]
[-0.0125 .25664 -48.5 -5.8125 ]
[-0.0125 .25664 0 5.8125 ]
[-0.0125 .33728 -37.375 -5.8125 ]
[-0.0125 .33728 0 5.8125 ]
[-0.0125 .41792 -48.5 -5.8125 ]
[-0.0125 .41792 0 5.8125 ]
[-0.0125 .49856 -42.9375 -5.8125 ]
[-0.0125 .49856 0 5.8125 ]
[-0.0125 .5792 -48.5 -5.8125 ]
[-0.0125 .5792 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -60.5625 -39.5 ]
[-0.01875 .30902 -48.5 39.5 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
gsave
.02381 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.18254 0 m
.18254 .00625 L
s
gsave
.18254 -0.0125 -68.5625 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
.34127 0 m
.34127 .00625 L
s
gsave
.34127 -0.0125 -71.3438 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(100) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -71.3438 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(150) show
1.000 setlinewidth
grestore
.65873 0 m
.65873 .00625 L
s
gsave
.65873 -0.0125 -71.3438 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(200) show
1.000 setlinewidth
grestore
.81746 0 m
.81746 .00625 L
s
gsave
.81746 -0.0125 -71.3438 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -71.3438 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(300) show
1.000 setlinewidth
grestore
.125 Mabswid
.05556 0 m
.05556 .00375 L
s
.0873 0 m
.0873 .00375 L
s
.11905 0 m
.11905 .00375 L
s
.15079 0 m
.15079 .00375 L
s
.21429 0 m
.21429 .00375 L
s
.24603 0 m
.24603 .00375 L
s
.27778 0 m
.27778 .00375 L
s
.30952 0 m
.30952 .00375 L
s
.37302 0 m
.37302 .00375 L
s
.40476 0 m
.40476 .00375 L
s
.43651 0 m
.43651 .00375 L
s
.46825 0 m
.46825 .00375 L
s
.53175 0 m
.53175 .00375 L
s
.56349 0 m
.56349 .00375 L
s
.59524 0 m
.59524 .00375 L
s
.62698 0 m
.62698 .00375 L
s
.69048 0 m
.69048 .00375 L
s
.72222 0 m
.72222 .00375 L
s
.75397 0 m
.75397 .00375 L
s
.78571 0 m
.78571 .00375 L
s
.84921 0 m
.84921 .00375 L
s
.88095 0 m
.88095 .00375 L
s
.9127 0 m
.9127 .00375 L
s
.94444 0 m
.94444 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -65.7813 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
68.563 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09536 m
.00625 .09536 L
s
gsave
-0.0125 .09536 -109.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.000025) show
1.000 setlinewidth
grestore
0 .176 m
.00625 .176 L
s
gsave
-0.0125 .176 -103.938 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00005) show
1.000 setlinewidth
grestore
0 .25664 m
.00625 .25664 L
s
gsave
-0.0125 .25664 -109.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.000075) show
1.000 setlinewidth
grestore
0 .33728 m
.00625 .33728 L
s
gsave
-0.0125 .33728 -98.375 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.0001) show
1.000 setlinewidth
grestore
0 .41792 m
.00625 .41792 L
s
gsave
-0.0125 .41792 -109.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.000125) show
1.000 setlinewidth
grestore
0 .49856 m
.00625 .49856 L
s
gsave
-0.0125 .49856 -103.938 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.00015) show
1.000 setlinewidth
grestore
0 .5792 m
.00625 .5792 L
s
gsave
-0.0125 .5792 -109.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.000175) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03084 m
.00375 .03084 L
s
0 .04697 m
.00375 .04697 L
s
0 .0631 m
.00375 .0631 L
s
0 .07923 m
.00375 .07923 L
s
0 .11148 m
.00375 .11148 L
s
0 .12761 m
.00375 .12761 L
s
0 .14374 m
.00375 .14374 L
s
0 .15987 m
.00375 .15987 L
s
0 .19212 m
.00375 .19212 L
s
0 .20825 m
.00375 .20825 L
s
0 .22438 m
.00375 .22438 L
s
0 .24051 m
.00375 .24051 L
s
0 .27276 m
.00375 .27276 L
s
0 .28889 m
.00375 .28889 L
s
0 .30502 m
.00375 .30502 L
s
0 .32115 m
.00375 .32115 L
s
0 .3534 m
.00375 .3534 L
s
0 .36953 m
.00375 .36953 L
s
0 .38566 m
.00375 .38566 L
s
0 .40179 m
.00375 .40179 L
s
0 .43404 m
.00375 .43404 L
s
0 .45017 m
.00375 .45017 L
s
0 .4663 m
.00375 .4663 L
s
0 .48243 m
.00375 .48243 L
s
0 .51468 m
.00375 .51468 L
s
0 .53081 m
.00375 .53081 L
s
0 .54694 m
.00375 .54694 L
s
0 .56307 m
.00375 .56307 L
s
0 .59532 m
.00375 .59532 L
s
0 .61145 m
.00375 .61145 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -155.031 -10.0313 Mabsadd m
1 1 Mabs scale
currentpoint translate
100.5 10.0313 translate
90 rotate
-100.5 -10.0313 translate
0 20.0625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.688 moveto
(\\310) show
68.563 12.688 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.125 12.688 moveto
(H) show
79.688 12.688 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
85.250 9.063 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 6.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
89.125 9.063 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 6.375 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.500 12.688 moveto
(H) show
99.063 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
104.625 12.688 moveto
(L) show
110.188 12.688 moveto
(L) show
115.750 12.688 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
121.313 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(id) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
132.438 12.688 moveto
(\\310) show
138.000 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .61178 m
.02381 .61803 L
s
.18254 .61178 m
.18254 .61803 L
s
.34127 .61178 m
.34127 .61803 L
s
.5 .61178 m
.5 .61803 L
s
.65873 .61178 m
.65873 .61803 L
s
.81746 .61178 m
.81746 .61803 L
s
.97619 .61178 m
.97619 .61803 L
s
.125 Mabswid
.05556 .61428 m
.05556 .61803 L
s
.0873 .61428 m
.0873 .61803 L
s
.11905 .61428 m
.11905 .61803 L
s
.15079 .61428 m
.15079 .61803 L
s
.21429 .61428 m
.21429 .61803 L
s
.24603 .61428 m
.24603 .61803 L
s
.27778 .61428 m
.27778 .61803 L
s
.30952 .61428 m
.30952 .61803 L
s
.37302 .61428 m
.37302 .61803 L
s
.40476 .61428 m
.40476 .61803 L
s
.43651 .61428 m
.43651 .61803 L
s
.46825 .61428 m
.46825 .61803 L
s
.53175 .61428 m
.53175 .61803 L
s
.56349 .61428 m
.56349 .61803 L
s
.59524 .61428 m
.59524 .61803 L
s
.62698 .61428 m
.62698 .61803 L
s
.69048 .61428 m
.69048 .61803 L
s
.72222 .61428 m
.72222 .61803 L
s
.75397 .61428 m
.75397 .61803 L
s
.78571 .61428 m
.78571 .61803 L
s
.84921 .61428 m
.84921 .61803 L
s
.88095 .61428 m
.88095 .61803 L
s
.9127 .61428 m
.9127 .61803 L
s
.94444 .61428 m
.94444 .61803 L
s
.25 Mabswid
0 .61803 m
1 .61803 L
s
.99375 .01472 m
1 .01472 L
s
.99375 .09536 m
1 .09536 L
s
.99375 .176 m
1 .176 L
s
.99375 .25664 m
1 .25664 L
s
.99375 .33728 m
1 .33728 L
s
.99375 .41792 m
1 .41792 L
s
.99375 .49856 m
1 .49856 L
s
.99375 .5792 m
1 .5792 L
s
.125 Mabswid
.99625 .03084 m
1 .03084 L
s
.99625 .04697 m
1 .04697 L
s
.99625 .0631 m
1 .0631 L
s
.99625 .07923 m
1 .07923 L
s
.99625 .11148 m
1 .11148 L
s
.99625 .12761 m
1 .12761 L
s
.99625 .14374 m
1 .14374 L
s
.99625 .15987 m
1 .15987 L
s
.99625 .19212 m
1 .19212 L
s
.99625 .20825 m
1 .20825 L
s
.99625 .22438 m
1 .22438 L
s
.99625 .24051 m
1 .24051 L
s
.99625 .27276 m
1 .27276 L
s
.99625 .28889 m
1 .28889 L
s
.99625 .30502 m
1 .30502 L
s
.99625 .32115 m
1 .32115 L
s
.99625 .3534 m
1 .3534 L
s
.99625 .36953 m
1 .36953 L
s
.99625 .38566 m
1 .38566 L
s
.99625 .40179 m
1 .40179 L
s
.99625 .43404 m
1 .43404 L
s
.99625 .45017 m
1 .45017 L
s
.99625 .4663 m
1 .4663 L
s
.99625 .48243 m
1 .48243 L
s
.99625 .51468 m
1 .51468 L
s
.99625 .53081 m
1 .53081 L
s
.99625 .54694 m
1 .54694 L
s
.99625 .56307 m
1 .56307 L
s
.99625 .59532 m
1 .59532 L
s
.99625 .61145 m
1 .61145 L
s
.25 Mabswid
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.0257 .01472 L
.02613 .01472 L
.02661 .01472 L
.02705 .01472 L
.02746 .01472 L
.02795 .01472 L
.02847 .01472 L
.02891 .01472 L
.02939 .01472 L
.02991 .01472 L
.03019 .01472 L
.03046 .01472 L
.03098 .01472 L
.03146 .01472 L
.03197 .01472 L
.03243 .01472 L
.03296 .01472 L
.03346 .01472 L
.03389 .01472 L
.03435 .01473 L
.03485 .01473 L
.03532 .01472 L
.03582 .01472 L
.03635 .01473 L
.03686 .01473 L
.03732 .01473 L
.0376 .01473 L
.03786 .01472 L
.03815 .01472 L
.03845 .01472 L
.03896 .01473 L
.03925 .01473 L
.03953 .01473 L
.04004 .01473 L
.04053 .01472 L
.04106 .01473 L
.04135 .01473 L
.04162 .01473 L
.04191 .01473 L
.04217 .01473 L
.04245 .01472 L
.04276 .01472 L
.04327 .01473 L
.04356 .01473 L
.04383 .01473 L
.04434 .01472 L
.04482 .01472 L
.04526 .01472 L
.04573 .01472 L
Mistroke
.04624 .01472 L
.04653 .01472 L
.04679 .01472 L
.04731 .01472 L
.04777 .01472 L
.04829 .01472 L
.04858 .01472 L
.04885 .01472 L
.04937 .01472 L
.04985 .01472 L
.05036 .01472 L
.05064 .01472 L
.0509 .01472 L
.05119 .01472 L
.05146 .01472 L
.05174 .01472 L
.05205 .01472 L
.05234 .01472 L
.05265 .01472 L
.05292 .01472 L
.05321 .01472 L
.05352 .01472 L
.05385 .01472 L
.05417 .01472 L
.05445 .01472 L
.05474 .01472 L
.055 .01472 L
.05529 .01472 L
.05559 .01472 L
.0561 .01472 L
.05639 .01472 L
.05667 .01472 L
.05718 .01472 L
.05743 .01472 L
.05772 .01472 L
.05822 .01472 L
.0587 .01472 L
.05897 .01472 L
.05925 .01472 L
.05976 .01472 L
.06005 .01472 L
.06031 .01473 L
.0606 .01473 L
.06091 .01473 L
.06143 .01472 L
.06172 .01472 L
.06199 .01472 L
.06249 .01473 L
.06302 .01473 L
.06349 .01472 L
Mistroke
.06394 .01472 L
.06446 .01473 L
.06493 .01473 L
.06539 .01473 L
.06582 .01472 L
.06629 .01472 L
.06679 .01473 L
.06726 .01473 L
.0677 .01473 L
.0681 .01473 L
.06853 .01472 L
.069 .01472 L
.06953 .01472 L
.06979 .01473 L
.07007 .01473 L
.07059 .01472 L
.07109 .01472 L
.07158 .01472 L
.07201 .01472 L
.07248 .01472 L
.07298 .01472 L
.07343 .01472 L
.07393 .01472 L
.07445 .01472 L
.07488 .01472 L
.07534 .01472 L
.07584 .01472 L
.07631 .01472 L
.07659 .01472 L
.07685 .01472 L
.07714 .01472 L
.07745 .01472 L
.07796 .01472 L
.07825 .01472 L
.07852 .01472 L
.07902 .01472 L
.07949 .01472 L
.07975 .01472 L
.08003 .01472 L
.08053 .01472 L
.08081 .01472 L
.08107 .01472 L
.08134 .01472 L
.08164 .01472 L
.08194 .01472 L
.08227 .01472 L
.08257 .01472 L
.08284 .01472 L
.08338 .01472 L
.08368 .01472 L
Mistroke
.08396 .01472 L
.08447 .01472 L
.08473 .01472 L
.08502 .01472 L
.08554 .01472 L
.08603 .01472 L
.08629 .01472 L
.08658 .01472 L
.08711 .01472 L
.08761 .01472 L
.08813 .01472 L
.08863 .01472 L
.08908 .01472 L
.08958 .01472 L
.09011 .01472 L
.09056 .01472 L
.09106 .01473 L
.0916 .01473 L
.0919 .01472 L
.09217 .01472 L
.0927 .01472 L
.09321 .01473 L
.09368 .01473 L
.09418 .01473 L
.0946 .01472 L
.09507 .01472 L
.09558 .01473 L
.09586 .01473 L
.09612 .01473 L
.0966 .01473 L
.0971 .01472 L
.09764 .01472 L
.09812 .01473 L
.09839 .01473 L
.09868 .01473 L
.09921 .01472 L
.09971 .01472 L
.10024 .01473 L
.10068 .01473 L
.10118 .01472 L
.10148 .01472 L
.10176 .01472 L
.10229 .01473 L
.10259 .01473 L
.10286 .01472 L
.10316 .01472 L
.10348 .01472 L
.10376 .01472 L
.10407 .01472 L
.10435 .01472 L
Mistroke
.10461 .01472 L
.10511 .01472 L
.10564 .01472 L
.10614 .01472 L
.10642 .01472 L
.10668 .01472 L
.10716 .01472 L
.10766 .01472 L
.1095 .01472 L
.10996 .01472 L
.11045 .01472 L
.11098 .01472 L
.11147 .01472 L
.11201 .01472 L
.11231 .01472 L
.11259 .01472 L
.1131 .01472 L
.11336 .01472 L
.11364 .01472 L
.11414 .01472 L
.11461 .01472 L
.11487 .01472 L
.11515 .01473 L
.11565 .01473 L
.11613 .01472 L
.11656 .01472 L
.11707 .01472 L
.11755 .01473 L
.11798 .01472 L
.11843 .01472 L
.11882 .01472 L
.11925 .01473 L
.11971 .01473 L
.12021 .01473 L
.12067 .01472 L
.1211 .01473 L
.12162 .01473 L
.12211 .01473 L
.12255 .01473 L
.12302 .01472 L
.12354 .01473 L
.12381 .01473 L
.12409 .01473 L
.1246 .01473 L
.12508 .01472 L
.12556 .01472 L
.12601 .01472 L
.12642 .01473 L
.12687 .01473 L
.12735 .01473 L
Mistroke
.12786 .01472 L
.12831 .01472 L
.12879 .01472 L
.12906 .01472 L
.12936 .01472 L
.12988 .01472 L
.13017 .01472 L
.13049 .01472 L
.13106 .01473 L
.13134 .01473 L
.13164 .01473 L
.13192 .01473 L
.13218 .01473 L
.13268 .01473 L
.1332 .01473 L
.1351 .01472 L
.13562 .01472 L
.13619 .01472 L
.13672 .01472 L
.1372 .01472 L
.1377 .01472 L
.13818 .01472 L
.13872 .01472 L
.13922 .01472 L
.14012 .01473 L
.1411 .01473 L
.14157 .01473 L
.14208 .01473 L
.14238 .01473 L
.14264 .01473 L
.14317 .01473 L
.1437 .01473 L
.14401 .01473 L
.14429 .01472 L
.14485 .01472 L
.14536 .01472 L
.14562 .01472 L
.1459 .01472 L
.14618 .01472 L
.14648 .01472 L
.14675 .01472 L
.14703 .01472 L
.14754 .01473 L
.14807 .01473 L
.14857 .01473 L
.14902 .01472 L
.14951 .01472 L
.15005 .01472 L
.15035 .01473 L
.15063 .01473 L
Mistroke
.15093 .01472 L
.1512 .01472 L
.15152 .01472 L
.15182 .01472 L
.15231 .01474 L
.15283 .01475 L
.15313 .01475 L
.15341 .01475 L
.15394 .01474 L
.1544 .01472 L
.15488 .01472 L
.15542 .01472 L
.15592 .01472 L
.15619 .01472 L
.15648 .01473 L
.15701 .01473 L
.15753 .01473 L
.15801 .01472 L
.15846 .01472 L
.15888 .01473 L
.15934 .01474 L
.15983 .01474 L
.16031 .01474 L
.16083 .01474 L
.16132 .01474 L
.16176 .01475 L
.16229 .01475 L
.16279 .01475 L
.16307 .01475 L
.16333 .01475 L
.16391 .01475 L
.16443 .01475 L
.16499 .01474 L
.16531 .01474 L
.1656 .01474 L
.16618 .01473 L
.16666 .01472 L
.16719 .01472 L
.16768 .01472 L
.16814 .01472 L
.16866 .01473 L
.16915 .01474 L
.16942 .01474 L
.16972 .01474 L
.17023 .01474 L
.17407 .01473 L
.17456 .01473 L
.17508 .01473 L
.17536 .01474 L
.17566 .01475 L
Mistroke
.17619 .01475 L
.17668 .01475 L
.17722 .01474 L
.17768 .01473 L
.17819 .01472 L
.1785 .01472 L
.17879 .01472 L
.1791 .01472 L
.17942 .01473 L
.18 .01474 L
.18029 .01475 L
.18055 .01476 L
.18081 .01476 L
.18109 .01476 L
.18137 .01476 L
.18168 .01476 L
.18221 .01475 L
.18271 .01474 L
.18297 .01474 L
.18325 .01473 L
.18377 .01473 L
.18427 .01473 L
.18474 .01472 L
.185 .01472 L
.18528 .01472 L
.18579 .01472 L
.1861 .01473 L
.18638 .01473 L
.18692 .01475 L
.18785 .01478 L
.18872 .01481 L
.18921 .01482 L
.18973 .01482 L
.19021 .01483 L
.19065 .01483 L
.19114 .01483 L
.19142 .01483 L
.19168 .01483 L
.19221 .01482 L
.1925 .01482 L
.19277 .01481 L
.19378 .01479 L
.19474 .01475 L
.19525 .01474 L
.19573 .01472 L
.196 .01472 L
.19629 .01473 L
.19679 .01474 L
.19727 .01475 L
.19778 .01476 L
Mistroke
.19821 .01477 L
.19869 .01477 L
.19898 .01477 L
.19925 .01478 L
.19976 .01478 L
.20005 .01477 L
.20031 .01477 L
.2006 .01477 L
.20091 .01476 L
.20193 .01474 L
.20244 .01473 L
.20272 .01473 L
.20299 .01473 L
.2035 .01473 L
.20395 .01473 L
.20448 .01473 L
.20498 .01473 L
.20544 .01473 L
.20586 .01473 L
.20632 .01473 L
.2068 .01473 L
.20729 .01474 L
.20781 .01475 L
.20831 .01478 L
.20876 .0148 L
.20929 .01483 L
.20959 .01484 L
.20986 .01485 L
.21037 .01485 L
.21066 .01485 L
.21091 .01485 L
.21275 .01483 L
.21326 .01483 L
.21379 .01482 L
.21424 .01481 L
.21474 .01477 L
.21521 .01474 L
.21564 .01473 L
.21615 .01476 L
.21661 .01479 L
.21835 .01488 L
.21881 .0149 L
.21931 .01492 L
.21979 .01493 L
.22022 .01493 L
.2207 .01493 L
.22123 .01493 L
.22149 .01492 L
.22177 .01492 L
.22228 .0149 L
Mistroke
.22332 .01486 L
.22443 .0148 L
.22495 .01477 L
.22523 .01475 L
.22549 .01474 L
.22595 .01472 L
.22646 .01474 L
.22743 .01478 L
.22836 .01481 L
.22887 .01483 L
.22915 .01483 L
.22942 .01484 L
.22989 .01484 L
.23039 .01483 L
.23081 .01482 L
.23126 .01482 L
.23169 .01482 L
.23209 .01483 L
.23256 .01484 L
.233 .01485 L
.23346 .01485 L
.23396 .01485 L
.23448 .01484 L
.23474 .01484 L
.23502 .01484 L
.23553 .01485 L
.23601 .01487 L
.2366 .0149 L
.23717 .01492 L
.23768 .01494 L
.23796 .01495 L
.23823 .01495 L
.23872 .01495 L
.23917 .01495 L
.23969 .01494 L
.24018 .01492 L
.2407 .0149 L
.24118 .01488 L
.24171 .01485 L
.24227 .0148 L
.24273 .01475 L
.24317 .01473 L
.24367 .0148 L
.24413 .01486 L
.24498 .01498 L
.24587 .01508 L
.24634 .01513 L
.24686 .01517 L
.24733 .0152 L
.24777 .01522 L
Mistroke
.24828 .01522 L
.24876 .01522 L
.24928 .0152 L
.24954 .01518 L
.24983 .01516 L
.25086 .01507 L
.25198 .01493 L
.25296 .01482 L
.2535 .01476 L
.25401 .01472 L
.25446 .01475 L
.25495 .01479 L
.25523 .0148 L
.25549 .01481 L
.25599 .01482 L
.25644 .01482 L
.25686 .01482 L
.25732 .0148 L
.25781 .01479 L
.25835 .01476 L
.25892 .01473 L
.25921 .01472 L
.25954 .01472 L
.25984 .01473 L
.26011 .01474 L
.26039 .01474 L
.26066 .01474 L
.26093 .01474 L
.26124 .01474 L
.2615 .01473 L
.26178 .01472 L
.26228 .01473 L
.26276 .01476 L
.26328 .0148 L
.26376 .01484 L
.26421 .0149 L
.26532 .01507 L
.26581 .01515 L
.26633 .01523 L
.26685 .0153 L
.26733 .01534 L
.26779 .01536 L
.26827 .01537 L
.26878 .01537 L
.26925 .01536 L
.26977 .01533 L
.27007 .01531 L
.27033 .01528 L
.27127 .01513 L
.27174 .01503 L
Mistroke
.27226 .01489 L
.27271 .01478 L
.27318 .01478 L
.27364 .01489 L
.27405 .01499 L
.27504 .01522 L
.27556 .01532 L
.27612 .01542 L
.27642 .01546 L
.27669 .01549 L
.27722 .01552 L
.27751 .01554 L
.27781 .01554 L
.27811 .01554 L
.27838 .01553 L
.27887 .01551 L
.27932 .01547 L
.27983 .01541 L
.28037 .01533 L
.28248 .01496 L
.28301 .01487 L
.28351 .01479 L
.28379 .01475 L
.28409 .01473 L
.28461 .0148 L
.28512 .01486 L
.28565 .01492 L
.2861 .01496 L
.28659 .01499 L
.28713 .01501 L
.28771 .01503 L
.28826 .01505 L
.28876 .01508 L
.28998 .01516 L
.29109 .01523 L
.29156 .01526 L
.29206 .01531 L
.29262 .01538 L
.29314 .01545 L
.2942 .01559 L
.29473 .01565 L
.29503 .01567 L
.29532 .01568 L
.29584 .01568 L
.29631 .01567 L
.29657 .01565 L
.29686 .01563 L
.29737 .01556 L
.29785 .01548 L
.29836 .01536 L
Mistroke
.29926 .01508 L
.29975 .01489 L
.30029 .01476 L
.3008 .01499 L
.30127 .0152 L
.30222 .01561 L
.30311 .01593 L
.3036 .01608 L
.30406 .01618 L
.30456 .01626 L
.30483 .01628 L
.30511 .0163 L
.30563 .01629 L
.30612 .01625 L
.30666 .01617 L
.30696 .0161 L
.30723 .01604 L
.30907 .01547 L
.31004 .01517 L
.31057 .01503 L
.31107 .01492 L
.3115 .01484 L
.31196 .01478 L
.31248 .01474 L
.31295 .01472 L
.31337 .01473 L
.31384 .01475 L
.31428 .01479 L
.31469 .01483 L
.31569 .01495 L
.3162 .01499 L
.31648 .01501 L
.31675 .01502 L
.31705 .01502 L
.31731 .01502 L
.31762 .015 L
.31792 .01497 L
.31843 .0149 L
.31872 .01485 L
.31899 .01478 L
.31947 .01478 L
.31992 .01493 L
.32095 .01536 L
.32197 .01587 L
.32304 .01641 L
.32347 .0166 L
.32394 .01676 L
.32446 .01689 L
.32494 .01697 L
.32541 .01699 L
Mistroke
.32585 .01698 L
.32625 .01693 L
.32668 .01683 L
.32715 .01668 L
.32767 .01644 L
.32872 .01578 L
.32919 .01543 L
.32969 .01504 L
.33017 .01477 L
.33061 .01511 L
.33161 .01585 L
.33255 .01644 L
.33307 .01671 L
.33335 .01682 L
.33364 .01692 L
.33415 .01705 L
.33462 .01712 L
.33507 .01714 L
.33554 .01712 L
.33599 .01706 L
.3364 .01696 L
.33688 .01682 L
.3374 .01664 L
.33834 .01623 L
.34047 .01526 L
.34099 .01504 L
.34155 .01483 L
.34186 .01472 L
.34216 .01482 L
.34273 .015 L
.34469 .01544 L
.34678 .01596 L
.34888 .01664 L
.34987 .01703 L
.35078 .01737 L
.35123 .01751 L
.3517 .01761 L
.35217 .01767 L
.35269 .01768 L
.35314 .01763 L
.35362 .01751 L
.35408 .01734 L
.35449 .01713 L
.35502 .0168 L
.35557 .01636 L
.35657 .01538 L
.35683 .01509 L
.35712 .01476 L
.35764 .01529 L
.35882 .01666 L
Mistroke
.35986 .0177 L
.36039 .0181 L
.36069 .01829 L
.36096 .01844 L
.36145 .01863 L
.36197 .01873 L
.36246 .01873 L
.36292 .01865 L
.36339 .01849 L
.36389 .01826 L
.3648 .0177 L
.36687 .01628 L
.36741 .01598 L
.36769 .01585 L
.36799 .01573 L
.36828 .01563 L
.36854 .01556 L
.36905 .01547 L
.36955 .01544 L
.37008 .01547 L
.37059 .01555 L
.37105 .01564 L
.37194 .01585 L
.37241 .01594 L
.37291 .01601 L
.37335 .01603 L
.37383 .01598 L
.37427 .01589 L
.37468 .01573 L
.37519 .01546 L
.37565 .01513 L
.37617 .01475 L
.37642 .015 L
.37671 .01531 L
.37856 .01775 L
.37955 .01911 L
.3801 .01977 L
.38061 .02028 L
.38109 .02065 L
.38161 .02091 L
.38209 .02101 L
.38252 .02099 L
.38296 .02084 L
.38338 .0206 L
.38383 .02022 L
.38432 .01967 L
.38531 .01815 L
.38622 .01645 L
.38674 .01541 L
.38703 .01483 L
Mistroke
.38729 .01513 L
.3878 .01613 L
.38829 .01703 L
.38886 .01802 L
.38946 .01893 L
.39002 .01962 L
.39053 .02012 L
.39099 .02043 L
.39147 .02065 L
.39175 .02072 L
.39201 .02075 L
.3925 .02071 L
.39303 .02055 L
.39352 .02029 L
.39406 .01992 L
.39463 .01944 L
.39659 .01743 L
.39845 .01558 L
.39895 .01514 L
.39948 .01473 L
.39979 .01496 L
.40006 .01517 L
.4006 .01555 L
.40257 .01697 L
.40619 .02033 L
.40707 .02118 L
.40755 .02157 L
.40801 .02188 L
.40827 .02201 L
.40856 .02212 L
.40905 .02221 L
.40955 .02216 L
.41002 .02196 L
.4105 .02161 L
.41095 .02113 L
.41145 .02044 L
.41199 .01952 L
.41301 .01729 L
.41357 .01588 L
.41409 .01493 L
.41454 .01616 L
.41503 .01746 L
.41605 .01999 L
.41653 .02102 L
.41699 .02185 L
.41743 .02251 L
.41784 .02299 L
.41833 .02337 L
.41887 .02357 L
.41939 .02354 L
Mistroke
.41969 .02343 L
.41996 .02328 L
.42043 .02291 L
.42095 .02237 L
.4219 .02117 L
.42301 .0197 L
.42362 .01899 L
.42419 .01844 L
.42472 .01805 L
.42503 .0179 L
.4253 .01779 L
.42579 .0177 L
.42631 .01772 L
.42681 .01783 L
.42709 .01792 L
.42735 .01803 L
.42782 .01823 L
.42833 .01846 L
.42879 .01863 L
.42923 .01874 L
.42968 .01876 L
.43017 .01865 L
.43068 .01837 L
.43096 .01812 L
.43123 .01783 L
.43176 .01707 L
.43233 .016 L
.43287 .01476 L
.43337 .01602 L
.43431 .01892 L
.43605 .02467 L
.43651 .02603 L
.437 .0273 L
.43746 .02827 L
.43789 .02898 L
.4384 .02949 L
.43886 .02967 L
.43936 .02952 L
.43965 .02928 L
.43991 .02895 L
.44034 .02821 L
.44081 .02712 L
.44177 .02407 L
.44281 .01988 L
.44331 .01765 L
.44377 .01558 L
.44425 .01601 L
.44477 .01825 L
.44587 .02249 L
.4468 .02525 L
Mistroke
.44732 .02641 L
.4478 .0272 L
.44823 .02768 L
.44869 .02797 L
.44918 .02803 L
.44963 .02788 L
.45015 .02747 L
.45045 .02714 L
.45072 .02678 L
.45176 .02503 L
.45372 .02089 L
.45481 .01854 L
.45584 .01646 L
.45641 .01536 L
.45674 .01477 L
.45703 .0152 L
.45811 .01716 L
.46181 .02501 L
.46278 .02726 L
.4633 .02837 L
.46384 .02943 L
.46432 .0302 L
.46484 .03084 L
.46532 .03119 L
.46577 .03128 L
.46605 .0312 L
.46634 .03102 L
.46687 .03039 L
.46716 .02987 L
.46743 .02928 L
.46805 .02755 L
.46905 .02367 L
.47012 .01839 L
.47064 .01553 L
.47094 .01554 L
.47121 .01705 L
.47225 .02256 L
.47325 .02713 L
.47373 .02887 L
.47418 .03018 L
.47464 .03124 L
.47515 .03199 L
.4756 .03231 L
.47608 .03232 L
.47634 .03219 L
.47663 .03195 L
.47715 .03128 L
.47766 .03039 L
.47812 .02943 L
.47904 .02736 L
Mistroke
.48003 .02529 L
.48051 .02448 L
.48096 .02387 L
.48137 .02347 L
.48181 .02319 L
.4823 .02309 L
.48283 .02318 L
.48327 .02341 L
.48376 .02376 L
.48433 .02423 L
.48488 .02465 L
.48537 .02493 L
.4859 .02502 L
.48617 .02496 L
.48645 .02481 L
.48697 .02424 L
.48728 .0237 L
.48758 .02304 L
.48812 .02142 L
.48865 .01939 L
.48913 .01712 L
.48965 .01522 L
.48992 .01683 L
.49021 .01869 L
.49234 .03367 L
.49339 .0402 L
.49385 .0425 L
.49436 .04449 L
.49481 .04572 L
.49523 .04636 L
.49568 .04648 L
.49617 .04595 L
.49667 .04469 L
.4972 .0426 L
.49765 .04024 L
.49814 .0371 L
.49923 .02851 L
.50027 .01924 L
.50055 .0167 L
.50084 .01541 L
.50116 .01829 L
.50146 .02088 L
.50254 .02942 L
.50303 .03264 L
.50355 .03559 L
.504 .03768 L
.5045 .03944 L
.50479 .04025 L
.50507 .04083 L
.50534 .04123 L
Mistroke
.50562 .04149 L
.5059 .0416 L
.50616 .04155 L
.50664 .04115 L
.50712 .04037 L
.50763 .03919 L
.50854 .03632 L
.51062 .02792 L
.51175 .02312 L
.51282 .01867 L
.51328 .01677 L
.51378 .01476 L
.51404 .01572 L
.51432 .01688 L
.51482 .01895 L
.51848 .03595 L
.51938 .04012 L
.52033 .04401 L
.52087 .04577 L
.52137 .04695 L
.52187 .04767 L
.52234 .04783 L
.52284 .04742 L
.52337 .04628 L
.52382 .04472 L
.52431 .04237 L
.52485 .03913 L
.52542 .0349 L
.52645 .02564 L
.52693 .0208 L
.52746 .01535 L
.52796 .01925 L
.52842 .02394 L
.52928 .03207 L
.53022 .03927 L
.5308 .04266 L
.53133 .04495 L
.53184 .04639 L
.53238 .04714 L
.53286 .04717 L
.53331 .04673 L
.5338 .04579 L
.53433 .04438 L
.53543 .04072 L
.53604 .0387 L
.5366 .037 L
.53713 .03574 L
.5376 .03489 L
.53813 .03434 L
.53843 .03421 L
Mistroke
.5387 .0342 L
.5392 .03443 L
.53973 .03497 L
.54069 .03634 L
.54097 .03675 L
.54128 .03714 L
.54156 .03744 L
.54183 .03763 L
.54233 .03768 L
.54286 .03718 L
.5434 .03595 L
.5437 .03489 L
.54397 .03367 L
.54451 .03061 L
.54501 .02682 L
.54556 .02178 L
.54586 .01862 L
.54614 .01542 L
.54644 .01767 L
.54678 .02196 L
.54737 .02997 L
.54929 .05649 L
.55026 .06729 L
.5508 .07185 L
.55131 .07485 L
.5516 .07596 L
.55187 .0766 L
.55239 .0767 L
.55267 .07613 L
.55293 .0752 L
.55322 .07375 L
.55353 .07172 L
.55403 .06739 L
.5545 .06228 L
.55556 .0475 L
.55654 .03136 L
.5568 .02692 L
.55708 .0221 L
.55759 .016 L
.5579 .02124 L
.55819 .02593 L
.55873 .03434 L
.5598 .04836 L
.56025 .05314 L
.56073 .05738 L
.56126 .06098 L
.56175 .06333 L
.56202 .0642 L
.56231 .06484 L
.56283 .06523 L
Mistroke
.56334 .06471 L
.56382 .06352 L
.56425 .06191 L
.56471 .05969 L
.56556 .05466 L
.56747 .04042 L
.56846 .03251 L
.5695 .0241 L
.56993 .02062 L
.57039 .01687 L
.57089 .01671 L
.57136 .02063 L
.57553 .05874 L
.57668 .06788 L
.57725 .07151 L
.57758 .07319 L
.57789 .07441 L
.57816 .07525 L
.57843 .07578 L
.5787 .07604 L
.57901 .07594 L
.57927 .07553 L
.57955 .07474 L
.58005 .0724 L
.58056 .06886 L
.58102 .06456 L
.58206 .0515 L
.58304 .03584 L
.58352 .02742 L
.58395 .01955 L
.58443 .01873 L
.58495 .02801 L
.58605 .0459 L
.58659 .05339 L
.58718 .06013 L
.58774 .06505 L
.58826 .06828 L
.58876 .07025 L
.58925 .07108 L
.58968 .07104 L
.59015 .07025 L
.59067 .0687 L
.59121 .06649 L
.59219 .06189 L
.59267 .05973 L
.59319 .05771 L
.59368 .05622 L
.59413 .05529 L
.59453 .05485 L
.59498 .0548 L
Mistroke
.59544 .0552 L
.59588 .05593 L
.59697 .05864 L
.5975 .05998 L
.598 .06089 L
.59845 .06124 L
.59892 .06092 L
.5994 .05968 L
.59993 .05703 L
.6002 .05507 L
.60049 .05254 L
.60101 .0468 L
.60156 .03882 L
.60217 .02805 L
.6027 .01712 L
.60299 .01897 L
.60326 .02532 L
.60427 .05102 L
.60625 .09956 L
.60673 .10894 L
.60724 .11723 L
.60754 .12103 L
.60781 .12383 L
.60833 .12738 L
.60881 .12826 L
.60925 .12707 L
.60974 .12355 L
.61026 .11734 L
.61075 .10921 L
.61121 .09979 L
.61208 .07836 L
.61311 .04848 L
.61368 .03128 L
.6142 .01532 L
.61465 .0274 L
.61513 .04097 L
.61615 .0664 L
.61672 .07805 L
.61733 .08836 L
.61761 .09223 L
.61791 .09573 L
.61845 .10048 L
.61896 .10323 L
.61944 .10428 L
.61997 .10385 L
.62027 .10294 L
.62054 .10172 L
.62106 .09845 L
.62156 .09437 L
.62248 .08471 L
Mistroke
.62454 .0574 L
.62633 .03117 L
.62682 .02375 L
.62733 .01578 L
.62778 .02057 L
.62826 .02831 L
.63036 .06356 L
.63152 .0831 L
.63262 .09996 L
.63364 .11245 L
.63392 .1151 L
.63421 .11746 L
.63475 .1204 L
.63522 .12146 L
.63567 .12097 L
.63616 .1187 L
.63669 .11412 L
.6372 .10761 L
.63766 .09996 L
.6387 .07735 L
.63968 .05082 L
.64011 .03813 L
.64058 .02383 L
.64109 .02111 L
.64137 .02946 L
.64163 .03713 L
.64277 .06748 L
.64377 .08797 L
.64433 .0964 L
.64484 .10205 L
.64537 .10588 L
.64566 .10718 L
.64593 .10786 L
.64645 .10799 L
.64694 .10689 L
.64722 .10584 L
.64752 .10448 L
.64805 .10159 L
.64862 .09819 L
.64924 .09476 L
.64952 .09343 L
.64978 .09233 L
.65027 .09081 L
.65073 .09008 L
.65123 .09013 L
.65149 .09048 L
.65178 .09112 L
.65208 .09204 L
.65237 .0931 L
.65342 .09785 L
Mistroke
.6539 .09988 L
.65441 .10144 L
.65489 .10195 L
.65533 .1013 L
.65585 .09881 L
.65614 .09646 L
.65641 .09363 L
.6569 .08662 L
.65743 .07654 L
.65846 .04822 L
.65896 .03097 L
.65943 .01669 L
.6597 .02766 L
.65999 .04005 L
.6605 .06259 L
.66164 .11425 L
.66262 .15477 L
.66353 .18523 L
.66399 .1966 L
.66449 .20542 L
.66476 .20857 L
.66504 .21063 L
.66555 .21098 L
.66598 .20787 L
.66644 .20114 L
.66688 .19168 L
.66728 .18063 L
.66825 .14495 L
.66917 .10275 L
.67008 .05691 L
.67058 .03069 L
.67105 .02233 L
.67131 .03527 L
.6716 .049 L
.67212 .07269 L
.67312 .11193 L
.67366 .12903 L
.67417 .1422 L
.67445 .14824 L
.67475 .15377 L
.67528 .16091 L
.67579 .16487 L
.67605 .16585 L
.67633 .16617 L
.67683 .16492 L
.6773 .16184 L
.67776 .15711 L
.67827 .15034 L
.67919 .1345 L
.68092 .09676 L
Mistroke
.68188 .07309 L
.68292 .0463 L
.6834 .0336 L
.6839 .01997 L
.68433 .0213 L
.6848 .03448 L
.68665 .08818 L
.68862 .14378 L
.68921 .15812 L
.68977 .16993 L
.69031 .17936 L
.69081 .18588 L
.69128 .18984 L
.69179 .19139 L
.69229 .18999 L
.69258 .18781 L
.69284 .18484 L
.69337 .17631 L
.69367 .16994 L
.69395 .16305 L
.695 .12913 L
.69601 .08667 L
.69697 .0416 L
.69723 .02882 L
.69751 .01536 L
.69781 .02868 L
.69809 .04186 L
.69911 .08629 L
.7002 .12424 L
.70082 .1402 L
.70109 .1459 L
.70139 .15119 L
.70191 .1579 L
.70219 .1604 L
.70245 .16204 L
.70293 .16343 L
.70343 .16305 L
.7037 .16221 L
.704 .16091 L
.70459 .15748 L
.70515 .15388 L
.70565 .15083 L
.70618 .14836 L
.70667 .14697 L
.70718 .1467 L
.70748 .14713 L
.70775 .14789 L
.7082 .1499 L
.70869 .153 L
.70969 .1608 L
Mistroke
.71019 .16455 L
.71067 .16726 L
.7111 .16854 L
.71157 .16818 L
.71208 .16516 L
.71234 .1624 L
.71262 .1583 L
.71312 .14809 L
.71359 .13483 L
.71451 .09839 L
.71535 .05299 L
.71579 .0252 L
.71627 .0372 L
.71677 .07373 L
.71724 .1089 L
.71824 .18355 L
.71929 .2547 L
.71984 .28543 L
.72014 .29937 L
.72045 .31229 L
.72074 .32212 L
.721 .32932 L
.72152 .33823 L
.72203 .34 L
.72251 .33521 L
.72303 .32295 L
.72332 .31303 L
.72359 .30225 L
.7246 .24681 L
.72556 .17848 L
.72648 .10388 L
.72698 .06181 L
.72745 .02286 L
.72785 .03902 L
.72828 .07244 L
.72919 .13665 L
.72969 .16737 L
.73024 .19608 L
.73073 .21707 L
.73124 .23478 L
.7317 .24665 L
.73221 .25541 L
.73268 .25958 L
.73311 .26039 L
.73355 .25841 L
.73401 .25352 L
.73452 .2452 L
.73499 .23514 L
.73675 .18142 L
.73879 .10114 L
Mistroke
.73968 .06249 L
.74017 .04051 L
.74064 .01924 L
.7409 .02234 L
.74119 .0357 L
.74169 .05938 L
.74267 .10653 L
.7449 .21039 L
.7459 .24914 L
.74644 .26649 L
.74696 .27955 L
.74744 .28843 L
.74796 .29392 L
.74843 .29487 L
.74886 .29213 L
.74934 .28503 L
.74984 .27259 L
.75032 .25634 L
.75076 .23788 L
.75182 .17954 L
.75283 .11133 L
.75334 .07429 L
.75388 .03431 L
.75434 .029 L
.75484 .06521 L
.75598 .1383 L
.75702 .1899 L
.75754 .20923 L
.75782 .21761 L
.75812 .22517 L
.7584 .23112 L
.75866 .23548 L
.75916 .24132 L
.75945 .24328 L
.75972 .24424 L
.76002 .24449 L
.76034 .244 L
.76087 .2419 L
.76145 .23867 L
.76199 .23578 L
.76249 .23378 L
.76277 .23317 L
.76307 .233 L
.7636 .23413 L
.76411 .23697 L
.76464 .24177 L
.76561 .25367 L
.76658 .26623 L
.76687 .26908 L
.76713 .2712 L
Mistroke
.76763 .2731 L
.7681 .27171 L
.76853 .26703 L
.769 .25744 L
.76951 .24157 L
.76999 .22033 L
.77044 .19488 L
.77147 .11693 L
.772 .06661 L
.7725 .0159 L
.77278 .04698 L
.77309 .08201 L
.77362 .14537 L
.77546 .36045 L
.77599 .41278 L
.77649 .45502 L
.77695 .4864 L
.77743 .51134 L
.77785 .52576 L
.77831 .53306 L
.77873 .53177 L
.77913 .52378 L
.77959 .50606 L
.78001 .48248 L
.7805 .44706 L
.78096 .40627 L
.78279 .19493 L
.78371 .0744 L
.78424 .02272 L
.78473 .08382 L
.78576 .19868 L
.78629 .25017 L
.78686 .29658 L
.78735 .32995 L
.78789 .35888 L
.78838 .37832 L
.78883 .39066 L
.78936 .39838 L
.78966 .39969 L
.78994 .39905 L
.79044 .39356 L
.79098 .3822 L
.79146 .36774 L
.79191 .35101 L
.79293 .30349 L
.79503 .17808 L
.79614 .10246 L
.79674 .05909 L
.79704 .03742 L
.79731 .01731 L
Mistroke
.79781 .04971 L
.79836 .09081 L
.79951 .17901 L
.80049 .25163 L
.80155 .32498 L
.8025 .37995 L
.80302 .40429 L
.80351 .42253 L
.80378 .4303 L
.80407 .43682 L
.80458 .44315 L
.8051 .4425 L
.80558 .43524 L
.80601 .42296 L
.80648 .4037 L
.80692 .37991 L
.80732 .35359 L
.80924 .17976 L
.81019 .07599 L
.81045 .04713 L
.81073 .01656 L
.81123 .06671 L
.81213 .15675 L
.81312 .23928 L
.81363 .27364 L
.81418 .30365 L
.81476 .32773 L
.81502 .33608 L
.8153 .34357 L
.81558 .34948 L
.81584 .3537 L
.81635 .35897 L
.81682 .36095 L
.81731 .36103 L
.81784 .3599 L
.81812 .35919 L
.81842 .35858 L
.81868 .35831 L
.81896 .35841 L
.81946 .35993 L
.81977 .36192 L
.82006 .36447 L
.82038 .36833 L
.82069 .37284 L
.82184 .39528 L
.82283 .41663 L
.82333 .42504 L
.82362 .42839 L
.82389 .43028 L
.82436 .42996 L
Mistroke
.8248 .42466 L
.8253 .41144 L
.82578 .39085 L
.82633 .35598 L
.82693 .30437 L
.82802 .17405 L
.82853 .09717 L
.82881 .05171 L
.82907 .02198 L
.82954 .104 L
.83004 .19762 L
.8311 .39386 L
.83209 .56468 L
Mfstroke
.83209 .56468 m
.83247 .61803 L
s
.83748 .61803 m
.83812 .52505 L
.83902 .36256 L
.83998 .17448 L
.84044 .08229 L
.84088 .03237 L
.84127 .10642 L
.8417 .18286 L
.84269 .3405 L
.84323 .41242 L
.84373 .46937 L
.8442 .51282 L
.84463 .54464 L
.8451 .57128 L
.84561 .58994 L
.84608 .59853 L
.84653 .59911 L
.84703 .59201 L
.84756 .5761 L
.84809 .5528 L
.84864 .52118 L
.84963 .44976 L
.85144 .28545 L
.85243 .18244 L
.85336 .0795 L
.85389 .01997 L
.85418 .04349 L
.85446 .0751 L
.85545 .19115 L
.85739 .41031 L
.8585 .51758 L
.85954 .59521 L
s
.85954 .59521 m
.85996 .61803 L
s
.86256 .61803 m
.8626 .61637 L
.86288 .59895 L
.8634 .55976 L
.86388 .51405 L
.86505 .37003 L
.86611 .21052 L
.86659 .134 L
.86712 .05031 L
.86761 .05682 L
.86807 .12602 L
.86915 .27297 L
.87017 .38136 L
.87101 .44626 L
.87148 .47294 L
.87191 .4917 L
.87236 .50603 L
.87285 .51669 L
.87336 .52352 L
.87384 .52722 L
.8743 .52957 L
.87481 .53195 L
.87529 .53514 L
.87572 .53961 L
.87624 .54736 L
.87678 .5589 L
.87774 .5871 L
s
.87774 .5871 m
.87862 .61803 L
s
.88196 .61803 m
.88234 .59041 L
.88285 .54005 L
.88332 .4786 L
.88375 .41083 L
.88427 .3147 L
.88482 .19663 L
.88528 .08428 L
.8858 .07887 L
.88625 .20202 L
.88674 .33818 L
.88762 .58375 L
s
.88762 .58375 m
.88775 .61803 L
s
.89529 .61803 m
.89605 .40278 L
.89655 .25628 L
.89701 .12095 L
.8975 .04706 L
.89802 .19145 L
.89898 .42808 L
s
.89898 .42808 m
.89993 .61803 L
s
.9065 .61803 m
.90747 .49941 L
.90855 .33674 L
.90959 .17009 L
.91005 .09209 L
.91055 .02181 L
.91083 .07093 L
.91109 .11563 L
.91159 .20313 L
.91342 .51416 L
s
.91342 .51416 m
.91411 .61803 L
s
.92108 .61803 m
.92145 .55382 L
.92228 .38207 L
.92316 .18722 L
.92362 .08364 L
.92412 .05716 L
.92457 .15487 L
.925 .24115 L
.926 .4216 L
.92706 .56817 L
s
.92706 .56817 m
.92754 .61803 L
s
.94018 .61803 m
.9409 .42454 L
.94141 .25839 L
.94189 .08453 L
.94233 .11163 L
.9428 .30176 L
s
.9428 .30176 m
.94357 .61803 L
s
.95254 .61803 m
.95306 .39685 L
.95335 .27356 L
.95362 .15868 L
.9541 .06929 L
.95463 .27873 L
s
.95463 .27873 m
.95561 .61803 L
s
.96446 .61803 m
.96513 .47951 L
.96604 .26593 L
.96654 .14458 L
.967 .02855 L
.96744 .11064 L
.96791 .2297 L
.96874 .43622 L
s
.96874 .43622 m
.96952 .61803 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[219]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
ogooQgoo003oOon7Ool00?moohMoo`00hGoo0P00Xgoo003POol01000Oomoo`00XWoo003POol00`00
Oomoo`2SOol00=moo`@00:=oo`00h7oo00<007ooOol0Xgoo003oOon7Ool00?moohMoo`00ogooQgoo
003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool004Uoo`03001oogoo02eoo`03001oogoo009o
o`03001oogoo02Ioo`D0009oo`03001oogoo009oo`03001oogoo02Aoo`D0009oo`03001oogoo009o
o`03001oogoo02Aoo`<000=oo`03001oogoo009oo`03001oogoo02Eoo`<000=oo`03001oogoo009o
o`03001oogoo02Eoo`8000Aoo`03001oogoo009oo`03001oogoo00Eoo`00B7oo00<007oo0000;Goo
00<007oo00000Woo00<007oo0000:Goo00L007ooOomoo`00Ool00002Ool00`00Ool0000WOol01`00
Oomoogoo001oo`00009oo`03001oo`0002Eoo`03001oogoo009oo`03001oo`00009oo`03001oo`00
02Ioo`03001oogoo009oo`03001oo`00009oo`03001oo`0002Qoo`06001oogoo001oo`000Woo00<0
07oo00001Woo0018Ool00`00Ool0000_Ool01P00Oomoo`00Ool002Uoo`07001oogooOol007oo0000
0Woo00<007oo00009goo00<007ooOol00goo00H007ooOol007oo000VOol01`00Oomoogoo001oo`00
009oo`03001oo`0002Moo`03001oogoo00=oo`06001oogoo001oo`009goo00L007ooOomoo`00Ool0
0002Ool00`00Ool00006Ool004Qoo`03001oo`0002eoo`8000=oo`03001oo`0002Uoo`07001oogoo
Ool007oo00000Woo00<007oo00009goo00@007ooOomoo`8000=oo`03001oo`0002Ioo`07001oogoo
Ool007oo00000Woo00<007oo00009goo00@007ooOomoo`8000=oo`03001oo`0002Qoo`06001oogoo
001oo`000Woo00<007oo00001Woo0018Ool00`00Ool0000]Ool00`00Oomoo`02Ool00`00Ool0000Y
Ool01`00Oomoogoo001oo`00009oo`03001oo`0002Moo`05001oogooOol00004Ool00`00Ool0000U
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool0000VOol00`00Ool00002Ool00`00Oomoo`02
Ool00`00Ool0000VOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool00006Ool004Uoo`03001o
ogoo02aoo`<000=oo`03001oogoo02Moo`8000Aoo`03001oogoo009oo`03001oogoo02Eoo`8000=o
o`<000=oo`03001oogoo02Eoo`03001oogoo009oo`03001oogoo009oo`03001oogoo02Ioo`04001o
ogooOol30003Ool00`00Oomoo`0VOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`05Ool0
0?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo0012Oooo00120003Ool0049oo`03
001oogoo00Eoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Qoo`03
001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Qoo`03001oogoo00Moo`03001oogoo00Moo`03001oogoo00Moo`03
001oogoo00Moo`03001oogoo00Eoo`03001oogoo005oo`00@Woo00<007ooOol01Goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
27oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol0
1Goo00<007ooOol00Goo0012Ool00`00Oomoo`3oOolnOol00`00Oomoo`01Ool003Uoo`03001oogoo
00Ioo`03001oogoo0?moocioo`03001oogoo005oo`00>7oo00<007oo00001gooo`00@P000goo000h
Ool00`00Ool00007Ool00`00Oomoo`1NOol20004Ool60003Ool60003Ool00`00Ool00002000017oo
001oo`000Woo0P0000=oo`0000000`000Woo00<007ooOol00`000Woo0P0017oo0P000Woo00@007oo
Oomoo`8000=oo`03001oogoo00=oo`04001oogoo0003Ool20003Ool00`00Oomoo`03Ool01000Oomo
o`0017oo00<007ooOol01goo00<007ooOol02Goo00<007ooOol02goo00<007ooOol01goo00<007oo
Ool01Goo00D007ooOomoo`0003aoo`03001oogoo005oo`00>7oo00<007oo00001goo00<007ooOol0
Mgoo0P0000=oo`0000000goo100000=oo`00Ool00Woo00@007ooOol0009oo`03001oo`00009oo`80
00Aoo`80009oo`04001oogooOol20003Ool00`00Oomoo`02Ool20002Ool01000Oomoogoo0P000goo
00<007ooOol00goo00@007ooOol000=oo`8000=oo`03001oogoo00=oo`05001oogooOol00003Ool0
1@00Oomoogoo00003Goo00<007ooOol01goo00<007ooOol01Goo00D007ooOomoo`0000Eoo`03001o
ogoo00Eoo`03001oogoo00moo`03001oogoo01Yoo`03001oogoo005oo`00>7oo00<007oo00001goo
00<007ooOol0Pgoo00<007ooOol00Woo00@007oo001oo`8000=oo`04001oo`000002Ool40002Ool0
1000Oomoogoo0P000Woo0P0017oo0P000Woo00@007ooOomoo`8000=oo`03001oogoo00=oo`03001o
ogoo0080009oo`8000=oo`03001oogoo00=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo
00D007ooOomoo`0000=oo`03001oogoo00Moo`05001oogooOol00003Ool01@00Oomoogoo00001Goo
00<007ooOol01Goo00<007ooOol03goo00<007ooOol06Woo00<007ooOol00Goo000iOol00`00Oomo
o`06Ool00`00Oomoo`29Ool200000goo00000003Ool01P00Ool00000Ool000=oo`03001oogoo0080
0004Ool007oo0002Ool20004Ool20002Ool20002Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`02
0002Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`020003Ool01@00Oomoogoo00001Goo00D007oo
Oomoo`0000=oo`03001oogoo00Moo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007oo
Ool01Goo00<007ooOol03goo00<007ooOol03goo00<007ooOol027oo00<007ooOol00Goo0012Ool2
002:Ool20006Ool300000goo00000003Ool00`00Oomoo`0200001Woo001oogoo001oo`8000Aoo`80
009oo`80009oo`8000=oo`03001oogoo00=oo`03001oogoo0080009oo`8000=oo`03001oogoo00=o
o`03001oogoo008000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`00
00Eoo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00<007ooOol01Goo00<007ooOol03goo
00<007ooOol03goo00<007ooOol01goo0P000goo0012Ool00`00Oomoo`2EOol00`00Oomoo`02Ool0
1`00Ool007oo001oo`00009oo`04001oo`000002Ool01000Ool000000Woo0P000Woo0P000Woo0P00
17oo0P000Woo0P000Woo0P000goo00<007ooOol00goo00<007ooOol00P000goo00D007ooOomoo`00
00Eoo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogoo
Ool00005Ool01@00Oomoogoo00000goo00<007ooOol03goo00<007ooOol03goo00<007ooOol027oo
00<007ooOol00Goo0012Ool00`00Oomoo`2JOol01`00Ool007oo001oo`00009oo`04001oo`000002
Ool40002Ool2000017oo001oo`000Woo0P0017oo0P000Woo0P000Woo0P000goo00<007ooOol00goo
00<007ooOol00P000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01@00Oomoogoo0000
1Goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00<007ooOol0
3goo00<007ooOol03goo00<007ooOol027oo00<007ooOol00Goo0012Ool00`00Oomoo`2KOol20000
0goo00000003Ool01000Ool007oo0P000goo00<007ooOol00P0000Aoo`00Ool0009oo`8000Aoo`80
009oo`80009oo`8000=oo`03001oogoo00=oo`03001oogoo0080009oo`8000=oo`03001oogoo00=o
o`05001oogooOol00003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogooOol0
0005Ool01@00Oomoogoo00000goo00<007ooOol03goo00<007ooOol03goo00<007ooOol027oo00<0
07ooOol00Goo0012Ool00`00Oomoo`2KOol20002Ool02000Oomoogoo001oo`00Ool20003Ool00`00
Oomoo`0200001Woo001oogoo001oo`8000Aoo`80009oo`80009oo`8000=oo`03001oogoo00=oo`03
001oogoo0080009oo`8000=oo`03001oogoo00=oo`03001oogoo008000=oo`05001oogooOol00005
Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool00`00Oomoo`0?
Ool00`00Oomoo`0?Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`8009aoo`8000Moo`800003
Ool0000000Aoo`06001oo`00001oo`000Woo00@007oo000000Aoo`80009oo`80009oo`8000=oo`03
001oogoo00=oo`03001oogoo0080009oo`8000=oo`03001oogoo00=oo`03001oogoo008000=oo`05
001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003
Ool00`00Oomoo`0;Ool01@00Oomoogoo00004Goo00<007ooOol01goo0P000goo0012Ool00`00Oomo
o`2TOol00`00Oomoo`06Ool01P00Ool00000Ool0009oo`04001oo`000004Ool20002Ool20002Ool0
0`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`020002Ool20003Ool00`00Oomoo`03Ool00`00
Oomoo`020003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`05001oogooOol0000AOol00`00Oomoo`08Ool0
0`00Oomoo`01Ool0049oo`03001oogoo0:eoo`06001oo`00001oo`000Woo00D007oo001oo`0000=o
o`80009oo`80009oo`03001oo`00009oo`03001oogoo00=oo`03001oogoo0080009oo`8000=oo`03
001oogoo00=oo`03001oogoo008000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D0
07ooOomoo`0000Eoo`05001oogooOol00003Ool01@00Oomoogoo00002Goo00D007ooOomoo`00015o
o`03001oogoo00Qoo`03001oogoo005oo`00@Woo00<007ooOol0[Goo0P0000Aoo`00Ool0009oo`06
001oo`00Ool007oo10000Woo0P000Woo00<007oo00000Woo0P0017oo00<007ooOol00P000Woo0P00
0goo00<007ooOol00goo00<007ooOol00P000goo00D007ooOomoo`0000Eoo`05001oogooOol00003
Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogooOol00009Ool01@00Oomoogoo
00004Goo00<007ooOol027oo00<007ooOol00Goo0012Ool00`00Oomoo`2]Ool2000017oo001oo`00
0Woo00H007oo001oo`00Ool40002Ool20002Ool00`00Ool00002Ool20004Ool00`00Oomoo`020002
Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`020003Ool01@00Oomoogoo00001Goo00D007ooOomo
o`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`05001o
ogooOol00004Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`03001oogoo
0:eoo`80009oo`08001oogooOol007oo001oo`800004Ool000000002Ool20002Ool00`00Ool00002
Ool20004Ool00`00Oomoo`020002Ool20003Ool00`00Oomoo`03Ool00`00Oomoo`020003Ool01@00
Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Uoo`05001oogooOol00004Ool00`00Oomoo`0:Ool00`00Oomoo`08Ool00`00
Oomoo`01Ool0049oo`800:ioo`80009oo`08001oogooOol007oo001oo`8000=oo`03001oogoo0080
009oo`07001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo00<007ooOol00goo
00<007ooOol00P000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01@00Oomoogoo0000
1Goo00D007ooOomoo`0000=oo`05001oogooOol00009Ool01@00Oomoogoo000017oo00<007ooOol0
2Woo00<007ooOol01goo0P000goo0012Ool00`00Oomoo`2]Ool20006Ool01000Ool007oo0P000goo
00<007ooOol00P000Woo00L007oo001oo`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool2
0004Ool00`00Oomoo`020003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogoo
Ool00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`05001oogooOol00004Ool00`00
Oomoo`06Ool01@00Oomoogoo00002Woo00<007ooOol00Goo0012Ool00`00Oomoo`2]Ool20007Ool2
00000goo00000003Ool00`00Oomoo`0200002Goo001oogoo001oo`00Ool00003Ool20002Ool20002
Ool00`00Ool00002Ool20004Ool00`00Oomoo`020003Ool01@00Oomoogoo00001Goo00D007ooOomo
o`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uoo`05001o
ogooOol00003Ool20008Ool01@00Oomoogoo00002Woo00<007ooOol00Goo0012Ool00`00Oomoo`2]
Ool20007Ool00`00Oomoo`05Ool00`00Oomoo`0200002Goo001oogoo001oo`00Ool00003Ool20002
Ool20002Ool00`00Ool00002Ool20004Ool00`00Oomoo`020003Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uo
o`05001oogooOol00003Ool20008Ool01@00Oomoogoo00002Woo00<007ooOol00Goo0012Ool00`00
Oomoo`2]Ool20007Ool00`00Oomoo`06Ool01P00Ool00000Ool0009oo`05001oo`00Ool00003Ool2
0002Ool20002Ool00`00Ool00002Ool20003Ool20002Ool20003Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Uo
o`05001oogooOol00003Ool20008Ool01@00Oomoogoo00002Woo00<007ooOol00Goo0012Ool20030
Ool01P00Ool00000Ool0009oo`05001oo`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool2
0003Ool20002Ool20003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogooOol0
0005Ool01@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01000Oomo
ogoo0P0027oo00D007ooOomoo`0000Uoo`8000=oo`00@Woo00<007ooOol0_goo00H007oo000007oo
0002Ool01@00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P000goo0P000Woo0P00
0Woo0P000goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomo
ogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D0
07ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo005oo`00@Woo00<007ooOol0_goo00H007oo
000007oo0002Ool01@00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P000goo0P00
0Woo0P000Woo0P000goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool0
1@00Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01000Oomoogoo0P00
17oo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo005oo`004Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOomoo`<0
00=oo`03001oogoo00Yoo`03001oogoo0;moo`800004Ool007oo0002Ool03000Ool007oo001oo`00
Ool007oo001oo`80009oo`03001oo`00009oo`8000=oo`80009oo`80009oo`8000=oo`03001oogoo
00=oo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`05001oogoo
Ool00005Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00
Oomoo`08Ool00`00Oomoo`01Ool0015oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009o
o`03001oo`00009oo`03001oo`00009oo`03001oogoo009oo`03001oo`0000]oo`03001oogoo0;mo
o`80009oo`80009oo`06001oo`00Ool007oo0`0000=oo`00Ool00P000Woo00<007oo00000Woo0P00
0goo0P000Woo0P000Woo0P000goo00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol0
0005Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool01000Oomo
ogoo0P0017oo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo005oo`004Goo00<007oo
00001goo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00<007oo
Ool00goo00<007ooOol02Goo0`00_goo0P000Woo0P000Woo00H007oo001oo`00Ool300000goo001o
o`020002Ool00`00Ool00002Ool20003Ool20002Ool20002Ool20003Ool00`00Oomoo`03Ool01@00
Oomoogoo00000goo00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo
00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00<007ooOol01Woo
0`000goo000AOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00003Ool01000Oomoogoo0P0037oo00<007ooOol0_goo0P000Woo0P000Woo00@007oo001o
o`800006Ool00000Ool007oo0P000Woo00<007oo00000Woo0P000goo0P000Woo0P000Woo0P000goo
00<007ooOol00goo00D007ooOomoo`0000=oo`05001oogooOol00005Ool01@00Oomoogoo00000goo
00@007ooOomoo`8000Aoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`00
00=oo`03001oogoo00Qoo`03001oogoo005oo`004Goo00<007oo00001goo00<007oo00000Woo00<0
07oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007ooOol02goo00<0
07ooOol0_goo0P000Woo00P007ooOomoo`00Ool007oo0P0000Ioo`00001oo`00Ool20002Ool00`00
Ool00002Ool20003Ool20002Ool20002Ool20003Ool00`00Oomoo`03Ool01@00Oomoogoo00000goo
00D007ooOomoo`0000Eoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`00
00=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007ooOol00Goo
000BOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomo
o`02Ool01000Oomoogoo0`002goo00<007ooOol0_goo0P000Woo00P007ooOomoo`00Ool007oo0P00
17oo00@007oo0000009oo`03001oo`00009oo`8000=oo`80009oo`80009oo`8000=oo`8000Aoo`05
001oogooOol00003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`04001oogooOol20004
Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08
Ool00`00Oomoo`01Ool0049oo`03001oogoo0;moo`8000Moo`800003Ool0000000Aoo`04001oo`00
0002Ool01`00Ool007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol0
0003Ool01@00Oomoogoo00001Goo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomo
ogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08Ool00`00Oomo
o`01Ool0049oo`800<1oo`8000Moo`8000Moo`04001oo`000002Ool01`00Ool007oo001oo`0000=o
o`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol00003Ool01@00Oomoogoo00001Goo00D0
07ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Ao
o`05001oogooOol00003Ool00`00Oomoo`07Ool20003Ool0049oo`03001oogoo0;moo`8000Moo`80
00Moo`06001oo`00001oo`000Woo00D007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Ao
o`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol2
0004Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomo
o`08Ool00`00Oomoo`01Ool0049oo`03001oogoo0;moo`8000Moo`03001oogoo00Ioo`06001oo`00
001oo`000Woo00D007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol0
0003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomo
ogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08Ool00`00Oomo
o`01Ool0049oo`03001oogoo0;moo`8000Moo`03001oogoo00Ioo`06001oo`00001oo`000Woo00D0
07oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol00003Ool01000Oomo
ogoo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00@0
07ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`03
001oogoo0;moo`80011oo`06001oo`00001oo`000Woo00D007oo001oo`0000=oo`80009oo`80009o
o`8000=oo`8000Aoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=o
o`04001oogooOol20004Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol0
0003Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`800<5oo`03001oogoo00ioo`06001oo`00
001oo`000Woo00D007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol0
0003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomo
ogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`07Ool20003Ool0
049oo`03001oogoo0=5oo`06001oo`00001oo`000Woo00D007oo001oo`0000=oo`80009oo`80009o
o`8000=oo`8000Aoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=o
o`04001oogooOol20004Ool01@00Oomoogoo00000goo00@007ooOomoo`8000Aoo`05001oogooOol0
0003Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0049oo`03001oogoo0=5oo`06001oo`00001oo`00
0Woo00D007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`05001oogooOol00003Ool0
1000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool0
1000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo005oo`00@Woo
00<007ooOol0dGoo00H007oo000007oo0002Ool01@00Ool007oo00000goo0P000Woo0P000Woo0P00
0goo0P0017oo00<007ooOol00P000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`80
00Aoo`05001oogooOol00003Ool01000Oomoogoo0P0017oo00D007ooOomoo`0000=oo`03001oogoo
00Qoo`03001oogoo005oo`00@Woo00<007ooOol0dGoo00@007oo001oo`80009oo`05001oo`00Ool0
0003Ool20002Ool20002Ool20003Ool20004Ool00`00Oomoo`020002Ool00`00Ool00002Ool20004
Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004
Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007ooOol00Goo0012Ool2003BOol01000Ool0
07oo0P000Woo00D007oo001oo`0000=oo`80009oo`80009oo`8000=oo`8000Aoo`03001oogoo0080
009oo`03001oo`00009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo
00000goo00@007ooOomoo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`07Ool20003Ool0049o
o`03001oogoo0=5oo`04001oo`00Ool20002Ool02000Ool007oo001oo`00Ool20002Ool20002Ool2
0002Ool00`00Ool00004Ool00`00Oomoo`020002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo
00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo
00000goo00<007ooOol027oo00<007ooOol00Goo0012Ool00`00Oomoo`3AOol01000Ool007oo0P00
0Woo00`007oo001oo`00Ool007oo001oo`00Ool20002Ool20002Ool00`00Ool00004Ool00`00Oomo
o`020002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007oo
Oomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007oo
Ool00Goo0012Ool00`00Oomoo`3AOol01000Ool007oo0P000Woo00H007oo001oo`00Ool300000goo
001oo`020002Ool20002Ool00`00Ool00004Ool00`00Oomoo`020002Ool00`00Ool00002Ool20004
Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004
Ool01@00Oomoogoo00000goo00<007ooOol027oo00<007ooOol00Goo0012Ool00`00Oomoo`3AOol0
1000Ool007oo0P000Woo00H007oo001oo`00Ool300000goo001oo`020002Ool20002Ool00`00Ool0
0004Ool00`00Oomoo`020002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo
0P0017oo00D007ooOomoo`0000=oo`04001oogooOol20004Ool01@00Oomoogoo00000goo00<007oo
Ool027oo00<007ooOol00Goo0012Ool2003BOol01000Ool007oo0P000Woo00@007oo001oo`800006
Ool00000Ool007oo0P000Woo0P000Woo00<007oo00000goo0P000Woo0P000Woo00<007oo00000Woo
0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool01000Oomoogoo
0P0017oo00D007ooOomoo`0000=oo`03001oogoo00Moo`8000=oo`00@Woo00<007ooOol0dGoo00@0
07oo001oo`80009oo`03001oo`00009oo`07001oo`00001oo`00Ool00P000Woo00L007oo001oo`00
Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo
0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08
Ool00`00Oomoo`01Ool0049oo`03001oogoo0=5oo`80009oo`07001oogooOol007oo00000Woo00L0
07oo000007oo001oo`020002Ool01`00Ool007oo001oo`0000=oo`80009oo`80009oo`03001oo`00
009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo
0P0017oo00D007ooOomoo`0000=oo`03001oogoo00Qoo`03001oogoo005oo`00@Woo00<007ooOol0
dGoo0P001goo0P0017oo0P0000=oo`00Ool00P000Woo00L007oo001oo`00Ool00003Ool20002Ool2
0002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomo
o`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool00`00Oomoo`08Ool00`00Oomoo`01Ool0
01Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo00Yoo`03001oogoo0=5oo`8000Moo`8000Moo`04001oo`00
0002Ool01`00Ool007oo001oo`0000=oo`80009oo`80009oo`03001oo`00009oo`8000Aoo`05001o
ogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomo
o`0000=oo`03001oogoo00Qoo`03001oogoo005oo`005Woo00<007oo00001goo00<007oo00000Woo
00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00002goo00<007ooOol0dGoo
0P001goo0P001goo00@007oo0000009oo`07001oo`00Ool007oo00000goo0P000Woo0P000Woo00<0
07oo00000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool2
0002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo000FOol00`00Ool00007
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00004Ool00`00Oomoo`09
Ool3003AOol20007Ool20007Ool01000Ool000000Woo00L007oo001oo`00Ool00003Ool20002Ool2
0002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomo
o`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20007Ool30003Ool001Ioo`03001oo`00
00Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oo`00009oo`8000aoo`03
001oogoo0=5oo`8000Moo`8000Moo`04001oo`000002Ool01`00Ool007oo001oo`0000=oo`80009o
o`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomo
ogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`005Woo
00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo00<007oo00000Woo
00<007ooOol02goo00<007ooOol0dGoo0P001goo0P001goo00d007oo001oo`00Ool007oo001oo`00
Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo
0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00
Oomoo`01Ool001Moo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`04001oogooOol3000;Ool00`00Oomoo`3AOol20007Ool00`00Oomoo`06Ool03@00Ool007oo001o
o`00Ool007oo001oo`0000=oo`80009oo`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol0
0003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=o
o`8000Uoo`03001oogoo005oo`00@Woo00<007ooOol0dGoo0P001goo00<007ooOol01Woo00d007oo
001oo`00Ool007oo001oo`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00
Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogoo
Ool00003Ool20009Ool00`00Oomoo`01Ool0049oo`800=9oo`8000Moo`03001oogoo00Ioo`0=001o
o`00Ool007oo001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo00D0
07ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomo
ogoo00000goo0P0027oo0P000goo0012Ool00`00Oomoo`3AOol2000@Ool03@00Ool007oo001oo`00
Ool007oo001oo`0000=oo`80009oo`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol00003
Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`80
00Uoo`03001oogoo005oo`00@Woo00<007ooOol0dGoo0P0047oo00d007oo001oo`00Ool007oo001o
o`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P00
0Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool0
0`00Oomoo`01Ool0009oo`P003Qoo`03001oogoo0=9oo`03001oogoo00ioo`0=001oo`00Ool007oo
001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo00D007ooOomoo`00
00=oo`80009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo
0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3BOol00`00Oomoo`0>Ool03@00Ool007oo001o
o`00Ool007oo001oo`0000=oo`80009oo`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol0
0003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=o
o`8000Uoo`03001oogoo005oo`00@Woo0P00dgoo00<007ooOol03Woo00@007oo001oo`80009oo`05
001oo`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo
0P000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20008
Ool20003Ool000Eoo`<003Yoo`03001oogoo0=9oo`03001oogoo00ioo`04001oo`00Ool20002Ool0
1@00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo00D007ooOomoo`0000=o
o`80009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P00
2Goo00<007ooOol00Goo0003Ool2000017oo00000000>Goo00<007ooOol0hgoo00@007oo001oo`80
009oo`05001oo`00Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo
00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003
Ool20009Ool00`00Oomoo`01Ool0009oo`@00003Ool007oo03Uoo`03001oogoo0>=oo`04001oo`00
Ool20002Ool01@00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo00D007oo
Oomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo
00000goo0P002Goo00<007ooOol00Goo0006Ool2000jOol00`00Oomoo`3SOol01000Ool007oo0P00
0Woo00D007oo001oo`0000=oo`80009oo`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol0
0003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=o
o`8000Uoo`03001oogoo005oo`000goo0`00?7oo0P00i7oo00@007oo001oo`80009oo`05001oo`00
Ool00003Ool20002Ool20002Ool00`00Ool00002Ool20004Ool01@00Oomoogoo00000goo0P000Woo
0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20008Ool20003
Ool0049oo`03001oogoo0>=oo`04001oo`00Ool20002Ool01@00Ool007oo00000goo0P000Woo0P00
0Woo00<007oo00000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol0
0003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0012Ool00`00
Oomoo`3SOol01000Ool007oo0P000Woo00<007oo00000Woo00<007ooOol00P000Woo0P000Woo00<0
07oo00000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool2
0002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0004Ool4000jOol00`00
Oomoo`3SOol01000Ool007oo0P000goo0P000Woo0P0000=oo`0000000Woo0P000Woo00<007oo0000
0Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool20002Ool2
0004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0003Ool00`00Oomoo`02Ool00`00
Oomoo`0gOol00`00Oomoo`3SOol01000Ool007oo0P000goo0P000Woo0P0000=oo`0000000Woo0P00
0Woo00<007oo00000Woo0P0017oo00D007ooOomoo`00009oo`03001oo`00009oo`8000Aoo`05001o
ogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0002
Ool00`00Oomoo`04Ool00`00Oomoo`0fOol2003TOol01000Ool007oo0P000goo0P000Woo0P0000=o
o`0000000Woo0P000Woo00<007oo00000Woo0P000goo0P000goo00H007ooOol007oo0002Ool20004
Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Qoo`8000=oo`00
@Woo00<007ooOol0hgoo00@007oo001oo`8000=oo`80009oo`03001oo`000080009oo`80009oo`03
001oo`00009oo`8000=oo`8000=oo`06001oogoo001oo`000Woo0P0017oo00D007ooOomoo`0000=o
o`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool000Eoo`<003Yoo`03
001oogoo0>=oo`04001oo`00Ool20003Ool20004Ool30002Ool20002Ool00`00Ool00002Ool20003
Ool20003Ool01P00Oomoo`00Ool0009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool0
1@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0003Ool2000017oo00000000>Goo00<007oo
Ool0hgoo00@007oo001oo`8000=oo`8000Aoo`<0009oo`80009oo`03001oo`00009oo`8000=oo`80
00=oo`06001oogoo001oo`000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001o
ogooOol00003Ool20009Ool00`00Oomoo`01Ool0009oo`@00003Ool007oo00Uoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Yoo`03001oogoo0>=oo`04001oo`00Ool20003Ool20004Ool3
0002Ool20002Ool00`00Ool00002Ool20003Ool20003Ool01P00Oomoo`00Ool0009oo`8000Aoo`05
001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo
0006Ool20009Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00003Ool01`00Oomoogoo001oo`0000]oo`<00>=oo`04001oo`00Ool20003Ool20004Ool2
00000goo001oo`020002Ool00`00Ool00002Ool20003Ool20003Ool01P00Oomoo`00Ool0009oo`80
00Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00Oomoogoo00000goo0P001goo0`000goo
0003Ool3000;Ool00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool0
0`00Ool00003Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`3SOol01000Ool007oo0P00
0goo0P0017oo0P0000=oo`00Ool00P000Woo00<007oo00000Woo0P000goo0P000goo00H007ooOol0
07oo0002Ool20004Ool01@00Oomoogoo00000goo0P000Woo0P0017oo00D007ooOomoo`0000=oo`80
00Uoo`03001oogoo005oo`004Goo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000Woo00<007oo000017oo00<007ooOol00P0037oo00<007ooOol0hgoo00D007oo001oo`00
00Aoo`8000Aoo`800003Ool007oo0080009oo`03001oo`00009oo`8000=oo`8000=oo`06001oogoo
001oo`000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol00003Ool2
0009Ool00`00Oomoo`01Ool0015oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03
001oo`00009oo`03001oo`00009oo`03001oo`00009oo`03001oogoo00]oo`03001oogoo0>=oo`03
001oo`0000Ioo`8000Aoo`800003Ool007oo0080009oo`03001oo`00009oo`8000=oo`8000=oo`06
001oogoo001oo`000Woo0P0017oo00D007ooOomoo`0000=oo`80009oo`8000Aoo`05001oogooOol0
0003Ool20009Ool00`00Oomoo`01Ool000Aoo`03001oogoo00]oo`03001oogoo00Moo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`04001oogooOol30002Ool3000;Ool00`00Oomoo`3S
Ool00`00Ool00006Ool20004Ool200000goo001oo`020002Ool01`00Ool007oo001oo`0000=oo`80
009oo`80009oo`03001oo`00009oo`8000Aoo`05001oogooOol00003Ool20002Ool20004Ool01@00
Oomoogoo00000goo0P002Goo00<007ooOol00Goo0004Ool00`00Oomoo`0kOol00`00Oomoo`3SOol0
0`00Ool00006Ool20004Ool200000goo001oo`020002Ool01`00Ool007oo001oo`0000=oo`80009o
o`80009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool01@00Oomo
ogoo00000goo0P002Goo00<007ooOol00Goo0012Ool2003TOol20007Ool20004Ool04000Oomoo`00
Ool007oo001oo`00Ool007oo001oo`000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo0P00
0Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20008Ool20003Ool0049oo`03
001oogoo0>=oo`8000Moo`8000Moo`0=001oo`00Ool007oo001oo`00Ool007oo00000goo0P000Woo
0P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogoo
Ool00003Ool20009Ool00`00Oomoo`01Ool00003Ool00000008003eoo`03001oogoo0>=oo`8000Mo
o`8000Moo`0=001oo`00Ool007oo001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo0000
0Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool0
0`00Oomoo`01Ool000Aoo`03001oogoo03]oo`03001oogoo0>=oo`8000Moo`8000Moo`0=001oo`00
Ool007oo001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo0P000Woo
00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0049o
o`03001oogoo0>=oo`8000Moo`8000Moo`0=001oo`00Ool007oo001oo`00Ool007oo00000goo0P00
0Woo0P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001o
ogooOol00003Ool20009Ool00`00Oomoo`01Ool0049oo`800>Aoo`8000Moo`03001oogoo00Ioo`0=
001oo`00Ool007oo001oo`00Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo
0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20008Ool20003Ool000Ao
o`@003Yoo`03001oogoo0>=oo`8000Moo`03001oogoo00Ioo`0=001oo`00Ool007oo001oo`00Ool0
07oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009o
o`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool000=oo`03001oogoo009oo`03
001oogoo03Moo`03001oogoo0>=oo`8000Moo`03001oogoo00Ioo`0=001oo`00Ool007oo001oo`00
Ool007oo00000goo0P000Woo0P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80
009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0009oo`03001oogoo00Ao
o`03001oogoo03Ioo`03001oogoo0>=oo`80011oo`0=001oo`00Ool007oo001oo`00Ool007oo0000
0goo00@007oo001oo`80009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool2
0004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3SOol2000@
Ool03@00Ool007oo001oo`00Ool007oo001oo`0000=oo`04001oo`00Ool20002Ool00`00Ool00002
Ool20004Ool20002Ool01000Oomoogoo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03
001oogoo005oo`00@Woo0P00i7oo0P0047oo00d007oo001oo`00Ool007oo001oo`00Ool00003Ool0
1000Ool007oo0P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Ao
o`05001oogooOol00003Ool20008Ool20003Ool000Aoo`03001oogoo03]oo`03001oogoo0>=oo`80
011oo`0=001oo`00Ool007oo001oo`00Ool007oo00000goo00@007oo001oo`80009oo`03001oo`00
009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool01@00Oomoogoo00000goo0P002Goo
00<007ooOol00Goo0003Ool4000kOol00`00Oomoo`3SOol2000@Ool03@00Ool007oo001oo`00Ool0
07oo001oo`0000=oo`04001oo`00Ool20002Ool00`00Ool00002Ool20004Ool20002Ool01000Oomo
ogoo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`0017oo00@007oo
Ool003Yoo`03001oogoo0>=oo`80011oo`0=001oo`00Ool007oo001oo`00Ool007oo00000goo00@0
07oo001oo`80009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool0
1@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0004Ool01000Oomoo`00>Woo00<007ooOol0
hgoo0P0047oo00/007oo001oo`00Ool007oo001oo`00009oo`07001oogoo001oo`00Ool00P000Woo
00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003
Ool20009Ool00`00Oomoo`01Ool000Ioo`03001oogoo03Uoo`800>Aoo`80011oo`0;001oo`00Ool0
07oo001oo`00Ool00002Ool01`00Oomoo`00Ool007oo0080009oo`03001oo`00009oo`8000Aoo`80
009oo`04001oogooOol20002Ool20004Ool01@00Oomoogoo00000goo0P0027oo0P000goo0012Ool0
0`00Oomoo`3SOol2000@Ool02`00Ool007oo001oo`00Ool007oo00000Woo00L007ooOol007oo001o
o`020002Ool00`00Ool00002Ool20004Ool20002Ool01000Oomoogoo0P000Woo0P0017oo00D007oo
Oomoo`0000=oo`8000Uoo`03001oogoo005oo`000Woo00<007ooOol017oo00<007ooOol0=Woo00<0
07ooOol0i7oo00<007ooOol03Woo00@007oo001oo`80009oo`03001oo`00009oo`07001oogoo001o
o`00Ool00P000Woo00<007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05
001oogooOol00003Ool20009Ool00`00Oomoo`01Ool000=oo`03001oogoo009oo`03001oogoo03Mo
o`03001oogoo0>Aoo`03001oogoo00ioo`04001oo`00Ool20002Ool00`00Ool00002Ool01`00Oomo
o`00Ool007oo0080009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004
Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0004Ool4000EOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`050009Ool00`00Oomoo`3T
Ool00`00Oomoo`0>Ool01000Ool007oo0P000Woo00<007oo00000Woo00L007ooOol007oo001oo`02
0002Ool00`00Ool00002Ool20004Ool20002Ool01000Oomoogoo0P000Woo0P0017oo00D007ooOomo
o`0000=oo`8000Uoo`03001oogoo005oo`0077oo00<007oo00001goo00<007oo00000Woo00<007oo
00000Woo00<007oo00000goo00<007ooOol02Goo0`00i7oo00<007ooOol03Woo00@007oo001oo`80
009oo`03001oo`00009oo`07001oogoo001oo`00Ool00P000Woo00<007oo00000Woo0P0017oo0P00
0Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20007Ool30003Ool001aoo`03
001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo00Uoo`03
001oogoo0>Aoo`03001oogoo00ioo`04001oo`00Ool20002Ool00`00Ool00002Ool01`00Oomoo`00
Ool007oo0080009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool0
1@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo000LOol00`00Ool00007Ool00`00Ool00002
Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`09Ool00`00Oomoo`3eOol01000Ool007oo
0P000Woo00<007oo00000Woo00L007ooOol007oo001oo`020002Ool00`00Ool00002Ool20004Ool2
0002Ool01000Oomoogoo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005o
o`000Woo00<007ooOol017oo00<007ooOol047oo00<007oo00001goo00<007oo00000Woo00<007oo
00000Woo00<007oo00000goo00<007ooOol02Goo00<007ooOol0mGoo00@007oo001oo`80009oo`03
001oo`00009oo`07001oogoo001oo`00Ool00P000Woo00<007oo00000Woo0P0017oo0P000Woo00@0
07ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool000=oo`03
001oogoo009oo`03001oogoo019oo`03001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`04
001oogooOol2000;Ool00`00Oomoo`3eOol01000Ool007oo0P000Woo00<007oo00000Woo00L007oo
Ool007oo001oo`020002Ool00`00Ool00002Ool20004Ool20002Ool01000Oomoogoo0P000Woo0P00
17oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`0017oo1000>Woo0P00mWoo00@007oo
001oo`80009oo`03001oo`00009oo`07001oogoo001oo`00Ool00P000Woo00<007oo00000Woo0P00
17oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20008Ool20003Ool0
049oo`03001oogoo0?Eoo`04001oo`00Ool20003Ool20002Ool01`00Oomoo`00Ool007oo0080009o
o`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool01@00Oomoogoo0000
0goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3eOol01000Ool007oo0P000goo0P000Woo
0P0000Eoo`00Ool007oo0080009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002
Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0006Ool00`00Oomoo`0iOol0
0`00Oomoo`3eOol01000Ool007oo0P000goo0P000Woo0P0000Eoo`00Ool007oo0080009oo`03001o
o`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004Ool01@00Oomoogoo00000goo0P00
2Goo00<007ooOol00Goo0006Ool00`00Oomoo`0iOol00`00Oomoo`3eOol01000Ool007oo0P000goo
0P000goo00H007oo001oo`00Ool20002Ool00`00Ool00002Ool20004Ool20002Ool01000Oomoogoo
0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`001Woo00<007ooOol0
>Goo0P00mWoo00@007oo001oo`8000=oo`8000=oo`06001oo`00Ool007oo0P000Woo00<007oo0000
0Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20008Ool2
0003Ool000Ioo`03001oogoo03Uoo`03001oogoo0?Eoo`04001oo`00Ool20003Ool20003Ool01P00
Ool007oo001oo`80009oo`03001oo`00009oo`8000Aoo`80009oo`04001oogooOol20002Ool20004
Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3eOol01000Ool0
07oo0P000goo0P000goo00H007oo001oo`00Ool20002Ool00`00Ool00002Ool20004Ool20002Ool0
1000Oomoogoo0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`00@Woo
00<007ooOol0mGoo00@007oo001oo`8000=oo`8000=oo`0=001oo`00Ool007oo001oo`00Ool007oo
00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009
Ool00`00Oomoo`01Ool000Aoo`04001oogoo000jOol00`00Oomoo`3eOol01000Ool007oo0P000goo
0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002Ool01000Oomoogoo
0P000Woo0P0017oo00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`000Woo00<007oo0000
0`00>Woo00<007ooOol0mGoo00@007oo001oo`8000=oo`8000=oo`0=001oo`00Ool007oo001oo`00
Ool007oo00000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003
Ool20009Ool00`00Oomoo`01Ool000Moo`03001oogoo03Qoo`800?Ioo`04001oo`00Ool20003Ool2
0004Ool200002Woo001oo`00Ool007oo001oo`000Woo0P0017oo0P000Woo00@007ooOomoo`80009o
o`8000Aoo`05001oogooOol00003Ool20008Ool20003Ool0049oo`03001oogoo0?Eoo`04001oo`00
Ool20003Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo0P0017oo0P000Woo00@007oo
Oomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0049oo`03001o
ogoo0?Eoo`04001oo`00Ool20003Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo0P00
17oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomo
o`01Ool000Eoo`8003]oo`03001oogoo0?Eoo`04001oo`00Ool20003Ool20004Ool200002Woo001o
o`00Ool007oo001oo`000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogoo
Ool00003Ool20009Ool00`00Oomoo`01Ool000Aoo`04001oogoo000jOol00`00Oomoo`3eOol01000
Ool007oo0P000goo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`04
001oogooOol20002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0002Ool0
0`00Ool00002Ool00`00Oomoo`0hOol2003fOol00`00Ool00006Ool20004Ool200002Woo001oo`00
Ool007oo001oo`000Woo0P0017oo0P000Woo00@007ooOomoo`80009oo`8000Aoo`05001oogooOol0
0003Ool20008Ool20003Ool0009oo`H003Yoo`03001oogoo0?Eoo`03001oo`0000Ioo`8000Aoo`80
000:Ool007oo001oo`00Ool007oo0002Ool20004Ool20002Ool01000Oomoogoo0P000Woo0P0017oo
00D007ooOomoo`0000=oo`8000Uoo`03001oogoo005oo`00@Woo00<007ooOol0mGoo00<007oo0000
1Woo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`04001oogooOol2
0002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3e
Ool00`00Ool00006Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo0P0017oo0P000Woo
00@007ooOomoo`80009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0019o
o`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D0
0004Ool000000003Ool00`00Oomoo`0:Ool00`00Oomoo`3eOol00`00Ool00006Ool20004Ool20000
2Woo001oo`00Ool007oo001oo`000Woo00<007oo00000goo0P000Woo00@007ooOomoo`80009oo`80
00Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0009oo`P000Moo`03001oo`0000Mo
o`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`05001oogooOol00004Ool00`00Ool0
000;Ool3003eOol00`00Ool00006Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo00<0
07oo00000goo0P000Woo00H007ooOol007oo0002Ool20004Ool01@00Oomoogoo00000goo0P001goo
0`000goo000AOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`09Ool00`00Oomoo`3eOol00`00Ool00006Ool2
0004Ool200002Woo001oo`00Ool007oo001oo`000Woo00<007oo00000goo0P000Woo00H007ooOol0
07oo0002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo000AOol00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`02Ool01000Oomo
ogoo0P0037oo00<007ooOol0mGoo00<007oo00001Woo0P0017oo0P0000Yoo`00Ool007oo001oo`00
Ool0009oo`03001oo`0000=oo`80009oo`06001oogoo001oo`000Woo0P0017oo00D007ooOomoo`00
00=oo`8000Uoo`03001oogoo005oo`004Goo00<007oo00001goo00<007oo00000Woo00<007oo0000
0Woo00<007oo00000goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`3eOol0
0`00Ool00006Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo00<007oo00000goo0P00
0Woo00H007ooOol007oo0002Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo
000BOol00`00Oomoo`07Ool00`00Oomoo`02Ool00`00Oomoo`02Ool01000Oomoogoo0P0017oo00@0
07ooOomoo`<000]oo`03001oogoo0?Eoo`03001oo`0000Ioo`8000Aoo`80000:Ool007oo001oo`00
Ool007oo0002Ool00`00Ool00003Ool20002Ool01P00Oomoo`00Ool0009oo`8000Aoo`05001oogoo
Ool00003Ool20009Ool00`00Oomoo`01Ool0049oo`800?Ioo`03001oo`0000Ioo`8000Moo`09001o
o`00Ool007oo001oo`00009oo`03001oo`0000=oo`80009oo`06001oogoo001oo`000Woo0P0017oo
00D007ooOomoo`0000=oo`8000Qoo`8000=oo`00@Woo00<007ooOol0mGoo00<007oo00001Woo0P00
1goo00T007oo001oo`00Ool007oo00000Woo00<007oo00000goo0P000Woo00H007ooOol007oo0002
Ool20004Ool01@00Oomoogoo00000goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3eOol0
0`00Ool00006Ool00`00Oomoo`06Ool02@00Ool007oo001oo`00Ool00002Ool00`00Ool00003Ool2
0002Ool01P00Oomoo`00Ool0009oo`8000Aoo`05001oogooOol00003Ool20009Ool00`00Oomoo`01
Ool0049oo`03001oogoo0?Eoo`03001oo`0000Ioo`03001oogoo00Ioo`0;001oo`00Ool007oo001o
o`00Ool00002Ool01000Oomoogoo0P000Woo00H007ooOol007oo0002Ool20004Ool01@00Oomoogoo
00000goo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3eOol00`00Ool0000?Ool02`00Ool0
07oo001oo`00Ool007oo00000Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0009oo`8000Ao
o`05001oogooOol00003Ool20009Ool00`00Oomoo`01Ool0049oo`800?Ioo`03001oo`0000moo`0;
001oo`00Ool007oo001oo`00Ool00002Ool01P00Oomoo`00Ool0009oo`06001oogoo001oo`000Woo
0P0017oo00@007ooOomoo`80009oo`8000Qoo`8000=oo`00@Woo00<007ooOol0mGoo00<007oo0000
3goo00/007oo001oo`00Ool007oo001oo`00009oo`06001oogoo001oo`000Woo00H007ooOol007oo
0002Ool20004Ool01000Oomoogoo0P000Woo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3e
Ool00`00Ool0000?Ool02`00Ool007oo001oo`00Ool007oo00000Woo00H007ooOol007oo0002Ool0
1P00Oomoo`00Ool0009oo`8000Aoo`04001oogooOol20002Ool20009Ool00`00Oomoo`01Ool0049o
o`03001oogoo0?Eoo`03001oo`0000moo`0;001oo`00Ool007oo001oo`00Ool00002Ool01P00Oomo
o`00Ool0009oo`06001oogoo001oo`000Woo0P0017oo00@007ooOomoo`80009oo`8000Uoo`03001o
ogoo005oo`00@Woo00<007ooOol0mGoo00<007oo00003goo00/007oo001oo`00Ool007oo001oo`00
009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool20004Ool20002Ool20002Ool20009
Ool00`00Oomoo`01Ool0049oo`800?Ioo`80011oo`0;001oo`00Ool007oo001oo`00Ool00002Ool0
1P00Oomoo`00Ool0009oo`06001oogoo001oo`000Woo0P0017oo0P000Woo0P000Woo0P0027oo0P00
0goo0012Ool00`00Oomoo`3eOol2000@Ool01`00Ool007oo001oo`00009oo`80009oo`06001oogoo
001oo`000Woo00H007ooOol007oo0002Ool20004Ool20002Ool20002Ool20009Ool00`00Oomoo`01
Ool0049oo`03001oogoo0?Eoo`80011oo`07001oo`00Ool007oo00000Woo0P000Woo00H007ooOol0
07oo0002Ool01P00Oomoo`00Ool0009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo005o
o`00@Woo00<007ooOol0mGoo0P0047oo00L007oo001oo`00Ool00002Ool20002Ool01P00Oomoo`00
Ool0009oo`06001oogoo001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo
0012Ool00`00Oomoo`3eOol2000@Ool01`00Ool007oo001oo`00009oo`80009oo`06001oogoo001o
o`000Woo00H007ooOol007oo0002Ool20004Ool20002Ool20002Ool20009Ool00`00Oomoo`01Ool0
049oo`03001oogoo0?Eoo`80011oo`07001oo`00Ool007oo00000Woo0P000Woo00H007ooOol007oo
0002Ool01P00Oomoo`00Ool0009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo005oo`00
@Woo0P00mWoo0P0047oo00L007oo001oo`00Ool00002Ool20002Ool01P00Oomoo`00Ool0009oo`06
001oogoo001oo`000Woo0P0017oo0P000Woo0P000Woo0P0027oo0P000goo0012Ool00`00Oomoo`3e
Ool2000@Ool01000Ool007oo0P000goo0P000Woo00H007ooOol007oo0002Ool01P00Oomoo`00Ool0
009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo005oo`00@Woo00<007ooOol0mGoo0P00
47oo00@007oo001oo`8000=oo`80009oo`06001oogoo001oo`000Woo00H007ooOol007oo0002Ool2
0004Ool20002Ool20002Ool20009Ool00`00Oomoo`01Ool001Moo`03001oogoo009oo`03001oogoo
009oo`03001oogoo009oo`03001oogoo009oo`03001oogoo00D0009oo`03001oogoo00Yoo`03001o
ogoo0?Eoo`80011oo`04001oo`00Ool20003Ool20002Ool01P00Oomoo`00Ool0009oo`06001oogoo
001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo000FOol00`00Ool00007
Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool01`00Oomoogoo001oo`0000]oo`03
001oogoo0?Eoo`80011oo`04001oo`00Ool20003Ool20002Ool01P00Oomoo`00Ool0009oo`06001o
ogoo001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo000FOol00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool00`00Oomoo`03Ool00`00Oomo
o`09Ool3003eOol2000@Ool01000Ool007oo0P000goo0P000Woo00H007ooOol007oo0002Ool01P00
Oomoo`00Ool0009oo`8000Aoo`80009oo`80009oo`8000Moo`<000=oo`005Woo00<007oo00001goo
00<007oo00000Woo00<007oo00000Woo00<007oo00000goo00@007ooOomoo`8000aoo`03001oogoo
0?Ioo`03001oogoo00ioo`04001oo`00Ool20003Ool20002Ool01P00Oomoo`00Ool0009oo`06001o
ogoo001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo000FOol00`00Ool0
0007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003Ool01@00Oomoogoo00003Goo00<0
07ooOol0mWoo00<007ooOol03Woo00@007oo001oo`8000=oo`80009oo`06001oogoo001oo`000Woo
00H007ooOol007oo0002Ool20004Ool20002Ool20002Ool20009Ool00`00Oomoo`01Ool001Moo`03
001oogoo00Moo`03001oogoo009oo`03001oogoo009oo`04001oogooOol20003Ool3000;Ool00`00
Oomoo`3fOol00`00Oomoo`0>Ool01000Ool007oo0P000goo0P000Woo00H007ooOol007oo0002Ool0
1P00Oomoo`00Ool0009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo005oo`00@Woo00<0
07ooOol0mWoo00<007ooOol03Woo00@007oo001oo`8000=oo`80009oo`07001oogoo001oo`00Ool0
0P000Woo00<007oo00000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo0012Ool2
003gOol00`00Oomoo`0>Ool01000Ool007oo0P000goo0P000Woo00L007ooOol007oo001oo`020002
Ool00`00Ool00002Ool20004Ool20002Ool20002Ool20008Ool20003Ool0049oo`03001oogoo0?Io
o`03001oogoo00ioo`04001oo`00Ool20003Ool20002Ool01`00Oomoo`00Ool007oo0080009oo`03
001oo`00009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo005oo`00@Woo00<007ooOol0
mWoo00<007ooOol03Woo00@007oo001oo`8000=oo`80009oo`07001oogoo001oo`00Ool00P000Woo
00<007oo00000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo0012Ool00`00Oomo
o`3fOol00`00Oomoo`0>Ool01000Ool007oo0P000goo0P000Woo00h007ooOol007oo001oo`00Ool0
07oo001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo0012Ool00`00Oomo
o`3fOol00`00Oomoo`0>Ool01000Ool007oo0P000goo0P000Woo00h007ooOol007oo001oo`00Ool0
07oo001oo`000Woo0P0017oo0P000Woo0P000Woo0P002Goo00<007ooOol00Goo0012Ool2003gOol0
0`00Oomoo`0>Ool01000Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00Ool0
0002Ool20004Ool20002Ool20002Ool20008Ool20003Ool0049oo`03001oogoo0?Ioo`03001oogoo
00ioo`04001oo`00Ool20003Ool20003Ool03@00Ool007oo001oo`00Ool007oo001oo`00009oo`80
00Aoo`80009oo`80009oo`8000Uoo`03001oogoo005oo`00@Woo00<007ooOol0ogoo27oo00@007oo
001oo`8000=oo`8000=oo`0=001oo`00Ool007oo001oo`00Ool007oo00000Woo0P0017oo0P000Woo
0P000Woo0P002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3oOol8Ool01000Ool007oo0P000goo
0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002Ool20002Ool20009
Ool00`00Oomoo`01Ool0049oo`03001oogoo0?moo`Qoo`04001oo`00Ool20003Ool20003Ool03@00
Ool007oo001oo`00Ool007oo001oo`00009oo`8000Aoo`80009oo`80009oo`8000Uoo`03001oogoo
005oo`00@Woo0P00ogoo2Goo00@007oo001oo`8000=oo`8000=oo`0=001oo`00Ool007oo001oo`00
Ool007oo00000Woo0P0017oo0P000Woo0P000Woo0P0027oo0P000goo0012Ool00`00Oomoo`3oOol8
Ool01000Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004
Ool20002Ool2000017oo001oo`002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3oOol8Ool01000
Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002
Ool2000017oo001oo`002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3oOol8Ool01000Ool007oo
0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002Ool20000
17oo001oo`002Goo00<007ooOol00Goo0012Ool00`00Oomoo`3oOol8Ool01000Ool007oo0P000goo
0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002Ool2000017oo001o
o`002Goo00<007ooOol00Goo0012Ool2003oOol9Ool01000Ool007oo0P000goo0P000goo00d007oo
001oo`00Ool007oo001oo`00Ool00002Ool20004Ool20002Ool2000017oo001oo`0027oo0P000goo
0012Ool00`00Oomoo`3oOol8Ool01000Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo
001oo`00Ool00002Ool20004Ool20002Ool2000017oo001oo`002Goo00<007ooOol00Goo0012Ool0
0`00Oomoo`3oOol8Ool01000Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00
Ool00002Ool20004Ool20002Ool2000017oo001oo`002Goo00<007ooOol00Goo0012Ool00`00Oomo
o`3oOol8Ool01000Ool007oo0P000goo0P000goo00d007oo001oo`00Ool007oo001oo`00Ool00002
Ool20004Ool20002Ool2000017oo001oo`002Goo00<007ooOol00Goo000BOol00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`050002Ool00`00Oomoo`02
Ool00`00Oomoo`0:Ool00`00Oomoo`3oOol8Ool01000Ool007oo0P000goo0P0017oo0P0000Yoo`00
Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`800004Ool007oo0009Ool00`00Oomoo`01Ool0
015oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`0000=oo`03001oogoo
009oo`07001oogooOol007oo00002goo00<007ooOol0ogoo27oo00@007oo001oo`8000=oo`8000Ao
o`80000:Ool007oo001oo`00Ool007oo0002Ool20004Ool20002Ool2000017oo001oo`002Goo00<0
07ooOol00Goo000AOol00`00Ool00007Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00003
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`09Ool3003oOol8Ool01000Ool007oo0P00
0goo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`800004Ool007oo
0007Ool30003Ool0015oo`03001oo`0000Moo`03001oo`00009oo`03001oo`00009oo`03001oo`00
00=oo`03001oogoo00=oo`03001oogoo008000aoo`03001oogoo0?moo`Qoo`04001oo`00Ool20003
Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo0P0017oo0P000Woo0P0000Aoo`00Ool0
00Uoo`03001oogoo005oo`004Goo00<007oo00001goo00<007oo00000Woo00<007oo00000Woo00<0
07oo00000goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`0;Ool00`00Oomoo`3oOol8Ool01000
Ool007oo0P000goo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`80
0004Ool007oo0009Ool00`00Oomoo`01Ool0019oo`03001oogoo00Moo`03001oogoo009oo`03001o
ogoo009oo`04001oogooOol20003Ool30002Ool3000;Ool00`00Oomoo`3oOol8Ool01000Ool007oo
0P000goo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`8000Aoo`80009oo`800004Ool0
07oo0009Ool00`00Oomoo`01Ool0049oo`03001oogoo0?moo`Qoo`04001oo`00Ool20003Ool20004
Ool200002Woo001oo`00Ool007oo001oo`000Woo0P0017oo0P000Woo0P0000Aoo`00Ool000Uoo`03
001oogoo005oo`00@Woo0P00ogoo2Goo00<007oo00000Woo00@007ooOomoo`8000Aoo`80000:Ool0
07oo001oo`00Ool007oo0002Ool00`00Ool00003Ool20002Ool2000017oo001oo`0027oo0P000goo
0012Ool00`00Oomoo`3oOol8Ool00`00Ool00002Ool01000Oomoogoo0P0017oo0P0000Yoo`00Ool0
07oo001oo`00Ool0009oo`03001oo`0000=oo`80009oo`800004Ool007oo0009Ool00`00Oomoo`01
Ool0049oo`03001oogoo0?moo`Qoo`03001oo`0000Ioo`8000Aoo`80000:Ool007oo001oo`00Ool0
07oo0002Ool00`00Ool00003Ool20002Ool2000017oo001oo`002Goo00<007ooOol00Goo0012Ool0
0`00Oomoo`3oOol8Ool00`00Ool00006Ool20004Ool200002Woo001oo`00Ool007oo001oo`000Woo
00<007oo00000goo0P000Woo0P0000Aoo`00Ool000Uoo`03001oogoo005oo`00@Woo00<007ooOol0
ogoo27oo00<007oo00001Woo0P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`03001oo`00
00=oo`80009oo`800004Ool007oo0009Ool00`00Oomoo`01Ool0049oo`8000Ioo`03001oogoo02mo
o`03001oogoo031oo`03001oogoo031oo`03001oogoo031oo`03001oogoo02moo`03001oogoo009o
o`03001oo`0000Ioo`8000Aoo`80000:Ool007oo001oo`00Ool007oo0002Ool00`00Ool00003Ool2
0002Ool200001Woo001oo`00Ool000Ioo`8000=oo`00@Woo00<007ooOol01Goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo
00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<007ooOol00Woo
00<007oo00000goo00<007ooOol00P0017oo0P0000Yoo`00Ool007oo001oo`00Ool0009oo`03001o
o`0000=oo`80009oo`800006Ool007oo001oo`001goo00<007ooOol00Goo0012Oooo00120003Ool0
0?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {646.563, 406.563}} -> {-166.618, \
0.000355907, 0.985274, 9.69696*^-07}}],

Cell[TextData[{
  StyleBox["Grafik 53: ",
    FontWeight->"Bold"],
  "Abweichung von der Identit\[ADoubleDot]tsfunktion. Die Exzentrizit\
\[ADoubleDot]t wurde f\[UDoubleDot]r die Darstellung e = 0.2 \
gew\[ADoubleDot]hlt.  Der Effekt wird mit zunehmenden e \
gr\[ODoubleDot]\[SZ]er."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Deutlich ist die Abweichung von der 1. Mediane zu sehen. Die Exzentrizit\
\[ADoubleDot]t wurde f\[UDoubleDot]r die Grafik e = 0.2 gew\[ADoubleDot]hlt. \
Die Differenz steigt mit wachsendem e. Vermutungen liegen nahe, dass der gr\
\[ODoubleDot]\[SZ]te Beitrag f\[UDoubleDot]r den Fehler in der Approximation \
durch die Umkehrtransformation zu Stande kommt. Es zeigt sich im Vergleich \
mit den Differenzplots aus dem vorherigen Abschnitt, dass \
ungef\[ADoubleDot]hr an der selben Stelle die Abweichung am gr\[ODoubleDot]\
\[SZ]ten wird. Abhilfe k\[ODoubleDot]nnte dadurch geschaffen werden, dass man \
das Problem g\[ADoubleDot]nzlich von einer anderen Seite aufrollt. (Ist es \
zum Beispiel m\[ODoubleDot]glich, die Differentialgleichung f\[UDoubleDot]r \
die Amplitudenfunktion derart umzuformen, so dass aus ihr direkt die \
Umkehrfunktion mit Hilfe der St\[ODoubleDot]rungsrechnung abgeleitet werden k\
\[ODoubleDot]nnte?) N\[ADoubleDot]here Untersuchungen in diese Richtung, \
werden im  Anschluss an diese Arbeit durchgef\[UDoubleDot]hrt werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:67"],

Cell["Kap. 3.2.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.6. TauEquation",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:68"],

Cell[TextData[{
  "TauEquation[n] transformiert die unabh\[ADoubleDot]ngige Variable der \
Courant & Snyder transformierten polynomischen Bewegungsgleichung n-ter \
Ordnung \[UDoubleDot]ber die Beziehung: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  = \ \[Psi]/2 \@ 2\)]]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:69"],

Cell["-", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:70"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["CourantSnyderTransformedB, TransformIndependentVar",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TauEquation[
          n_Integer] := \(Module[{x}, $Derivation = \[IndentingNewLine]{x = \
\(CourantSnyderTransformedB[n]\)\[LeftDoubleBracket]1\[RightDoubleBracket], 
                x = TransformIndependentVar[x, 
                    y[\[Psi]], \[Tau][\[Psi]] \[Equal] \[Psi]\/\@8], 
                x = Expand[x\ 8], \[IndentingNewLine]TauTransformed[n] = 
                  Collect[x, {y[\[Tau]], \[Lambda], e}] \[Equal] 
                    0}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Es handelt sich um eine standardm\[ADoubleDot]\[SZ]ige Herleitung, wie sie \
von der Funktion ",
  StyleBox["TransformIndependentVar",
    FontSlant->"Italic"],
  " mehrfach durchgef\[UDoubleDot]hrt wird."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:71"],

Cell["Kap. 3.1., 3.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.7. TauTransformedA",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:72"],

Cell[TextData[{
  "TauTransformedA[n] ersetzt die vorkommende Variable t durch \
t(\[Psi](\[Tau])) und entwickelt die trigonometrischen Terme nach dem St\
\[ODoubleDot]rparameter e. Hierf\[UDoubleDot]r wird die inverse \
Phasenfunktion ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\^\(-1\)\)]],
  " bis zur n-ten Ordnung verwendet."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:73"],

Cell[TextData[{
  "Die Variable t in cos(n t) und sin(n t) wird \[UDoubleDot]ber die \
Beziehung ",
  Cell[BoxData[
      \(TraditionalForm\`t\  = \ \[Psi]\^\(-1\)\)]],
  "(t,e) und \[Psi]",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(=\)\(\ \)\(2 \@ 2\)\)\)\)]],
  "\[Tau] ersetzt. Die trigonometrischen Terme werden nach dem kleinen \
Parameter e entwickelt. Terme ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(e\^j\),
            "TraditionalForm"], \(y\^k\)}], TraditionalForm]]],
  " mit j+k > n werden hierbei vernachl\[ADoubleDot]ssigt."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:74"],

Cell[TextData[{
  "Voraussetzung: ",
  StyleBox["TauEquation, InversePhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TauTransformedA[
          n_Integer] := \(Module[{x}, $Derivation = \[IndentingNewLine]{x = 
                  TauEquation[n], 
                x = x /. \[InvisibleSpace]t \[Rule] 
                      Normal[InversePhaseFunction[n]], 
                x = x /. \[InvisibleSpace]\[Psi] \[Rule] \@8\ \[Tau], 
                x = x /. \[InvisibleSpace]Cos[arg_] \[RuleDelayed] 
                      Normal[Series[Cos[arg], {e, 0, n}]] /; 
                        MemberQ[arg, e, \[Infinity]], 
                x = TrigReduce[
                      x\[LeftDoubleBracket]1\[RightDoubleBracket]] \
/. \[InvisibleSpace]_\ y[\[Tau]]\^i_\ e\^j_ \[RuleDelayed] 0 /; i + j > n, 
                TauTransformedA[n] = 
                  Collect[x, {y[\[Tau]], e, Sin[_] | Cos[_]}] \[Equal] 
                    0}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Termanzahl weicht nicht wesentlich von jener der Ausgangsgleichung ab.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:75"],

Cell["Kap. 3.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.8. TauTransformedB",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:76"],

Cell[TextData[{
  "TauTransformedB[n] liefert die Bewegungsgleichung des Sitnikovproblems in \
den Variablen y und \[Tau] entwickelt bis zur Ordnung n, wobei Terme \
multipliziert mit ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(e\^j\),
            "TraditionalForm"], \(y\^k\)}], TraditionalForm]]],
  " mit j+k > n vernachl\[ADoubleDot]ssigt werden. Im Unterschied zu \
TauTransformedA[n] wird ein k\[UDoubleDot]nstlicher St\[ODoubleDot]rparameter \
\[Lambda] eingef\[UDoubleDot]hrt, der Terme gleicher Ordnungen zusammenh\
\[ADoubleDot]lt."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:77"],

Cell[TextData[{
  "Der k\[UDoubleDot]nstliche St\[ODoubleDot]rparameter \[Lambda] dient als \
Ordnungsparameter. Hierbei gilt ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^n\)]],
  " h\[ADoubleDot]lt alle Terme ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(e\^i\),
            "TraditionalForm"], \(y\^k\)}], TraditionalForm]]],
  " mit i+j = n multiplikativ zusammen. Diese Form der Darstellung bereitet \
die Gleichung auf die Methode von Poincar\[EAcute] - Lindstedt vor."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:78"],

Cell[TextData[{
  "Voraussetzung :",
  StyleBox["TauTransformedA",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(TauTransformedB[
          n_Integer] := \(Module[{x}, $Derivation = \[IndentingNewLine]{x = \
\(TauTransformedA[
                      n]\)\[LeftDoubleBracket]1\[RightDoubleBracket], \
\[IndentingNewLine]x = Expand[x], \[IndentingNewLine]x = 
                  x /. \[InvisibleSpace]y[\[Tau]]\^i_ \[RuleDelayed] \((\
\[Lambda]\ y[\[Tau]])\)\^i /; i \[GreaterEqual] 3, \[IndentingNewLine]x = 
                  x /. \[InvisibleSpace]e \[RuleDelayed] 
                      e\ \[Lambda], \[IndentingNewLine]TauTransformedB[n] = 
                  Collect[x, {\[Lambda], y[\[Tau]], e}] \[Equal] 
                    0}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Der Einf\[UDoubleDot]hrung des k\[UDoubleDot]nstlichen \
St\[ODoubleDot]rparameters \[Lambda] f\[ADoubleDot]llt eine spezielle \
Bedeutung zu. Wird die Methode der gedehnten Koordinaten an der Gleichung in \
einer anderen Form durchgef\[UDoubleDot]hrt, so erzeugt sie nicht konvergente \
Reihenglieder. Es ist daher wichtig, gleiche Potenzen auf einmal zu \
verarbeiten. Das Problem der multidimensionalen St\[ODoubleDot]rungsrechnung \
in den St\[ODoubleDot]rparametern erfordert viel Erfahrung. Wenig konnte \
hierzu in der Literatur gefunden werden. \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:79"],

Cell["Kap. 3.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.9. MPLExpansion",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:80"],

Cell["\<\
MPLExpansion[n] entwickelt eine St\[ODoubleDot]rungsl\[ODoubleDot]sung der \
nichtlinearen Bewegungsgleichung des Sitnikovproblems n-ter Ordnung \
(TauTransformedB[n])  bis  zur  n-ten Ordnung in \[Lambda]. Die \
L\[ODoubleDot]sung wird dem Objekt NonlinearSolution[m,n] zugewiesen, wobei \
vorgabem\[ADoubleDot]\[SZ]ig m = n ist. Die durch die Methode von Poincar\
\[EAcute]-Lindstedt erzeugten Zeitdehnungskoeffizienten werden in  \
SigmaFunction[m,n] gespeichert. Das aus dem St\[ODoubleDot]ransatz \
resultierende Gleichungssystem wird dem Objekt SigmaSystem[m,n] \
\[UDoubleDot]bergeben. Die Funktion implementiert das \
Poincar\[EAcute]-Lindstedt - Verfahren bis zu beliebiger Ordnung in \
\[Lambda]. Der Algorithmus schreibt Zwischenresultate in die Dateien \
\"X.pr\", \"Y.pr\", \"T.pr\". Diese werden in dem Ordner, in dem die Funktion \
ausgef\[UDoubleDot]hrt wird gespeichert, und nach Vollendigung der Herleitung \
wieder gel\[ODoubleDot]scht.  \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:81"],

Cell[TextData[{
  "Die Poincar\[EAcute] - Lindstedt Methode ist ein klassisches Verfahren der \
St\[ODoubleDot]rungstheorie, welches zus\[ADoubleDot]tzlich zu einem \
klassischen Ansatz der abh\[ADoubleDot]ngigen Variable ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(y(\[Tau])\  = \ \(y\_0\)(\[Tau]) + \(\(y\_1\)(\[Tau])\) 
                    e + \(\(y\_2\)(\[Tau])\) e\^2 +  ... \),
            "TraditionalForm"], "+", \(O(e\^n)\)}], TraditionalForm]]],
  " einen Ansatz in der unabh\[ADoubleDot]ngigen Variablen ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\  = \ \(\(\[Tau]\_0\)(\[Sigma]) + \
\(\(\[Tau]\_1\)(\[Sigma])\) e + \(\(\[Tau]\_2\)(\[Sigma])\) e\^2 +  ... \) + 
          O(e\^n)\)]],
  " durchf\[UDoubleDot]hrt. Dadurch k\[ODoubleDot]nnen \
S\[ADoubleDot]kularterme, die aufgrund der Methode auftreten \
k\[ODoubleDot]nnen, durch geeignete Wahl der ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\_i\)]],
  " vermieden werden. Diese werden w\[ADoubleDot]hrend der \
Durchf\[UDoubleDot]hrung des Algorithmus bestimmt. Ergebnis ist eine St\
\[ODoubleDot]rungsl\[ODoubleDot]sung y(\[Tau],e) sowie eine \
Zeitdehnungstransformation \[Tau](\[Sigma],e). Setzt man die beiden Ans\
\[ADoubleDot]tze in die Ausgangsgleichung ein, so erh\[ADoubleDot]lt man das \
nach den Potenzen in e geordnete Gleichungssystem, um die einzelnen Gr\
\[ODoubleDot]\[SZ]en zu bestimmen. Eine detaillierte Beschreibung der Methode \
kann in Kapitel 3 gefunden werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:82"],

Cell[TextData[{
  "Voraussetzungen:\n",
  StyleBox["PerturbativeSeries,\nTransformDependentVar,\n\
TransformIndependentVar,\nTauTransformedB",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(MPLExpansion[n_Integer, 
          opts___] := \(Module[{time = SessionTime[], j = 1, a, m, Int, 
              T = {\[CapitalTau]\_0[\[Sigma]] \[Rule] \[Sigma]}, X, Xcopy, Y, 
              x, xx, form}, \[IndentingNewLine]\[IndentingNewLine]Options[
                MPLExpansion] = {TraceFormat \[Rule] Identity, 
                StartingOrder \[Rule] 1, 
                Order \[Rule] 
                  n}; \[IndentingNewLine]\[IndentingNewLine]form = \
\(TraceFormat /. {opts}\) /. 
                Options[
                  MPLExpansion]; \[IndentingNewLine]a = \(StartingOrder /. \
{opts}\) /. Options[
                  MPLExpansion]; \[IndentingNewLine]m = \(Order /. {opts}\) /. 
                Options[
                  MPLExpansion]; \[IndentingNewLine]\[IndentingNewLine]Int[
                exp_] := Module[{c, s}, \[IndentingNewLine]s = 
                  TrigReduce[
                    Sin[2 \(\@ 2\) \[Sigma]]*exp]; \[IndentingNewLine]c = 
                  TrigReduce[
                    Cos[2 \(\@ 2\) \[Sigma]]*exp]; \[IndentingNewLine]s = 
                  Integrate[s, \[Sigma]]; \[IndentingNewLine]c = 
                  Integrate[
                    c, \[Sigma]]; \[IndentingNewLine]Cos[2 \(\@ 2\) \[Sigma]]*
                    s\/\(2 \@ 2\) - \(c\/\(2 \@ 2\)\) 
                    Sin[2 \(\@ 
                            2\) \[Sigma]]]; \[IndentingNewLine]\
\[IndentingNewLine]$Derivation = \[IndentingNewLine]{x = 
                  TauTransformedB[n], \[IndentingNewLine]ansatz[\[Tau]] = 
                  PerturbativeSeries[\[CapitalTau][\[Sigma]], \[Lambda], 
                      m] /. \[CapitalTau]\_0[\[Sigma]] \[Rule] \[Sigma], \
\[IndentingNewLine]ansatz[y] = 
                  PerturbativeSeries[y[\[Sigma]], \[Lambda], 
                    m], \[IndentingNewLine]x = 
                  TransformIndependentVar[x, 
                    y[\[Tau]], \[Tau][\[Sigma]] == 
                      ansatz[\[Tau]]], \[IndentingNewLine]x = 
                  TransformDependentVar[Normal[x], y[\[Sigma]], 
                    y[\[Sigma]] == 
                      ansatz[y]], \
\[IndentingNewLine]\[IndentingNewLine]Print["\<Provisional Results written to \
: \>", "\<X.pr, Y.pr, T.pr\>"], \[IndentingNewLine]\[IndentingNewLine]Print["\
\<>>> System to solve for... \>"], \[IndentingNewLine]X = \(Xcopy = 
                    Thread[x[\([1, 3]\)] \[Equal] 
                          0] /. \[Tau] \[Rule] \[Sigma]\), \
\[IndentingNewLine]Print[form[X], "\<  (time constrained: \>", 
                  SessionTime[] - 
                    time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Print["\<>> Unperturbed \
solution...\>"], \[IndentingNewLine]x = \(Y = {y\_0[\[Sigma]] \[Rule] 
                        C[1]\ Cos[2\ \@2\ \[Sigma]] + 
                          C[2]\ Sin[
                              2\ \@2\ \[Sigma]]}\), \[IndentingNewLine]Print[
                  form[x], "\<  (time constrained: \>", 
                  SessionTime[] - 
                    time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Table[{\[IndentingNewLine]x = 
                      Flatten[Table[D[x, {\[Sigma], i}], {i, 0, 2}]], 
                    Put[X = 
                        X /. x, "\<X.pr\>"], \[IndentingNewLine]\
\[IndentingNewLine]Print["\<>> Resulting equation for order...\>", \ 
                      k], \[IndentingNewLine]x = 
                      Expand[X[\([k + 1, 1]\)]], \[IndentingNewLine]x = 
                      TrigReduce[x], \[IndentingNewLine]x = 
                      Collect[x, Sin[_] | Cos[_]], \[IndentingNewLine]Print[
                      form[x \[Equal] 0], "\<  (time constrained: \>", 
                      SessionTime[] - 
                        time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]x = 
                      x /. y\_k[\[Sigma]] | \(y\_k''\)[\[Sigma]] \
\[RuleDelayed] 
                          0, \[IndentingNewLine]\[IndentingNewLine]Print["\<> \
Coefficient of secular term...\>"], \[IndentingNewLine]xx = \
\[IndentingNewLine]\((Cases[x, _*Sin[2 \(\@ 2\) \[Sigma]], \[Infinity]] /. 
                              Sin[2 \(\@ 2\) \[Sigma]] \[Rule] 
                                1)\)[\([1]\)] \[Equal] 
                        0, \[IndentingNewLine]Print[
                      form[xx], "\<  (time constrained: \>", 
                      SessionTime[] - 
                        time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Print["\<> Solving for \>", \
\[CapitalTau]\_k[\[Sigma]], "\<...\>"], \[IndentingNewLine]xx = 
                      DSolve[xx, \[CapitalTau]\_k[\[Sigma]], \[Sigma], 
                          GeneratedParameters \[Rule] $] /. $[_] \[Rule] 
                          0, \[IndentingNewLine]Print[
                      form[xx], "\<  (time constrained: \>", 
                      SessionTime[] - 
                        time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Put[
                      T = Flatten[
                          Append[T, 
                            xx]], "\<T.pr\>"], \[IndentingNewLine]\
\[IndentingNewLine]Print["\<>> Resulting equation for order... \>", 
                      k], \[IndentingNewLine]xx = 
                      Flatten[Table[D[xx, {\[Sigma], i}], {i, 0, 2}]], 
                    X = Expand[X /. xx], 
                    x = Expand[x /. xx], \[IndentingNewLine]x = 
                      x /. amp_*Sin[arg_] \[RuleDelayed] 
                          Simplify[amp]*Sin[arg], 
                    x = x /. amp_*Cos[arg_] \[RuleDelayed] 
                          Simplify[amp]*Cos[arg], \[IndentingNewLine]Print[
                      form[x + 
                            8\ y\_k[\[Sigma]] + \(y\_k''\)[\[Sigma]] \[Equal] 
                          0], "\<  (time constrained: \>", 
                      SessionTime[] - 
                        time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Print["\<>> Solving for \>", 
                      y\_k[\[Sigma]], "\< (with k[1]=k[2]=0)...\>"], \
\[IndentingNewLine]x = Int[x], \[IndentingNewLine]xx = 
                      TrigReduce[x], \[IndentingNewLine]xx = 
                      xx /. amp_\ *\ Sin[arg_] \[RuleDelayed] 
                          amp\ *\ Sin[Expand[arg]], \[IndentingNewLine]xx = 
                      xx /. amp_\ *\ Cos[arg_] \[RuleDelayed] 
                          amp\ *\ Cos[Expand[arg]], \[IndentingNewLine]Print[
                      form[xx], "\<  (time constrained: \>", 
                      SessionTime[] - 
                        time, "\<)\>"], \
\[IndentingNewLine]\[IndentingNewLine]Put[
                      x = \(Y = 
                          Append[Y, 
                            y\_k[\[Sigma]] \[Rule] 
                              xx]\), "\<Y.pr\>"]}, \[IndentingNewLine]{k, a, 
                    m}], \[IndentingNewLine]\[IndentingNewLine]Print["\<\
Results written to > SigmaSystem, > SigmaFunction, > NonlinearSolution (\>", 
                  m, "\< \>", 
                  n, "\<)\>"]; \
\[IndentingNewLine]\[IndentingNewLine]SigmaSystem[n, m] = 
                  Xcopy; \[IndentingNewLine]SigmaFunction[n, 
                    m] = \((ansatz[\[Tau]] /. 
                      T)\); \[IndentingNewLine]\[IndentingNewLine]x = 
                  ansatz[y] /. Y, \[IndentingNewLine]x = 
                  Collect[x[\([3]\)], 
                    Sin[_] | Cos[_]], \[IndentingNewLine]x = 
                  x /. amp_*Sin[arg_] \[RuleDelayed] 
                      FullSimplify[amp]*Sin[arg], \[IndentingNewLine]x = 
                  x /. amp_*Cos[arg_] \[RuleDelayed] 
                      FullSimplify[amp]*
                        Cos[arg], \[IndentingNewLine]NonlinearSolution[n, 
                    m] = SeriesData[\[Lambda], 0, x, 0, m + 1, 
                    1], \[IndentingNewLine]\[IndentingNewLine]DeleteFile[{"\<\
X.pr\>", "\<Y.pr\>", "\<T.pr\>"}], \
\[IndentingNewLine]\[IndentingNewLine]$Result = \
\[IndentingNewLine]{SigmaSystem[n, 
                      m], \[IndentingNewLine]\[Tau][\[Sigma]] \[Rule] 
                      SigmaFunction[n, 
                        m], \[IndentingNewLine]y[\[Sigma]] \[Rule] 
                      NonlinearSolution[n, 
                        m]}\[IndentingNewLine]\[IndentingNewLine]}]\)[\([\(-1\
\)]\)]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:83"],

Cell["\<\
Der wesentliche Parameter, der an die Funktion \[UDoubleDot]bergeben werden \
muss, ist die Ordnung der Ausgangsgleichung. Implizit wird daraus gefolgert, \
dass eine Entwicklung bis zu dieser Ordnung gemacht werden soll. Folgende zus\
\[ADoubleDot]tzliche Optionen k\[ODoubleDot]nnen der Funktion \
\[UDoubleDot]bergeben werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["TraceFormat\[Rule]format",
    FontSlant->"Italic"],
  ": Format in welchem, die Zwischenergebnisse auf dem Bildschirm ausgegeben \
werden sollen."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["StartingOrder\[Rule]n",
    FontSlant->"Italic"],
  ": Ordnung, mit der die Berechnungen begonnen werden sollen. Wird diese \
Option gesetzt, so erwartet der Befehl die Existenz der drei Dateien, die \
Zwischenergebnisse bis zur Ordnung (n-1) enthalten."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Order\[Rule]m",
    FontSlant->"Italic"],
  ": Soll die L\[ODoubleDot]sung zu einer anderen Ordnung entwickelt werden, \
als implizit durch die Ausgangsgleichung vorgesehen, so kann diese hier \
gesetzt werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:84"],

Cell["Kap. 3.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.10. SigmaSystem, SigmaFuntion, NonlinearSolution",
  
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:85"],

Cell["\<\
SigmaSystem[m,n], SigmaFunction[m,n] und NonlinearSolution[m,n] werden w\
\[ADoubleDot]hrend der Ausf\[UDoubleDot]hrung des Algorithmus \
MPLExpansion[n,opt] erzeugt und beinhalten die Resultate von diesem. Um eines \
der Objekte zu erzeugen, muss die Funktion MPLExpansion[n,opts] aufgerufen \
werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:86"],

Cell["s.o.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:87"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["MPLExpansion",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    \(-\)], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:88"],

Cell[TextData[{
  "Interessant ist es, die Anzahl der Terme und Operationen, die bei der \
Methode von Poincar\[EAcute]-Lindstedt erzeugt werden, zu untersuchen. In \
allen folgenden Grafiken ist mit Ordnung gemeint, dass von der Gleichung, \
definiert durch die Funktion ",
  StyleBox["TauEquation[n],",
    FontSlant->"Italic"],
  " ausgegangen wird, und diese durch einen St\[ODoubleDot]ransatz bis zur \
n-ten Ordnung entwickelt wurde."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0714286 0.142857 0.0147151 0.000359562 [
[.07143 -0.0125 -4.78125 -11.625 ]
[.07143 -0.0125 4.78125 0 ]
[.21429 -0.0125 -4.78125 -11.625 ]
[.21429 -0.0125 4.78125 0 ]
[.35714 -0.0125 -4.78125 -11.625 ]
[.35714 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.64286 -0.0125 -4.78125 -11.625 ]
[.64286 -0.0125 4.78125 0 ]
[.78571 -0.0125 -4.78125 -11.625 ]
[.78571 -0.0125 4.78125 0 ]
[.92857 -0.0125 -4.78125 -11.625 ]
[.92857 -0.0125 4.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .10461 -20.6875 -5.8125 ]
[-0.0125 .10461 0 5.8125 ]
[-0.0125 .1945 -20.6875 -5.8125 ]
[-0.0125 .1945 0 5.8125 ]
[-0.0125 .28439 -20.6875 -5.8125 ]
[-0.0125 .28439 0 5.8125 ]
[-0.0125 .37428 -26.25 -5.8125 ]
[-0.0125 .37428 0 5.8125 ]
[-0.0125 .46417 -26.25 -5.8125 ]
[-0.0125 .46417 0 5.8125 ]
[-0.0125 .55406 -26.25 -5.8125 ]
[-0.0125 .55406 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.875 -7.5625 ]
[-0.01875 .30902 -26.25 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -32.7188 0 ]
[.5 .63053 32.7188 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 0 m
.07143 .00625 L
s
gsave
.07143 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35714 0 m
.35714 .00625 L
s
gsave
.35714 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.64286 0 m
.64286 .00625 L
s
gsave
.64286 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92857 0 m
.92857 .00625 L
s
gsave
.92857 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10461 m
.00625 .10461 L
s
gsave
-0.0125 .10461 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
0 .1945 m
.00625 .1945 L
s
gsave
-0.0125 .1945 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .28439 m
.00625 .28439 L
s
gsave
-0.0125 .28439 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(750) show
1.000 setlinewidth
grestore
0 .37428 m
.00625 .37428 L
s
gsave
-0.0125 .37428 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
0 .46417 m
.00625 .46417 L
s
gsave
-0.0125 .46417 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1250) show
1.000 setlinewidth
grestore
0 .55406 m
.00625 .55406 L
s
gsave
-0.0125 .55406 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03269 m
.00375 .03269 L
s
0 .05067 m
.00375 .05067 L
s
0 .06865 m
.00375 .06865 L
s
0 .08663 m
.00375 .08663 L
s
0 .12258 m
.00375 .12258 L
s
0 .14056 m
.00375 .14056 L
s
0 .15854 m
.00375 .15854 L
s
0 .17652 m
.00375 .17652 L
s
0 .21247 m
.00375 .21247 L
s
0 .23045 m
.00375 .23045 L
s
0 .24843 m
.00375 .24843 L
s
0 .26641 m
.00375 .26641 L
s
0 .30237 m
.00375 .30237 L
s
0 .32034 m
.00375 .32034 L
s
0 .33832 m
.00375 .33832 L
s
0 .3563 m
.00375 .3563 L
s
0 .39226 m
.00375 .39226 L
s
0 .41023 m
.00375 .41023 L
s
0 .42821 m
.00375 .42821 L
s
0 .44619 m
.00375 .44619 L
s
0 .48215 m
.00375 .48215 L
s
0 .50012 m
.00375 .50012 L
s
0 .5181 m
.00375 .5181 L
s
0 .53608 m
.00375 .53608 L
s
0 .57204 m
.00375 .57204 L
s
0 .59002 m
.00375 .59002 L
s
0 .60799 m
.00375 .60799 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -100.625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -93.7188 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SigmaSystem) show
124.438 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01429 .01472 m
.01429 .01543 L
.12857 .01543 L
.12857 .01472 L
F
0 g
.5 Mabswid
.01429 .01472 m
.01429 .01543 L
.12857 .01543 L
.12857 .01472 L
.01429 .01472 L
s
1 0 0 r
.15714 .01472 m
.15714 .01579 L
.27143 .01579 L
.27143 .01472 L
F
0 g
.15714 .01472 m
.15714 .01579 L
.27143 .01579 L
.27143 .01472 L
.15714 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .01615 L
.41429 .01615 L
.41429 .01472 L
F
0 g
.3 .01472 m
.3 .01615 L
.41429 .01615 L
.41429 .01472 L
.3 .01472 L
s
1 0 0 r
.44286 .01472 m
.44286 .01651 L
.55714 .01651 L
.55714 .01472 L
F
0 g
.44286 .01472 m
.44286 .01651 L
.55714 .01651 L
.55714 .01472 L
.44286 .01472 L
s
1 0 0 r
.58571 .01472 m
.58571 .01687 L
.7 .01687 L
.7 .01472 L
F
0 g
.58571 .01472 m
.58571 .01687 L
.7 .01687 L
.7 .01472 L
.58571 .01472 L
s
1 0 0 r
.72857 .01472 m
.72857 .01723 L
.84286 .01723 L
.84286 .01472 L
F
0 g
.72857 .01472 m
.72857 .01723 L
.84286 .01723 L
.84286 .01472 L
.72857 .01472 L
s
1 0 0 r
.87143 .01472 m
.87143 .01759 L
.98571 .01759 L
.98571 .01472 L
F
0 g
.87143 .01472 m
.87143 .01759 L
.98571 .01759 L
.98571 .01472 L
.87143 .01472 L
s
.8 1 0 r
.01429 .01543 m
.01429 .01543 L
.12857 .01543 L
.12857 .01543 L
F
0 g
.01429 .01543 m
.01429 .01543 L
.12857 .01543 L
.12857 .01543 L
.01429 .01543 L
s
.8 1 0 r
.15714 .01579 m
.15714 .01579 L
.27143 .01579 L
.27143 .01579 L
F
0 g
.15714 .01579 m
.15714 .01579 L
.27143 .01579 L
.27143 .01579 L
.15714 .01579 L
s
.8 1 0 r
.3 .01615 m
.3 .01615 L
.41429 .01615 L
.41429 .01615 L
F
0 g
.3 .01615 m
.3 .01615 L
.41429 .01615 L
.41429 .01615 L
.3 .01615 L
s
.8 1 0 r
.44286 .01651 m
.44286 .01687 L
.55714 .01687 L
.55714 .01651 L
F
0 g
.44286 .01651 m
.44286 .01687 L
.55714 .01687 L
.55714 .01651 L
.44286 .01651 L
s
.8 1 0 r
.58571 .01687 m
.58571 .01795 L
.7 .01795 L
.7 .01687 L
F
0 g
.58571 .01687 m
.58571 .01795 L
.7 .01795 L
.7 .01687 L
.58571 .01687 L
s
.8 1 0 r
.72857 .01723 m
.72857 .02047 L
.84286 .02047 L
.84286 .01723 L
F
0 g
.72857 .01723 m
.72857 .02047 L
.84286 .02047 L
.84286 .01723 L
.72857 .01723 L
s
.8 1 0 r
.87143 .01759 m
.87143 .02442 L
.98571 .02442 L
.98571 .01759 L
F
0 g
.87143 .01759 m
.87143 .02442 L
.98571 .02442 L
.98571 .01759 L
.87143 .01759 L
s
0 1 .4 r
.01429 .01543 m
.01429 .01615 L
.12857 .01615 L
.12857 .01543 L
F
0 g
.01429 .01543 m
.01429 .01615 L
.12857 .01615 L
.12857 .01543 L
.01429 .01543 L
s
0 1 .4 r
.15714 .01579 m
.15714 .01759 L
.27143 .01759 L
.27143 .01579 L
F
0 g
.15714 .01579 m
.15714 .01759 L
.27143 .01759 L
.27143 .01579 L
.15714 .01579 L
s
0 1 .4 r
.3 .01615 m
.3 .02083 L
.41429 .02083 L
.41429 .01615 L
F
0 g
.3 .01615 m
.3 .02083 L
.41429 .02083 L
.41429 .01615 L
.3 .01615 L
s
0 1 .4 r
.44286 .01687 m
.44286 .02802 L
.55714 .02802 L
.55714 .01687 L
F
0 g
.44286 .01687 m
.44286 .02802 L
.55714 .02802 L
.55714 .01687 L
.44286 .01687 L
s
0 1 .4 r
.58571 .01795 m
.58571 .04312 L
.7 .04312 L
.7 .01795 L
F
0 g
.58571 .01795 m
.58571 .04312 L
.7 .04312 L
.7 .01795 L
.58571 .01795 L
s
0 1 .4 r
.72857 .02047 m
.72857 .07368 L
.84286 .07368 L
.84286 .02047 L
F
0 g
.72857 .02047 m
.72857 .07368 L
.84286 .07368 L
.84286 .02047 L
.72857 .02047 L
s
0 1 .4 r
.87143 .02442 m
.87143 .13445 L
.98571 .13445 L
.98571 .02442 L
F
0 g
.87143 .02442 m
.87143 .13445 L
.98571 .13445 L
.98571 .02442 L
.87143 .02442 L
s
0 .4 1 r
.01429 .01615 m
.01429 .01615 L
.12857 .01615 L
.12857 .01615 L
F
0 g
.01429 .01615 m
.01429 .01615 L
.12857 .01615 L
.12857 .01615 L
.01429 .01615 L
s
0 .4 1 r
.15714 .01759 m
.15714 .01795 L
.27143 .01795 L
.27143 .01759 L
F
0 g
.15714 .01759 m
.15714 .01795 L
.27143 .01795 L
.27143 .01759 L
.15714 .01759 L
s
0 .4 1 r
.3 .02083 m
.3 .02299 L
.41429 .02299 L
.41429 .02083 L
F
0 g
.3 .02083 m
.3 .02299 L
.41429 .02299 L
.41429 .02083 L
.3 .02083 L
s
0 .4 1 r
.44286 .02802 m
.44286 .03413 L
.55714 .03413 L
.55714 .02802 L
F
0 g
.44286 .02802 m
.44286 .03413 L
.55714 .03413 L
.55714 .02802 L
.44286 .02802 L
s
0 .4 1 r
.58571 .04312 m
.58571 .05966 L
.7 .05966 L
.7 .04312 L
F
0 g
.58571 .04312 m
.58571 .05966 L
.7 .05966 L
.7 .04312 L
.58571 .04312 L
s
0 .4 1 r
.72857 .07368 m
.72857 .11216 L
.84286 .11216 L
.84286 .07368 L
F
0 g
.72857 .07368 m
.72857 .11216 L
.84286 .11216 L
.84286 .07368 L
.72857 .07368 L
s
0 .4 1 r
.87143 .13445 m
.87143 .21895 L
.98571 .21895 L
.98571 .13445 L
F
0 g
.87143 .13445 m
.87143 .21895 L
.98571 .21895 L
.98571 .13445 L
.87143 .13445 L
s
.8 0 1 r
.01429 .01615 m
.01429 .01759 L
.12857 .01759 L
.12857 .01615 L
F
0 g
.01429 .01615 m
.01429 .01759 L
.12857 .01759 L
.12857 .01615 L
.01429 .01615 L
s
.8 0 1 r
.15714 .01795 m
.15714 .0237 L
.27143 .0237 L
.27143 .01795 L
F
0 g
.15714 .01795 m
.15714 .0237 L
.27143 .0237 L
.27143 .01795 L
.15714 .01795 L
s
.8 0 1 r
.3 .02299 m
.3 .03988 L
.41429 .03988 L
.41429 .02299 L
F
0 g
.3 .02299 m
.3 .03988 L
.41429 .03988 L
.41429 .02299 L
.3 .02299 L
s
.8 0 1 r
.44286 .03413 m
.44286 .07512 L
.55714 .07512 L
.55714 .03413 L
F
0 g
.44286 .03413 m
.44286 .07512 L
.55714 .07512 L
.55714 .03413 L
.44286 .03413 L
s
.8 0 1 r
.58571 .05966 m
.58571 .15099 L
.7 .15099 L
.7 .05966 L
F
0 g
.58571 .05966 m
.58571 .15099 L
.7 .15099 L
.7 .05966 L
.58571 .05966 L
s
.8 0 1 r
.72857 .11216 m
.72857 .30201 L
.84286 .30201 L
.84286 .11216 L
F
0 g
.72857 .11216 m
.72857 .30201 L
.84286 .30201 L
.84286 .11216 L
.72857 .11216 L
s
.8 0 1 r
.87143 .21895 m
.87143 .60332 L
.98571 .60332 L
.98571 .21895 L
F
0 g
.87143 .21895 m
.87143 .60332 L
.98571 .60332 L
.98571 .21895 L
.87143 .21895 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
eGoo00<007ooOol01Woo00<007ooOol0YGoo003DOol00`00Oomoo`08Ool00`00Oomoo`2TOol00<mo
o`80009oo`03001oogoo009oo`03001oogoo008000=oo`03001oogoo0:=oo`00cWoo00H007ooOol0
07oo0005Ool00`00Ool00004Ool00`00Oomoo`2SOol00<ioo`06001oogoo001oo`001Woo0P0017oo
00<007ooOol0Xgoo003>Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`03001oogoo0:=oo`00
cWoo00@007ooOol0009oo`03001oogoo00Aoo`05001oogooOol0002VOol00<moo`8000Aoo`04001o
ogooOol20003Ool00`00Oomoo`2UOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo001DOol5000WOol3000XOol2000ZOol3000XOol00`00Oomoo`0WOol2000ZOol00`00Oomoo`0[
Ool005Ioo`03001oogoo02Moo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Ioo`03001o
o`0002Qoo`03001oo`0002Uoo`03001oogoo02]oo`00EWoo00<007ooOol0:7oo00<007ooOol0:7oo
00<007ooOol09goo1000:Goo00<007ooOol09Woo00<007oo0000:Goo00<007ooOol0:goo001FOol0
0`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Ool0000XOol2000YOol2000[Ool0
0`00Oomoo`0ZOol005Ioo`03001oogoo02Moo`03001oo`0002Qoo`03001oo`0002Uoo`8002Qoo`03
001oogoo02Qoo`03001oogoo02Qoo`03001oo`0002aoo`00EGoo0P00:Woo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol09Woo0`00:Goo0P00:7oo0`00;7oo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00@Gooo`00;`005goo0011Ool00`00Oomoo`0COol00`00Oomoo`0X
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0X
Ool00`00Oomoo`0BOol00`00Oomoo`0EOol0045oo`03001oogoo01=oo`03001oogoo02Qoo`03001o
ogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001o
ogoo019oo`03001oogoo01Eoo`00>7oo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
5Goo000gOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol003Moo`03001oo`00
00Moool002l001Moo`00=goo00<007oo00001goo00@007ooOomoob@000Moob@000Moo`030003k0?/
0203k003001oogoo00Eoo`030003k0?/0203k003001oogoo00Eoob@000Qoob<000Qoob<000=oo`03
001oogoo01Eoo`00=goo00<007oo00001goo00<007ooOol0;7oo90001goo90001goo00<000?/0n`0
80?/00<007ooOol01Goo00<000?/0n`080?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol0
1Woo00<006OPIn007fOP00D007ooOomoo`0001Moo`00>7oo00<007ooOol01Woo00<007ooOol0Egoo
00<006@OI1l086@O00<007ooOol01Goo00<000?/0n`080?/00<007ooOol01Goo00<000?/0n`080?/
00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo8`000goo00<007ooOol05Goo0011Ool0
0`00Oomoo`1GOol00`00I1mT7`0PI1l00`00Oomoo`05OolT0007Ool00`000n`3k00P0n`00`00Oomo
o`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011
Ool2001HOol00`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`05Ool00`00
0n`3k00P0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00
Oomoogoo00005goo0011Ool00`00Oomoo`1GOol00`00I1mT7`0PI1l00`00Oomoo`05OolT0007Ool0
0`000n`3k00P0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`1GOolT0007Ool00`00I1mT7`0PI1l00`00Oomoo`05
Ool00`000n`3k00P0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O
0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05OolT
0008Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011
Ool00`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`06Ool0
0`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool20023
Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O
0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22Ool0
0`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22Ool00`00
I1mT7`0PI1l00`00Oomoo`05OolT0008Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O
0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool0
0`00I1mT7`0PI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`00
I1mT7`0PI1l00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00
Oomoogoo00005goo0011Ool20023Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`00I1mT7`0PI1l0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
5goo0011Ool00`00Oomoo`22Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`00I1mT7`0PI1l00`00
Oomoo`06OolS0008Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22OolT
0007Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3
k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool0
0`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool2002^Ool00`00I1mT7`0PI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool0
0`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo
0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000/Ool30003Ool00`00Oomoo`02Ool00`00
Oomoo`07Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000/Ool00`00Oomoo`02Ool00`00Ool0
0002Ool00`00Ool00008Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000]Ool00`00Oomoo`03
Ool01P00Oomoo`00Ool000Qoo`<00:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1
W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol002eoo`04001oogooOol20003
Ool00`00Ool00008Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000/Ool00`00Ool00002Ool0
0`00Oomoo`02Ool00`00Ool00008Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06OolS
0008Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000]Ool01000Oomoogoo0`000goo00<007oo
Ool01goo00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<006@OI1l07f@O00<007oo
Ool01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo00<006@OI1l0
86@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomo
o`0001Moo`00@Goo0P00[Woo00<006@OI1l086@O00<007ooOol01Woo00<006@OI1l07f@O00<007oo
Ool01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo00<006@OI1l0
86@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<006@OI1l07f@O
00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo00<0
06@OI1l086@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<000?/0n`07`?/00D0
07ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<006@O
I1l07f@O00<007ooOol01Woo8`000goo00<007ooOol05Goo0011Ool00`00Oomoo`2]Ool00`00I1mT
7`0PI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomo
ogoo00005goo0011Ool2002^Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT
7`0PI1l00`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]OolT
0008Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011
Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo0011Ool2003JOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool0
0`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool2003JOol00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomo
o`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011
Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
1@00Oomoogoo00005goo000]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00
Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo
000/Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`3IOol00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000^Ool01P00Oomoo`00
Ool0009oo`03001oo`0000Qoo`<00=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1
W`05001oogooOol0000GOol002aoo`8000=oo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo
0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`05001oogooOol0000GOol002ao
o`03001oogoo009oo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo0=Uoo`03001T7f@O01mT
7`03001oogoo00Ioo`030001W`6O01l1W`05001oogooOol0000GOol002aoo`<000=oo`03001oogoo
009oo`03001oogoo00Moo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O
01l1W`05001oogooOol0000GOol0045oo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Io
o`030001W`6O01l1W`05001oogooOol0000GOol0045oo`800=Yoo`03001T7f@O01mT7`03001oogoo
00Ioo`030001W`6O01l1W`05001oogooOol0000GOol0045oo`03001oogoo0=Uoo`03001T7f@O01mT
7`03001oogoo00Ioo`030001W`6O01l1W`05001oogooOol0000GOol0045oo`03001oogoo0=Uoo`03
001T7f@O01mT7`03001oogoo00Ioob<000=oo`03001oogoo01Eoo`00@Goo00<007ooOol0fGoo00<0
06@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007oo
Ool0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00
@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo0P00fWoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l0
7f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo
00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<0
07ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@O
I1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P00fWoo00<0
06@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007oo
Ool0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00
@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0
06@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007oo
Ool01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P00fWoo00<006@OI1l07f@O00<0
07ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@O
I1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0
fGoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00;Goo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol01goo00<007ooOol0fGoo00<006@OI1l07f@O
00<007ooOol01Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00;Goo00L007ooOomoo`00Ool0
0002Ool00`00Ool00008Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT
7`0OI1l01@00Oomoogoo00005goo000]Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Qoo`<00=Uo
o`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`05001oogooOol0000GOol002ioo`03
001oogoo008000=oo`03001oo`0000Qoo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Io
o`03001T7f@O01mT7`05001oogooOol0000GOol002aoo`03001oo`00009oo`03001oogoo009oo`03
001oo`0000Qoo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`05
001oogooOol0000GOol001Qoo`03001oogoo009oo`03001oogoo00aoo`<0009oo`<000=oo`03001o
ogoo00Moo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`05001o
ogooOol0000GOol001Qoo`H002=oo`03001oogoo0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`03
001T7f@O01mT7`05001oogooOol0000GOol001Uoo`80009oo`03001oogoo025oo`800=Yoob<000Qo
o`03001T7f@O01mT7`05001oogooOol0000GOol001Qoo`03001oogoo008002Aoo`03001oogoo0?mo
o`Eoo`03001T7f@O01mT7`05001oogooOol0000GOol001Qoo`H002=oo`03001oogoo0?moo`Eoo`03
001T7f@O01mT7`05001oogooOol0000GOol001Yoo`05001oo`00Ool0000ROol00`00Oomoo`3oOol5
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo000IOol5000SOol00`00Oomoo`3oOol5Ool00`00
I1mT7`0OI1l01@00Oomoogoo00005goo000HOol01`00Ool007oo001oo`00029oo`03001oogoo0?mo
o`Eoo`03001T7f@O01mT7`05001oogooOol0000GOol001Uoo`D002=oo`800?moo`Ioo`03001T7f@O
01mT7`05001oogooOol0000GOol001Qoo`05001oo`00Ool0000TOol00`00Oomoo`3oOol5Ool00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0OI1l01@00
Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2003oOol6
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0OI1l01@00Oomoogoo
00005goo0011Ool00`00Oomoo`0AOolg002lOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool00`00Oomoo`0?Ooli002lOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool2000@Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00
Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`2jOol00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00;Ool2000H
Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000UOol50002Ool00`00Oomo
o`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00<Ool00`00
Oomoo`0FOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000WOol01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`<000moo`03001oogoo011l00Ioo`80
00Aoo`07001oogoo001oo`00Ool01@003Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`009goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00
Oomoo`0?Ool00`00Oomoo`0@O008Ool03P00Oomoo`00Ool007oo001oo`00Ool007oo0002Ool00`00
Oomoo`0:Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000WOol01`00Oomo
ogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011l
00Moo`0?001oogooOol007oo001oo`00Ool007oo001oo`00009oo`03001oogoo00Yoo`03001oogoo
0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Moo`07001oogooOol007oo00000Woo00<0
07oo00000Woo00<007oo00002Goo00<007ooOol03goo00<007ooOol047`01goo0P0000Aoo`00001o
o`@00004Ool007ooOol3000=Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
000VOol20004Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@O00EOol00`00Oomoo`0=Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo
00005goo0011Ool2000@Ool00`00Oomoo`0@O00DOol2000?Ool00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`2j
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00U
Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@O00UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00
Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@In0UOol00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0FOol2000=Ool00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0@In0HOol00`00Oomoo`0:Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In07Ool20002Ool30002Ool30003Ool3000<Ool00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0@In06Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo00Yo
o`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`80011oo`03001oogoo
011Wh0Ioo`03001oogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool0
0`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@In05Ool40002Ool400000goo00000004Ool3000<Ool00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In06Ool00`00Oomoo`0L
Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@In0AOol00`00Oomoo`0AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo
00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2j
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@In0UOol00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`0?Ool00`00Oomoo`0@0n`UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo
00005goo000UOol5000017oo000000000goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol0
3goo00<007ooOol040?/9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00
9goo00D007ooOomoo`0000Aoo`03001oo`00009oo`03001oo`0000Uoo`<000moo`03001oogoo0103
k0aoo`03001oogoo01Ioo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Mo
o`03001oogoo009oo`03001oogoo00=oo`06001oogoo001oo`002Goo00<007ooOol03goo00<007oo
Ool040?/1Woo10000Woo00@007ooOomoo`@0015oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001o
ogooOol0000GOol002Moo`03001oogoo009oo`04001oogooOol20003Ool00`00Ool00009Ool00`00
Oomoo`0?Ool00`00Oomoo`0@0n`6Ool300000goo000000030002Ool01000Oomoo`0047oo00<007oo
Ool0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009goo00L007ooOomoo`00Ool00002Ool0
0`00Oomoo`02Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`8Ool01@00Oomoogoo
000017oo00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0
02Ioo`8000Aoo`04001oogooOol30003Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0@
0n`7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool2000@Ool00`00Oomoo`0@0n`AOol00`00Oomoo`0AOol00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`@Ool2
000COol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0@0n`UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`UOol00`00Oomoo`2jOol00`00I1mT
7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2j
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0eOol00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT
7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@0Il6Ool40006Ool4000AOol0
0`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@0Il6Ool30008Ool01000Oomoo`0047oo00<007ooOol0^Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O27oo00<007ooOol01Woo00@007oo
Ool0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo
00moo`03001oogoo0101W`Moo`80009oo`03001oo`0000=oo`<0015oo`03001oogoo0;Yoo`03001T
7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo00moo`03001oogoo0101W`aoo`03001o
ogoo009oo`03001oogoo015oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0
045oo`03001oogoo00moo`03001oogoo0101W`aoo`04001oogooOol2000COol00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@0IlUOol00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo000UOol50002Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`0?
Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000W
Ool01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`<000moo`03001oogoo
011T7bEoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Moo`03001oogoo
00=oo`06001oogoo001oo`000Woo00<007oo00002Goo00<007ooOol03goo00<007ooOol046@O9Goo
00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009goo00@007ooOomoo`8000=o
o`03001oo`00009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011T7bEoo`03001oogoo
0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Moo`05001oogooOol00004Ool00`00Ool0
0002Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1l6Ool4000017oo001oo`000Woo
10004Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009Woo0P000goo0`00
0goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol046@O1Woo0`000goo
00<007ooOol00Woo00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0
000GOol0045oo`03001oogoo00moo`03001oogoo011T7`Qoo`03001oogoo00<000=oo`04001oogoo
000@Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00
Oomoo`0@I1l7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lAOol00`00Oomoo`0AOol0
0`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@I1l@Ool2000COol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT
7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ooli002lOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00I1mT7`0OI1l0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5OolS0003Ool00`00Oomoo`0EOol0045oo`80
0?moobaoo`03001oogoo01Eoo`00@Goo00<007ooOol0ogoo:goo00<007ooOol05Goo0011Ool00`00
Oomoo`3oOol[Ool00`00Oomoo`0EOol0045oool002l001Moo`00ogooQgoo003oOon7Ool00?moohMo
o`00ogooQgoo003oOon7Ool00?moohMoo`00aGoo0P004Goo0P00[7oo0037Ool00`00Oomoo`0?Ool0
0`00Oomoo`2ZOol00;Yoo`<0009oo`<000=oo`@00005Ool007oo001oo`04000017oo000000000goo
00@007ooOomoo`8000Aoo`8000=oo`800006Ool007oo001oo`00UWoo002jOol00`00Ool00003Ool0
1@00Oomoogoo00000Woo0P0000Eoo`00Ool007oo00<0009oo`03001oo`00009oo`03001oo`0000Ao
o`04001oogoo0002Ool00`00Ool00003Ool01@00Ool007oo0000UWoo002lOol01@00Oomoogoo0000
0goo00<007ooOol00P0000Aoo`00Ool000=oo`03001oogoo009oo`06001oogoo001oo`000goo00D0
07ooOomoo`0000Aoo`<00006Ool007oo001oo`00UWoo002kOol01000Oomoogoo0P0017oo1@0000=o
o`00Ool00Woo0P000goo00<007ooOol00P0000=oo`0000000Woo0P0000=oo`0000000P000Woo0`00
00Eoo`00001oo`0009Moo`00^Woo00<007oo00005Woo00<007oo000037oo00<007ooOol0XGoo002j
Ool30003Ool00`00Oomoo`0@Ool3002`Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
ogooQgoo003oOon7Ool00?moohMoo`00\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-3.23002, 228.426, 0.0232398, 9.23337}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 54: ",
    FontWeight->"Bold"],
  "Gr\[ODoubleDot]\[SZ]e des Gleichungssystems in Abh\[ADoubleDot]ngigkeit \
des St\[ODoubleDot]rparameters \[Lambda], dass mit Hilfe der Methode von \
Poincar\[EAcute] - Lindstedt gel\[ODoubleDot]st werden muss."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Das Differentialgleichungssystem, das durch den Algorithmus \
gel\[ODoubleDot]st werden muss, ist f\[UDoubleDot]r die 7. Ordnung in \
\[Lambda] durch \[UDoubleDot]ber 1500 Operationen definiert. Es ist eine \
Herausforderung, dieses auf automatisierten Wege zu l\[ODoubleDot]sen. Die \
Anzahl der Terme und Operationen w\[ADoubleDot]chst mit steigender Ordnung \
stark exponentiell an, eine obere Grenze bez\[UDoubleDot]glich der \
Berechenbarkeit ist offensichtlich. Dennoch handelt es sich bei den \
Differentialgleichungen um einfache inhomogene Gleichungen, die im \
Wesentlichen nichtlinear gest\[ODoubleDot]rte Oszillatoren sind. Die \
Gleichungen k\[ODoubleDot]nnen durch Auffinden von Integralen dennoch gel\
\[ODoubleDot]st werden, wie im Abschnitt 3.3. beschrieben wird.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0714286 0.142857 0.0147151 0.00905544 [
[.07143 -0.0125 -4.78125 -11.625 ]
[.07143 -0.0125 4.78125 0 ]
[.21429 -0.0125 -4.78125 -11.625 ]
[.21429 -0.0125 4.78125 0 ]
[.35714 -0.0125 -4.78125 -11.625 ]
[.35714 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.64286 -0.0125 -4.78125 -11.625 ]
[.64286 -0.0125 4.78125 0 ]
[.78571 -0.0125 -4.78125 -11.625 ]
[.78571 -0.0125 4.78125 0 ]
[.92857 -0.0125 -4.78125 -11.625 ]
[.92857 -0.0125 4.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .10527 -15.125 -5.8125 ]
[-0.0125 .10527 0 5.8125 ]
[-0.0125 .19582 -15.125 -5.8125 ]
[-0.0125 .19582 0 5.8125 ]
[-0.0125 .28638 -15.125 -5.8125 ]
[-0.0125 .28638 0 5.8125 ]
[-0.0125 .37693 -15.125 -5.8125 ]
[-0.0125 .37693 0 5.8125 ]
[-0.0125 .46749 -15.125 -5.8125 ]
[-0.0125 .46749 0 5.8125 ]
[-0.0125 .55804 -15.125 -5.8125 ]
[-0.0125 .55804 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -26.75 -7.5625 ]
[-0.01875 .30902 -15.125 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -74.3125 0 ]
[.5 .63053 74.3125 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 0 m
.07143 .00625 L
s
gsave
.07143 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35714 0 m
.35714 .00625 L
s
gsave
.35714 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.64286 0 m
.64286 .00625 L
s
gsave
.64286 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92857 0 m
.92857 .00625 L
s
gsave
.92857 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .10527 m
.00625 .10527 L
s
gsave
-0.0125 .10527 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
1.000 setlinewidth
grestore
0 .19582 m
.00625 .19582 L
s
gsave
-0.0125 .19582 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
1.000 setlinewidth
grestore
0 .28638 m
.00625 .28638 L
s
gsave
-0.0125 .28638 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
1.000 setlinewidth
grestore
0 .37693 m
.00625 .37693 L
s
gsave
-0.0125 .37693 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
1.000 setlinewidth
grestore
0 .46749 m
.00625 .46749 L
s
gsave
-0.0125 .46749 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(50) show
1.000 setlinewidth
grestore
0 .55804 m
.00625 .55804 L
s
gsave
-0.0125 .55804 -76.125 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(60) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03283 m
.00375 .03283 L
s
0 .05094 m
.00375 .05094 L
s
0 .06905 m
.00375 .06905 L
s
0 .08716 m
.00375 .08716 L
s
0 .12338 m
.00375 .12338 L
s
0 .14149 m
.00375 .14149 L
s
0 .1596 m
.00375 .1596 L
s
0 .17771 m
.00375 .17771 L
s
0 .21393 m
.00375 .21393 L
s
0 .23205 m
.00375 .23205 L
s
0 .25016 m
.00375 .25016 L
s
0 .26827 m
.00375 .26827 L
s
0 .30449 m
.00375 .30449 L
s
0 .3226 m
.00375 .3226 L
s
0 .34071 m
.00375 .34071 L
s
0 .35882 m
.00375 .35882 L
s
0 .39504 m
.00375 .39504 L
s
0 .41315 m
.00375 .41315 L
s
0 .43127 m
.00375 .43127 L
s
0 .44938 m
.00375 .44938 L
s
0 .4856 m
.00375 .4856 L
s
0 .50371 m
.00375 .50371 L
s
0 .52182 m
.00375 .52182 L
s
0 .53993 m
.00375 .53993 L
s
0 .57615 m
.00375 .57615 L
s
0 .59426 m
.00375 .59426 L
s
0 .61237 m
.00375 .61237 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -89.5 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -135.313 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.250 moveto
(8) show
68.563 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SigmaFunction) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
140.875 12.250 moveto
(@) show
146.438 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
157.563 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
168.688 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(#1) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
179.813 12.250 moveto
(D) show
185.375 12.250 moveto
(<) show
196.500 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(&) show
207.625 12.250 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01429 .01472 m
.01429 .02377 L
.12857 .02377 L
.12857 .01472 L
F
0 g
.5 Mabswid
.01429 .01472 m
.01429 .02377 L
.12857 .02377 L
.12857 .01472 L
.01429 .01472 L
s
1 0 0 r
.15714 .01472 m
.15714 .02377 L
.27143 .02377 L
.27143 .01472 L
F
0 g
.15714 .01472 m
.15714 .02377 L
.27143 .02377 L
.27143 .01472 L
.15714 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .02377 L
.41429 .02377 L
.41429 .01472 L
F
0 g
.3 .01472 m
.3 .02377 L
.41429 .02377 L
.41429 .01472 L
.3 .01472 L
s
1 0 0 r
.44286 .01472 m
.44286 .02377 L
.55714 .02377 L
.55714 .01472 L
F
0 g
.44286 .01472 m
.44286 .02377 L
.55714 .02377 L
.55714 .01472 L
.44286 .01472 L
s
1 0 0 r
.58571 .01472 m
.58571 .02377 L
.7 .02377 L
.7 .01472 L
F
0 g
.58571 .01472 m
.58571 .02377 L
.7 .02377 L
.7 .01472 L
.58571 .01472 L
s
1 0 0 r
.72857 .01472 m
.72857 .02377 L
.84286 .02377 L
.84286 .01472 L
F
0 g
.72857 .01472 m
.72857 .02377 L
.84286 .02377 L
.84286 .01472 L
.72857 .01472 L
s
1 0 0 r
.87143 .01472 m
.87143 .02377 L
.98571 .02377 L
.98571 .01472 L
F
0 g
.87143 .01472 m
.87143 .02377 L
.98571 .02377 L
.98571 .01472 L
.87143 .01472 L
s
.8 1 0 r
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
F
0 g
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
.01429 .02377 L
s
.8 1 0 r
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
F
0 g
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
.15714 .02377 L
s
.8 1 0 r
.3 .02377 m
.3 .02377 L
.41429 .02377 L
.41429 .02377 L
F
0 g
.3 .02377 m
.3 .02377 L
.41429 .02377 L
.41429 .02377 L
.3 .02377 L
s
.8 1 0 r
.44286 .02377 m
.44286 .02377 L
.55714 .02377 L
.55714 .02377 L
F
0 g
.44286 .02377 m
.44286 .02377 L
.55714 .02377 L
.55714 .02377 L
.44286 .02377 L
s
.8 1 0 r
.58571 .02377 m
.58571 .02377 L
.7 .02377 L
.7 .02377 L
F
0 g
.58571 .02377 m
.58571 .02377 L
.7 .02377 L
.7 .02377 L
.58571 .02377 L
s
.8 1 0 r
.72857 .02377 m
.72857 .02377 L
.84286 .02377 L
.84286 .02377 L
F
0 g
.72857 .02377 m
.72857 .02377 L
.84286 .02377 L
.84286 .02377 L
.72857 .02377 L
s
.8 1 0 r
.87143 .02377 m
.87143 .02377 L
.98571 .02377 L
.98571 .02377 L
F
0 g
.87143 .02377 m
.87143 .02377 L
.98571 .02377 L
.98571 .02377 L
.87143 .02377 L
s
0 1 .4 r
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
F
0 g
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
.01429 .02377 L
s
0 1 .4 r
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
F
0 g
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
.15714 .02377 L
s
0 1 .4 r
.3 .02377 m
.3 .04188 L
.41429 .04188 L
.41429 .02377 L
F
0 g
.3 .02377 m
.3 .04188 L
.41429 .04188 L
.41429 .02377 L
.3 .02377 L
s
0 1 .4 r
.44286 .02377 m
.44286 .04188 L
.55714 .04188 L
.55714 .02377 L
F
0 g
.44286 .02377 m
.44286 .04188 L
.55714 .04188 L
.55714 .02377 L
.44286 .02377 L
s
0 1 .4 r
.58571 .02377 m
.58571 .06905 L
.7 .06905 L
.7 .02377 L
F
0 g
.58571 .02377 m
.58571 .06905 L
.7 .06905 L
.7 .02377 L
.58571 .02377 L
s
0 1 .4 r
.72857 .02377 m
.72857 .0781 L
.84286 .0781 L
.84286 .02377 L
F
0 g
.72857 .02377 m
.72857 .0781 L
.84286 .0781 L
.84286 .02377 L
.72857 .02377 L
s
0 1 .4 r
.87143 .02377 m
.87143 .11432 L
.98571 .11432 L
.98571 .02377 L
F
0 g
.87143 .02377 m
.87143 .11432 L
.98571 .11432 L
.98571 .02377 L
.87143 .02377 L
s
0 .4 1 r
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
F
0 g
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
.01429 .02377 L
s
0 .4 1 r
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
F
0 g
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
.15714 .02377 L
s
0 .4 1 r
.3 .04188 m
.3 .0781 L
.41429 .0781 L
.41429 .04188 L
F
0 g
.3 .04188 m
.3 .0781 L
.41429 .0781 L
.41429 .04188 L
.3 .04188 L
s
0 .4 1 r
.44286 .04188 m
.44286 .0781 L
.55714 .0781 L
.55714 .04188 L
F
0 g
.44286 .04188 m
.44286 .0781 L
.55714 .0781 L
.55714 .04188 L
.44286 .04188 L
s
0 .4 1 r
.58571 .06905 m
.58571 .16866 L
.7 .16866 L
.7 .06905 L
F
0 g
.58571 .06905 m
.58571 .16866 L
.7 .16866 L
.7 .06905 L
.58571 .06905 L
s
0 .4 1 r
.72857 .0781 m
.72857 .21393 L
.84286 .21393 L
.84286 .0781 L
F
0 g
.72857 .0781 m
.72857 .21393 L
.84286 .21393 L
.84286 .0781 L
.72857 .0781 L
s
0 .4 1 r
.87143 .11432 m
.87143 .35882 L
.98571 .35882 L
.98571 .11432 L
F
0 g
.87143 .11432 m
.87143 .35882 L
.98571 .35882 L
.98571 .11432 L
.87143 .11432 L
s
.8 0 1 r
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
F
0 g
.01429 .02377 m
.01429 .02377 L
.12857 .02377 L
.12857 .02377 L
.01429 .02377 L
s
.8 0 1 r
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
F
0 g
.15714 .02377 m
.15714 .02377 L
.27143 .02377 L
.27143 .02377 L
.15714 .02377 L
s
.8 0 1 r
.3 .0781 m
.3 .10527 L
.41429 .10527 L
.41429 .0781 L
F
0 g
.3 .0781 m
.3 .10527 L
.41429 .10527 L
.41429 .0781 L
.3 .0781 L
s
.8 0 1 r
.44286 .0781 m
.44286 .10527 L
.55714 .10527 L
.55714 .0781 L
F
0 g
.44286 .0781 m
.44286 .10527 L
.55714 .10527 L
.55714 .0781 L
.44286 .0781 L
s
.8 0 1 r
.58571 .16866 m
.58571 .26827 L
.7 .26827 L
.7 .16866 L
F
0 g
.58571 .16866 m
.58571 .26827 L
.7 .26827 L
.7 .16866 L
.58571 .16866 L
s
.8 0 1 r
.72857 .21393 m
.72857 .34977 L
.84286 .34977 L
.84286 .21393 L
F
0 g
.72857 .21393 m
.72857 .34977 L
.84286 .34977 L
.84286 .21393 L
.72857 .21393 L
s
.8 0 1 r
.87143 .35882 m
.87143 .60332 L
.98571 .60332 L
.98571 .35882 L
F
0 g
.87143 .35882 m
.87143 .60332 L
.98571 .60332 L
.98571 .35882 L
.87143 .35882 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
d7oo00<007ooOol01Woo00<007ooOol0ZWoo003?Ool00`00Oomoo`08Ool00`00Oomoo`2YOol00<Uo
o`8000=oo`05001oogooOol00002Ool20004Ool00`00Oomoo`2XOol00<Qoo`04001oogoo0002Ool0
0`00Oomoo`02Ool00`00Ool00005Ool00`00Oomoo`2XOol00<Qoo`04001oogoo0002Ool00`00Oomo
o`03Ool20005Ool00`00Oomoo`2XOol00<Qoo`04001oogoo0002Ool00`00Oomoo`04Ool00`00Oomo
o`03Ool00`00Oomoo`2XOol00<Qoo`04001oogoo0003Ool00`00Oomoo`03Ool00`00Oomoo`02Ool0
0`00Oomoo`2YOol00<Uoo`8000Eoo`03001oogoo008000Aoo`03001oogoo0:Yoo`00ogooQgoo003o
Oon7Ool00?moohMoo`00ogooQgoo003oOon7Ool004ioo`D002Moo`<002Qoo`8002Yoo`<002Qoo`03
001oogoo02Moo`8002Yoo`03001oogoo035oo`00D7oo00<007ooOol09goo00<007ooOol0:Woo00<0
07ooOol0:7oo00<007ooOol09Woo00<007oo0000:7oo00<007oo0000:Goo00<007ooOol0<Goo001@
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0WOol4000YOol00`00Oomoo`0VOol00`00
Ool0000YOol00`00Oomoo`0aOol0051oo`03001oogoo02Qoo`03001oogoo02Uoo`03001oogoo02Io
o`03001oo`0002Qoo`8002Uoo`8002]oo`03001oogoo031oo`00D7oo00<007ooOol09goo00<007oo
0000:7oo00<007oo0000:Goo0P00:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007oo0000<Woo
001?Ool2000ZOol00`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0VOol3000YOol2000XOol3
000bOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo000lOooo000_000LOol0
03aoo`03001oogoo019oo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo
02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo01=oo`03001oogoo01Yoo`00?7oo00<0
07ooOol04Woo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<007ooOol0:7oo00<0
07ooOol0:7oo00<007ooOol0:7oo00<007ooOol04goo00<007ooOol06Woo000bOol00`00Oomoo`07
Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0JOol0035oo`03001oo`0000Qoo`03001oogoo0?moob]o
o`03001oogoo01Yoo`00<Goo00<007oo000027ooo`00;`0077oo000aOol00`00Ool00008Ool01@00
Oomoogoo00008G`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`0
00<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol01Woo
00<007`0O0007g`000<007ooOol01Woo00<007`0O0007g`000<007ooOol00Woo00<007ooOol06Woo
000aOol00`00Ool00008Ool01000Oomoogoo8`0027oo90001goo90001goo90001goo90001goo9000
1goo90000goo00<007ooOol06Woo000bOol00`00Oomoo`07Ool00`00Oomoo`1GOol00`000n`3k00O
0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomoo`0J
Ool003aoo`03001oogoo05Moo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001o
ogoo00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003
k0?/01l3k003001oogoo009oo`03001oogoo01Yoo`00?7oo0P00F7oo00<000?/0n`07`?/00<007oo
Ool01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/
0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol00Woo00<007ooOol06Woo000lOol0
0`00Oomoo`1GOol00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo05Moo`030003k0?/01l3k003001oogoo
00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/
01l3k003001oogoo00Ioo`030003k0?/01l3k003001oogoo009oo`03001oogoo01Yoo`00?7oo00<0
07ooOol0Egoo8`0027oo8`0027oo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00<0
07ooOol01Woo00<000?/0n`07`?/00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`1G
Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O
0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`02
Ool00`00Oomoo`0JOol003aoo`03001oogoo05Moo`030001W`6O01l1W`03001oogoo00Ioo`030001
W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001o
ogoo00Ioo`030003k0?/01l3k003001oogoo009oo`03001oogoo01Yoo`00?7oo0P00F7oo00<0006O
0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/00<007oo
Ool01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol00Woo00<007oo
Ool06Woo000lOol00`00Oomoo`1GOol00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il0
0`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo05Moo`030001W`6O
01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k003001oogoo
00Ioo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001oogoo009oo`03001oogoo
01Yoo`00?7oo00<007ooOol0Egoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<0
07ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<0
00?/0n`07`?/00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`1GOol00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomoo`0J
Ool003aoo`8005Qoo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Io
ob<000Qoo`030003k0?/01l3k003001oogoo00Ioo`030003k0?/01l3k003001oogoo009oo`03001o
ogoo01Yoo`00?7oo00<007ooOol0Egoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O
00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo
00<000?/0n`07`?/00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`1GOol00`000Il1
W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomo
o`0JOol003aoo`03001oogoo05Moob<000Qoob<000Qoo`030001W`6O01l1W`03001oogoo00Ioob<0
00Qoo`030003k0?/01l3k003001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0Egoo00<0
06@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol00Woo00<0
07ooOol06Woo000lOol00`00Oomoo`1GOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`8005Qoo`03001T7f@O01mT
7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Io
o`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k003001oogoo009oo`03001oogoo01Yo
o`00?7oo00<007ooOol0Egoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00<007oo
Ool01Woo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/
0n`07`?/00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`1GOol00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool0
0`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`02Ool00`00Oomoo`0JOol0
03aoo`03001oogoo05Moo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo
00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/
01l3k003001oogoo009oo`03001oogoo01Yoo`00:goo1@000Woo00<007ooOol01goo00<007ooOol0
Egoo00<006@OI1l07f@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il0
7`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol0
0Woo00<007ooOol06Woo000]Ool01`00Oomoogoo001oo`0000Qoo`8005Qoob<000Qoob<000Qoo`03
0001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k003
001oogoo009oo`03001oogoo01Yoo`00;Goo00L007ooOomoo`00Ool00008Ool00`00Oomoo`2]Ool0
0`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`02Ool00`00Oomoo`0JOol002eoo`07001oogooOol007oo000027oo00<007ooOol0[Goo
00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`07`?/
00<007ooOol00Woo00<007ooOol06Woo000]Ool01`00Oomoogoo001oo`0000Qoo`03001oogoo0:eo
o`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioob<000Aoo`03001o
ogoo01Yoo`00;7oo0P0017oo00<007ooOol01goo00<007ooOol0[Goo00<0006O0Il07`6O00<007oo
Ool01Woo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007oo
Ool06Woo000lOol2002^Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eoo`03
0001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03
001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<0006O0Il07`6O00<007ooOol0
1Woo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol0
6Woo000lOol00`00Oomoo`2]Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eo
o`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1
W`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<0006O0Il07`6O00<007oo
Ool01Woo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007oo
Ool06Woo000lOol2002^Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eoo`03
0001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03
001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<0006O0Il07`6O00<007ooOol0
1Woo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol0
6Woo000lOol00`00Oomoo`2]Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eo
o`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1
W`03001oogoo009oo`03001oogoo01Yoo`00?7oo0P00[Woo00<0006O0Il07`6O00<007ooOol01Woo
00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo
000lOol00`00Oomoo`2]Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomo
o`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eoo`03
0001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03
001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo8`0027oo00<0006O0Il07`6O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`2]
Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eoo`03001T7f@O01mT7`03001o
ogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001o
ogoo01Yoo`00?7oo0P00[Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007oo
Ool01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`2]Ool0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il0
0`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo0:eoo`03001T7f@O01mT7`03001oogoo
00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001oogoo
01Yoo`00?7oo00<007ooOol0[Goo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000/Ool30003Ool00`00
Oomoo`07Ool00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol002aoo`03001oogoo009o
o`03001oo`0000Qoo`800:ioo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001o
ogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00;Goo00L007ooOomoo`00
Ool00008Ool00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol002eoo`07001oogooOol0
07oo000027oo00<007ooOol0[Goo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000/Ool00`00Ool00002
Ool00`00Ool00008Ool00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol002eoo`03001o
ogoo009oo`03001oogoo00Moo`03001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`030001
W`6O01l1W`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo
00<007ooOol0[Goo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo
00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol2002^Ool00`00I1mT7`0OI1l0
0`00Oomoo`06OolS0008Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03
001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Ioo`03
0001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<006@OI1l0
7f@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol0
0Woo00<007ooOol06Woo000lOol00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003ao
o`03001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Io
o`030001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo0P00[Woo00<006@OI1l07f@O
00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo
00<007ooOol06Woo000lOol00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03
001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Ioo`03
0001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<006@OI1l0
7f@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol0
0Woo00<007ooOol06Woo000lOol00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003ao
o`03001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Io
o`030001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo0P00[Woo00<006@OI1l07f@O
00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo
00<007ooOol06Woo000lOol00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03
001oogoo0:eoo`03001T7f@O01mT7`03001oogoo00Ioo`03001T7f@O01mT7`03001oogoo00Ioo`03
0001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0[Goo00<006@OI1l0
7f@O00<007ooOol01Woo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol0
0Woo00<007ooOol06Woo000lOol00`00Oomoo`2]Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003ao
o`800:ioob<000Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009o
o`03001oogoo01Yoo`00?7oo00<007ooOol0f7oo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`3HOol00`00I1mT7`0OI1l0
0`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo
0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001oogoo
01Yoo`00;7oo0P0017oo00<007ooOol01goo00<007ooOol0f7oo00<006@OI1l07f@O00<007ooOol0
1Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000^Ool01P00Oomoo`00Ool000Qo
o`03001oogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009o
o`03001oogoo01Yoo`00;Goo00L007ooOomoo`00Ool00008Ool2003IOol00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol002ioo`06001oogoo001o
o`0027oo00<007ooOol0f7oo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007oo
Ool00Woo00<007ooOol06Woo000MOol00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Ool00002Ool0
0`00Ool00008Ool00`00Oomoo`3HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
0`00Oomoo`02Ool00`00Oomoo`0JOol001eoo`H000Yoo`03001oogoo009oo`03001oogoo00Moo`03
001oogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03
001oogoo01Yoo`007Woo0P000Woo00<007ooOol05goo00<007ooOol0f7oo00<006@OI1l07f@O00<0
07ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000MOol00`00Oomoo`02
000JOol2003IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool0
0`00Oomoo`0JOol001eoo`H001Uoo`03001oogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`03
0001W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`007goo00D007oo001oo`0001Qoo`03001o
ogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001o
ogoo01Yoo`007Woo1@006Goo00<007ooOol0f7oo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000MOol01`00Ool007oo001oo`0001Qoo`03001o
ogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo009oo`03001o
ogoo01Yoo`007Woo1@006Goo0P00fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O
00<007ooOol00Woo00<007ooOol06Woo000MOol01@00Ool007oo00006Woo00<007ooOol0f7oo00<0
06@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000l
Ool00`00Oomoo`3HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02
Ool00`00Oomoo`0JOol003aoo`03001oogoo0=Qoo`03001T7f@O01mT7`03001oogoo00Ioo`030001
W`6O01l1W`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0f7oo00<006@OI1l07f@O
00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomo
o`3HOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomo
o`0JOol003aoo`800=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo
009oo`03001oogoo01Yoo`00?7oo00<007ooOol0f7oo00<006@OI1l07f@O00<007ooOol01Woo00<0
006O0Il07`6O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`0FOolg002;Ool00`00
I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`02Ool00`00Oomoo`0JOol003ao
o`03001oogoo01AoocT008]oob<000Qoo`030001W`6O01l1W`03001oogoo009oo`03001oogoo01Yo
o`00?7oo00<007ooOol057oo00<007ooOol0=Goo00<007ooOol0]7oo00<0006O0Il07`6O00<007oo
Ool00Woo00<007ooOol06Woo000lOol2000EOol00`00Oomoo`0eOol00`00Oomoo`2dOolS0004Ool0
0`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo011l02Eoo`03001oogoo0;Aoo`03001T
7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol047`0
9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00
Oomoo`0DOol00`00Oomoo`0@O00;Ool2000HOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomo
o`02Ool00`00Oomoo`0JOol002eoo`<0009oo`03001oogoo00Moo`03001oogoo01Aoo`03001oogoo
011l00aoo`03001oogoo01Ioo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001o
ogoo01Yoo`00;Woo00H007ooOol007oo0008Ool00`00Oomoo`0DOol00`00Oomoo`0@O006Ool20004
Ool01`00Oomoo`00Ool007oo00D000eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009o
o`03001oogoo01Yoo`00;7oo100000Aoo`00Ool000Qoo`8001Eoo`03001oogoo011l00Qoo`0>001o
ogoo001oo`00Ool007oo001oo`00Ool0009oo`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O
01mT7`03001oogoo009oo`03001oogoo01Yoo`00;7oo00<007oo00000Woo00<007oo000027oo00<0
07ooOol057oo00<007ooOol047`01goo00l007ooOomoo`00Ool007oo001oo`00Ool007oo00000Woo
00<007ooOol02Woo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo
000]Ool20002Ool00`00Ool00008Ool00`00Oomoo`0DOol00`00Oomoo`0@O007Ool2000017oo0000
07oo100000Aoo`00Oomoo`<000eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03
001oogoo01Yoo`00;Woo00D007ooOomoo`0000Uoo`03001oogoo01Aoo`03001oogoo011l01Eoo`03
001oogoo00eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00
?7oo00<007ooOol057oo00<007ooOol047`057oo0P003goo00<007ooOol0]7oo00<006@OI1l07f@O
00<007ooOol00Woo00<007ooOol06Woo000lOol2000EOol00`00Oomoo`0@O00UOol00`00Oomoo`2d
Ool00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001o
ogoo011l02Eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00
?7oo00<007ooOol057oo00<007ooOol047`09Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007oo
Ool00Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`2dOol0
0`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo
03Eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<0
07ooOol057oo00<007ooOol046OP9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo
00<007ooOol06Woo000lOol2000EOol00`00Oomoo`0@In0FOol2000=Ool00`00Oomoo`2dOol00`00
I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo011W
h1Qoo`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo
01Yoo`00?7oo00<007ooOol057oo00<007ooOol046OP1goo0P000Woo0`000Woo0`000goo0`0037oo
00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomo
o`0DOol00`00Oomoo`0@In06Ool01000Oomoo`000Woo00<007ooOol00Woo00D007ooOomoo`00009o
o`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yo
o`00?7oo00<007ooOol057oo00<007ooOol046OP1Woo00<007ooOol00goo00<007ooOol00Woo00D0
07ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009o
o`03001oogoo01Yoo`00?7oo0P005Goo00<007ooOol046OP1Goo10000Woo100000=oo`00000017oo
0`0037oo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol0
0`00Oomoo`0DOol00`00Oomoo`0@In06Ool00`00Oomoo`0LOol00`00Oomoo`2dOol00`00I1mT7`0O
I1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo011Wh15oo`03
001oogoo015oo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00
?7oo00<007ooOol057oo00<007ooOol046OP9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007oo
Ool00Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0@In0UOol00`00Oomoo`2d
Ool00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001o
ogoo011Wh2Eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00
?7oo0P005Goo00<007ooOol0=Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<0
07ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`2dOol00`00I1mT7`0O
I1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo0103k2Eoo`03
001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol0
57oo00<007ooOol040?/9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007oo
Ool06Woo000]Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0@0n`<
Ool00`00Oomoo`0FOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0J
Ool002aoo`03001oo`00009oo`03001oo`0000Qoo`8001Eoo`03001oogoo0103k0Ioo`@0009oo`04
001oogooOol4000AOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0J
Ool002ioo`06001oogoo001oo`0027oo00<007ooOol057oo00<007ooOol040?/1Woo0`0000=oo`00
00000`000Woo00@007ooOol0011oo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03
001oogoo01Yoo`00;7oo0P000goo00<007oo000027oo00<007ooOol057oo00<007ooOol040?/27oo
00D007ooOomoo`0000Aoo`04001oogoo000@Ool00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomo
o`02Ool00`00Oomoo`0JOol002aoo`03001oogoo009oo`03001oo`0000Qoo`03001oogoo01Aoo`03
001oogoo0103k0Moo`8000=oo`03001oogoo009oo`<0015oo`03001oogoo0;Aoo`03001T7f@O01mT
7`03001oogoo009oo`03001oogoo01Yoo`00;7oo0`000goo00<007ooOol01goo00<007ooOol057oo
00<007ooOol040?/4Goo00<007ooOol04Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol0
0Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`@Ool2000COol00`00Oomo
o`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`8001Eoo`03001oogoo
0103k2Eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo
00<007ooOol057oo00<007ooOol040?/9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol0
0Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0n`UOol00`00Oomoo`2dOol0
0`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo
03Eoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<0
07ooOol057oo00<007ooOol0=Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<0
07ooOol06Woo000lOol2000EOol00`00Oomoo`0@0IlUOol00`00Oomoo`2dOol00`00I1mT7`0OI1l0
0`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo0101WbEoo`03001o
ogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo
00<007ooOol0406O9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol0
6Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0@0IlUOol00`00Oomoo`2dOol00`00I1mT7`0OI1l0
0`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo0101W`Ioo`@000Io
o`@0015oo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo
0P005Goo00<007ooOol0406O1Woo0`0027oo00@007ooOol0011oo`03001oogoo0;Aoo`03001T7f@O
01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol0406O27oo
00<007ooOol01Woo00@007ooOol0011oo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009o
o`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol0406O1goo0P000Woo00<007oo0000
0goo0`004Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000l
Ool00`00Oomoo`0DOol00`00Oomoo`0@0Il<Ool00`00Oomoo`02Ool00`00Oomoo`0AOol00`00Oomo
o`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03
001oogoo0101W`aoo`04001oogooOol2000COol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomo
o`02Ool00`00Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo0101WbEoo`03001oogoo0;Ao
o`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo0P005Goo00<007ooOol0406O
9Goo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00
Oomoo`0DOol00`00Oomoo`0eOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00
Oomoo`0JOol003aoo`03001oogoo01Aoo`03001oogoo03Eoo`03001oogoo0;Aoo`03001T7f@O01mT
7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol046@O9Goo00<0
07ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000/Ool20004Ool00`00
Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0@I1lUOol00`00Oomoo`2dOol00`00I1mT7`0OI1l0
0`00Oomoo`02Ool00`00Oomoo`0JOol002aoo`03001oo`00009oo`03001oo`0000Qoo`8001Eoo`03
001oogoo011T7bEoo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yo
o`00;7oo00<007oo00000Woo00<007oo000027oo00<007ooOol057oo00<007ooOol046@O9Goo00<0
07ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000/Ool20003Ool00`00
Ool00008Ool00`00Oomoo`0DOol00`00Oomoo`0@I1l6Ool4000017oo001oo`000Woo10004Goo00<0
07ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000/Ool00`00Oomoo`02
Ool00`00Ool00008Ool00`00Oomoo`0DOol00`00Oomoo`0@I1l6Ool30003Ool00`00Oomoo`02Ool0
1000Oomoo`0047oo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo
000]Ool20003Ool00`00Oomoo`07Ool00`00Oomoo`0DOol00`00Oomoo`0@I1l8Ool00`00Oomoo`03
0003Ool01000Oomoo`0047oo00<007ooOol0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007oo
Ool06Woo000lOol00`00Oomoo`0DOol00`00Oomoo`0@I1l7Ool20003Ool00`00Oomoo`02Ool3000A
Ool00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`8001Eo
o`03001oogoo011T7a5oo`03001oogoo015oo`03001oogoo0;Aoo`03001T7f@O01mT7`03001oogoo
009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol046@O47oo0P004goo00<007oo
Ool0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomoo`0DOol0
0`00Oomoo`0@I1lUOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0J
Ool003aoo`03001oogoo01Aoo`03001oogoo011T7bEoo`03001oogoo0;Aoo`03001T7f@O01mT7`03
001oogoo009oo`03001oogoo01Yoo`00?7oo00<007ooOol057oo00<007ooOol046@O9Goo00<007oo
Ool0]7oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol2000EOol00`00Oomo
o`0eOol00`00Oomoo`2dOol00`00I1mT7`0OI1l00`00Oomoo`02Ool00`00Oomoo`0JOol003aoo`03
001oogoo01AoocT00;Ioo`03001T7f@O01mT7`03001oogoo009oo`03001oogoo01Yoo`00?7oo00<0
07ooOol0ogoo17oo00<006@OI1l07f@O00<007ooOol00Woo00<007ooOol06Woo000lOol00`00Oomo
o`3oOol4OolS0004Ool00`00Oomoo`0JOol003aoo`03001oogoo0?moob]oo`03001oogoo01Yoo`00
?7oo00<007ooOol0ogoo:goo00<007ooOol06Woo000lOol2003oOol/Ool00`00Oomoo`0JOol003ao
ool002l001aoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
SGoo00<007ooOol02goo0P00?Goo0P0097oo0P000goo00<007ooOol0OWoo002<Ool00`00Oomoo`0>
Ool00`00Oomoo`0jOol01P00Oomoo`00Ool000Yoo`03001oogoo00Ioo`03001oo`0000]oo`03001o
ogoo009oo`03001oogoo07eoo`00S7oo00@007ooOomoo`<0009oo`<000=oo`@00005Ool007oo001o
o`070004Ool50002Ool00`00Ool000020003Ool20002Ool30003Ool200000goo00000002Ool00`00
Oomoo`08Ool02000Oomoogoo001oo`00Ool50003Ool00`00Oomoo`07Ool01000Ool007oo1@0017oo
00<007ooOol00Woo00<007ooOol01goo1000LWoo002<Ool01`00Oomoogoo001oo`0000=oo`05001o
ogooOol00002Ool200001Goo001oo`00Ool00`000Woo00<007ooOol00Woo00H007ooOol007oo0002
Ool00`00Ool00004Ool01000Oomoo`000Woo00D007ooOomoo`00009oo`03001oo`00009oo`03001o
ogoo00Qoo`03001oogoo00D0009oo`03001oogoo00Aoo`03001oogoo00Eoo`D0009oo`03001oogoo
00Aoo`03001oogoo009oo`03001oogoo00Moo`03001oo`0007=oo`00Rgoo00<007ooOol017oo00D0
07ooOomoo`0000=oo`03001oogoo00800004Ool007oo0003Ool01000Oomoo`0017oo00H007ooOol0
07oo0002Ool00`00Ool00004Ool00`00Oomoo`03Ool01@00Oomoogoo00000Woo00<007oo00000Woo
00<007ooOol027oo00L007ooOomoo`00Ool00003Ool00`00Oomoo`0=Ool00`00Ool00003Ool00`00
Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`06Ool2001dOol008aoo`03001oogoo009oo`04001o
ogooOol20004Ool500000goo001oo`02Ool20002Ool20002Ool200000goo000000040002Ool30000
0goo000000020002Ool20004Ool200000goo00000002000;Ool00`00Oomoo`050002Ool00`00Oomo
o`0<Ool50002Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`1bOol0
08aoo`07001oogooOol007oo00005Woo00@007ooOol0011oo`03001oogoo01Yoo`07001oogooOol0
07oo00000goo00<007ooOol03Goo00<007oo00000goo00<007ooOol017oo00<007ooOol00Woo00<0
07ooOol027oo0`00LWoo002=Ool00`00Oomoo`030003Ool00`00Oomoo`0?Ool5000FOol00`00Oomo
o`0DOol20003Ool01000Ool007oo0P0047oo00@007oo001oo`8000Eoo`8000=oo`03001oogoo07io
o`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo0000
\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-3.10075, 9.07003, 0.0232398, 0.366627}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 55: ",
    FontWeight->"Bold"],
  "Anzahl der Operationen, die von der Funktion MPLExpansion in Abh\
\[ADoubleDot]ngigkeit des St\[ODoubleDot]rparameters \[Lambda] erzeugt \
werden."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0714286 0.142857 0.0147151 0.000310281 [
[.07143 -0.0125 -4.78125 -11.625 ]
[.07143 -0.0125 4.78125 0 ]
[.21429 -0.0125 -4.78125 -11.625 ]
[.21429 -0.0125 4.78125 0 ]
[.35714 -0.0125 -4.78125 -11.625 ]
[.35714 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.64286 -0.0125 -4.78125 -11.625 ]
[.64286 -0.0125 4.78125 0 ]
[.78571 -0.0125 -4.78125 -11.625 ]
[.78571 -0.0125 4.78125 0 ]
[.92857 -0.0125 -4.78125 -11.625 ]
[.92857 -0.0125 4.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .09229 -20.6875 -5.8125 ]
[-0.0125 .09229 0 5.8125 ]
[-0.0125 .16986 -20.6875 -5.8125 ]
[-0.0125 .16986 0 5.8125 ]
[-0.0125 .24743 -20.6875 -5.8125 ]
[-0.0125 .24743 0 5.8125 ]
[-0.0125 .325 -26.25 -5.8125 ]
[-0.0125 .325 0 5.8125 ]
[-0.0125 .40257 -26.25 -5.8125 ]
[-0.0125 .40257 0 5.8125 ]
[-0.0125 .48014 -26.25 -5.8125 ]
[-0.0125 .48014 0 5.8125 ]
[-0.0125 .55771 -26.25 -5.8125 ]
[-0.0125 .55771 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.875 -7.5625 ]
[-0.01875 .30902 -26.25 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -49.2813 0 ]
[.5 .63053 49.2813 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 0 m
.07143 .00625 L
s
gsave
.07143 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35714 0 m
.35714 .00625 L
s
gsave
.35714 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.64286 0 m
.64286 .00625 L
s
gsave
.64286 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92857 0 m
.92857 .00625 L
s
gsave
.92857 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .09229 m
.00625 .09229 L
s
gsave
-0.0125 .09229 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(250) show
1.000 setlinewidth
grestore
0 .16986 m
.00625 .16986 L
s
gsave
-0.0125 .16986 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .24743 m
.00625 .24743 L
s
gsave
-0.0125 .24743 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(750) show
1.000 setlinewidth
grestore
0 .325 m
.00625 .325 L
s
gsave
-0.0125 .325 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
0 .40257 m
.00625 .40257 L
s
gsave
-0.0125 .40257 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1250) show
1.000 setlinewidth
grestore
0 .48014 m
.00625 .48014 L
s
gsave
-0.0125 .48014 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
0 .55771 m
.00625 .55771 L
s
gsave
-0.0125 .55771 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1750) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03023 m
.00375 .03023 L
s
0 .04574 m
.00375 .04574 L
s
0 .06126 m
.00375 .06126 L
s
0 .07677 m
.00375 .07677 L
s
0 .1078 m
.00375 .1078 L
s
0 .12331 m
.00375 .12331 L
s
0 .13883 m
.00375 .13883 L
s
0 .15434 m
.00375 .15434 L
s
0 .18537 m
.00375 .18537 L
s
0 .20088 m
.00375 .20088 L
s
0 .2164 m
.00375 .2164 L
s
0 .23191 m
.00375 .23191 L
s
0 .26294 m
.00375 .26294 L
s
0 .27845 m
.00375 .27845 L
s
0 .29397 m
.00375 .29397 L
s
0 .30948 m
.00375 .30948 L
s
0 .34051 m
.00375 .34051 L
s
0 .35602 m
.00375 .35602 L
s
0 .37154 m
.00375 .37154 L
s
0 .38705 m
.00375 .38705 L
s
0 .41808 m
.00375 .41808 L
s
0 .43359 m
.00375 .43359 L
s
0 .44911 m
.00375 .44911 L
s
0 .46462 m
.00375 .46462 L
s
0 .49565 m
.00375 .49565 L
s
0 .51117 m
.00375 .51117 L
s
0 .52668 m
.00375 .52668 L
s
0 .54219 m
.00375 .54219 L
s
0 .57322 m
.00375 .57322 L
s
0 .58874 m
.00375 .58874 L
s
0 .60425 m
.00375 .60425 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -100.625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -110.281 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(NonlinearSolution) show
157.563 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01429 .01472 m
.01429 .01534 L
.12857 .01534 L
.12857 .01472 L
F
0 g
.5 Mabswid
.01429 .01472 m
.01429 .01534 L
.12857 .01534 L
.12857 .01472 L
.01429 .01472 L
s
1 0 0 r
.15714 .01472 m
.15714 .01534 L
.27143 .01534 L
.27143 .01472 L
F
0 g
.15714 .01472 m
.15714 .01534 L
.27143 .01534 L
.27143 .01472 L
.15714 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .01565 L
.41429 .01565 L
.41429 .01472 L
F
0 g
.3 .01472 m
.3 .01565 L
.41429 .01565 L
.41429 .01472 L
.3 .01472 L
s
1 0 0 r
.44286 .01472 m
.44286 .01596 L
.55714 .01596 L
.55714 .01472 L
F
0 g
.44286 .01472 m
.44286 .01596 L
.55714 .01596 L
.55714 .01472 L
.44286 .01472 L
s
1 0 0 r
.58571 .01472 m
.58571 .01627 L
.7 .01627 L
.7 .01472 L
F
0 g
.58571 .01472 m
.58571 .01627 L
.7 .01627 L
.7 .01472 L
.58571 .01472 L
s
1 0 0 r
.72857 .01472 m
.72857 .01658 L
.84286 .01658 L
.84286 .01472 L
F
0 g
.72857 .01472 m
.72857 .01658 L
.84286 .01658 L
.84286 .01472 L
.72857 .01472 L
s
1 0 0 r
.87143 .01472 m
.87143 .01689 L
.98571 .01689 L
.98571 .01472 L
F
0 g
.87143 .01472 m
.87143 .01689 L
.98571 .01689 L
.98571 .01472 L
.87143 .01472 L
s
.8 1 0 r
.01429 .01534 m
.01429 .01596 L
.12857 .01596 L
.12857 .01534 L
F
0 g
.01429 .01534 m
.01429 .01596 L
.12857 .01596 L
.12857 .01534 L
.01429 .01534 L
s
.8 1 0 r
.15714 .01534 m
.15714 .01596 L
.27143 .01596 L
.27143 .01534 L
F
0 g
.15714 .01534 m
.15714 .01596 L
.27143 .01596 L
.27143 .01534 L
.15714 .01534 L
s
.8 1 0 r
.3 .01565 m
.3 .01689 L
.41429 .01689 L
.41429 .01565 L
F
0 g
.3 .01565 m
.3 .01689 L
.41429 .01689 L
.41429 .01565 L
.3 .01565 L
s
.8 1 0 r
.44286 .01596 m
.44286 .01968 L
.55714 .01968 L
.55714 .01596 L
F
0 g
.44286 .01596 m
.44286 .01968 L
.55714 .01968 L
.55714 .01596 L
.44286 .01596 L
s
.8 1 0 r
.58571 .01627 m
.58571 .02371 L
.7 .02371 L
.7 .01627 L
F
0 g
.58571 .01627 m
.58571 .02371 L
.7 .02371 L
.7 .01627 L
.58571 .01627 L
s
.8 1 0 r
.72857 .01658 m
.72857 .03147 L
.84286 .03147 L
.84286 .01658 L
F
0 g
.72857 .01658 m
.72857 .03147 L
.84286 .03147 L
.84286 .01658 L
.72857 .01658 L
s
.8 1 0 r
.87143 .01689 m
.87143 .04357 L
.98571 .04357 L
.98571 .01689 L
F
0 g
.87143 .01689 m
.87143 .04357 L
.98571 .04357 L
.98571 .01689 L
.87143 .01689 L
s
0 1 .4 r
.01429 .01596 m
.01429 .01658 L
.12857 .01658 L
.12857 .01596 L
F
0 g
.01429 .01596 m
.01429 .01658 L
.12857 .01658 L
.12857 .01596 L
.01429 .01596 L
s
0 1 .4 r
.15714 .01596 m
.15714 .01658 L
.27143 .01658 L
.27143 .01596 L
F
0 g
.15714 .01596 m
.15714 .01658 L
.27143 .01658 L
.27143 .01596 L
.15714 .01596 L
s
0 1 .4 r
.3 .01689 m
.3 .01844 L
.41429 .01844 L
.41429 .01689 L
F
0 g
.3 .01689 m
.3 .01844 L
.41429 .01844 L
.41429 .01689 L
.3 .01689 L
s
0 1 .4 r
.44286 .01968 m
.44286 .02961 L
.55714 .02961 L
.55714 .01968 L
F
0 g
.44286 .01968 m
.44286 .02961 L
.55714 .02961 L
.55714 .01968 L
.44286 .01968 L
s
0 1 .4 r
.58571 .02371 m
.58571 .04698 L
.7 .04698 L
.7 .02371 L
F
0 g
.58571 .02371 m
.58571 .04698 L
.7 .04698 L
.7 .02371 L
.58571 .02371 L
s
0 1 .4 r
.72857 .03147 m
.72857 .09353 L
.84286 .09353 L
.84286 .03147 L
F
0 g
.72857 .03147 m
.72857 .09353 L
.84286 .09353 L
.84286 .03147 L
.72857 .03147 L
s
0 1 .4 r
.87143 .04357 m
.87143 .16613 L
.98571 .16613 L
.98571 .04357 L
F
0 g
.87143 .04357 m
.87143 .16613 L
.98571 .16613 L
.98571 .04357 L
.87143 .04357 L
s
0 .4 1 r
.01429 .01658 m
.01429 .0172 L
.12857 .0172 L
.12857 .01658 L
F
0 g
.01429 .01658 m
.01429 .0172 L
.12857 .0172 L
.12857 .01658 L
.01429 .01658 L
s
0 .4 1 r
.15714 .01658 m
.15714 .0172 L
.27143 .0172 L
.27143 .01658 L
F
0 g
.15714 .01658 m
.15714 .0172 L
.27143 .0172 L
.27143 .01658 L
.15714 .01658 L
s
0 .4 1 r
.3 .01844 m
.3 .02185 L
.41429 .02185 L
.41429 .01844 L
F
0 g
.3 .01844 m
.3 .02185 L
.41429 .02185 L
.41429 .01844 L
.3 .01844 L
s
0 .4 1 r
.44286 .02961 m
.44286 .0445 L
.55714 .0445 L
.55714 .02961 L
F
0 g
.44286 .02961 m
.44286 .0445 L
.55714 .0445 L
.55714 .02961 L
.44286 .02961 L
s
0 .4 1 r
.58571 .04698 m
.58571 .08205 L
.7 .08205 L
.7 .04698 L
F
0 g
.58571 .04698 m
.58571 .08205 L
.7 .08205 L
.7 .04698 L
.58571 .04698 L
s
0 .4 1 r
.72857 .09353 m
.72857 .18971 L
.84286 .18971 L
.84286 .09353 L
F
0 g
.72857 .09353 m
.72857 .18971 L
.84286 .18971 L
.84286 .09353 L
.72857 .09353 L
s
0 .4 1 r
.87143 .16613 m
.87143 .36161 L
.98571 .36161 L
.98571 .16613 L
F
0 g
.87143 .16613 m
.87143 .36161 L
.98571 .36161 L
.98571 .16613 L
.87143 .16613 L
s
.8 0 1 r
.01429 .0172 m
.01429 .01844 L
.12857 .01844 L
.12857 .0172 L
F
0 g
.01429 .0172 m
.01429 .01844 L
.12857 .01844 L
.12857 .0172 L
.01429 .0172 L
s
.8 0 1 r
.15714 .0172 m
.15714 .01844 L
.27143 .01844 L
.27143 .0172 L
F
0 g
.15714 .0172 m
.15714 .01844 L
.27143 .01844 L
.27143 .0172 L
.15714 .0172 L
s
.8 0 1 r
.3 .02185 m
.3 .02651 L
.41429 .02651 L
.41429 .02185 L
F
0 g
.3 .02185 m
.3 .02651 L
.41429 .02651 L
.41429 .02185 L
.3 .02185 L
s
.8 0 1 r
.44286 .0445 m
.44286 .06188 L
.55714 .06188 L
.55714 .0445 L
F
0 g
.44286 .0445 m
.44286 .06188 L
.55714 .06188 L
.55714 .0445 L
.44286 .0445 L
s
.8 0 1 r
.58571 .08205 m
.58571 .12642 L
.7 .12642 L
.7 .08205 L
F
0 g
.58571 .08205 m
.58571 .12642 L
.7 .12642 L
.7 .08205 L
.58571 .08205 L
s
.8 0 1 r
.72857 .18971 m
.72857 .3101 L
.84286 .3101 L
.84286 .18971 L
F
0 g
.72857 .18971 m
.72857 .3101 L
.84286 .3101 L
.84286 .18971 L
.72857 .18971 L
s
.8 0 1 r
.87143 .36161 m
.87143 .60332 L
.98571 .60332 L
.98571 .36161 L
F
0 g
.87143 .36161 m
.87143 .60332 L
.98571 .60332 L
.98571 .36161 L
.87143 .36161 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
eGoo00<007ooOol01Woo00<007ooOol0YGoo003DOol00`00Oomoo`08Ool00`00Oomoo`2TOol00<mo
o`80009oo`03001oogoo009oo`03001oogoo008000=oo`03001oogoo0:=oo`00cWoo00H007ooOol0
07oo0005Ool00`00Ool00004Ool00`00Oomoo`2SOol00<ioo`06001oogoo001oo`001Woo0P0017oo
00<007ooOol0Xgoo003>Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`03001oogoo0:=oo`00
cWoo00@007ooOol0009oo`03001oogoo00Aoo`05001oogooOol0002VOol00<moo`8000Aoo`04001o
ogooOol20003Ool00`00Oomoo`2UOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo001DOol5000WOol3000XOol2000ZOol3000XOol00`00Oomoo`0WOol2000ZOol00`00Oomoo`0[
Ool005Ioo`03001oogoo02Moo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Ioo`03001o
o`0002Qoo`03001oo`0002Uoo`03001oogoo02]oo`00EWoo00<007ooOol0:7oo00<007ooOol0:7oo
00<007ooOol09goo1000:Goo00<007ooOol09Woo00<007oo0000:Goo00<007ooOol0:goo001FOol0
0`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Ool0000XOol2000YOol2000[Ool0
0`00Oomoo`0ZOol005Ioo`03001oogoo02Moo`03001oo`0002Qoo`03001oo`0002Uoo`8002Qoo`03
001oogoo02Qoo`03001oogoo02Qoo`03001oo`0002aoo`00EGoo0P00:Woo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol09Woo0`00:Goo0P00:7oo0`00;7oo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00@Gooo`00;`005goo0011Ool00`00Oomoo`0COol00`00Oomoo`0X
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0X
Ool00`00Oomoo`0BOol00`00Oomoo`0EOol0045oo`03001oogoo01=oo`03001oogoo02Qoo`03001o
ogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001o
ogoo019oo`03001oogoo01Eoo`00>7oo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
5Goo000gOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol003Moo`03001oo`00
00Moool002l001Moo`00=goo00<007oo00001goo00@007ooOomoob@000Moob@000Moob@000Moob@0
00Moo`03001Wh6OP021Wh003001oogoo00Ioo`03001Wh6OP01mWh003001oogoo00Ioo`03001Wh6OP
01mWh005001oogooOol0000GOol003Moo`03001oo`0000Moo`03001oogoo05Moob@000Moo`030003
k0?/0203k003001oogoo00Eoob@000Qoo`03001Wh6OP01mWh003001oogoo00Ioo`03001Wh6OP01mW
h005001oogooOol0000GOol003Qoo`03001oogoo00Ioo`03001oogoo05Moob@000Moo`030003k0?/
0203k003001oogoo00Eoo`030003k0?/0203k003001oogoo00Ioo`03001Wh6OP01mWh003001oogoo
00Ioo`03001Wh6OP01mWh005001oogooOol0000GOol0045oo`8008=oob@000Moo`030003k0?/0203
k003001oogoo00Ioo`03001Wh6OP01mWh003001oogoo00Ioo`03001Wh6OP01mWh005001oogooOol0
000GOol0045oo`03001oogoo089oo`030001W`6O0201W`03001oogoo00Eoo`030003k0?/0203k003
001oogoo00Ioob<000Qoo`03001Wh6OP01mWh005001oogooOol0000GOol0045oo`03001oogoo089o
o`030001W`6O0201W`03001oogoo00Eoo`030003k0?/0203k003001oogoo00Ioo`030003k0?/01l3
k003001oogoo00Ioo`03001Wh6OP01mWh005001oogooOol0000GOol0045oo`03001oogoo089oo`03
0001W`6O0201W`03001oogoo00Eoo`030003k0?/0203k003001oogoo00Ioo`030003k0?/01l3k003
001oogoo00Ioo`03001Wh6OP01mWh005001oogooOol0000GOol0045oo`03001oogoo089oo`030001
W`6O0201W`03001oogoo00Eoo`030003k0?/0203k003001oogoo00Ioo`030003k0?/01l3k003001o
ogoo00Ioob<000=oo`03001oogoo01Eoo`00@Goo0P00Pgoo90001goo900027oo00<000?/0n`07`?/
00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<0
06@OI1l086@O00<007ooOol01Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/00<0
07ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@O
I1l086@O00<007ooOol01Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/00<007oo
Ool01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@OI1l0
86@O00<007ooOol01Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol0
1Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@OI1l086@O
00<007ooOol01Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo
00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo0P00Pgoo90001goo00<0006O0Il0806O00<0
07ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol0[Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/00<007oo
Ool01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo00<0006O0Il0
806O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0[Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/
00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo0P00[Woo00<0006O0Il0
806O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0[Goo00<0006O0Il0806O00<007ooOol01Woo00<000?/0n`07`?/
00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo00<007ooOol0[Goo9000
27oo00<000?/0n`07`?/00<007ooOol01Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00@Goo
00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo
00<000?/0n`07`?/00D007ooOomoo`0001Moo`00;7oo0`000goo00<007ooOol00Woo00<007ooOol0
1goo00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol0
1Woo00<000?/0n`07`?/00D007ooOomoo`0001Moo`00;7oo00<007ooOol00Woo00<007oo00000Woo
00<007oo000027oo0`00[Goo00<006@OI1l086@O00<007ooOol01Woo8`0027oo00<000?/0n`07`?/
00D007ooOomoo`0001Moo`00;Goo00<007ooOol00goo00H007ooOol007oo0008Ool00`00Oomoo`2]
Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O
0n`01@00Oomoogoo00005goo000]Ool01000Oomoogoo0P000goo00<007oo000027oo00<007ooOol0
[Goo00<006@OI1l086@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo00<000?/0n`0
7`?/00D007ooOomoo`0001Moo`00;7oo00<007oo00000Woo00<007ooOol00Woo00<007oo000027oo
00<007ooOol0[Goo00<006@OI1l086@O00<007ooOol01Woo00<0006O0Il07`6O00<007ooOol01Woo
00<000?/0n`07`?/00D007ooOomoo`0001Moo`00;Goo00@007ooOomoo`<000=oo`03001oogoo00Mo
o`03001oogoo0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Io
o`030003k0?/01l3k005001oogooOol0000GOol0045oo`800:ioo`03001T7f@O021T7`03001oogoo
00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045o
o`03001oogoo0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Io
o`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0:eoo`03001T7f@O021T7`03
001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000G
Ool0045oo`03001oogoo0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001o
ogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`800:ioo`03001T7f@O021T7`03
001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000G
Ool0045oo`03001oogoo0:eoob@000Qoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3
k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`03
0003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001o
ogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O
01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`800=Yoo`030001
W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo
0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045o
o`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0
000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005
001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003
k0?/01l3k005001oogooOol0000GOol0045oo`800=Yoo`030001W`6O01l1W`03001oogoo00Ioo`03
0003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001o
ogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O
01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol002eoo`03001oogoo009o
o`03001oogoo009oo`03001oogoo00Moo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Io
ob<000=oo`03001oogoo01Eoo`00;7oo00<007oo00000Woo00<007oo00000Woo00<007oo000027oo
0`00fGoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00
;Woo00H007ooOol007oo0002Ool00`00Ool00008Ool00`00Oomoo`3IOol00`000Il1W`0O0Il00`00
Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000/Ool20003Ool00`00Ool00002Ool0
0`00Ool00008Ool00`00Oomoo`3IOol00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il0
1@00Oomoogoo00005goo000/Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool00008Ool00`00
Oomoo`3IOol00`000Il1W`0O0Il00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo
000/Ool30003Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`3IOol00`000Il1W`0O0Il0
0`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool2003JOol00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOolS
0008Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00
Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo
0011Ool2003JOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo0000
5goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00
Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool2003JOol00`00I1mT7`0OI1l00`00Oomo
o`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol0
0`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00
Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo
0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomo
ogoo00005goo0011Ool2003JOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00
Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000]Ool00`00Oomoo`02Ool00`00Oomoo`02Ool0
0`00Oomoo`07Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
1@00Oomoogoo00005goo000]Ool01`00Oomoogoo001oo`00009oo`03001oo`0000Qoo`03001oogoo
0=Uoo`03001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`05001oogooOol0000GOol002eo
o`03001oogoo00=oo`06001oogoo001oo`0027oo0`00fGoo00<006@OI1l07f@O00<007ooOol01Woo
00<0006O0Il07`6O00D007ooOomoo`0001Moo`00;Woo00<007ooOol00P000goo00<007oo000027oo
00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`00
01Moo`00;7oo00<007oo00000Woo00<007ooOol00Woo00<007oo000027oo00<007ooOol0fGoo00<0
06@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00;7oo0`000Woo
0`000goo00<007ooOol01goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00D007ooOomoo`0001Moo`00@Goo0P00fWoo00<006@OI1l07f@O00<007ooOol01Woo00<0
006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007oo
Ool01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l0
7f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo
00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Mo
o`00@Goo0P00fWoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D0
07ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol0
1Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O
00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`0067oo00<007ooOol00Woo00<0
07ooOol08Goo0P00fWoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomo
o`0001Moo`0067oo1P008goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00D007ooOomoo`0001Moo`006Goo0P000Woo00<007ooOol08Goo00<007ooOol0fGoo00<0
06@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`0067oo00<007oo
Ool00P0097oo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D0
07ooOomoo`0001Moo`0067oo1P008goo0P00fWoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00D007ooOomoo`0001Moo`006Woo00D007oo001oo`00029oo`03001oogoo0=Uoob<000Qo
o`030001W`6O01l1W`05001oogooOol0000GOol001Uoo`D002=oo`03001oogoo0?moo`Eoo`030001
W`6O01l1W`05001oogooOol0000GOol001Qoo`07001oo`00Ool007oo00008Woo00<007ooOol0ogoo
1Goo00<0006O0Il07`6O00D007ooOomoo`0001Moo`006Goo1@001goo1@000Woo00<007ooOol00Woo
00<007ooOol00Woo00<007ooOol027oo00<007ooOol0ogoo1Goo00<0006O0Il07`6O00D007ooOomo
o`0001Moo`0067oo00D007oo001oo`0000Yoo`07001oogooOol007oo00000Woo00<007oo00000Woo
00<007oo00002Goo0`00ogoo1Goo00<0006O0Il07`6O00D007ooOomoo`0001Moo`009goo00L007oo
Oomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00Oomoo`3oOol5Ool00`000Il1
W`0O0Il01@00Oomoogoo00005goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03
001oo`0000Uoo`03001oogoo0?moo`Eoo`030001W`6O01l1W`05001oogooOol0000GOol002Moo`07
001oogooOol007oo00000Woo00<007oo00000Woo00<007oo00002Goo00<007ooOol0ogoo1Goo00<0
006O0Il07`6O00D007ooOomoo`0001Moo`009Woo0P0017oo00<007ooOol00Woo00<007ooOol00Woo
00<007ooOol027oo00<007ooOol0ogoo1Goo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo
0P00ogoo1Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0ogoo1Goo00<0
006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol04Goo=`00_7oo00<0006O0Il07`6O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo>@00_7oo00<0006O0Il07`6O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<0006O0Il07`6O
00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol0=Goo00<007ooOol0^Woo00<0006O0Il0
7`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`09Goo00<007ooOol0
^Woo8`000goo00<007ooOol05Goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
O00;Ool2000HOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@
Ool00`00Oomoo`0@O00<Ool00`00Oomoo`0FOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@O006Ool20004Ool01`00Oomoo`00Ool0
07oo00D000eoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001o
ogoo00moo`03001oogoo011l00Qoo`0>001oogoo001oo`00Ool007oo001oo`00Ool0009oo`03001o
ogoo00Yoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo
00moo`03001oogoo011l00Moo`0?001oogooOol007oo001oo`00Ool007oo001oo`00009oo`03001o
ogoo00Yoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo
00moo`03001oogoo011l00Moo`800004Ool00000Ool4000017oo001oogoo0`003Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol047`05Goo00<0
07ooOol03Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007oo
Ool03goo00<007ooOol047`057oo0P003goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`09Goo00<007ooOol0^Woo00<006@OI1l0
7f@O00D007ooOomoo`0001Moo`009Goo1@0000Aoo`00000000=oo`03001oogoo009oo`03001oogoo
00Qoo`03001oogoo00moo`03001oogoo011l02Eoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001o
ogooOol0000GOol002Moo`05001oogooOol00004Ool00`00Ool00002Ool00`00Ool00009Ool00`00
Oomoo`0?Ool00`00Oomoo`0@O00UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo000WOol00`00Oomoo`02Ool00`00Oomoo`03Ool01P00Oomoo`00Ool000Uoo`<000moo`03001o
ogoo03Eoo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Moo`03001oogoo
009oo`04001oogooOol20003Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000WOol01`00Oomoogoo001oo`00009o
o`03001oogoo009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011Wh2Eoo`03001oogoo
0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Ioo`8000Aoo`04001oogooOol30003Ool0
0`00Oomoo`08Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0FOol2000=Ool00`00Oomoo`2jOol00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@In0HOol00`00Oomoo`0:
Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@In07Ool20002Ool30002Ool30003Ool3000<Ool00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In06Ool01000Oomoo`00
0Woo00<007ooOol00Woo00D007ooOomoo`00009oo`03001oogoo00Yoo`03001oogoo0;Yoo`03001T
7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo00moo`03001oogoo011Wh0Ioo`03001o
ogoo00=oo`03001oogoo009oo`05001oogooOol00002Ool00`00Oomoo`0:Ool00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In05Ool4
0002Ool400000goo00000004Ool3000<Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo
00005goo0011Ool2000@Ool00`00Oomoo`0@In06Ool00`00Oomoo`0LOol00`00Oomoo`2jOol00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0AOol00`00
Oomoo`0AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00
Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In0UOol00`00Oomoo`2jOol00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0eOol00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0@0n`UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0@0n`UOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool2000@Ool00`00Oomoo`0@0n`<Ool00`00Oomoo`0FOol00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`6Ool40002Ool01000
Oomoogoo10004Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol03goo00<007ooOol040?/1Woo0`0000=oo`0000000`000Woo00@007ooOol0011oo`03001o
ogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Eoo`D0009oo`03001oogoo009oo`03
001oogoo009oo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo0103k0Qoo`05001oogooOol0
0004Ool01000Oomoo`0047oo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00
9goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@0n`7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo000WOol00`00Oomoo`03Ool01P00Oomoo`00Ool0009oo`03001oo`00
00Uoo`<000moo`03001oogoo0103k15oo`03001oogoo015oo`03001oogoo0;Yoo`03001T7f@O01mT
7`05001oogooOol0000GOol002Moo`04001oogooOol20003Ool00`00Ool00002Ool00`00Ool00009
Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`@Ool2000COol00`00Oomoo`2jOol00`00I1mT7`0OI1l0
1@00Oomoogoo00005goo000WOol01@00Oomoogoo000017oo00<007oo00000Woo00<007oo00002Goo
00<007ooOol03goo00<007ooOol040?/9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`009Woo0P000goo0`000goo00<007ooOol00Woo00<007ooOol027oo00<007ooOol03goo
00<007ooOol040?/9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo
00<007ooOol03goo00<007ooOol040?/9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo0P0047oo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l0
7f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O
9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007oo
Ool0406O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007oo
Ool03goo00<007ooOol0406O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol0406O1Woo10001Woo10004Goo00<007ooOol0^Woo00<0
06@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O1Woo0`00
27oo00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045o
o`03001oogoo00moo`03001oogoo0101W`Qoo`03001oogoo00Ioo`04001oogoo000@Ool00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@0Il7Ool2
0002Ool00`00Ool00003Ool3000AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0Il<Ool00`00Oomoo`02Ool00`00Oomoo`0AOol0
0`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00
Oomoo`0@0Il<Ool01000Oomoogoo0P004goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0^Woo00<006@OI1l0
7f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O9Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol0=Goo00<007oo
Ool0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0
=Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol046@O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009Goo
1@000Woo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol027oo00<007ooOol03goo00<007oo
Ool046@O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009goo00<007oo
Ool00Woo00L007ooOomoo`00Ool00002Ool00`00Ool00009Ool3000?Ool00`00Oomoo`0@I1lUOol0
0`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000WOol00`00Oomoo`02Ool00`00
Oomoo`03Ool01P00Oomoo`00Ool000Uoo`03001oogoo00moo`03001oogoo011T7bEoo`03001oogoo
0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol002Moo`03001oogoo00=oo`03001oogoo0080
00=oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011T7`Ioo`@00004Ool007oo0002Ool4
000AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo000WOol01`00Oomoogoo
001oo`00009oo`03001oogoo009oo`03001oo`0000Uoo`03001oogoo00moo`03001oogoo011T7`Io
o`<000=oo`03001oogoo009oo`04001oogoo000@Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00
Oomoogoo00005goo000VOol20003Ool30002Ool30003Ool00`00Oomoo`08Ool00`00Oomoo`0?Ool0
0`00Oomoo`0@I1l8Ool00`00Oomoo`030003Ool01000Oomoo`0047oo00<007ooOol0^Woo00<006@O
I1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol046@O1goo0P000goo00<007oo
Ool00Woo0`004Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol03goo00<007ooOol046@O4Goo00<007ooOol04Goo00<007ooOol0^Woo00<006@OI1l07f@O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046@O47oo0P004goo00<007oo
Ool0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0
46@O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0
3goo00<007ooOol046@O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00
@Goo0P0047oo00<007ooOol046@O9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l07f@O00D0
07ooOomoo`0001Moo`00@Goo00<007ooOol03goo>@00_7oo00<006@OI1l07f@O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol0ogoo1Goo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P00
ogoo1Woo8`000goo00<007ooOol05Goo0011Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol0045o
o`03001oogoo0?moob]oo`03001oogoo01Eoo`00@Goo00<007ooOol0ogoo:goo00<007ooOol05Goo
0011Oooo000_000GOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo002XOol3000017oo001oogoo0P0000=oo`0000000Woo00<007oo0000
0P000Woo0`0000=oo`0000000Woo00<007ooOol00P000Woo100000Aoo`000000009oo`<000=oo`80
009oo`<000=oo`<0009oo`80009oo`<000=oo`800003Ool00000009oo`03001oogoo08Moo`00ZGoo
00H007oo000007oo0002Ool00`00Ool00002Ool01000Oomoo`0017oo00D007ooOomoo`00009oo`03
001oo`0000Aoo`<000=oo`07001oogooOol007oo00000Woo00@007ooOol0009oo`05001oogooOol0
0002Ool00`00Ool00002Ool01000Oomoo`000goo00H007ooOol007oo0002Ool00`00Oomoo`27Ool0
0:Uoo`06001oo`00001oo`000Woo00<007oo00000Woo00@007ooOol000Aoo`05001oogooOol00002
Ool00`00Ool000020004Ool01@00Oomoogoo00001Goo00@007ooOol0009oo`04001oogoo0003Ool0
1P00Oomoo`00Ool000Eoo`05001oogooOol00002Ool00`00Ool00002Ool00`00Oomoo`27Ool00:Uo
o`800004Ool007ooOol200000goo000000020003Ool01000Oomoogoo0P000Woo10000Woo0`000goo
0P000Woo10000Woo00<007ooOol00Woo0P000goo00<007ooOol00P0000=oo`00000010000Woo0P00
17oo0P0000=oo`0000000P00RWoo002YOol200000goo001oo`0;Ool00`00Oomoo`0JOol00`00Ool0
0008Ool00`00Oomoo`06Ool00`00Oomoo`2IOol00:Qoo`800003Ool0000000]oo`8000Aoo`03001o
ogoo01Eoo`<000Moo`8000ioo`03001oogoo09=oo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00ogooQgoo0000\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {607.813, 367.813}} -> {-1.56523, \
1.34012, 0.00540782, 0.00540782}, {{104.5, 474.313}, {602.063, 373.5}} -> \
{-3.23002, 3537.53, 0.0232398, 10.6999}, {{178.438, 233.938}, {469.313, \
395.313}} -> {-10.9028, 18.4931, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 56: ",
    FontWeight->"Bold"],
  "Anzahl der Operationen, die eine L\[ODoubleDot]sung des Sitnikovproblems \
in Abh\[ADoubleDot]ngigkeit des Systemparameters \[Lambda] darstellen."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Eine Beschreibung der Funktion ",
  StyleBox["MPLExpansio",
    FontSlant->"Italic"],
  "n, die diese Objekte erzeugt, kann in 5.3.9. gefunden werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:89"],

Cell["Kap. 3.3.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.11. InverseSigmaFunction",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:90"],

Cell["\<\
InverseSigmaFunction[n,m] berechnet die Umkehrtransformation zu der anhand \
der Poincar\[EAcute]-Lindstedt Methode gefundenen Zeitdehnungsfunktion \
SigmaFunction[n,m].\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:91"],

Cell["\<\
Die Poincar\[EAcute]-Lindstedt Methode oder Methode der gedehnten Koordinaten \
f\[UDoubleDot]hrt an einer Differentialgleichung zwei St\[ODoubleDot]rans\
\[ADoubleDot]tze durch. Einen f\[UDoubleDot]r die abh\[ADoubleDot]ngige, \
einen f\[UDoubleDot]r die unabh\[ADoubleDot]ngige Variable. Nach der Durchf\
\[UDoubleDot]hrung ist es notwendig, eine Umkehrtransformation zu der \
Zeitdehnungsfunktion resultierend von dem Ansatz zu finden, um die L\
\[ODoubleDot]sung in der alten Zeit darstellen zu k\[ODoubleDot]nnen. Hierf\
\[UDoubleDot]r ist es notwendig, eine St\[ODoubleDot]rreihe zu invertieren, \
was nach einem einfachen Schema durchgef\[UDoubleDot]hrt werden kann.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Die Umkehrung einer St\[ODoubleDot]rreihe erfolgt, indem die inverse \
Transformation als St\[ODoubleDot]rreihe angesetzt und in diese eingesetzt \
wird. Unter Vernachl\[ADoubleDot]ssigung h\[ODoubleDot]herer Ordnungen wird \
das daraus resultierende Gleichungssystem f\[UDoubleDot]r die einzelnen \
Ordnungen des St\[ODoubleDot]rparameters sukzessive gel\[ODoubleDot]st. \
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:92"],

Cell[TextData[{
  "Voraussetzung :",
  StyleBox[" PerturbativeSeries, SigmaFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(InverseSigmaFunction[n_Integer, 
          m_Integer] := \(Module[{x}, $Derivation = {x = SigmaFunction[n, m], 
                If[n \[Equal] 0, InverseSigmaFunction[0, 0] = \[Tau], 
                  InverseSigmaFunction[n, m] = 
                    InversePerturbativeSeries[x, \[Tau][\[Sigma]], 
                      m]]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\)\
,
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Die Funktion ",
  StyleBox["InverseSigmaFunction",
    FontSlant->"Italic"],
  " dient als Verwaltungsfunktion und ruft als eigentlichen Algorithmus die \
Funktion ",
  StyleBox["PerturbativeSeries",
    FontSlant->"Italic"],
  " auf, die auf jede beliebige St\[ODoubleDot]rreihe angewandt werden kann."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(InversePerturbativeSeries[ser_SeriesData, \[Psi]_[t_], 
          n_] := \(Module[{e = ser\[LeftDoubleBracket]1\[RightDoubleBracket], 
              x, xx, X}, $Derivation = {x = Normal[ser], 
                xx = Normal[PerturbativeSeries[t[\[Psi]], e, n]], 
                x = x /. \[InvisibleSpace]t \[Rule] xx, 
                x = Series[x, {e, 0, n}] \[Equal] \[Psi], 
                X = x\[LeftDoubleBracket]1, 3\[RightDoubleBracket], 
                X = {X\[LeftDoubleBracket]1\[RightDoubleBracket] \[Equal] \
\[Psi], Thread[Rest[X] \[Equal] 0]}, 
                x = Solve[
                    X\[LeftDoubleBracket]1\[RightDoubleBracket], \
\("\<Subscript\>"[t, 0]\)[\[Psi]]], X = Flatten[X /. \[InvisibleSpace]x], 
                X = Solve[X, 
                    Table[\("\<Subscript\>"[t, i]\)[\[Psi]], {i, 1, n}]], 
                X = Flatten[Append[X, x]], 
                x = xx /. \[InvisibleSpace]X, $Result = 
                  Series[x, {e, 0, 
                      n}]}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\)\
,
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "InversePerturbativeSeries[",
  StyleBox["ser,\[Psi][t],n",
    FontSlant->"Italic"],
  "] bestimmt die Inverse einer St\[ODoubleDot]rreihe ",
  StyleBox["ser",
    FontSlant->"Italic"],
  " der Form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              FormBox[\(\[Psi]\_0[t] + \[Psi]\_1[t]\),
                "TraditionalForm"], "\[Lambda]"}], 
            "+", \(\[Psi]\_2[t] \[Lambda]\^2\), "+"}], "..."}], 
        TraditionalForm]]],
  ", mit bekannten Funktionen ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_i\)]],
  ", bis zur Ordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O(\[Lambda]\^n)\)]],
  ". Das Resultat entspricht daher einer Reihenentwicklung um den selben \
Parameter \[Lambda] der Form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(t\_0[\[Psi]] + t\_1[\[Psi]] \[Lambda] + 
                t\_2[\[Psi]] \[Lambda]\^2 +  ... \),
            "TraditionalForm"], "+", \(O[\[Lambda]]\^n\)}], 
        TraditionalForm]]],
  ". Die unbekannten Koeffizientenfunktionen ",
  Cell[BoxData[
      \(TraditionalForm\`t\_i\)]],
  " werden bestimmt und ausgegeben. Die Funktion greift auf das Objekt ",
  StyleBox["PerturbativeSeries",
    FontSlant->"Italic"],
  " zu, welches nicht anderes als eine St\[ODoubleDot]rreihe mit unbekannten \
Koeffizienten um einen St\[ODoubleDot]rparameter bis zu einer bestimmten \
Ordnung definiert:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[GridBox[{
          {\(PerturbativeSeries[f_[x_], {e_, eo_}, {a_, o_}] := 
              SeriesData[e, eo, 
                Table[\("\<Subscript\>"[f, i]\)[x], {i, a, o + 1}], a, o + 1, 
                1]\)},
          {" "},
          {\(PerturbativeSeries[f_[x_], {e_, eo_}, o_] := 
              PerturbativeSeries[f[x], {e, eo}, {0, o}]\)},
          {" "},
          {\(PerturbativeSeries[f_[x_], e_, {a_, o_}] := 
              PerturbativeSeries[f[x], {e, 0}, {a, o}]\)},
          {" "},
          {\(PerturbativeSeries[f_[x_], e_, o_] := 
              PerturbativeSeries[f[x], {e, 0}, {0, o}]\)}
          },
        GridBaseline->{Baseline, {1, 1}},
        ColumnWidths->0.999,
        ColumnAlignments->{Left}],
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Der Algorithmus funktioniert f\[UDoubleDot]r beliebige \
St\[ODoubleDot]rreihen, die Berechnungszeit und Genauigkeit h\[ADoubleDot]ngt \
von der Komplexit\[ADoubleDot]t der Koeffizientenfunktionen der Eingabe ab.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:93"],

Cell["\<\
Die Bestimmung der Inversen t(\[Psi]) einer gegebenen St\[ODoubleDot]rreihe \
\[Psi](t) f\[UDoubleDot]hrt im Allgemeinen zu dem Problem, dass \
f\[UDoubleDot]r gro\[SZ]e Werte f\[UDoubleDot]r die unabh\[ADoubleDot]ngige \
Variable die Identit\[ADoubleDot]tsfunktion id = t(\[Psi](t)) = \[Psi](t(\
\[Psi]) um die erste Meridiane zu oszillieren beginnt. Die Genauigkeit ist \
daher durch den Abbruchfehler stark eingeschr\[ADoubleDot]nkt, das Ergebnis \
sollte sorgf\[ADoubleDot]ltig auf die Anwendbarkeit \[UDoubleDot]berpr\
\[UDoubleDot]ft werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:94"],

Cell["Kap. 3.4.1.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.12. Sigma",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:95"],

Cell[TextData[{
  "Sigma[n] berechnet die nichtlineare Phasenfunktion der L\[ODoubleDot]sung \
der Bewegungsgleichung des Sitnikov Problems bis zur Ordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O(\[Lambda]\^n)\)]],
  ". Die dort auftretende unabh\[ADoubleDot]ngige Variable \[Sigma] wird \
\[UDoubleDot]ber die Funktion in die Zeit t r\[UDoubleDot]cktransformiert."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:96"],

Cell["\<\
\[CapitalUDoubleDot]ber die inverse Zeitdehnungsfunktion, die von der Methode \
der gedehnten Koordinaten her r\[UDoubleDot]hrt, und der linearisierten \
Phasenfunktion, die mit Hilfe der Floquet Theorie hergeleitet wurde, wird die \
nicht lineare Phasenfunktion der L\[ODoubleDot]sung des Sitnikov Problems \
aufgestellt und nach den Einfluss der einzelnen Terme auf die \
L\[ODoubleDot]sung geordnet.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:97"],

Cell[TextData[{
  "Voraussetzung :",
  StyleBox[" InverseSigmaFunction, PhaseFunction",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(Sigma[
          n_] := \(Module[{x}, $Derivation = {x = 
                  ExpandAll[
                      Normal[\(InverseSigmaFunction[n, n]\[IndentingNewLine]
                          \(\(/.\)\(\[InvisibleSpace]\)\(\[Tau] \[Rule] \
\[Psi]\/\(2\ \@2\)\)\)\) /. \[InvisibleSpace]\[Psi] \[Rule] 
                            Normal[
                              PhaseFunction[
                                n]]]] /. \[InvisibleSpace]\[Lambda] \[Rule] 
                      1; x = x /. \[InvisibleSpace]{C[1] \[RuleDelayed] 
                        C[1]\ \[Lambda], C[2] \[RuleDelayed] C[2]\ \[Lambda], 
                      e \[RuleDelayed] e\ \[Lambda]}; 
                x = x /. \[InvisibleSpace]\[Lambda]\^m_ \[RuleDelayed] 
                      0 /; m > n; 
                x = x /. \[InvisibleSpace]\[Lambda] \[Rule] 1; 
                x = Collect[x, {t, Sin[_] | Cos[_], e}]; 
                x = x //. \[InvisibleSpace]a_\ C[1]\^p_ + a_\ C[2]\^p_ + 
                        b___ \[RuleDelayed] a\ \((C[1]\^p + C[2]\^p)\) + b, 
                Sigma[n] = 
                  x //. \[InvisibleSpace]a_\ C[1]\^p1_\ C[2]\^p2_ + 
                        a_\ C[1]\^p2_\ C[2]\^p1_ + b___ \[RuleDelayed] 
                      a\ \((C[1]\^p1\ C[2]\^p2 + C[1]\^p2\ C[2]\^p1)\) + 
                        b}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\)\
,
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Es handelt sich hier im Wesentlichen darum, Muster zu erkennen und zu \
ersetzen. Die Berechnungszeit, um diese Muster zu identifizieren, h\
\[ADoubleDot]ngt vor allem von dem Verfahren ab, welches von dem CAS \
verwendet wird.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:98"],

Cell["Kap. 3.4.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["5.3.13. SolutionOfLhotka",
  FontWeight->"Bold"]], "Subsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  FontSize->14,
  CellTags->"c:99"],

Cell[TextData[{
  "SolutionOfLhotka[n] berechnet die L\[ODoubleDot]sung der \
Bewegungsgleichung des Sitnikov Problems bis zur Ordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O(\[Lambda]\^n)\)]],
  ". Die unabh\[ADoubleDot]ngige Variable \[Sigma] wird \[UDoubleDot]ber die \
Funktion Sigma[n] in die alte Zeit t transformiert."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Mathematische Beschreibung",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:100"],

Cell["\<\
\[CapitalUDoubleDot]ber die Floquet Theorie wird die linearisierte \
Amplituden- und Phasenfunktion der L\[ODoubleDot]sung bestimmt und dazu \
verwendet, die Bewegungsgleichung anhand der Courant & Snyder Transformation \
in einen nichtlinear gest\[ODoubleDot]rten Oszillator \[UDoubleDot]berzuf\
\[UDoubleDot]hren. Diese wird mit der Methode von Poincar\[EAcute]-Lindstedt \
gel\[ODoubleDot]st, die Terme geordnet und in eine physikalisch relevante \
Form gebracht.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Implementation in Mathematica",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:101"],

Cell[TextData[{
  "Voraussetzung : ",
  StyleBox["AmplitudeFunction, NonlinearSolution",
    FontSlant->"Italic"]
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[BoxData[
    StyleBox[\(SolutionOfLhotka[
          n_Integer] := \(Module[{x}, $Derivation = {x = 
                  ExpandAll[
                    Normal[AmplitudeFunction[n]]\ Normal[
                          NonlinearSolution[n, 
                            n]] /. \[InvisibleSpace]\[Lambda] \[Rule] 1]; 
                x = x /. \[InvisibleSpace]{C[i_] \[RuleDelayed] 
                        C[i]\ \[Lambda], e \[RuleDelayed] e\ \[Lambda]}; 
                x = ExpandAll[x]; 
                x = x /. \[InvisibleSpace]\[Lambda]\^m_ \[RuleDelayed] 
                      0 /; m > n; 
                x = Collect[
                    x, {Cos[_\ \[Sigma]], Sin[_\ \[Sigma]], 
                      Cos[_ + _\ \[Sigma]], 
                      Sin[_ + _\ \[Sigma]], \[Lambda]}]; 
                x = x /. \[InvisibleSpace]a_\ \[Lambda] \[RuleDelayed] 
                      FullSimplify[a]\ \[Lambda]; 
                x = x /. \[InvisibleSpace]a_\ \[Lambda]\^i_ \[RuleDelayed] 
                      FullSimplify[a]\ \[Lambda]\^i; 
                x = x /. \[InvisibleSpace]amp_\ Cos[arg_] \[RuleDelayed] 
                      amp\ Cos[Expand[arg]]; 
                x = x /. \[InvisibleSpace]amp_\ Sin[arg_] \[RuleDelayed] 
                      amp\ Sin[Expand[arg]]; 
                SolutionOfLhotka[n] = 
                  x /. \[InvisibleSpace]\[Lambda] \[Rule] 
                      1}]\)\[LeftDoubleBracket]\(-1\)\[RightDoubleBracket]\),
      FontSize->10]], "Input",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Analyse",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:102"],

Cell["\<\
Die Funktion stellt die Ergebnisse der nicht linearen Analyse zusammen und \
gibt die L\[ODoubleDot]sung des Sitnikov Problems aus. Es werden ein letztes \
Mal die Terme nach ihrem Einfluss auf die L\[ODoubleDot]sung geordnet und der \
k\[UDoubleDot]nstliche St\[ODoubleDot]rparameter \[Lambda] durch die Identit\
\[ADoubleDot]t ersetzt.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["", "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 390 241.033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0714286 0.142857 0.0147151 0.00023966 [
[.07143 -0.0125 -4.78125 -11.625 ]
[.07143 -0.0125 4.78125 0 ]
[.21429 -0.0125 -4.78125 -11.625 ]
[.21429 -0.0125 4.78125 0 ]
[.35714 -0.0125 -4.78125 -11.625 ]
[.35714 -0.0125 4.78125 0 ]
[.5 -0.0125 -4.78125 -11.625 ]
[.5 -0.0125 4.78125 0 ]
[.64286 -0.0125 -4.78125 -11.625 ]
[.64286 -0.0125 4.78125 0 ]
[.78571 -0.0125 -4.78125 -11.625 ]
[.78571 -0.0125 4.78125 0 ]
[.92857 -0.0125 -4.78125 -11.625 ]
[.92857 -0.0125 4.78125 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -13.125 -23.25 ]
[.5 -0.0125 13.125 -11.625 ]
[-0.0125 .01472 -9.5625 -5.8125 ]
[-0.0125 .01472 0 5.8125 ]
[-0.0125 .13454 -20.6875 -5.8125 ]
[-0.0125 .13454 0 5.8125 ]
[-0.0125 .25437 -26.25 -5.8125 ]
[-0.0125 .25437 0 5.8125 ]
[-0.0125 .3742 -26.25 -5.8125 ]
[-0.0125 .3742 0 5.8125 ]
[-0.0125 .49403 -26.25 -5.8125 ]
[-0.0125 .49403 0 5.8125 ]
[-0.0125 .61386 -26.25 -5.8125 ]
[-0.0125 .61386 0 5.8125 ]
[ 0 0 -0.125 0 ]
[-0.01875 .30902 -37.875 -7.5625 ]
[-0.01875 .30902 -26.25 7.5625 ]
[ 0 .61803 .125 0 ]
[ 1 0 .125 0 ]
[.5 .63053 -46.5 0 ]
[.5 .63053 46.5 11.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07143 0 m
.07143 .00625 L
s
gsave
.07143 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.21429 0 m
.21429 .00625 L
s
gsave
.21429 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
1.000 setlinewidth
grestore
.35714 0 m
.35714 .00625 L
s
gsave
.35714 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
1.000 setlinewidth
grestore
.5 0 m
.5 .00625 L
s
gsave
.5 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
1.000 setlinewidth
grestore
.64286 0 m
.64286 .00625 L
s
gsave
.64286 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
1.000 setlinewidth
grestore
.78571 0 m
.78571 .00625 L
s
gsave
.78571 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
1.000 setlinewidth
grestore
.92857 0 m
.92857 .00625 L
s
gsave
.92857 -0.0125 -65.7813 -15.625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
s
gsave
.5 -0.0125 -74.125 -27.25 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def

63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(O) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
68.563 12.250 moveto
(H) show
74.125 12.250 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(l) show
%%IncludeResource: font Mathematica2Mono
%%IncludeFont: Mathematica2Mono
/Mathematica2Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.250 moveto
(L) show
85.250 12.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .01472 m
.00625 .01472 L
s
gsave
-0.0125 .01472 -70.5625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
0 .13454 m
.00625 .13454 L
s
gsave
-0.0125 .13454 -81.6875 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(500) show
1.000 setlinewidth
grestore
0 .25437 m
.00625 .25437 L
s
gsave
-0.0125 .25437 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1000) show
1.000 setlinewidth
grestore
0 .3742 m
.00625 .3742 L
s
gsave
-0.0125 .3742 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
1.000 setlinewidth
grestore
0 .49403 m
.00625 .49403 L
s
gsave
-0.0125 .49403 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2000) show
1.000 setlinewidth
grestore
0 .61386 m
.00625 .61386 L
s
gsave
-0.0125 .61386 -87.25 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2500) show
1.000 setlinewidth
grestore
.125 Mabswid
0 .03868 m
.00375 .03868 L
s
0 .06265 m
.00375 .06265 L
s
0 .08661 m
.00375 .08661 L
s
0 .11058 m
.00375 .11058 L
s
0 .15851 m
.00375 .15851 L
s
0 .18248 m
.00375 .18248 L
s
0 .20644 m
.00375 .20644 L
s
0 .23041 m
.00375 .23041 L
s
0 .27834 m
.00375 .27834 L
s
0 .30231 m
.00375 .30231 L
s
0 .32627 m
.00375 .32627 L
s
0 .35024 m
.00375 .35024 L
s
0 .39817 m
.00375 .39817 L
s
0 .42214 m
.00375 .42214 L
s
0 .4461 m
.00375 .4461 L
s
0 .47007 m
.00375 .47007 L
s
0 .518 m
.00375 .518 L
s
0 .54197 m
.00375 .54197 L
s
0 .56593 m
.00375 .56593 L
s
0 .5899 m
.00375 .5899 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
-0.01875 .30902 -100.625 -9.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
68.5625 9.8125 translate
90 rotate
-68.5625 -9.8125 translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(N) show
68.563 12.250 moveto
(#) show
74.125 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .61803 m
1 .61803 L
s
1 0 m
1 .61803 L
s
0 .01472 m
1 .01472 L
s
0 0 m
0 .61803 L
s
gsave
.5 .63053 -107.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.625 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(SolutionOfLhotka) show
152.000 12.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01429 .01472 m
.01429 .01519 L
.12857 .01519 L
.12857 .01472 L
F
0 g
.5 Mabswid
.01429 .01472 m
.01429 .01519 L
.12857 .01519 L
.12857 .01472 L
.01429 .01472 L
s
1 0 0 r
.15714 .01472 m
.15714 .01519 L
.27143 .01519 L
.27143 .01472 L
F
0 g
.15714 .01472 m
.15714 .01519 L
.27143 .01519 L
.27143 .01472 L
.15714 .01472 L
s
1 0 0 r
.3 .01472 m
.3 .01567 L
.41429 .01567 L
.41429 .01472 L
F
0 g
.3 .01472 m
.3 .01567 L
.41429 .01567 L
.41429 .01472 L
.3 .01472 L
s
1 0 0 r
.44286 .01472 m
.44286 .01759 L
.55714 .01759 L
.55714 .01472 L
F
0 g
.44286 .01472 m
.44286 .01759 L
.55714 .01759 L
.55714 .01472 L
.44286 .01472 L
s
1 0 0 r
.58571 .01472 m
.58571 .01999 L
.7 .01999 L
.7 .01472 L
F
0 g
.58571 .01472 m
.58571 .01999 L
.7 .01999 L
.7 .01472 L
.58571 .01472 L
s
1 0 0 r
.72857 .01472 m
.72857 .02286 L
.84286 .02286 L
.84286 .01472 L
F
0 g
.72857 .01472 m
.72857 .02286 L
.84286 .02286 L
.84286 .01472 L
.72857 .01472 L
s
1 0 0 r
.87143 .01472 m
.87143 .02622 L
.98571 .02622 L
.98571 .01472 L
F
0 g
.87143 .01472 m
.87143 .02622 L
.98571 .02622 L
.98571 .01472 L
.87143 .01472 L
s
.8 1 0 r
.01429 .01519 m
.01429 .01567 L
.12857 .01567 L
.12857 .01519 L
F
0 g
.01429 .01519 m
.01429 .01567 L
.12857 .01567 L
.12857 .01519 L
.01429 .01519 L
s
.8 1 0 r
.15714 .01519 m
.15714 .01615 L
.27143 .01615 L
.27143 .01519 L
F
0 g
.15714 .01519 m
.15714 .01615 L
.27143 .01615 L
.27143 .01519 L
.15714 .01519 L
s
.8 1 0 r
.3 .01567 m
.3 .01759 L
.41429 .01759 L
.41429 .01567 L
F
0 g
.3 .01567 m
.3 .01759 L
.41429 .01759 L
.41429 .01567 L
.3 .01567 L
s
.8 1 0 r
.44286 .01759 m
.44286 .02286 L
.55714 .02286 L
.55714 .01759 L
F
0 g
.44286 .01759 m
.44286 .02286 L
.55714 .02286 L
.55714 .01759 L
.44286 .01759 L
s
.8 1 0 r
.58571 .01999 m
.58571 .03101 L
.7 .03101 L
.7 .01999 L
F
0 g
.58571 .01999 m
.58571 .03101 L
.7 .03101 L
.7 .01999 L
.58571 .01999 L
s
.8 1 0 r
.72857 .02286 m
.72857 .04371 L
.84286 .04371 L
.84286 .02286 L
F
0 g
.72857 .02286 m
.72857 .04371 L
.84286 .04371 L
.84286 .02286 L
.72857 .02286 L
s
.8 1 0 r
.87143 .02622 m
.87143 .06241 L
.98571 .06241 L
.98571 .02622 L
F
0 g
.87143 .02622 m
.87143 .06241 L
.98571 .06241 L
.98571 .02622 L
.87143 .02622 L
s
0 1 .4 r
.01429 .01567 m
.01429 .01615 L
.12857 .01615 L
.12857 .01567 L
F
0 g
.01429 .01567 m
.01429 .01615 L
.12857 .01615 L
.12857 .01567 L
.01429 .01567 L
s
0 1 .4 r
.15714 .01615 m
.15714 .01711 L
.27143 .01711 L
.27143 .01615 L
F
0 g
.15714 .01615 m
.15714 .01711 L
.27143 .01711 L
.27143 .01615 L
.15714 .01615 L
s
0 1 .4 r
.3 .01759 m
.3 .01999 L
.41429 .01999 L
.41429 .01759 L
F
0 g
.3 .01759 m
.3 .01999 L
.41429 .01999 L
.41429 .01759 L
.3 .01759 L
s
0 1 .4 r
.44286 .02286 m
.44286 .03293 L
.55714 .03293 L
.55714 .02286 L
F
0 g
.44286 .02286 m
.44286 .03293 L
.55714 .03293 L
.55714 .02286 L
.44286 .02286 L
s
0 1 .4 r
.58571 .03101 m
.58571 .05881 L
.7 .05881 L
.7 .03101 L
F
0 g
.58571 .03101 m
.58571 .05881 L
.7 .05881 L
.7 .03101 L
.58571 .03101 L
s
0 1 .4 r
.72857 .04371 m
.72857 .10147 L
.84286 .10147 L
.84286 .04371 L
F
0 g
.72857 .04371 m
.72857 .10147 L
.84286 .10147 L
.84286 .04371 L
.72857 .04371 L
s
0 1 .4 r
.87143 .06241 m
.87143 .1772 L
.98571 .1772 L
.98571 .06241 L
F
0 g
.87143 .06241 m
.87143 .1772 L
.98571 .1772 L
.98571 .06241 L
.87143 .06241 L
s
0 .4 1 r
.01429 .01615 m
.01429 .01711 L
.12857 .01711 L
.12857 .01615 L
F
0 g
.01429 .01615 m
.01429 .01711 L
.12857 .01711 L
.12857 .01615 L
.01429 .01615 L
s
0 .4 1 r
.15714 .01711 m
.15714 .01855 L
.27143 .01855 L
.27143 .01711 L
F
0 g
.15714 .01711 m
.15714 .01855 L
.27143 .01855 L
.27143 .01711 L
.15714 .01711 L
s
0 .4 1 r
.3 .01999 m
.3 .0243 L
.41429 .0243 L
.41429 .01999 L
F
0 g
.3 .01999 m
.3 .0243 L
.41429 .0243 L
.41429 .01999 L
.3 .01999 L
s
0 .4 1 r
.44286 .03293 m
.44286 .04923 L
.55714 .04923 L
.55714 .03293 L
F
0 g
.44286 .03293 m
.44286 .04923 L
.55714 .04923 L
.55714 .03293 L
.44286 .03293 L
s
0 .4 1 r
.58571 .05881 m
.58571 .10339 L
.7 .10339 L
.7 .05881 L
F
0 g
.58571 .05881 m
.58571 .10339 L
.7 .10339 L
.7 .05881 L
.58571 .05881 L
s
0 .4 1 r
.72857 .10147 m
.72857 .19973 L
.84286 .19973 L
.84286 .10147 L
F
0 g
.72857 .10147 m
.72857 .19973 L
.84286 .19973 L
.84286 .10147 L
.72857 .10147 L
s
0 .4 1 r
.87143 .1772 m
.87143 .37205 L
.98571 .37205 L
.98571 .1772 L
F
0 g
.87143 .1772 m
.87143 .37205 L
.98571 .37205 L
.98571 .1772 L
.87143 .1772 L
s
.8 0 1 r
.01429 .01711 m
.01429 .01807 L
.12857 .01807 L
.12857 .01711 L
F
0 g
.01429 .01711 m
.01429 .01807 L
.12857 .01807 L
.12857 .01711 L
.01429 .01711 L
s
.8 0 1 r
.15714 .01855 m
.15714 .02047 L
.27143 .02047 L
.27143 .01855 L
F
0 g
.15714 .01855 m
.15714 .02047 L
.27143 .02047 L
.27143 .01855 L
.15714 .01855 L
s
.8 0 1 r
.3 .0243 m
.3 .03053 L
.41429 .03053 L
.41429 .0243 L
F
0 g
.3 .0243 m
.3 .03053 L
.41429 .03053 L
.41429 .0243 L
.3 .0243 L
s
.8 0 1 r
.44286 .04923 m
.44286 .06936 L
.55714 .06936 L
.55714 .04923 L
F
0 g
.44286 .04923 m
.44286 .06936 L
.55714 .06936 L
.55714 .04923 L
.44286 .04923 L
s
.8 0 1 r
.58571 .10339 m
.58571 .15899 L
.7 .15899 L
.7 .10339 L
F
0 g
.58571 .10339 m
.58571 .15899 L
.7 .15899 L
.7 .10339 L
.58571 .10339 L
s
.8 0 1 r
.72857 .19973 m
.72857 .31741 L
.84286 .31741 L
.84286 .19973 L
F
0 g
.72857 .19973 m
.72857 .31741 L
.84286 .31741 L
.84286 .19973 L
.72857 .19973 L
s
.8 0 1 r
.87143 .37205 m
.87143 .60332 L
.98571 .60332 L
.98571 .37205 L
F
0 g
.87143 .37205 m
.87143 .60332 L
.98571 .60332 L
.98571 .37205 L
.87143 .37205 L
s
MathSubEnd
P
% End of sub-graphic
0 g
.21905 .35187 m
.21905 .54235 L
.3619 .54235 L
.3619 .35187 L
F
1 g
.21429 .35664 m
.21429 .54711 L
.35714 .54711 L
.35714 .35664 L
F
0 g
.001 w
[ ] 0 setdash
.21429 .35664 m
.35714 .35664 L
.35714 .54711 L
.21429 .54711 L
.21429 .35664 L
s
% Start of sub-graphic
p
0.214286 0.356636 0.357143 0.547112 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0222222 0.222222 [
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
1 0 0 r
.05357 .04 m
.05357 .26222 L
.35119 .26222 L
.35119 .04 L
F
0 g
gsave
.38988 .15111 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(symb) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 1 0 r
.05357 .29778 m
.05357 .52 L
.35119 .52 L
.35119 .29778 L
F
0 g
gsave
.38988 .40889 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(trig) show
85.250 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 1 .4 r
.05357 .55556 m
.05357 .77778 L
.35119 .77778 L
.35119 .55556 L
F
0 g
gsave
.38988 .66667 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .4 1 r
.05357 .81333 m
.05357 1.03556 L
.35119 1.03556 L
.35119 .81333 L
F
0 g
gsave
.38988 .92444 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(^) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.8 0 1 r
.05357 1.07111 m
.05357 1.29333 L
.35119 1.29333 L
.35119 1.07111 L
F
0 g
gsave
.38988 1.18222 -61 -10.4375 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.875 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
68.563 13.000 moveto
%%IncludeResource: font Mathematica1Mono
%%IncludeFont: Mathematica1Mono
/Mathematica1Mono findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(*) show
74.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 9.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
79.688 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  CellLabel->"From (MathKernel5) In[223]:=",
  PageWidth->PaperWidth,
  TextJustification->1,
  ImageSize->{390, 241},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000660000lA000`40O003h00OogooQgoo003oOon7
Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00
eGoo00<007ooOol01Woo00<007ooOol0YGoo003DOol00`00Oomoo`08Ool00`00Oomoo`2TOol00<mo
o`80009oo`03001oogoo009oo`03001oogoo008000=oo`03001oogoo0:=oo`00cWoo00H007ooOol0
07oo0005Ool00`00Ool00004Ool00`00Oomoo`2SOol00<ioo`06001oogoo001oo`001Woo0P0017oo
00<007ooOol0Xgoo003>Ool01P00Oomoo`00Ool000Moo`03001oogoo009oo`03001oogoo0:=oo`00
cWoo00@007ooOol0009oo`03001oogoo00Aoo`05001oogooOol0002VOol00<moo`8000Aoo`04001o
ogooOol20003Ool00`00Oomoo`2UOol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogoo
Qgoo001DOol5000WOol3000XOol2000ZOol3000XOol00`00Oomoo`0WOol2000ZOol00`00Oomoo`0[
Ool005Ioo`03001oogoo02Moo`03001oogoo02Yoo`03001oogoo02Qoo`03001oogoo02Ioo`03001o
o`0002Qoo`03001oo`0002Uoo`03001oogoo02]oo`00EWoo00<007ooOol0:7oo00<007ooOol0:7oo
00<007ooOol09goo1000:Goo00<007ooOol09Woo00<007oo0000:Goo00<007ooOol0:goo001FOol0
0`00Oomoo`0XOol00`00Oomoo`0YOol00`00Oomoo`0VOol00`00Ool0000XOol2000YOol2000[Ool0
0`00Oomoo`0ZOol005Ioo`03001oogoo02Moo`03001oo`0002Qoo`03001oo`0002Uoo`8002Qoo`03
001oogoo02Qoo`03001oogoo02Qoo`03001oo`0002aoo`00EGoo0P00:Woo00<007ooOol0:7oo00<0
07ooOol0:Goo00<007ooOol09Woo0`00:Goo0P00:7oo0`00;7oo003oOon7Ool00?moohMoo`00ogoo
Qgoo003oOon7Ool00?moohMoo`00@Gooo`00;`005goo0011Ool00`00Oomoo`0COol00`00Oomoo`0X
Ool00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0XOol00`00Oomoo`0X
Ool00`00Oomoo`0BOol00`00Oomoo`0EOol0045oo`03001oogoo01=oo`03001oogoo02Qoo`03001o
ogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001oogoo02Qoo`03001o
ogoo019oo`03001oogoo01Eoo`00>7oo00<007ooOol01Woo00<007ooOol0ogoo:goo00<007ooOol0
5Goo000gOol00`00Ool00007Ool00`00Oomoo`3oOol[Ool00`00Oomoo`0EOol003Moo`03001oo`00
00Moool002l001Moo`00=goo00<007oo00001goo00@007ooOomoob@000Moob@000Moob@000Moob@0
00Moob@000Qoo`03001l07`001ml0003001oogoo00Ioo`03001l07`001ml0005001oogooOol0000G
Ool003Moo`03001oo`0000Moo`03001oogoo05Moo`030001W`6O0201W`03001oogoo00Eoob@000Mo
o`03001Wh6OP021Wh003001oogoo00Ioob<000Qoo`03001l07`001ml0005001oogooOol0000GOol0
03Qoo`03001oogoo00Ioo`03001oogoo05Moob@000Moo`030003k0?/0203k003001oogoo00Eoo`03
001Wh6OP021Wh003001oogoo00Ioo`03001Wh6OP01mWh003001oogoo00Ioob<000=oo`03001oogoo
01Eoo`00@Goo00<007ooOol0Egoo90001goo00<000?/0n`080?/00<007ooOol01Goo00<006OPIn00
86OP00<007ooOol01Woo00<006OPIn007fOP00<007ooOol01Woo00<006OPIn007fOP00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0PWoo90001goo900027oo00<006OPIn007fOP00<007ooOol01Woo
00<006OPIn007fOP00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<0006O0Il0806O00<0
07ooOol01Goo00<000?/0n`080?/00<007ooOol01Woo00<006OPIn007fOP00<007ooOol01Woo00<0
06OPIn007fOP00D007ooOomoo`0001Moo`00@Goo0P00Pgoo00<0006O0Il0806O00<007ooOol01Goo
00<000?/0n`080?/00<007ooOol01Woo00<006OPIn007fOP00<007ooOol01Woo00<006OPIn007fOP
00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<0006O0Il0806O00<007ooOol01Goo00<0
00?/0n`080?/00<007ooOol01Woo8`0027oo00<006OPIn007fOP00D007ooOomoo`0001Moo`00@Goo
00<007ooOol0PWoo00<0006O0Il0806O00<007ooOol01Goo00<000?/0n`080?/00<007ooOol01Woo
00<000?/0n`07`?/00<007ooOol01Woo00<006OPIn007fOP00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol0PWoo90001goo00<000?/0n`080?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol0
1Woo00<006OPIn007fOP00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@OI1l086@O
00<007ooOol01Goo00<000?/0n`080?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo
00<006OPIn007fOP00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@OI1l086@O00<0
07ooOol01Goo00<000?/0n`080?/00<007ooOol01Woo00<000?/0n`07`?/00<007ooOol01Woo00<0
06OPIn007fOP00D007ooOomoo`0001Moo`00@Goo00<007ooOol0PWoo00<006@OI1l086@O00<007oo
Ool01Goo900027oo00<000?/0n`07`?/00<007ooOol01Woo00<006OPIn007fOP00D007ooOomoo`00
01Moo`00@Goo0P00Pgoo00<006@OI1l086@O00<007ooOol01Goo00<0006O0Il0806O00<007ooOol0
1Woo00<000?/0n`07`?/00<007ooOol01Woo8`000goo00<007ooOol05Goo0011Ool00`00Oomoo`22
Ool00`00I1mT7`0PI1l00`00Oomoo`05Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O
0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`22OolT
0007Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3
k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`000Il1W`0P0Il00`00Oomoo`06
Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool0
0`00Oomoo`2]Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool0
0`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`000Il1W`0P0Il00`00
Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo
0011Ool00`00Oomoo`2]Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool2002^Ool00`000Il1W`0P0Il00`00
Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo
0011Ool00`00Oomoo`2]Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomo
o`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`000Il1W`0P
0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo
00005goo0011Ool00`00Oomoo`2]Ool00`000Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
0`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00
0Il1W`0P0Il00`00Oomoo`06Ool00`000n`3k00O0n`00`00Oomoo`06Ool00`000n`3k00O0n`01@00
Oomoogoo00005goo0011Ool00`00Oomoo`2]OolT0008OolS0008Ool00`000n`3k00O0n`01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool0
0`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
1@00Oomoogoo00005goo0011Ool2002^Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O
0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool0
0`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`00
0Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomo
o`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3
k00O0n`01@00Oomoogoo00005goo0011Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l00`00Oomoo`06
Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo00005goo000]Ool0
0`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`07Ool00`00Oomoo`2]Ool00`00I1mT7`0PI1l0
0`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00Oomoogoo0000
5goo000/Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00008Ool00`00Oomoo`2]Ool00`00
I1mT7`0PI1l00`00Oomoo`06Ool00`000Il1W`0O0Il00`00Oomoo`06Ool00`000n`3k00O0n`01@00
Oomoogoo00005goo000^Ool01P00Oomoo`00Ool0009oo`03001oo`0000Qoo`<00:eoo`03001T7f@O
021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogoo
Ool0000GOol002aoo`8000=oo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo0:eoo`03001T
7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001o
ogooOol0000GOol002aoo`03001oogoo009oo`03001oo`00009oo`03001oo`0000Qoo`03001oogoo
0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/
01l3k005001oogooOol0000GOol002aoo`<000=oo`03001oogoo009oo`03001oogoo00Moo`03001o
ogoo0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003
k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0:eoo`03001T7f@O021T7`03001oogoo
00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045o
o`03001oogoo0:eoo`03001T7f@O021T7`03001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Io
o`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0:eoo`03001T7f@O021T7`03
001oogoo00Ioo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000G
Ool0045oo`800:ioob@000Qoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001o
ogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/
01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Io
o`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001W`6O01l1W`03
001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo0=Uoo`030001
W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045oo`03001oogoo
0=Uoo`030001W`6O01l1W`03001oogoo00Ioo`030003k0?/01l3k005001oogooOol0000GOol0045o
o`03001oogoo0=Uoo`030001W`6O01l1W`03001oogoo00Ioob<000=oo`03001oogoo01Eoo`00@Goo
0P00fWoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00
@Goo00<007ooOol0fGoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol0fGoo00<0006O0Il07`6O00<007ooOol01Woo00<0006O0Il07`6O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<0006O0Il07`6O00<007ooOol01Woo00<0
006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<0006O0Il07`6O00<007oo
Ool01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo8`0027oo00<0
006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007oo
Ool01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo0P00fWoo00<006@OI1l07f@O00<0
07ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@O
I1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0
fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo
00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D0
07ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O
0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol0
1Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O
00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo0P00fWoo00<006@OI1l0
7f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0fGoo
00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il0
7`6O00D007ooOomoo`0001Moo`009Goo1@000Woo00<007ooOol00Woo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007oo
Oomoo`0001Moo`009goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool0
0`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo0000
5goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00009oo`03001oo`0000Uoo`<00=Uoo`03
001T7f@O01mT7`03001oogoo00Ioo`030001W`6O01l1W`05001oogooOol0000GOol002Moo`07001o
ogooOol007oo00000Woo00<007oo00000Woo00<007oo00002Goo00<007ooOol0fGoo00<006@OI1l0
7f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`009goo00L007ooOomoo`00
Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000VOol20004Ool00`00Oomoo`02Ool0
0`00Oomoo`02Ool00`00Oomoo`08Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool0
0`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00
Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT
7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3I
Ool00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011Ool2
003JOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo0011
Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`00
0Il1W`0O0Il01@00Oomoogoo00005goo0011Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomo
o`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000HOol00`00Oomoo`02Ool00`00Oomoo`0Q
Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo000HOol6000SOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il01@00Oomoogoo00005goo000IOol20002Ool00`00Oomoo`0QOol2003JOol00`00I1mT7`0O
I1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo00005goo000HOol00`00Oomoo`02000T
Ool00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo000HOol6000SOol00`00Oomoo`3IOol00`00I1mT7`0OI1l00`00Oomoo`06Ool00`000Il1
W`0O0Il01@00Oomoogoo00005goo000JOol01@00Ool007oo00008Woo00<007ooOol0fGoo00<006@O
I1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`006Goo1@008goo00<0
07ooOol0fGoo00<006@OI1l07f@O00<007ooOol01Woo00<0006O0Il07`6O00D007ooOomoo`0001Mo
o`0067oo00L007oo001oo`00Ool0000ROol00`00Oomoo`3IOolS0008Ool00`000Il1W`0O0Il01@00
Oomoogoo00005goo000IOol5000SOol00`00Oomoo`3oOol5Ool00`000Il1W`0O0Il01@00Oomoogoo
00005goo000HOol01@00Ool007oo000097oo00<007ooOol0ogoo1Goo00<0006O0Il07`6O00D007oo
Oomoo`0001Moo`00@Goo0P00ogoo1Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol0ogoo1Goo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0ogoo1Goo
00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0ogoo1Goo00<0006O0Il07`6O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol0ogoo1Goo00<0006O0Il07`6O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol0ogoo1Goo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<0
07ooOol04Goo=`00_7oo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo0P0047oo>@00_7oo
00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<0
07ooOol0^Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007oo
Ool0=Goo00<007ooOol0^Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00@Goo00<007ooOol0
3goo00<007ooOol047`09Goo00<007ooOol0^Woo00<0006O0Il07`6O00D007ooOomoo`0001Moo`00
@Goo00<007ooOol03goo00<007ooOol047`09Goo00<007ooOol0^Woo00<0006O0Il07`6O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`02goo0P0067oo00<007ooOol0^Woo
00<0006O0Il07`6O00D007ooOomoo`0001Moo`009Goo1@000Woo00<007ooOol00Woo00<007ooOol0
0Woo00<007ooOol027oo00<007ooOol03goo00<007ooOol047`037oo00<007ooOol05Woo00<007oo
Ool0^Woo8`000goo00<007ooOol05Goo000WOol01`00Oomoogoo001oo`00009oo`03001oo`00009o
o`03001oo`0000Uoo`<000moo`03001oogoo011l00Ioo`8000Aoo`07001oogoo001oo`00Ool01@00
3Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`009goo00<007ooOol00goo
00H007ooOol007oo0002Ool00`00Ool00009Ool00`00Oomoo`0?Ool00`00Oomoo`0@O008Ool03P00
Oomoo`00Ool007oo001oo`00Ool007oo0002Ool00`00Oomoo`0:Ool00`00Oomoo`2jOol00`00I1mT
7`0OI1l01@00Oomoogoo00005goo000WOol01000Oomoogoo0P000goo00<007oo00000Woo00<007oo
00002Goo00<007ooOol03goo00<007ooOol047`01goo00l007ooOomoo`00Ool007oo001oo`00Ool0
07oo00000Woo00<007ooOol02Woo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Mo
o`009goo00D007ooOomoo`0000Aoo`03001oo`00009oo`03001oo`0000Uoo`03001oogoo00moo`03
001oogoo011l00Moo`800004Ool00000Ool4000017oo001oogoo0`003Goo00<007ooOol0^Woo00<0
06@OI1l07f@O00D007ooOomoo`0001Moo`009Woo0P000goo0`000goo00<007ooOol00Woo00<007oo
Ool027oo00<007ooOol03goo00<007ooOol047`05Goo00<007ooOol03Goo00<007ooOol0^Woo00<0
06@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol047`057oo0P00
3goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol047`09Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo
0P0047oo00<007ooOol047`09Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol047`09Goo00<007ooOol0^Woo00<006@OI1l07f@O00D0
07ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@O
I1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP
9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol046OP5Woo0P003Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol046OP67oo00<007ooOol02Woo00<007ooOol0^Woo00<0
06@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol046OP1goo0P000Woo0`00
0Woo0`000goo0`0037oo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo
00<007ooOol03goo00<007ooOol046OP1Woo00@007ooOol0009oo`03001oogoo009oo`05001oogoo
Ool00002Ool00`00Oomoo`0:Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@In06Ool00`00Oomoo`03Ool00`00Oomoo`02Ool01@00
Oomoogoo00000Woo00<007ooOol02Woo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`00
01Moo`00@Goo00<007ooOol03goo00<007ooOol046OP1Goo10000Woo100000=oo`00000017oo0`00
37oo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol046OP1Woo00<007ooOol077oo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP4Goo00<007ooOol04Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol046OP
9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol046OP9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo
0P0047oo00<007ooOol046OP9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Mo
o`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l0
7f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/9Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/
9Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo
00<007ooOol040?/37oo00<007ooOol05Woo00<007ooOol0^Woo00<006@OI1l07f@O00D007ooOomo
o`0001Moo`00@Goo00<007ooOol03goo00<007ooOol040?/1Woo10000Woo00@007ooOomoo`@0015o
o`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`80011oo`03001oogoo
0103k0Ioo`<00003Ool0000000<0009oo`04001oogoo000@Ool00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0n`8Ool01@00Oomoogoo
000017oo00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0
045oo`03001oogoo00moo`03001oogoo0103k0Moo`8000=oo`03001oogoo009oo`<0015oo`03001o
ogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo00moo`03001oogoo
0103k15oo`03001oogoo015oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0
045oo`03001oogoo00moo`03001oogoo0103k11oo`8001=oo`03001oogoo0;Yoo`03001T7f@O01mT
7`05001oogooOol0000GOol0045oo`03001oogoo00moo`03001oogoo0103k2Eoo`03001oogoo0;Yo
o`03001T7f@O01mT7`05001oogooOol0000GOol002Ioo`<000=oo`03001oogoo009oo`03001oogoo
009oo`03001oogoo00Qoo`03001oogoo00moo`03001oogoo0103k2Eoo`03001oogoo0;Yoo`03001T
7f@O01mT7`05001oogooOol0000GOol002Ioo`03001oogoo009oo`03001oo`00009oo`03001oo`00
009oo`03001oo`0000Uoo`<000moo`03001oogoo0103k2Eoo`03001oogoo0;Yoo`03001T7f@O01mT
7`05001oogooOol0000GOol002Moo`07001oogooOol007oo00000Woo00<007oo00000Woo00<007oo
00002Goo00<007ooOol03goo00<007ooOol0=Goo00<007ooOol0^Woo00<006@OI1l07f@O00D007oo
Oomoo`0001Moo`009goo00L007ooOomoo`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool0
0`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo000VOol00`00Ool00002Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool00`00
Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo000WOol00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`08Ool00`00
Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo0000
5goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l0
1@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol0
0`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@0Il6Ool40006Ool4
000AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0@0Il6Ool30008Ool01000Oomoo`0047oo00<007ooOol0^Woo00<006@OI1l07f@O
00D007ooOomoo`0001Moo`00@Goo00<007ooOol03goo00<007ooOol0406O27oo00<007ooOol01Woo
00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03
001oogoo00moo`03001oogoo0101W`Moo`80009oo`03001oo`0000=oo`<0015oo`03001oogoo0;Yo
o`03001T7f@O01mT7`05001oogooOol0000GOol0045oo`03001oogoo00moo`03001oogoo0101W`ao
o`03001oogoo009oo`03001oogoo015oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogooOol0
000GOol0045oo`03001oogoo00moo`03001oogoo0101W`aoo`04001oogooOol2000COol00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0@0IlUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool2000@Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo
0011Ool00`00Oomoo`0?Ool00`00Oomoo`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomo
ogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT
7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomo
o`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@
I1lUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011
Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1l6Ool4000017oo001oo`000Woo10004Goo00<007ooOol0
^Woo00<006@OI1l07f@O00D007ooOomoo`0001Moo`00@Goo0P0047oo00<007ooOol046@O1Woo0`00
0goo00<007ooOol00Woo00@007ooOol0011oo`03001oogoo0;Yoo`03001T7f@O01mT7`05001oogoo
Ool0000GOol0045oo`03001oogoo00moo`03001oogoo011T7`Qoo`03001oogoo00<000=oo`04001o
ogoo000@Ool00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0@I1l7Ool20003Ool00`00Oomoo`02Ool3000AOol00`00Oomoo`2jOol00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lAOol00`00
Oomoo`0AOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomo
o`0?Ool00`00Oomoo`0@I1l@Ool2000COol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo
00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2jOol00`00I1mT7`0O
I1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomoo`0@I1lUOol00`00Oomoo`2j
Ool00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool2000@Ool00`00Oomoo`0@I1lUOol00`00
Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?Ool00`00Oomo
o`0eOol00`00Oomoo`2jOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`0?
Ooli002lOol00`00I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5Ool00`00
I1mT7`0OI1l01@00Oomoogoo00005goo0011Ool00`00Oomoo`3oOol5OolS0003Ool00`00Oomoo`0E
Ool0045oo`03001oogoo0?moob]oo`03001oogoo01Eoo`009Woo0`000goo00<007ooOol00Woo00<0
07ooOol00Woo00<007ooOol027oo00<007ooOol0ogoo:goo00<007ooOol05Goo000VOol00`00Oomo
o`02Ool00`00Ool00002Ool00`00Ool00002Ool00`00Ool00009Ool3003oOol[Ool00`00Oomoo`0E
Ool002Moo`03001oogoo00=oo`06001oogoo001oo`000Woo00<007oo00002Gooo`00;`005goo000W
Ool01000Oomoogoo0P000goo00<007oo00000Woo00<007oo0000ogooCgoo000VOol00`00Ool00002
Ool00`00Oomoo`02Ool00`00Ool00002Ool00`00Ool0003oOom?Ool002Moo`04001oogooOol30003
Ool00`00Oomoo`02Ool00`00Oomoo`3oOom>Ool00?moohMoo`00ogooQgoo003oOon7Ool00?moohMo
o`00ogooQgoo002/Ool30003Ool20002Ool30003Ool30002Ool20002Ool30003Ool200000goo0000
0002Ool00`00Oomoo`020002Ool300000goo00000006000017oo001oogoo0P000goo0P0000Aoo`00
001oo`800003Ool00000008008]oo`00[7oo00<007oo00000Woo00@007ooOol0009oo`05001oogoo
Ool00002Ool00`00Ool00002Ool01000Oomoo`000goo00H007ooOol007oo0002Ool00`00Ool00002
Ool01000Oomoo`000goo00H007ooOol007oo0002Ool00`00Ool00002Ool00`00Ool00002Ool01@00
Ool007oo00000Woo0`00S7oo002^Ool01000Oomoo`000Woo00@007ooOol000=oo`06001oogoo001o
o`001Goo00D007ooOomoo`00009oo`03001oo`00009oo`03001oo`00009oo`04001oogoo0003Ool0
0`00Oomoo`02Ool01P00Oomoo`00Ool0009oo`03001oo`0000Aoo`<000Aoo`03001oogoo08Yoo`00
[Goo00<007ooOol00Woo0P000goo00<007ooOol00P0000=oo`00000010000Woo0P0017oo0P0000=o
o`0000000P000Woo00D007ooOol007oo00<0009oo`03001oogoo009oo`<000=oo`800003Ool00000
0080009oo`04001oo`000002Ool2002<Ool00:aoo`03001oo`0000Qoo`03001oogoo00Ioo`03001o
ogoo015oo`04001oogoo0002Ool01@00Oomoogoo000017oo00<007ooOol01goo00<007ooOol00Woo
00<007ooOol0TGoo002/Ool30007Ool2000>Ool00`00Oomoo`0<Ool20004Ool00`00Ool000020002
Ool2000=Ool2002COol00?moohMoo`00ogooQgoo003oOon7Ool00?moohMoo`00ogooQgoo003oOon7
Ool00?moohMoo`00\
\>"],
  ImageRangeCache->{{{94.9375, 483.938}, {301.938, 61.9375}} -> {-1.56523, \
-0.313996, 0.00540782, 0.00540782}, {{104.5, 474.313}, {296.188, 67.625}} -> \
{-3.23002, 342.707, 0.0232398, 13.8528}, {{178.438, 233.938}, {163.438, \
89.4375}} -> {-10.9028, -6.30788, 0.0605412, 0.081082}}],

Cell[TextData[{
  StyleBox["Grafik 57: ",
    FontWeight->"Bold"],
  "Anzahl der von SolutionOfLhotka erzeugten Terme und Operationen, die \
notwendig sind, um einen Funktionswert zu berechnen. Die Anzahl der \
Operationen w\[ADoubleDot]chst exponentiell an, der \
L\[ODoubleDot]sungsmethode ist daher eine obere Schranke aufgrund der \
Berechenbarkeit gesetzt."
}], "Caption",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Schon f\[UDoubleDot]r die 7. Ordnung in \[Lambda] sind ~2500 Operationen \
notwendig, um einen Punkt der Bahn des Sitnikov Problems zu \
l\[ODoubleDot]sen. Der Sinn der verwendeten St\[ODoubleDot]rungstheorie liegt \
weniger darin, einen Zahlenwert zu einem Zeitpunkt t auszugeben, als vielmehr \
die Abh\[ADoubleDot]ngigkeiten der Systemparameter zu studieren, wie es in \
Kapitel 4 auch ansatzweise getan wird. Auch wenn es theoretisch \
m\[ODoubleDot]glich w\[ADoubleDot]re, die in dieser Arbeit entstandenen \
Algorithmen dazu zu verwenden, L\[ODoubleDot]sungen h\[ODoubleDot]herer \
Ordnungen zu erzeugen, scheint dies in Angesicht von Grafik 57 nicht \
sinnvoll. Zu viele Terme werden produziert und der Zuwachs in der Genauigkeit \
l\[ADoubleDot]ge au\[SZ]erhalb des Bereichs, in dem die polynomische \
Approximation funktioniert.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Vorkommen",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  TextJustification->1,
  CellTags->"c:103"],

Cell["Kap. 3.4.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["5.4. Weitere Objekte des SDS", "Subsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:104"],

Cell[TextData[{
  "Die Definitionen der weiteren Objekte des ",
  StyleBox["Sitnikov Derivation System ",
    FontSlant->"Italic"],
  "finden sich auf der beiliegenden CD wieder. Ihre Verwendung sollte anhand \
der Namensgebung ersichtlich sein, im Folgenden werden die wichtigsten von \
ihnen noch einmal zusammengestellt und eine kurze Beschreibung angef\
\[UDoubleDot]hrt. Diese kann auch \[UDoubleDot]ber den in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " zur Verf\[UDoubleDot]gung gestellten Operator ",
  StyleBox["?name",
    FontSlant->"Italic"],
  " abgerufen werden."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[CellGroupData[{

Cell["AmplitudeSet", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:105"],

Cell[TextData[{
  "AmplitudeSet[N] erstellt die Menge der nichtlinearen Amplitudenfunktionen \
{",
  Cell[BoxData[
      \(TraditionalForm\`A\_k\)]],
  "},  k = 1..N, wobei die Indizierung mit jener aus Abschnitt 3.4. konform \
geht."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Coefficient",
  FontWeight->"Bold"]], "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:106"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Coefficient[e, z\_0, v\_0]\)]],
  " bestimmt den numerischen Wert der Konstanten C[1] und C[2] anhand der \
Systemkonfiguration, definiert durch die Exzentrizit\[ADoubleDot]t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(e\)\(,\)\)\)]],
  " der Anfangsamplitude ",
  Cell[BoxData[
      \(TraditionalForm\`z\_0\)]],
  " und der Anfangsgeschwindigkeit ",
  Cell[BoxData[
      \(TraditionalForm\`v\_0\)]],
  " des dritten K\[ODoubleDot]rpers."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["CourantSnyderTransform", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:107"],

Cell["\<\
CourantSnyderTransform wird in 5.5.3. beschrieben. Die Funktion \
f\[UDoubleDot]hrt die Courant & Snyder Transformation an allgemeinen \
Differentialgleichungen durch.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["CtoKLM", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:108"],

Cell[TextData[{
  "CtoKLM[i,j] ersetzt die auftretenden Konstanten C[1] und C[2] durch jene, \
wie sie in Kapitel  3.4.2. anhand (131.1-131.5) definiert sind. \
F\[UDoubleDot]r den Fall ",
  Cell[BoxData[
      \(TraditionalForm\`A\_k\)]],
  " sind i = 1 und j = 2, f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`B\_k\)]],
  " ist i = 2 und j = 1  zu setzen."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["DifferentialOrder", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:109"],

Cell[TextData[{
  "DifferentialOrder[expr] wird in vielen Funktionen des SDS verwendet und \
bestimmt die h\[ODoubleDot]chste auftretende Ableitung in einem Ausdruck ",
  StyleBox["expr",
    FontSlant->"Italic"],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["FrequencySet", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:110"],

Cell[TextData[{
  "FrequencySet[N] erstellt die Menge der nichtlinearen Phasenfunktionen ",
  Cell[BoxData[
      \(TraditionalForm\`{\[Psi]\_k}, \ k\  = \ 1.  . N\)]],
  ", wobei die Indizierung mit jener aus Abschnitt 3.4. konform geht."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["GetResults", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:111"],

Cell["\<\
GetResults l\[ADoubleDot]dt die vorberechneten Ergebnisse dieser Arbeit in \
den Arbeitsspeicher und weist sie den entsprechenden Objekten zu.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["InhomogenPart", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:112"],

Cell["\<\
InhomogenPart wird f\[UDoubleDot]r mehrere Funktionen verwendet und \
extrahiert den inhomogenen Anteil einer Differentialgleichung.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["InversePerturbativeSeries", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:113"],

Cell[TextData[{
  "InversePerturbativeSeries[ser,y[x],n] erstellt zu einer \
St\[ODoubleDot]rreihe ser der Form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(y\_0[x] + y\_1[x]\ \[Lambda]\)\(+\)\) ... \) + 
        O[\[Lambda]]\^m\)]],
  " die Umkehrtransformation x[y] der Ordnung n in Form einer \
St\[ODoubleDot]rreihe ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(x\_0[y] + x\_1[y]\ \[Lambda]\)\(+\)\) ... \) 
        O[\[Lambda]]\^n\)]],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["KeplerSolution", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:114"],

Cell["\<\
KeplerSolution[n] gibt die iterierte Form der L\[ODoubleDot]sung der \
transzendenten Keplergleichung wieder.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["KLMtoC", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:115"],

Cell[TextData[{
  "KLMtoC[i,j] ersetzt die in Abschnitt 3.4.2. definierten Konstanten ",
  Cell[BoxData[
      \(TraditionalForm\`K\_p\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L\_p\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`M\_p\)]],
  " durch jene, in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " verwendeten C[1] und C[2]. Wird die Funktion f\[UDoubleDot]r ",
  Cell[BoxData[
      \(TraditionalForm\`A\_k\)]],
  " angewendet, so sind i = 1 und j = 2 zu setzen. F\[UDoubleDot]r die \
Amplitudefunktionen ",
  Cell[BoxData[
      \(TraditionalForm\`B\_k\)]],
  " umgekehrt (i = 2, j = 1)."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["LinearEquation", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:116"],

Cell[TextData[{
  "LinearEquation[N] gibt die linearisierte Bewegungsgleichung des Sitnikov \
Problems der Ordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O(e\^N)\)]],
  " wieder."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["ParticularDSolve", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:117"],

Cell["\<\
ParticularDSolve ist der Kern des Algorithmus AmplitudeFunction und wird auch \
dort (5.4.4.) beschrieben.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["PerturbativeSeries", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:118"],

Cell[TextData[{
  "PerturbativeSeries[f[x],\[Lambda],N] erstellt das Objekt ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_0[x] + f\_1[x]\ \[Lambda]\)\(+\)\) ... \) 
        O[\[Lambda]]\^\(N + 1\)\)]],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rewrite", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:119"],

Cell["Rewrite[equ] setzt eine Gleichung gleich Null.", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["SignSet", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:120"],

Cell[TextData[{
  "SignSet[N] erstellt die Menge der Vorzeichenfunktionen {",
  Cell[BoxData[
      \(TraditionalForm\`sgn[k]\)]],
  "}, k = 1,..,N, wobei die Indizierung mit jener aus Abschnitt 3.4. konform \
geht."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution\.b4A", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:121"],

Cell[TextData[{
  "Solution\.b4A[k] gibt ",
  Cell[BoxData[
      \(TraditionalForm\`A\_k\)]],
  ", definiert in Abschnitt 3.4. wieder."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution\.b4B", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:122"],

Cell[TextData[{
  "Solution\.b4B[k] gibt ",
  Cell[BoxData[
      \(TraditionalForm\`B\_k\)]],
  ", definiert in Abschnitt 3.4. wieder."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution\.b4Psi", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:123"],

Cell[TextData[{
  "Solution\.b4Psi[k] gibt ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_k\)]],
  ", definiert in Abschnitt 3.4. wieder."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solution\.b4z", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:124"],

Cell["\<\
Solution\.b4z[N] gibt die L\[ODoubleDot]sung der Bewegungsgleichung des \
Sitnikov Problems in den Variablen z und t mit noch nicht bestimmten \
Konstanten C[1] und C[2] der Ordnung N wieder.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["TauTransformed", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:125"],

Cell[TextData[{
  "TauTransformed[N] gibt die \[Tau]-transformierte Bewegungsgleichung des \
Sitnikov Problems bis zur Ordnung ",
  Cell[BoxData[
      \(TraditionalForm\`O(\[Lambda]\^\(N + 1\))\)]],
  " wieder. Im Unterschied zu TauEquation[N] erfolgt die Sortierung nach dem \
Parameter \[Lambda]."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransformDependentVar", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:126"],

Cell[TextData[{
  "TransformDependentVar[equ,f[t],f[t]==F[f[t]]] transformiert eine \
Differentialgleichung equ der Funktion f[t] \[UDoubleDot]ber die Relation \
f[t] = F[g[t]] oder ",
  Cell[BoxData[
      \(TraditionalForm\`g[t] == \(G\^\(-1\)\)[f[t]]\)]],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["TransformIndependentVar", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:127"],

Cell[TextData[{
  "TransformDependentVar[equn,f[t],t[s]==F[s]] transformiert eine \
Differentialgleichung equ der Funktion f[t] \[UDoubleDot]ber die Relation \
t[s]==F[s] oder ",
  Cell[BoxData[
      \(TraditionalForm\`s[t] == \(F\^\(-1\)\)[t]\)]],
  "."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["$Derivation", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:128"],

Cell["\<\
Die Variable $Derivation beinhaltet die Zwischenschritte der letzten \
Berechnung, ausgef\[UDoubleDot]hrt mit einem Objekt des SDS.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["$Objects", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:129"],

Cell["\<\
Die Variable $Objects beinhaltet alle aktiven Objekte des SDS, die in den \
Hauptspeicher geladen wurden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]],

Cell[CellGroupData[{

Cell["$Result", "Subsubsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:130"],

Cell["\<\
Die Variable $Results beinhaltet das letzte Ergebnis, ausgef\[UDoubleDot]hrt \
mit einem Objekt des SDS, das keine automatische Zuweisung besitzt.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Abschlie\[SZ]ende Bemerkung", "Subsection",
  PageWidth->PaperWidth,
  CellDingbat->None,
  TextJustification->1,
  CellTags->"c:131"],

Cell[TextData[{
  "Alle Objekte des SDS wurden an den Ergebnissen dieser Arbeit und dar\
\[UDoubleDot]ber hinaus getestet. Viele Funktionen (",
  StyleBox["TransformDependentVar, DifferentialOrder",
    FontSlant->"Italic"],
  ", etc...) wurden abstrakter geschrieben, als f\[UDoubleDot]r diese Arbeit \
notwendig, um sie f\[UDoubleDot]r sp\[ADoubleDot]tere Zwecke einsetzen zu k\
\[ODoubleDot]nnen. Sie wurden nicht auf alle m\[ODoubleDot]glichen F\
\[ADoubleDot]lle getestet, ihre Ergebnisse m\[UDoubleDot]ssen f\[UDoubleDot]r \
jede nicht in dieser Arbeit durchgef\[UDoubleDot]hrte Anwendung auf \
Konsistenz und Richtigkeit getestet und m\[ODoubleDot]glicherweise \
modifiziert werden! Der Autor \[UDoubleDot]bernimmt keine Verantwortung f\
\[UDoubleDot]r eventuell auftretende Fehler in Berechnungen und daraus \
folgende Sch\[ADoubleDot]den."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Das Package wurde f\[UDoubleDot]r ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " V5 geschrieben und auch getestet. F\[UDoubleDot]r Adaption auf niedrigere \
Versionen siehe ",
  StyleBox["Incompatible Changes ",
    FontSlant->"Italic"],
  "(",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Help Browser / ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " Reference)."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell["\<\
Updates, Diskussionsbeitr\[ADoubleDot]ge und \
Verbesserungsvorschl\[ADoubleDot]ge k\[ODoubleDot]nnen \[UDoubleDot]ber \
e-mail Kontakt mit dem Autor \[UDoubleDot]ber die Adresse - \
lhotka@astro.univie.ac.at - bezogen bzw. eingebracht werden.\
\>", "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 693}},
Editable->False,
ScreenStyleEnvironment->"EnhancedPrintoutNonGray",
PrintingStyleEnvironment->"EnhancedPrintoutNonGray",
WindowSize->{536, 567},
WindowMargins->{{-32, Automatic}, {Automatic, -7}},
PrintingCopies->1,
PrintingStartingPageNumber->87,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {
          ValueBox[ ""]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ ""]}], "Header"], Inherited, Inherited}},
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1776, 53, 145, 4, 56, "Section",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2014, 65, 144, 4, 43, "Subsection",
      CellTags->"c:2"]},
  "c:3"->{
    Cell[7226, 155, 162, 4, 48, "Subsection",
      CellTags->"c:3"]},
  "c:4"->{
    Cell[7663, 172, 172, 5, 48, "Subsection",
      CellTags->"c:4"]},
  "c:5"->{
    Cell[8629, 205, 161, 4, 32, "Subsubsection",
      CellTags->"c:5"]},
  "c:6"->{
    Cell[9576, 228, 164, 4, 32, "Subsubsection",
      CellTags->"c:6"]},
  "c:7"->{
    Cell[10437, 257, 142, 4, 32, "Subsubsection",
      CellTags->"c:7"]},
  "c:8"->{
    Cell[95841, 3033, 144, 4, 40, "Subsubsection",
      CellTags->"c:8"]},
  "c:9"->{
    Cell[96118, 3047, 172, 5, 48, "Subsection",
      CellTags->"c:9"]},
  "c:10"->{
    Cell[96567, 3064, 162, 4, 40, "Subsubsection",
      CellTags->"c:10"]},
  "c:11"->{
    Cell[97310, 3086, 165, 4, 40, "Subsubsection",
      CellTags->"c:11"]},
  "c:12"->{
    Cell[98075, 3114, 143, 4, 40, "Subsubsection",
      CellTags->"c:12"]},
  "c:13"->{
    Cell[98324, 3127, 145, 4, 40, "Subsubsection",
      CellTags->"c:13"]},
  "c:14"->{
    Cell[98595, 3141, 179, 5, 48, "Subsection",
      CellTags->"c:14"]},
  "c:15"->{
    Cell[99192, 3160, 162, 4, 40, "Subsubsection",
      CellTags->"c:15"]},
  "c:16"->{
    Cell[100566, 3200, 165, 4, 40, "Subsubsection",
      CellTags->"c:16"]},
  "c:17"->{
    Cell[101681, 3233, 143, 4, 40, "Subsubsection",
      CellTags->"c:17"]},
  "c:18"->{
    Cell[179003, 5918, 145, 4, 40, "Subsubsection",
      CellTags->"c:18"]},
  "c:19"->{
    Cell[179274, 5932, 173, 5, 48, "Subsection",
      CellTags->"c:19"]},
  "c:20"->{
    Cell[179720, 5949, 162, 4, 40, "Subsubsection",
      CellTags->"c:20"]},
  "c:21"->{
    Cell[182744, 6036, 165, 4, 40, "Subsubsection",
      CellTags->"c:21"]},
  "c:22"->{
    Cell[192386, 6262, 143, 4, 40, "Subsubsection",
      CellTags->"c:22"]},
  "c:23"->{
    Cell[280336, 9115, 145, 4, 40, "Subsubsection",
      CellTags->"c:23"]},
  "c:24"->{
    Cell[280607, 9129, 169, 5, 48, "Subsection",
      CellTags->"c:24"]},
  "c:25"->{
    Cell[281093, 9146, 162, 4, 40, "Subsubsection",
      CellTags->"c:25"]},
  "c:26"->{
    Cell[282336, 9185, 165, 4, 40, "Subsubsection",
      CellTags->"c:26"]},
  "c:27"->{
    Cell[283265, 9217, 143, 4, 40, "Subsubsection",
      CellTags->"c:27"]},
  "c:28"->{
    Cell[284090, 9245, 145, 4, 40, "Subsubsection",
      CellTags->"c:28"]},
  "c:29"->{
    Cell[284361, 9259, 170, 5, 48, "Subsection",
      CellTags->"c:29"]},
  "c:30"->{
    Cell[284807, 9276, 162, 4, 40, "Subsubsection",
      CellTags->"c:30"]},
  "c:31"->{
    Cell[285774, 9314, 165, 4, 40, "Subsubsection",
      CellTags->"c:31"]},
  "c:32"->{
    Cell[286814, 9346, 143, 4, 40, "Subsubsection",
      CellTags->"c:32"]},
  "c:33"->{
    Cell[373980, 12176, 145, 4, 40, "Subsubsection",
      CellTags->"c:33"]},
  "c:34"->{
    Cell[374251, 12190, 166, 5, 48, "Subsection",
      CellTags->"c:34"]},
  "c:35"->{
    Cell[374717, 12207, 162, 4, 40, "Subsubsection",
      CellTags->"c:35"]},
  "c:36"->{
    Cell[375641, 12237, 165, 4, 40, "Subsubsection",
      CellTags->"c:36"]},
  "c:37"->{
    Cell[376403, 12266, 143, 4, 40, "Subsubsection",
      CellTags->"c:37"]},
  "c:38"->{
    Cell[474737, 15249, 145, 4, 40, "Subsubsection",
      CellTags->"c:38"]},
  "c:39"->{
    Cell[475008, 15263, 170, 5, 48, "Subsection",
      CellTags->"c:39"]},
  "c:40"->{
    Cell[475870, 15291, 162, 4, 40, "Subsubsection",
      CellTags->"c:40"]},
  "c:41"->{
    Cell[478457, 15363, 165, 4, 40, "Subsubsection",
      CellTags->"c:41"]},
  "c:42"->{
    Cell[480341, 15413, 143, 4, 40, "Subsubsection",
      CellTags->"c:42"]},
  "c:43"->{
    Cell[675849, 21400, 145, 4, 40, "Subsubsection",
      CellTags->"c:43"]},
  "c:44"->{
    Cell[676120, 21414, 168, 4, 48, "Subsection",
      CellTags->"c:44"]},
  "c:45"->{
    Cell[676563, 21431, 175, 5, 48, "Subsection",
      CellTags->"c:45"]},
  "c:46"->{
    Cell[677003, 21448, 162, 4, 40, "Subsubsection",
      CellTags->"c:46"]},
  "c:47"->{
    Cell[677989, 21480, 165, 4, 40, "Subsubsection",
      CellTags->"c:47"]},
  "c:48"->{
    Cell[679478, 21523, 143, 4, 40, "Subsubsection",
      CellTags->"c:48"]},
  "c:49"->{
    Cell[679875, 21539, 145, 4, 40, "Subsubsection",
      CellTags->"c:49"]},
  "c:50"->{
    Cell[680152, 21553, 174, 5, 48, "Subsection",
      CellTags->"c:50"]},
  "c:51"->{
    Cell[680733, 21575, 162, 4, 40, "Subsubsection",
      CellTags->"c:51"]},
  "c:52"->{
    Cell[682179, 21617, 165, 4, 40, "Subsubsection",
      CellTags->"c:52"]},
  "c:53"->{
    Cell[684501, 21674, 143, 4, 40, "Subsubsection",
      CellTags->"c:53"]},
  "c:54"->{
    Cell[748292, 23736, 145, 4, 40, "Subsubsection",
      CellTags->"c:54"]},
  "c:55"->{
    Cell[748569, 23750, 181, 5, 48, "Subsection",
      CellTags->"c:55"]},
  "c:56"->{
    Cell[749190, 23769, 162, 4, 40, "Subsubsection",
      CellTags->"c:56"]},
  "c:57"->{
    Cell[750673, 23817, 165, 4, 40, "Subsubsection",
      CellTags->"c:57"]},
  "c:58"->{
    Cell[758705, 24039, 145, 4, 40, "Subsubsection",
      CellTags->"c:58"]},
  "c:59"->{
    Cell[758976, 24053, 181, 5, 48, "Subsection",
      CellTags->"c:59"]},
  "c:60"->{
    Cell[759600, 24074, 162, 4, 40, "Subsubsection",
      CellTags->"c:60"]},
  "c:61"->{
    Cell[759962, 24092, 165, 4, 40, "Subsubsection",
      CellTags->"c:61"]},
  "c:62"->{
    Cell[761505, 24137, 145, 4, 40, "Subsubsection",
      CellTags->"c:62"]},
  "c:63"->{
    Cell[761776, 24151, 176, 5, 48, "Subsection",
      CellTags->"c:63"]},
  "c:64"->{
    Cell[762180, 24167, 162, 4, 40, "Subsubsection",
      CellTags->"c:64"]},
  "c:65"->{
    Cell[763195, 24193, 165, 4, 40, "Subsubsection",
      CellTags->"c:65"]},
  "c:66"->{
    Cell[765177, 24243, 143, 4, 40, "Subsubsection",
      CellTags->"c:66"]},
  "c:67"->{
    Cell[874094, 27948, 145, 4, 40, "Subsubsection",
      CellTags->"c:67"]},
  "c:68"->{
    Cell[874365, 27962, 167, 5, 48, "Subsection",
      CellTags->"c:68"]},
  "c:69"->{
    Cell[874900, 27981, 162, 4, 40, "Subsubsection",
      CellTags->"c:69"]},
  "c:70"->{
    Cell[875168, 27994, 165, 4, 40, "Subsubsection",
      CellTags->"c:70"]},
  "c:71"->{
    Cell[876462, 28034, 145, 4, 40, "Subsubsection",
      CellTags->"c:71"]},
  "c:72"->{
    Cell[876739, 28048, 171, 5, 48, "Subsection",
      CellTags->"c:72"]},
  "c:73"->{
    Cell[877336, 28069, 162, 4, 40, "Subsubsection",
      CellTags->"c:73"]},
  "c:74"->{
    Cell[878177, 28098, 165, 4, 40, "Subsubsection",
      CellTags->"c:74"]},
  "c:75"->{
    Cell[879670, 28141, 145, 4, 40, "Subsubsection",
      CellTags->"c:75"]},
  "c:76"->{
    Cell[879941, 28155, 171, 5, 48, "Subsection",
      CellTags->"c:76"]},
  "c:77"->{
    Cell[880770, 28181, 162, 4, 40, "Subsubsection",
      CellTags->"c:77"]},
  "c:78"->{
    Cell[881542, 28207, 165, 4, 40, "Subsubsection",
      CellTags->"c:78"]},
  "c:79"->{
    Cell[883309, 28253, 145, 4, 40, "Subsubsection",
      CellTags->"c:79"]},
  "c:80"->{
    Cell[883580, 28267, 168, 5, 48, "Subsection",
      CellTags->"c:80"]},
  "c:81"->{
    Cell[884806, 28295, 162, 4, 40, "Subsubsection",
      CellTags->"c:81"]},
  "c:82"->{
    Cell[886569, 28337, 165, 4, 40, "Subsubsection",
      CellTags->"c:82"]},
  "c:83"->{
    Cell[895388, 28508, 148, 4, 40, "Subsubsection",
      CellTags->"c:83"]},
  "c:84"->{
    Cell[896866, 28556, 145, 4, 40, "Subsubsection",
      CellTags->"c:84"]},
  "c:85"->{
    Cell[897137, 28570, 204, 6, 48, "Subsection",
      CellTags->"c:85"]},
  "c:86"->{
    Cell[897744, 28590, 162, 4, 40, "Subsubsection",
      CellTags->"c:86"]},
  "c:87"->{
    Cell[898015, 28603, 165, 4, 40, "Subsubsection",
      CellTags->"c:87"]},
  "c:88"->{
    Cell[898456, 28625, 143, 4, 40, "Subsubsection",
      CellTags->"c:88"]},
  "c:89"->{
    Cell[1087741, 34988, 145, 4, 40, "Subsubsection",
      CellTags->"c:89"]},
  "c:90"->{
    Cell[1088012, 35002, 177, 5, 48, "Subsection",
      CellTags->"c:90"]},
  "c:91"->{
    Cell[1088459, 35019, 162, 4, 40, "Subsubsection",
      CellTags->"c:91"]},
  "c:92"->{
    Cell[1089855, 35052, 165, 4, 40, "Subsubsection",
      CellTags->"c:92"]},
  "c:93"->{
    Cell[1094917, 35195, 143, 4, 40, "Subsubsection",
      CellTags->"c:93"]},
  "c:94"->{
    Cell[1095720, 35217, 145, 4, 40, "Subsubsection",
      CellTags->"c:94"]},
  "c:95"->{
    Cell[1095993, 35231, 162, 5, 48, "Subsection",
      CellTags->"c:95"]},
  "c:96"->{
    Cell[1096615, 35251, 162, 4, 40, "Subsubsection",
      CellTags->"c:96"]},
  "c:97"->{
    Cell[1097292, 35271, 165, 4, 40, "Subsubsection",
      CellTags->"c:97"]},
  "c:98"->{
    Cell[1099453, 35326, 145, 4, 40, "Subsubsection",
      CellTags->"c:98"]},
  "c:99"->{
    Cell[1099724, 35340, 173, 5, 48, "Subsection",
      CellTags->"c:99"]},
  "c:100"->{
    Cell[1100317, 35360, 163, 4, 40, "Subsubsection",
      CellTags->"c:100"]},
  "c:101"->{
    Cell[1101059, 35381, 166, 4, 40, "Subsubsection",
      CellTags->"c:101"]},
  "c:102"->{
    Cell[1102979, 35429, 144, 4, 40, "Subsubsection",
      CellTags->"c:102"]},
  "c:103"->{
    Cell[1163772, 37465, 146, 4, 40, "Subsubsection",
      CellTags->"c:103"]},
  "c:104"->{
    Cell[1164044, 37479, 141, 4, 48, "Subsection",
      CellTags->"c:104"]},
  "c:105"->{
    Cell[1164866, 37505, 128, 4, 40, "Subsubsection",
      CellTags->"c:105"]},
  "c:106"->{
    Cell[1165329, 37525, 169, 5, 40, "Subsubsection",
      CellTags->"c:106"]},
  "c:107"->{
    Cell[1166100, 37553, 138, 4, 40, "Subsubsection",
      CellTags->"c:107"]},
  "c:108"->{
    Cell[1166518, 37570, 122, 4, 40, "Subsubsection",
      CellTags->"c:108"]},
  "c:109"->{
    Cell[1167113, 37593, 133, 4, 40, "Subsubsection",
      CellTags->"c:109"]},
  "c:110"->{
    Cell[1167566, 37612, 128, 4, 40, "Subsubsection",
      CellTags->"c:110"]},
  "c:111"->{
    Cell[1168034, 37630, 126, 4, 40, "Subsubsection",
      CellTags->"c:111"]},
  "c:112"->{
    Cell[1168415, 37646, 129, 4, 40, "Subsubsection",
      CellTags->"c:112"]},
  "c:113"->{
    Cell[1168789, 37662, 141, 4, 40, "Subsubsection",
      CellTags->"c:113"]},
  "c:114"->{
    Cell[1169486, 37687, 130, 4, 40, "Subsubsection",
      CellTags->"c:114"]},
  "c:115"->{
    Cell[1169838, 37703, 122, 4, 40, "Subsubsection",
      CellTags->"c:115"]},
  "c:116"->{
    Cell[1170690, 37737, 130, 4, 40, "Subsubsection",
      CellTags->"c:116"]},
  "c:117"->{
    Cell[1171105, 37756, 132, 4, 40, "Subsubsection",
      CellTags->"c:117"]},
  "c:118"->{
    Cell[1171456, 37772, 134, 4, 40, "Subsubsection",
      CellTags->"c:118"]},
  "c:119"->{
    Cell[1171905, 37791, 123, 4, 40, "Subsubsection",
      CellTags->"c:119"]},
  "c:120"->{
    Cell[1172179, 37804, 123, 4, 40, "Subsubsection",
      CellTags->"c:120"]},
  "c:121"->{
    Cell[1172619, 37823, 129, 4, 40, "Subsubsection",
      CellTags->"c:121"]},
  "c:122"->{
    Cell[1172985, 37841, 129, 4, 40, "Subsubsection",
      CellTags->"c:122"]},
  "c:123"->{
    Cell[1173351, 37859, 131, 4, 40, "Subsubsection",
      CellTags->"c:123"]},
  "c:124"->{
    Cell[1173726, 37877, 129, 4, 40, "Subsubsection",
      CellTags->"c:124"]},
  "c:125"->{
    Cell[1174159, 37894, 130, 4, 40, "Subsubsection",
      CellTags->"c:125"]},
  "c:126"->{
    Cell[1174690, 37914, 137, 4, 40, "Subsubsection",
      CellTags->"c:126"]},
  "c:127"->{
    Cell[1175192, 37934, 139, 4, 40, "Subsubsection",
      CellTags->"c:127"]},
  "c:128"->{
    Cell[1175687, 37954, 127, 4, 40, "Subsubsection",
      CellTags->"c:128"]},
  "c:129"->{
    Cell[1176058, 37970, 124, 4, 40, "Subsubsection",
      CellTags->"c:129"]},
  "c:130"->{
    Cell[1176400, 37986, 123, 4, 40, "Subsubsection",
      CellTags->"c:130"]},
  "c:131"->{
    Cell[1176794, 38003, 140, 4, 48, "Subsection",
      CellTags->"c:131"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 1179732, 38085},
  {"c:2", 1179810, 38088},
  {"c:3", 1179891, 38091},
  {"c:4", 1179973, 38094},
  {"c:5", 1180055, 38097},
  {"c:6", 1180140, 38100},
  {"c:7", 1180225, 38103},
  {"c:8", 1180311, 38106},
  {"c:9", 1180398, 38109},
  {"c:10", 1180483, 38112},
  {"c:11", 1180572, 38115},
  {"c:12", 1180661, 38118},
  {"c:13", 1180750, 38121},
  {"c:14", 1180839, 38124},
  {"c:15", 1180925, 38127},
  {"c:16", 1181014, 38130},
  {"c:17", 1181104, 38133},
  {"c:18", 1181194, 38136},
  {"c:19", 1181284, 38139},
  {"c:20", 1181371, 38142},
  {"c:21", 1181461, 38145},
  {"c:22", 1181551, 38148},
  {"c:23", 1181641, 38151},
  {"c:24", 1181731, 38154},
  {"c:25", 1181818, 38157},
  {"c:26", 1181908, 38160},
  {"c:27", 1181998, 38163},
  {"c:28", 1182088, 38166},
  {"c:29", 1182178, 38169},
  {"c:30", 1182265, 38172},
  {"c:31", 1182355, 38175},
  {"c:32", 1182445, 38178},
  {"c:33", 1182535, 38181},
  {"c:34", 1182626, 38184},
  {"c:35", 1182714, 38187},
  {"c:36", 1182805, 38190},
  {"c:37", 1182896, 38193},
  {"c:38", 1182987, 38196},
  {"c:39", 1183078, 38199},
  {"c:40", 1183166, 38202},
  {"c:41", 1183257, 38205},
  {"c:42", 1183348, 38208},
  {"c:43", 1183439, 38211},
  {"c:44", 1183530, 38214},
  {"c:45", 1183618, 38217},
  {"c:46", 1183706, 38220},
  {"c:47", 1183797, 38223},
  {"c:48", 1183888, 38226},
  {"c:49", 1183979, 38229},
  {"c:50", 1184070, 38232},
  {"c:51", 1184158, 38235},
  {"c:52", 1184249, 38238},
  {"c:53", 1184340, 38241},
  {"c:54", 1184431, 38244},
  {"c:55", 1184522, 38247},
  {"c:56", 1184610, 38250},
  {"c:57", 1184701, 38253},
  {"c:58", 1184792, 38256},
  {"c:59", 1184883, 38259},
  {"c:60", 1184971, 38262},
  {"c:61", 1185062, 38265},
  {"c:62", 1185153, 38268},
  {"c:63", 1185244, 38271},
  {"c:64", 1185332, 38274},
  {"c:65", 1185423, 38277},
  {"c:66", 1185514, 38280},
  {"c:67", 1185605, 38283},
  {"c:68", 1185696, 38286},
  {"c:69", 1185784, 38289},
  {"c:70", 1185875, 38292},
  {"c:71", 1185966, 38295},
  {"c:72", 1186057, 38298},
  {"c:73", 1186145, 38301},
  {"c:74", 1186236, 38304},
  {"c:75", 1186327, 38307},
  {"c:76", 1186418, 38310},
  {"c:77", 1186506, 38313},
  {"c:78", 1186597, 38316},
  {"c:79", 1186688, 38319},
  {"c:80", 1186779, 38322},
  {"c:81", 1186867, 38325},
  {"c:82", 1186958, 38328},
  {"c:83", 1187049, 38331},
  {"c:84", 1187140, 38334},
  {"c:85", 1187231, 38337},
  {"c:86", 1187319, 38340},
  {"c:87", 1187410, 38343},
  {"c:88", 1187501, 38346},
  {"c:89", 1187592, 38349},
  {"c:90", 1187684, 38352},
  {"c:91", 1187773, 38355},
  {"c:92", 1187865, 38358},
  {"c:93", 1187957, 38361},
  {"c:94", 1188049, 38364},
  {"c:95", 1188141, 38367},
  {"c:96", 1188230, 38370},
  {"c:97", 1188322, 38373},
  {"c:98", 1188414, 38376},
  {"c:99", 1188506, 38379},
  {"c:100", 1188596, 38382},
  {"c:101", 1188690, 38385},
  {"c:102", 1188784, 38388},
  {"c:103", 1188878, 38391},
  {"c:104", 1188972, 38394},
  {"c:105", 1189063, 38397},
  {"c:106", 1189157, 38400},
  {"c:107", 1189251, 38403},
  {"c:108", 1189345, 38406},
  {"c:109", 1189439, 38409},
  {"c:110", 1189533, 38412},
  {"c:111", 1189627, 38415},
  {"c:112", 1189721, 38418},
  {"c:113", 1189815, 38421},
  {"c:114", 1189909, 38424},
  {"c:115", 1190003, 38427},
  {"c:116", 1190097, 38430},
  {"c:117", 1190191, 38433},
  {"c:118", 1190285, 38436},
  {"c:119", 1190379, 38439},
  {"c:120", 1190473, 38442},
  {"c:121", 1190567, 38445},
  {"c:122", 1190661, 38448},
  {"c:123", 1190755, 38451},
  {"c:124", 1190849, 38454},
  {"c:125", 1190943, 38457},
  {"c:126", 1191037, 38460},
  {"c:127", 1191131, 38463},
  {"c:128", 1191225, 38466},
  {"c:129", 1191319, 38469},
  {"c:130", 1191413, 38472},
  {"c:131", 1191507, 38475}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 145, 4, 56, "Section",
  CellTags->"c:1"],
Cell[1924, 59, 65, 2, 27, "Text"],

Cell[CellGroupData[{
Cell[2014, 65, 144, 4, 43, "Subsection",
  CellTags->"c:2"],
Cell[2161, 71, 2061, 30, 350, "Text"],
Cell[4225, 103, 939, 16, 146, "Text"],
Cell[5167, 121, 2022, 29, 346, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7226, 155, 162, 4, 48, "Subsection",
  CellTags->"c:3"],
Cell[7391, 161, 235, 6, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7663, 172, 172, 5, 48, "Subsection",
  CellTags->"c:4"],
Cell[7838, 179, 766, 22, 64, "Text"],

Cell[CellGroupData[{
Cell[8629, 205, 161, 4, 32, "Subsubsection",
  CellTags->"c:5"],
Cell[8793, 211, 746, 12, 128, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9576, 228, 164, 4, 32, "Subsubsection",
  CellTags->"c:6"],
Cell[9743, 234, 152, 6, 26, "Text"],
Cell[9898, 242, 502, 10, 106, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10437, 257, 142, 4, 32, "Subsubsection",
  CellTags->"c:7"],
Cell[10582, 263, 201, 5, 44, "Text"],
Cell[10786, 270, 68, 2, 24, "Caption"],
Cell[10857, 274, 84042, 2731, 248, 43661, 2226, "GraphicsData", "PostScript", \
"Graphics"],
Cell[94902, 3007, 296, 8, 38, "Caption"],
Cell[95201, 3017, 603, 11, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95841, 3033, 144, 4, 40, "Subsubsection",
  CellTags->"c:8"],
Cell[95988, 3039, 81, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[96118, 3047, 172, 5, 48, "Subsection",
  CellTags->"c:9"],
Cell[96293, 3054, 249, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[96567, 3064, 162, 4, 40, "Subsubsection",
  CellTags->"c:10"],
Cell[96732, 3070, 541, 11, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97310, 3086, 165, 4, 40, "Subsubsection",
  CellTags->"c:11"],
Cell[97478, 3092, 155, 6, 34, "Text"],
Cell[97636, 3100, 402, 9, 90, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98075, 3114, 143, 4, 40, "Subsubsection",
  CellTags->"c:12"],
Cell[98221, 3120, 66, 2, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[98324, 3127, 145, 4, 40, "Subsubsection",
  CellTags->"c:13"],
Cell[98472, 3133, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[98595, 3141, 179, 5, 48, "Subsection",
  CellTags->"c:14"],
Cell[98777, 3148, 390, 8, 74, "Text"],

Cell[CellGroupData[{
Cell[99192, 3160, 162, 4, 40, "Subsubsection",
  CellTags->"c:15"],
Cell[99357, 3166, 1172, 29, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[100566, 3200, 165, 4, 40, "Subsubsection",
  CellTags->"c:16"],
Cell[100734, 3206, 155, 6, 34, "Text"],
Cell[100892, 3214, 752, 14, 192, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101681, 3233, 143, 4, 40, "Subsubsection",
  CellTags->"c:17"],
Cell[101827, 3239, 501, 9, 90, "Text"],
Cell[102331, 3250, 68, 2, 34, "Caption"],
Cell[102402, 3254, 75749, 2636, 250, 43726, 2235, "GraphicsData", \
"PostScript", "Graphics"],
Cell[178154, 5892, 328, 8, 38, "Caption"],
Cell[178485, 5902, 481, 11, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[179003, 5918, 145, 4, 40, "Subsubsection",
  CellTags->"c:18"],
Cell[179151, 5924, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[179274, 5932, 173, 5, 48, "Subsection",
  CellTags->"c:19"],
Cell[179450, 5939, 245, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[179720, 5949, 162, 4, 40, "Subsubsection",
  CellTags->"c:20"],
Cell[179885, 5955, 703, 19, 74, "Text"],
Cell[180591, 5976, 595, 17, 42, "DisplayFormula"],
Cell[181189, 5995, 1518, 36, 138, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[182744, 6036, 165, 4, 40, "Subsubsection",
  CellTags->"c:21"],
Cell[182912, 6042, 179, 6, 34, "Text"],
Cell[183094, 6050, 1920, 38, 212, "Input"],
Cell[185017, 6090, 542, 12, 90, "Text"],
Cell[185562, 6104, 1828, 34, 314, "Input"],
Cell[187393, 6140, 895, 16, 154, "Text"],
Cell[188291, 6158, 474, 9, 90, "Input"],
Cell[188768, 6169, 198, 7, 34, "Text"],
Cell[188969, 6178, 672, 19, 36, "Input"],
Cell[189644, 6199, 2158, 45, 106, "Input"],
Cell[191805, 6246, 544, 11, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[192386, 6262, 143, 4, 40, "Subsubsection",
  CellTags->"c:22"],
Cell[192532, 6268, 1018, 17, 170, "Text"],
Cell[193553, 6287, 303, 7, 58, "Text"],
Cell[193859, 6296, 68, 2, 34, "Caption"],
Cell[193930, 6300, 85821, 2793, 250, 44770, 2280, "GraphicsData", \
"PostScript", "Graphics"],
Cell[279754, 9095, 261, 7, 38, "Caption"],
Cell[280018, 9104, 281, 6, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[280336, 9115, 145, 4, 40, "Subsubsection",
  CellTags->"c:23"],
Cell[280484, 9121, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[280607, 9129, 169, 5, 48, "Subsection",
  CellTags->"c:24"],
Cell[280779, 9136, 289, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[281093, 9146, 162, 4, 40, "Subsubsection",
  CellTags->"c:25"],
Cell[281258, 9152, 529, 10, 90, "Text"],
Cell[281790, 9164, 198, 5, 54, "DisplayFormula"],
Cell[281991, 9171, 308, 9, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[282336, 9185, 165, 4, 40, "Subsubsection",
  CellTags->"c:26"],
Cell[282504, 9191, 155, 6, 34, "Text"],
Cell[282662, 9199, 566, 13, 150, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[283265, 9217, 143, 4, 40, "Subsubsection",
  CellTags->"c:27"],
Cell[283411, 9223, 426, 8, 74, "Text"],
Cell[283840, 9233, 213, 7, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[284090, 9245, 145, 4, 40, "Subsubsection",
  CellTags->"c:28"],
Cell[284238, 9251, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[284361, 9259, 170, 5, 48, "Subsection",
  CellTags->"c:29"],
Cell[284534, 9266, 248, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[284807, 9276, 162, 4, 40, "Subsubsection",
  CellTags->"c:30"],
Cell[284972, 9282, 197, 5, 42, "Text"],
Cell[285172, 9289, 194, 5, 50, "DisplayFormula"],
Cell[285369, 9296, 368, 13, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[285774, 9314, 165, 4, 40, "Subsubsection",
  CellTags->"c:31"],
Cell[285942, 9320, 170, 6, 34, "Text"],
Cell[286115, 9328, 662, 13, 142, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[286814, 9346, 143, 4, 40, "Subsubsection",
  CellTags->"c:32"],
Cell[286960, 9352, 376, 11, 58, "Text"],
Cell[287339, 9365, 68, 2, 34, "Caption"],
Cell[287410, 9369, 85839, 2782, 250, 44710, 2268, "GraphicsData", \
"PostScript", "Graphics"],
Cell[373252, 12153, 316, 8, 38, "Caption"],
Cell[373571, 12163, 372, 8, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[373980, 12176, 145, 4, 40, "Subsubsection",
  CellTags->"c:33"],
Cell[374128, 12182, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[374251, 12190, 166, 5, 48, "Subsection",
  CellTags->"c:34"],
Cell[374420, 12197, 272, 6, 58, "Text"],

Cell[CellGroupData[{
Cell[374717, 12207, 162, 4, 40, "Subsubsection",
  CellTags->"c:35"],
Cell[374882, 12213, 722, 19, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[375641, 12237, 165, 4, 40, "Subsubsection",
  CellTags->"c:36"],
Cell[375809, 12243, 151, 6, 34, "Text"],
Cell[375963, 12251, 403, 10, 74, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[376403, 12266, 143, 4, 40, "Subsubsection",
  CellTags->"c:37"],
Cell[376549, 12272, 221, 5, 42, "Text"],
Cell[376773, 12279, 68, 2, 34, "Caption"],
Cell[376844, 12283, 97411, 2945, 250, 44738, 2289, "GraphicsData", \
"PostScript", "Graphics"],
Cell[474258, 15230, 241, 7, 38, "Caption"],
Cell[474502, 15239, 198, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[474737, 15249, 145, 4, 40, "Subsubsection",
  CellTags->"c:38"],
Cell[474885, 15255, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[475008, 15263, 170, 5, 48, "Subsection",
  CellTags->"c:39"],
Cell[475181, 15270, 664, 17, 62, "Text"],

Cell[CellGroupData[{
Cell[475870, 15291, 162, 4, 40, "Subsubsection",
  CellTags->"c:40"],
Cell[476035, 15297, 722, 16, 74, "Text"],
Cell[476760, 15315, 307, 8, 40, "DisplayFormula"],
Cell[477070, 15325, 914, 23, 90, "Text"],
Cell[477987, 15350, 433, 8, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[478457, 15363, 165, 4, 40, "Subsubsection",
  CellTags->"c:41"],
Cell[478625, 15369, 170, 6, 34, "Text"],
Cell[478798, 15377, 1506, 31, 202, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[480341, 15413, 143, 4, 40, "Subsubsection",
  CellTags->"c:42"],
Cell[480487, 15419, 378, 8, 74, "Text"],

Cell[CellGroupData[{
Cell[480890, 15431, 75, 2, 36, "Input"],
Cell[480968, 15435, 96205, 2961, 250, 45890, 2334, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[577188, 18399, 247, 7, 38, "Caption"],
Cell[577438, 18408, 336, 7, 58, "Text"],
Cell[577777, 18417, 68, 2, 34, "Caption"],
Cell[577848, 18421, 97682, 2965, 250, 45887, 2319, "GraphicsData", \
"PostScript", "Graphics"],
Cell[675533, 21388, 279, 7, 38, "Caption"]
}, Open  ]],

Cell[CellGroupData[{
Cell[675849, 21400, 145, 4, 40, "Subsubsection",
  CellTags->"c:43"],
Cell[675997, 21406, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[676120, 21414, 168, 4, 48, "Subsection",
  CellTags->"c:44"],
Cell[676291, 21420, 235, 6, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[676563, 21431, 175, 5, 48, "Subsection",
  CellTags->"c:45"],
Cell[676741, 21438, 237, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[677003, 21448, 162, 4, 40, "Subsubsection",
  CellTags->"c:46"],
Cell[677168, 21454, 117, 2, 34, "Text"],
Cell[677288, 21458, 193, 4, 54, "DisplayFormula"],
Cell[677484, 21464, 468, 11, 64, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[677989, 21480, 165, 4, 40, "Subsubsection",
  CellTags->"c:47"],
Cell[678157, 21486, 155, 6, 34, "Text"],
Cell[678315, 21494, 1126, 24, 160, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[679478, 21523, 143, 4, 40, "Subsubsection",
  CellTags->"c:48"],
Cell[679624, 21529, 214, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[679875, 21539, 145, 4, 40, "Subsubsection",
  CellTags->"c:49"],
Cell[680023, 21545, 80, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[680152, 21553, 174, 5, 48, "Subsection",
  CellTags->"c:50"],
Cell[680329, 21560, 379, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[680733, 21575, 162, 4, 40, "Subsubsection",
  CellTags->"c:51"],
Cell[680898, 21581, 826, 16, 122, "Text"],
Cell[681727, 21599, 328, 9, 54, "DisplayFormula"],
Cell[682058, 21610, 84, 2, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[682179, 21617, 165, 4, 40, "Subsubsection",
  CellTags->"c:52"],
Cell[682347, 21623, 155, 6, 34, "Text"],
Cell[682505, 21631, 1959, 38, 240, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[684501, 21674, 143, 4, 40, "Subsubsection",
  CellTags->"c:53"],
Cell[684647, 21680, 592, 12, 90, "Text"],
Cell[685242, 21694, 68, 2, 34, "Caption"],
Cell[685313, 21698, 62513, 2017, 250, 34332, 1663, "GraphicsData", \
"PostScript", "Graphics"],
Cell[747829, 23717, 287, 8, 38, "Caption"],
Cell[748119, 23727, 136, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[748292, 23736, 145, 4, 40, "Subsubsection",
  CellTags->"c:54"],
Cell[748440, 23742, 80, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[748569, 23750, 181, 5, 48, "Subsection",
  CellTags->"c:55"],
Cell[748753, 23757, 412, 8, 74, "Text"],

Cell[CellGroupData[{
Cell[749190, 23769, 162, 4, 40, "Subsubsection",
  CellTags->"c:56"],
Cell[749355, 23775, 215, 5, 42, "Text"],
Cell[749573, 23782, 175, 4, 36, "DisplayFormula"],
Cell[749751, 23788, 462, 10, 60, "Text"],
Cell[750216, 23800, 174, 4, 36, "DisplayFormula"],
Cell[750393, 23806, 243, 6, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[750673, 23817, 165, 4, 40, "Subsubsection",
  CellTags->"c:57"],
Cell[750841, 23823, 180, 6, 34, "Text"],
Cell[751024, 23831, 1431, 30, 172, "Input"],
Cell[752458, 23863, 338, 9, 58, "Text"],
Cell[752799, 23874, 1703, 37, 222, "Input"],
Cell[754505, 23913, 618, 24, 58, "Text"],
Cell[755126, 23939, 264, 8, 42, "Text"],
Cell[755393, 23949, 755, 15, 138, "Input"],
Cell[756151, 23966, 364, 13, 42, "Text"],
Cell[756518, 23981, 258, 8, 42, "Text"],
Cell[756779, 23991, 1254, 23, 186, "Input"],
Cell[758036, 24016, 632, 18, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[758705, 24039, 145, 4, 40, "Subsubsection",
  CellTags->"c:58"],
Cell[758853, 24045, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[758976, 24053, 181, 5, 48, "Subsection",
  CellTags->"c:59"],
Cell[759160, 24060, 415, 10, 74, "Text"],

Cell[CellGroupData[{
Cell[759600, 24074, 162, 4, 40, "Subsubsection",
  CellTags->"c:60"],
Cell[759765, 24080, 160, 7, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[759962, 24092, 165, 4, 40, "Subsubsection",
  CellTags->"c:61"],
Cell[760130, 24098, 183, 6, 34, "Text"],
Cell[760316, 24106, 871, 17, 122, "Input"],
Cell[761190, 24125, 278, 7, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[761505, 24137, 145, 4, 40, "Subsubsection",
  CellTags->"c:62"],
Cell[761653, 24143, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[761776, 24151, 176, 5, 48, "Subsection",
  CellTags->"c:63"],
Cell[761955, 24158, 200, 5, 42, "Text"],

Cell[CellGroupData[{
Cell[762180, 24167, 162, 4, 40, "Subsubsection",
  CellTags->"c:64"],
Cell[762345, 24173, 813, 15, 122, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[763195, 24193, 165, 4, 40, "Subsubsection",
  CellTags->"c:65"],
Cell[763363, 24199, 171, 6, 34, "Text"],
Cell[763537, 24207, 1603, 31, 282, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[765177, 24243, 143, 4, 40, "Subsubsection",
  CellTags->"c:66"],
Cell[765323, 24249, 408, 8, 74, "Text"],
Cell[765734, 24259, 733, 15, 106, "Text"],
Cell[766470, 24276, 1360, 25, 218, "Input"],
Cell[767833, 24303, 1106, 32, 74, "Text"],
Cell[768942, 24337, 68, 2, 34, "Caption"],
Cell[769013, 24341, 103566, 3572, 250, 51784, 2927, "GraphicsData", \
"PostScript", "Graphics"],
Cell[872582, 27915, 347, 9, 38, "Caption"],
Cell[872932, 27926, 1125, 17, 186, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[874094, 27948, 145, 4, 40, "Subsubsection",
  CellTags->"c:67"],
Cell[874242, 27954, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[874365, 27962, 167, 5, 48, "Subsection",
  CellTags->"c:68"],
Cell[874535, 27969, 340, 8, 66, "Text"],

Cell[CellGroupData[{
Cell[874900, 27981, 162, 4, 40, "Subsubsection",
  CellTags->"c:69"],
Cell[875065, 27987, 66, 2, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[875168, 27994, 165, 4, 40, "Subsubsection",
  CellTags->"c:70"],
Cell[875336, 28000, 188, 6, 34, "Text"],
Cell[875527, 28008, 610, 11, 132, "Input"],
Cell[876140, 28021, 285, 8, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[876462, 28034, 145, 4, 40, "Subsubsection",
  CellTags->"c:71"],
Cell[876610, 28040, 80, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[876739, 28048, 171, 5, 48, "Subsection",
  CellTags->"c:72"],
Cell[876913, 28055, 398, 10, 58, "Text"],

Cell[CellGroupData[{
Cell[877336, 28069, 162, 4, 40, "Subsubsection",
  CellTags->"c:73"],
Cell[877501, 28075, 639, 18, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[878177, 28098, 165, 4, 40, "Subsubsection",
  CellTags->"c:74"],
Cell[878345, 28104, 170, 6, 34, "Text"],
Cell[878518, 28112, 965, 18, 156, "Input"],
Cell[879486, 28132, 147, 4, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[879670, 28141, 145, 4, 40, "Subsubsection",
  CellTags->"c:75"],
Cell[879818, 28147, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[879941, 28155, 171, 5, 48, "Subsection",
  CellTags->"c:76"],
Cell[880115, 28162, 630, 15, 74, "Text"],

Cell[CellGroupData[{
Cell[880770, 28181, 162, 4, 40, "Subsubsection",
  CellTags->"c:77"],
Cell[880935, 28187, 570, 15, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[881542, 28207, 165, 4, 40, "Subsubsection",
  CellTags->"c:78"],
Cell[881710, 28213, 152, 6, 34, "Text"],
Cell[881865, 28221, 778, 14, 106, "Input"],
Cell[882646, 28237, 626, 11, 106, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[883309, 28253, 145, 4, 40, "Subsubsection",
  CellTags->"c:79"],
Cell[883457, 28259, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[883580, 28267, 168, 5, 48, "Subsection",
  CellTags->"c:80"],
Cell[883751, 28274, 1030, 17, 170, "Text"],

Cell[CellGroupData[{
Cell[884806, 28295, 162, 4, 40, "Subsubsection",
  CellTags->"c:81"],
Cell[884971, 28301, 1561, 31, 170, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[886569, 28337, 165, 4, 40, "Subsubsection",
  CellTags->"c:82"],
Cell[886737, 28343, 228, 7, 90, "Text"],
Cell[886968, 28352, 8383, 151, 1708, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[895388, 28508, 148, 4, 40, "Subsubsection",
  CellTags->"c:83"],
Cell[895539, 28514, 402, 8, 74, "Text"],
Cell[895944, 28524, 236, 7, 42, "Text"],
Cell[896183, 28533, 343, 8, 58, "Text"],
Cell[896529, 28543, 300, 8, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[896866, 28556, 145, 4, 40, "Subsubsection",
  CellTags->"c:84"],
Cell[897014, 28562, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[897137, 28570, 204, 6, 48, "Subsection",
  CellTags->"c:85"],
Cell[897344, 28578, 375, 8, 74, "Text"],

Cell[CellGroupData[{
Cell[897744, 28590, 162, 4, 40, "Subsubsection",
  CellTags->"c:86"],
Cell[897909, 28596, 69, 2, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[898015, 28603, 165, 4, 40, "Subsubsection",
  CellTags->"c:87"],
Cell[898183, 28609, 150, 6, 34, "Text"],
Cell[898336, 28617, 83, 3, 36, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[898456, 28625, 143, 4, 40, "Subsubsection",
  CellTags->"c:88"],
Cell[898602, 28631, 501, 11, 90, "Text"],
Cell[899106, 28644, 59795, 2039, 250, 35669, 1735, "GraphicsData", \
"PostScript", "Graphics"],
Cell[958904, 30685, 344, 8, 38, "Caption"],
Cell[959251, 30695, 853, 14, 138, "Text"],
Cell[960107, 30711, 68, 2, 34, "Caption"],
Cell[960178, 30715, 65592, 2142, 250, 36880, 1781, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1025773, 32859, 281, 8, 38, "Caption"],
Cell[1026057, 32869, 68, 2, 34, "Caption"],
Cell[1026128, 32873, 61059, 2092, 250, 36767, 1786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1087190, 34967, 280, 7, 38, "Caption"],
Cell[1087473, 34976, 231, 7, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1087741, 34988, 145, 4, 40, "Subsubsection",
  CellTags->"c:89"],
Cell[1087889, 34994, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1088012, 35002, 177, 5, 48, "Subsection",
  CellTags->"c:90"],
Cell[1088192, 35009, 242, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[1088459, 35019, 162, 4, 40, "Subsubsection",
  CellTags->"c:91"],
Cell[1088624, 35025, 746, 12, 122, "Text"],
Cell[1089373, 35039, 445, 8, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1089855, 35052, 165, 4, 40, "Subsubsection",
  CellTags->"c:92"],
Cell[1090023, 35058, 171, 6, 34, "Text"],
Cell[1090197, 35066, 489, 10, 106, "Input"],
Cell[1090689, 35078, 383, 11, 58, "Text"],
Cell[1091075, 35091, 1160, 22, 170, "Input"],
Cell[1092238, 35115, 1519, 44, 122, "Text"],
Cell[1093760, 35161, 832, 21, 174, "Input"],
Cell[1094595, 35184, 285, 6, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1094917, 35195, 143, 4, 40, "Subsubsection",
  CellTags->"c:93"],
Cell[1095063, 35201, 620, 11, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1095720, 35217, 145, 4, 40, "Subsubsection",
  CellTags->"c:94"],
Cell[1095868, 35223, 76, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1095993, 35231, 162, 5, 48, "Subsection",
  CellTags->"c:95"],
Cell[1096158, 35238, 432, 9, 58, "Text"],

Cell[CellGroupData[{
Cell[1096615, 35251, 162, 4, 40, "Subsubsection",
  CellTags->"c:96"],
Cell[1096780, 35257, 475, 9, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1097292, 35271, 165, 4, 40, "Subsubsection",
  CellTags->"c:97"],
Cell[1097460, 35277, 173, 6, 34, "Text"],
Cell[1097636, 35285, 1477, 27, 234, "Input"],
Cell[1099116, 35314, 300, 7, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1099453, 35326, 145, 4, 40, "Subsubsection",
  CellTags->"c:98"],
Cell[1099601, 35332, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1099724, 35340, 173, 5, 48, "Subsection",
  CellTags->"c:99"],
Cell[1099900, 35347, 392, 9, 58, "Text"],

Cell[CellGroupData[{
Cell[1100317, 35360, 163, 4, 40, "Subsubsection",
  CellTags->"c:100"],
Cell[1100483, 35366, 539, 10, 90, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1101059, 35381, 166, 4, 40, "Subsubsection",
  CellTags->"c:101"],
Cell[1101228, 35387, 174, 6, 34, "Text"],
Cell[1101405, 35395, 1537, 29, 202, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1102979, 35429, 144, 4, 40, "Subsubsection",
  CellTags->"c:102"],
Cell[1103126, 35435, 410, 8, 74, "Text"],
Cell[1103539, 35445, 68, 2, 34, "Caption"],
Cell[1103610, 35449, 58783, 1982, 250, 34430, 1675, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1162396, 37433, 426, 10, 66, "Caption"],
Cell[1162825, 37445, 910, 15, 154, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1163772, 37465, 146, 4, 40, "Subsubsection",
  CellTags->"c:103"],
Cell[1163921, 37471, 74, 2, 34, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1164044, 37479, 141, 4, 48, "Subsection",
  CellTags->"c:104"],
Cell[1164188, 37485, 653, 16, 90, "Text"],

Cell[CellGroupData[{
Cell[1164866, 37505, 128, 4, 40, "Subsubsection",
  CellTags->"c:105"],
Cell[1164997, 37511, 295, 9, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1165329, 37525, 169, 5, 40, "Subsubsection",
  CellTags->"c:106"],
Cell[1165501, 37532, 562, 16, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1166100, 37553, 138, 4, 40, "Subsubsection",
  CellTags->"c:107"],
Cell[1166241, 37559, 240, 6, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1166518, 37570, 122, 4, 40, "Subsubsection",
  CellTags->"c:108"],
Cell[1166643, 37576, 433, 12, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1167113, 37593, 133, 4, 40, "Subsubsection",
  CellTags->"c:109"],
Cell[1167249, 37599, 280, 8, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1167566, 37612, 128, 4, 40, "Subsubsection",
  CellTags->"c:110"],
Cell[1167697, 37618, 300, 7, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1168034, 37630, 126, 4, 40, "Subsubsection",
  CellTags->"c:111"],
Cell[1168163, 37636, 215, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1168415, 37646, 129, 4, 40, "Subsubsection",
  CellTags->"c:112"],
Cell[1168547, 37652, 205, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1168789, 37662, 141, 4, 40, "Subsubsection",
  CellTags->"c:113"],
Cell[1168933, 37668, 516, 14, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1169486, 37687, 130, 4, 40, "Subsubsection",
  CellTags->"c:114"],
Cell[1169619, 37693, 182, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1169838, 37703, 122, 4, 40, "Subsubsection",
  CellTags->"c:115"],
Cell[1169963, 37709, 690, 23, 74, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1170690, 37737, 130, 4, 40, "Subsubsection",
  CellTags->"c:116"],
Cell[1170823, 37743, 245, 8, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1171105, 37756, 132, 4, 40, "Subsubsection",
  CellTags->"c:117"],
Cell[1171240, 37762, 179, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1171456, 37772, 134, 4, 40, "Subsubsection",
  CellTags->"c:118"],
Cell[1171593, 37778, 275, 8, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1171905, 37791, 123, 4, 40, "Subsubsection",
  CellTags->"c:119"],
Cell[1172031, 37797, 111, 2, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1172179, 37804, 123, 4, 40, "Subsubsection",
  CellTags->"c:120"],
Cell[1172305, 37810, 277, 8, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1172619, 37823, 129, 4, 40, "Subsubsection",
  CellTags->"c:121"],
Cell[1172751, 37829, 197, 7, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1172985, 37841, 129, 4, 40, "Subsubsection",
  CellTags->"c:122"],
Cell[1173117, 37847, 197, 7, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1173351, 37859, 131, 4, 40, "Subsubsection",
  CellTags->"c:123"],
Cell[1173485, 37865, 204, 7, 34, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1173726, 37877, 129, 4, 40, "Subsubsection",
  CellTags->"c:124"],
Cell[1173858, 37883, 264, 6, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1174159, 37894, 130, 4, 40, "Subsubsection",
  CellTags->"c:125"],
Cell[1174292, 37900, 361, 9, 58, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1174690, 37914, 137, 4, 40, "Subsubsection",
  CellTags->"c:126"],
Cell[1174830, 37920, 325, 9, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1175192, 37934, 139, 4, 40, "Subsubsection",
  CellTags->"c:127"],
Cell[1175334, 37940, 316, 9, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1175687, 37954, 127, 4, 40, "Subsubsection",
  CellTags->"c:128"],
Cell[1175817, 37960, 204, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1176058, 37970, 124, 4, 40, "Subsubsection",
  CellTags->"c:129"],
Cell[1176185, 37976, 178, 5, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[1176400, 37986, 123, 4, 40, "Subsubsection",
  CellTags->"c:130"],
Cell[1176526, 37992, 219, 5, 42, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[1176794, 38003, 140, 4, 48, "Subsection",
  CellTags->"c:131"],
Cell[1176937, 38009, 909, 16, 138, "Text"],
Cell[1177849, 38027, 479, 17, 58, "Text"],
Cell[1178331, 38046, 316, 7, 58, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

