(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.0'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6406,        200]*)
(*NotebookOutlinePosition[      7773,        247]*)
(*  CellTagsIndexPosition[      7683,        240]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Danksagung", "Section",
  PageWidth->PaperWidth,
  TextAlignment->Center,
  CellTags->"c:1"],

Cell["", "Text",
  PageWidth->PaperWidth],

Cell["\<\
Ich danke der Universit\[ADoubleDot]t Wien, insbesondere dem Institut f\
\[UDoubleDot]r Astronomie f\[UDoubleDot]r meine Ausbildung,  Prof. Dipl. Ing. \
Dr. Johannes Hagel f\[UDoubleDot]r die hilfreichen und anregenden \
Diskussionen und Prof. Dr. Rudolf Dvorak f\[UDoubleDot]r die Bereitstellung \
eines Arbeitsplatzes. Ich danke allen Menschen, die mir geholfen haben, die \
Arbeit durchzusehen, im speziellen den Mitgliedern der ADG - Vienna, Renate \
Zechner, Birgit Priebe, Barbara Funk und Florian Freistetter. Die Arbeit w\
\[ADoubleDot]re nicht das geworden, was sie ist, ohne die \
Unterst\[UDoubleDot]tzung von Renate, meinen Freunden und Eltern. Danke !\
\>", "Text",
  PageWidth->PaperWidth]
}, Open  ]],

Cell[CellGroupData[{

Cell["Anhang I : Sitnikov Derivation System", "Section",
  PageWidth->PaperWidth,
  PageBreakAbove->True,
  TextAlignment->Center,
  TextJustification->1,
  CellTags->"c:2"],

Cell["", "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Auf der beiliegenden CD befindet sich die Dateistruktur ",
  StyleBox["Sitnikov Derivation System",
    FontSlant->"Italic"],
  ". Im Ordner PDO werden die allgemeinen Objekte der \
St\[ODoubleDot]rungstheorie, wie ",
  StyleBox["PerturbativeSeries",
    FontSlant->"Italic"],
  " oder ",
  StyleBox["TransformDependentVar",
    FontSlant->"Italic"],
  " definiert. Der Ordner SDO enth\[ADoubleDot]lt die Funktionen, die in \
Kapitel 5 besprochen und f\[UDoubleDot]r diese Arbeit verwendet worden sind. \
SDR enth\[ADoubleDot]lt Berechnungen bis zur 13. Ordnung. Der Ordner ",
  StyleBox["WorkingFolder",
    FontSlant->"Italic"],
  " wird durch Initialisierung durch die Datei",
  StyleBox[" init",
    FontSlant->"Italic"],
  " als Arbeitsverzeichnis definiert."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Das gesamte System wird durch den Befehl ",
  StyleBox["Get[init] ",
    FontSlant->"Italic"],
  "in den Speicher einer ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " - Sitzung geladen. Zudem werden die Funktionen ",
  StyleBox["GetResults[opts] ",
    FontSlant->"Italic"],
  "und die Systemvariablen ",
  StyleBox["$ObjectsSDO",
    FontSlant->"Italic"],
  ", ",
  StyleBox["$ObjectsdPDO",
    FontSlant->"Italic"],
  ", ",
  StyleBox["$ObjectsSDR",
    FontSlant->"Italic"],
  " definiert. In letzteren sind die Funktionsnamen der Algorithmen \
gespeichert. Die Namen aller Objekte werden in der Systemvariable ",
  StyleBox["$Objects",
    FontSlant->"Italic"],
  "  gehalten."
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Durch Initialisierung werden nur die Definitionen aus den Ordnern PDO und \
SDO in den Speicher geladen. Um die Ergebnisse aus dem Ordner SDR in die \
Sitzung miteinzubinden, kann die Funktion ",
  StyleBox["GetResults[opts] ",
    FontSlant->"Italic"],
  "verwendet werden. F\[UDoubleDot]hrt man die Funktion ohne Argumente aus, \
werden nur die Definitionen aus den Ordnern ",
  StyleBox["Linear Analysis",
    FontSlant->"Italic"],
  " und ",
  StyleBox["Nonlinear Analysis",
    FontSlant->"Italic"],
  "  definiert. Folgende Optionen k\[ODoubleDot]nnen zudem gesetzt werden:"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Linear\[Rule]True|Fal",
    FontSlant->"Italic"],
  "se: Inhalt des Ordners Linear Analysis laden/nicht laden"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Nonlinear\[Rule]True|False",
    FontSlant->"Italic"],
  ": Inhalt des Ordners Nonlinear Analysis laden/nicht laden"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  StyleBox["Special\[Rule]True|False",
    FontSlant->"Italic"],
  ": Inhalt des Ordners Special Analysis laden/nicht laden"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1],

Cell[TextData[{
  "Das Symbol ",
  StyleBox["$Derivation",
    FontSlant->"Italic"],
  " h\[ADoubleDot]lt die zuletzt durchgef\[UDoubleDot]hrte Herleitung, das \
Objekt ",
  StyleBox["$Result",
    FontSlant->"Italic"],
  " das letzte Ergebnis. Das gesamte Package darf frei verwendet und \
weitergegeben werden unter der Voraussetzung, dass die Rechte des urspr\
\[UDoubleDot]nglichen Entwicklers gewahrt bleiben und bei einer  Ver\
\[ADoubleDot]nderung der Implementierungen mit angef\[UDoubleDot]hrt werden. \
"
}], "Text",
  PageWidth->PaperWidth,
  TextJustification->1]
}, Open  ]]
},
FrontEndVersion->"5.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 693}},
Editable->False,
ScreenStyleEnvironment->"EnhancedPrintoutNonGray",
PrintingStyleEnvironment->"EnhancedPrintoutNonGray",
WindowSize->{565, 600},
WindowMargins->{{38, Automatic}, {Automatic, 27}},
PrintingCopies->1,
PrintingStartingPageNumber->127,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{None, Inherited, Cell[ 
        TextData[ {
          ValueBox[ ""]}], "Header"]}, {Cell[ 
        TextData[ {
          ValueBox[ ""]}], "Header"], Inherited, None}},
PageHeaderLines->{False, False},
Magnification->1,
StyleDefinitions -> "ArticleClassic.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "c:1"->{
    Cell[1776, 53, 98, 3, 56, "Section",
      CellTags->"c:1"]},
  "c:2"->{
    Cell[2671, 77, 173, 5, 56, "Section",
      PageBreakAbove->True,
      CellTags->"c:2"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"c:1", 7486, 229},
  {"c:2", 7563, 232}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 98, 3, 56, "Section",
  CellTags->"c:1"],
Cell[1877, 58, 41, 1, 27, "Text"],
Cell[1921, 61, 713, 11, 129, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2671, 77, 173, 5, 56, "Section",
  PageBreakAbove->True,
  CellTags->"c:2"],
Cell[2847, 84, 65, 2, 27, "Text"],
Cell[2915, 88, 844, 22, 112, "Text"],
Cell[3762, 112, 773, 26, 95, "Text"],
Cell[4538, 140, 660, 16, 95, "Text"],
Cell[5201, 158, 199, 6, 27, "Text"],
Cell[5403, 166, 205, 6, 27, "Text"],
Cell[5611, 174, 201, 6, 27, "Text"],
Cell[5815, 182, 575, 15, 78, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

